@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -13,15 +13,11 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-#include <stdbool.h>
-
 #include <isc/base64.h>
 #include <isc/buffer.h>
 #include <isc/event.h>
 #include <isc/file.h>
 #include <isc/mem.h>
-#include <isc/mutex.h>
 #include <isc/net.h>
 #include <isc/netaddr.h>
 #include <isc/random.h>
@@ -68,7 +64,7 @@ typedef ISC_LIST(controllistener_t) controllistenerlist_t;
 
 struct controlkey {
 	char *				keyname;
-	uint32_t			algorithm;
+	isc_uint32_t			algorithm;
 	isc_region_t			secret;
 	ISC_LINK(controlkey_t)		link;
 };
@@ -76,39 +72,38 @@ struct controlkey {
 struct controlconnection {
 	isc_socket_t *			sock;
 	isccc_ccmsg_t			ccmsg;
-	bool				ccmsg_valid;
-	bool				sending;
+	isc_boolean_t			ccmsg_valid;
+	isc_boolean_t			sending;
 	isc_timer_t *			timer;
 	isc_buffer_t *			buffer;
 	controllistener_t *		listener;
-	uint32_t			nonce;
+	isc_uint32_t			nonce;
 	ISC_LINK(controlconnection_t)	link;
 };
 
 struct controllistener {
-	ns_controls_t *			controls;
+	named_controls_t *		controls;
 	isc_mem_t *			mctx;
 	isc_task_t *			task;
 	isc_sockaddr_t			address;
 	isc_socket_t *			sock;
 	dns_acl_t *			acl;
-	bool				listening;
-	bool				exiting;
+	isc_boolean_t			listening;
+	isc_boolean_t			exiting;
 	controlkeylist_t		keys;
 	controlconnectionlist_t		connections;
 	isc_sockettype_t		type;
-	uint32_t			perm;
-	uint32_t			owner;
-	uint32_t			group;
-	bool				readonly;
+	isc_uint32_t			perm;
+	isc_uint32_t			owner;
+	isc_uint32_t			group;
+	isc_boolean_t			readonly;
 	ISC_LINK(controllistener_t)	link;
 };
 
-struct ns_controls {
-	ns_server_t			*server;
+struct named_controls {
+	named_server_t			*server;
 	controllistenerlist_t 		listeners;
-	bool				shuttingdown;
-	isc_mutex_t			symtab_lock;
+	isc_boolean_t			shuttingdown;
 	isccc_symtab_t			*symtab;
 };
 
@@ -183,7 +178,7 @@ maybe_free_connection(controlconnection_t *conn) {
 
 	ISC_LIST_UNLINK(listener->connections, conn, link);
 #ifdef ENABLE_AFL
-	if (ns_g_fuzz_type == ns_fuzz_rndc) {
+	if (named_g_fuzz_type == isc_fuzz_rndc) {
 		named_fuzz_notify();
 	}
 #endif
@@ -202,12 +197,12 @@ shutdown_listener(controllistener_t *listener) {
 
 		isc_sockaddr_format(&listener->address, socktext,
 				    sizeof(socktext));
-		isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-			      NS_LOGMODULE_CONTROL, ISC_LOG_NOTICE,
+		isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+			      NAMED_LOGMODULE_CONTROL, ISC_LOG_NOTICE,
 			      "stopping command channel on %s", socktext);
 		if (listener->type == isc_sockettype_unix)
-			isc_socket_cleanunix(&listener->address, true);
-		listener->exiting = true;
+			isc_socket_cleanunix(&listener->address, ISC_TRUE);
+		listener->exiting = ISC_TRUE;
 	}
 
 	for (conn = ISC_LIST_HEAD(listener->connections);
@@ -225,21 +220,23 @@ shutdown_listener(controllistener_t *listener) {
 	maybe_free_listener(listener);
 }
 
-static bool
+static isc_boolean_t
 address_ok(isc_sockaddr_t *sockaddr, dns_acl_t *acl) {
+	dns_aclenv_t *env =
+		ns_interfacemgr_getaclenv(named_g_server->interfacemgr);
 	isc_netaddr_t netaddr;
 	isc_result_t result;
 	int match;
 
 	isc_netaddr_fromsockaddr(&netaddr, sockaddr);
 
-	result = dns_acl_match(&netaddr, NULL, acl,
-			       &ns_g_server->aclenv, &match, NULL);
+	result = dns_acl_match(&netaddr, NULL, NULL, 0, NULL, acl, env, &match,
+			       NULL);
 
 	if (result != ISC_R_SUCCESS || match <= 0)
-		return (false);
+		return (ISC_FALSE);
 	else
-		return (true);
+		return (ISC_TRUE);
 }
 
 static isc_result_t
@@ -253,7 +250,7 @@ control_accept(controllistener_t *listener) {
 				 "isc_socket_accept() failed: %s",
 				 isc_result_totext(result));
 	else
-		listener->listening = true;
+		listener->listening = ISC_TRUE;
 	return (result);
 }
 
@@ -286,7 +283,7 @@ control_senddone(isc_task_t *task, isc_event_t *event) {
 
 	UNUSED(task);
 
-	conn->sending = false;
+	conn->sending = ISC_FALSE;
 
 	if (sevent->result != ISC_R_SUCCESS &&
 	    sevent->result != ISC_R_CANCELED)
@@ -296,8 +293,8 @@ control_senddone(isc_task_t *task, isc_event_t *event) {
 
 		(void)isc_socket_getpeername(sock, &peeraddr);
 		isc_sockaddr_format(&peeraddr, socktext, sizeof(socktext));
-		isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-			      NS_LOGMODULE_CONTROL, ISC_LOG_WARNING,
+		isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+			      NAMED_LOGMODULE_CONTROL, ISC_LOG_WARNING,
 			      "error sending command response to %s: %s",
 			      socktext, isc_result_totext(sevent->result));
 	}
@@ -319,20 +316,20 @@ log_invalid(isccc_ccmsg_t *ccmsg, isc_result_t result) {
 
 	(void)isc_socket_getpeername(ccmsg->sock, &peeraddr);
 	isc_sockaddr_format(&peeraddr, socktext, sizeof(socktext));
-	isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-		      NS_LOGMODULE_CONTROL, ISC_LOG_ERROR,
+	isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+		      NAMED_LOGMODULE_CONTROL, ISC_LOG_ERROR,
 		      "invalid command from %s: %s",
 		      socktext, isc_result_totext(result));
 }
 
 static void
 control_recvmessage(isc_task_t *task, isc_event_t *event) {
-	controlconnection_t *conn;
-	controllistener_t *listener;
-	controlkey_t *key;
+	controlconnection_t *conn = NULL;
+	controllistener_t *listener = NULL;
+	controlkey_t *key = NULL;
 	isccc_sexpr_t *request = NULL;
 	isccc_sexpr_t *response = NULL;
-	uint32_t algorithm;
+	isc_uint32_t algorithm;
 	isccc_region_t secret;
 	isc_stdtime_t now;
 	isc_buffer_t b;
@@ -340,11 +337,11 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
 	isc_buffer_t *text;
 	isc_result_t result;
 	isc_result_t eresult;
-	isccc_sexpr_t *_ctrl;
+	isccc_sexpr_t *_ctrl = NULL;
 	isccc_time_t sent;
 	isccc_time_t exp;
-	uint32_t nonce;
-	isccc_sexpr_t *data;
+	isc_uint32_t nonce;
+	isccc_sexpr_t *data = NULL;
 
 	REQUIRE(event->ev_type == ISCCC_EVENT_CCMSG);
 
@@ -436,10 +433,8 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
 	/*
 	 * Duplicate suppression (required for UDP).
 	 */
-	LOCK(&listener->controls->symtab_lock);
 	isccc_cc_cleansymtab(listener->controls->symtab, now);
 	result = isccc_cc_checkdup(listener->controls->symtab, request, now);
-	UNLOCK(&listener->controls->symtab_lock);
 	if (result != ISC_R_SUCCESS) {
 		if (result == ISC_R_EXISTS)
 			result = ISCCC_R_DUPLICATE;
@@ -462,11 +457,13 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
 	 * Establish nonce.
 	 */
 	if (conn->nonce == 0) {
-		while (conn->nonce == 0)
-			isc_random_get(&conn->nonce);
+		while (conn->nonce == 0) {
+			isc_random_buf(&conn->nonce, sizeof(conn->nonce));
+		}
 		eresult = ISC_R_SUCCESS;
 	} else
-		eresult = ns_control_docommand(request, listener->readonly, &text);
+		eresult = named_control_docommand(request, listener->readonly,
+						  &text);
 
 	result = isccc_cc_createresponse(request, now, now + 60, &response);
 	if (result != ISC_R_SUCCESS)
@@ -523,7 +520,7 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
 	result = isc_socket_send(conn->sock, &r, task, control_senddone, conn);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup_response;
-	conn->sending = true;
+	conn->sending = ISC_TRUE;
 
 	isc_mem_put(listener->mctx, secret.rstart, REGION_SIZE(secret));
 	isccc_sexpr_free(&request);
@@ -543,7 +540,7 @@ control_recvmessage(isc_task_t *task, isc_event_t *event) {
  cleanup:
 	isc_socket_detach(&conn->sock);
 	isccc_ccmsg_invalidate(&conn->ccmsg);
-	conn->ccmsg_valid = false;
+	conn->ccmsg_valid = ISC_FALSE;
 	maybe_free_connection(conn);
 	maybe_free_listener(listener);
 }
@@ -576,12 +573,12 @@ newconnection(controllistener_t *listener, isc_socket_t *sock) {
 	/* Set a 32 KiB upper limit on incoming message. */
 	isccc_ccmsg_setmaxsize(&conn->ccmsg, 32768);
 
-	conn->ccmsg_valid = true;
-	conn->sending = false;
+	conn->ccmsg_valid = ISC_TRUE;
+	conn->sending = ISC_FALSE;
 	conn->buffer = NULL;
 	conn->timer = NULL;
 	isc_interval_set(&interval, 60, 0);
-	result = isc_timer_create(ns_g_timermgr, isc_timertype_once,
+	result = isc_timer_create(named_g_timermgr, isc_timertype_once,
 				  NULL, &interval, listener->task,
 				  control_timeout, conn, &conn->timer);
 	if (result != ISC_R_SUCCESS)
@@ -607,7 +604,7 @@ newconnection(controllistener_t *listener, isc_socket_t *sock) {
 		isc_timer_detach(&conn->timer);
 	isc_mem_put(listener->mctx, conn, sizeof(*conn));
 #ifdef ENABLE_AFL
-	if (ns_g_fuzz_type == ns_fuzz_rndc) {
+	if (named_g_fuzz_type == isc_fuzz_rndc) {
 		named_fuzz_notify();
 	}
 #endif
@@ -624,7 +621,7 @@ control_newconn(isc_task_t *task, isc_event_t *event) {
 
 	UNUSED(task);
 
-	listener->listening = false;
+	listener->listening = ISC_FALSE;
 
 	if (nevent->result != ISC_R_SUCCESS) {
 		if (nevent->result == ISC_R_CANCELED) {
@@ -641,8 +638,8 @@ control_newconn(isc_task_t *task, isc_event_t *event) {
 	    !address_ok(&peeraddr, listener->acl)) {
 		char socktext[ISC_SOCKADDR_FORMATSIZE];
 		isc_sockaddr_format(&peeraddr, socktext, sizeof(socktext));
-		isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-			      NS_LOGMODULE_CONTROL, ISC_LOG_WARNING,
+		isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+			      NAMED_LOGMODULE_CONTROL, ISC_LOG_WARNING,
 			      "rejected command channel message from %s",
 			      socktext);
 		isc_socket_detach(&sock);
@@ -653,8 +650,8 @@ control_newconn(isc_task_t *task, isc_event_t *event) {
 	if (result != ISC_R_SUCCESS) {
 		char socktext[ISC_SOCKADDR_FORMATSIZE];
 		isc_sockaddr_format(&peeraddr, socktext, sizeof(socktext));
-		isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-			      NS_LOGMODULE_CONTROL, ISC_LOG_WARNING,
+		isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+			      NAMED_LOGMODULE_CONTROL, ISC_LOG_WARNING,
 			      "dropped command channel from %s: %s",
 			      socktext, isc_result_totext(result));
 		isc_socket_detach(&sock);
@@ -668,7 +665,7 @@ control_newconn(isc_task_t *task, isc_event_t *event) {
 }
 
 static void
-controls_shutdown(ns_controls_t *controls) {
+controls_shutdown(named_controls_t *controls) {
 	controllistener_t *listener;
 	controllistener_t *next;
 
@@ -686,9 +683,9 @@ controls_shutdown(ns_controls_t *controls) {
 }
 
 void
-ns_controls_shutdown(ns_controls_t *controls) {
+named_controls_shutdown(named_controls_t *controls) {
 	controls_shutdown(controls);
-	controls->shuttingdown = true;
+	controls->shuttingdown = ISC_TRUE;
 }
 
 static isc_result_t
@@ -772,7 +769,7 @@ register_keys(const cfg_obj_t *control, const cfg_obj_t *keylist,
 
 		result = cfgkeylist_find(keylist, keyid->keyname, &keydef);
 		if (result != ISC_R_SUCCESS) {
-			cfg_obj_log(control, ns_g_lctx, ISC_LOG_WARNING,
+			cfg_obj_log(control, named_g_lctx, ISC_LOG_WARNING,
 				    "couldn't find key '%s' for use with "
 				    "command channel %s",
 				    keyid->keyname, socktext);
@@ -792,10 +789,10 @@ register_keys(const cfg_obj_t *control, const cfg_obj_t *keylist,
 			algstr = cfg_obj_asstring(algobj);
 			secretstr = cfg_obj_asstring(secretobj);
 
-			if (ns_config_getkeyalgorithm2(algstr, NULL,
-					&algtype, NULL) != ISC_R_SUCCESS)
+			if (named_config_getkeyalgorithm2(algstr, NULL,
+					  &algtype, NULL) != ISC_R_SUCCESS)
 			{
-				cfg_obj_log(control, ns_g_lctx,
+				cfg_obj_log(control, named_g_lctx,
 					    ISC_LOG_WARNING,
 					    "unsupported algorithm '%s' in "
 					    "key '%s' for use with command "
@@ -811,7 +808,8 @@ register_keys(const cfg_obj_t *control, const cfg_obj_t *keylist,
 			result = isc_base64_decodestring(secretstr, &b);
 
 			if (result != ISC_R_SUCCESS) {
-				cfg_obj_log(keydef, ns_g_lctx, ISC_LOG_WARNING,
+				cfg_obj_log(keydef, named_g_lctx,
+					    ISC_LOG_WARNING,
 					    "secret for key '%s' on "
 					    "command channel %s: %s",
 					    keyid->keyname, socktext,
@@ -825,7 +823,8 @@ register_keys(const cfg_obj_t *control, const cfg_obj_t *keylist,
 			keyid->secret.base = isc_mem_get(mctx,
 							 keyid->secret.length);
 			if (keyid->secret.base == NULL) {
-				cfg_obj_log(keydef, ns_g_lctx, ISC_LOG_WARNING,
+				cfg_obj_log(keydef, named_g_lctx,
+					    ISC_LOG_WARNING,
 					   "couldn't register key '%s': "
 					   "out of memory", keyid->keyname);
 				ISC_LIST_UNLINK(*keyids, keyid, link);
@@ -860,15 +859,15 @@ get_rndckey(isc_mem_t *mctx, controlkeylist_t *keyids) {
 	unsigned int algtype;
 	isc_buffer_t b;
 
-	isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-		      NS_LOGMODULE_CONTROL, ISC_LOG_INFO,
+	isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+		      NAMED_LOGMODULE_CONTROL, ISC_LOG_INFO,
 		      "configuring command channel from '%s'",
-		      ns_g_keyfile);
-	if (! isc_file_exists(ns_g_keyfile))
+		      named_g_keyfile);
+	if (! isc_file_exists(named_g_keyfile))
 		return (ISC_R_FILENOTFOUND);
 
-	CHECK(cfg_parser_create(mctx, ns_g_lctx, &pctx));
-	CHECK(cfg_parse_file(pctx, ns_g_keyfile, &cfg_type_rndckey, &config));
+	CHECK(cfg_parser_create(mctx, named_g_lctx, &pctx));
+	CHECK(cfg_parse_file(pctx, named_g_keyfile, &cfg_type_rndckey, &config));
 	CHECK(cfg_map_get(config, "key", &key));
 
 	keyid = isc_mem_get(mctx, sizeof(*keyid));
@@ -883,7 +882,7 @@ get_rndckey(isc_mem_t *mctx, controlkeylist_t *keyids) {
 	if (keyid->keyname == NULL)
 		CHECK(ISC_R_NOMEMORY);
 
-	CHECK(bind9_check_key(key, ns_g_lctx));
+	CHECK(bind9_check_key(key, named_g_lctx));
 
 	(void)cfg_map_get(key, "algorithm", &algobj);
 	(void)cfg_map_get(key, "secret", &secretobj);
@@ -892,9 +891,9 @@ get_rndckey(isc_mem_t *mctx, controlkeylist_t *keyids) {
 	algstr = cfg_obj_asstring(algobj);
 	secretstr = cfg_obj_asstring(secretobj);
 
-	if (ns_config_getkeyalgorithm2(algstr, NULL,
-				       &algtype, NULL) != ISC_R_SUCCESS) {
-		cfg_obj_log(key, ns_g_lctx,
+	if (named_config_getkeyalgorithm2(algstr, NULL,
+					  &algtype, NULL) != ISC_R_SUCCESS) {
+		cfg_obj_log(key, named_g_lctx,
 			    ISC_LOG_WARNING,
 			    "unsupported algorithm '%s' in "
 			    "key '%s' for use with command "
@@ -908,7 +907,7 @@ get_rndckey(isc_mem_t *mctx, controlkeylist_t *keyids) {
 	result = isc_base64_decodestring(secretstr, &b);
 
 	if (result != ISC_R_SUCCESS) {
-		cfg_obj_log(key, ns_g_lctx, ISC_LOG_WARNING,
+		cfg_obj_log(key, named_g_lctx, ISC_LOG_WARNING,
 			    "secret for key '%s' on command channel: %s",
 			    keyid->keyname, isc_result_totext(result));
 		goto cleanup;
@@ -918,7 +917,7 @@ get_rndckey(isc_mem_t *mctx, controlkeylist_t *keyids) {
 	keyid->secret.base = isc_mem_get(mctx,
 					 keyid->secret.length);
 	if (keyid->secret.base == NULL) {
-		cfg_obj_log(key, ns_g_lctx, ISC_LOG_WARNING,
+		cfg_obj_log(key, named_g_lctx, ISC_LOG_WARNING,
 			   "couldn't register key '%s': "
 			   "out of memory", keyid->keyname);
 		CHECK(ISC_R_NOMEMORY);
@@ -969,7 +968,7 @@ get_key_info(const cfg_obj_t *config, const cfg_obj_t *control,
 }
 
 static void
-update_listener(ns_controls_t *cp, controllistener_t **listenerp,
+update_listener(named_controls_t *cp, controllistener_t **listenerp,
 		const cfg_obj_t *control, const cfg_obj_t *config,
 		isc_sockaddr_t *addr, cfg_aclconfctx_t *aclconfctx,
 		const char *socktext, isc_sockettype_t type)
@@ -1042,13 +1041,13 @@ update_listener(ns_controls_t *cp, controllistener_t **listenerp,
 		 * sake of avoiding this message would be too much trouble.
 		 */
 		if (control != NULL)
-			cfg_obj_log(control, ns_g_lctx, ISC_LOG_WARNING,
+			cfg_obj_log(control, named_g_lctx, ISC_LOG_WARNING,
 				    "couldn't install new keys for "
 				    "command channel %s: %s",
 				    socktext, isc_result_totext(result));
 		else
-			isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-				      NS_LOGMODULE_CONTROL, ISC_LOG_WARNING,
+			isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+				      NAMED_LOGMODULE_CONTROL, ISC_LOG_WARNING,
 				      "couldn't install new keys for "
 				      "command channel %s: %s",
 				      socktext, isc_result_totext(result));
@@ -1059,7 +1058,7 @@ update_listener(ns_controls_t *cp, controllistener_t **listenerp,
 	 */
 	if (control != NULL && type == isc_sockettype_tcp) {
 		allow = cfg_tuple_get(control, "allow");
-		result = cfg_acl_fromconfig(allow, config, ns_g_lctx,
+		result = cfg_acl_fromconfig(allow, config, named_g_lctx,
 					    aclconfctx, listener->mctx, 0,
 					    &new_acl);
 	} else {
@@ -1080,19 +1079,19 @@ update_listener(ns_controls_t *cp, controllistener_t **listenerp,
 		dns_acl_detach(&new_acl);
 		/* XXXDCL say the old acl is still used? */
 	} else if (control != NULL)
-		cfg_obj_log(control, ns_g_lctx, ISC_LOG_WARNING,
+		cfg_obj_log(control, named_g_lctx, ISC_LOG_WARNING,
 			    "couldn't install new acl for "
 			    "command channel %s: %s",
 			    socktext, isc_result_totext(result));
 	else
-		isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-			      NS_LOGMODULE_CONTROL, ISC_LOG_WARNING,
+		isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+			      NAMED_LOGMODULE_CONTROL, ISC_LOG_WARNING,
 			      "couldn't install new acl for "
 			      "command channel %s: %s",
 			      socktext, isc_result_totext(result));
 
 	if (result == ISC_R_SUCCESS && type == isc_sockettype_unix) {
-		uint32_t perm, owner, group;
+		isc_uint32_t perm, owner, group;
 		perm  = cfg_obj_asuint32(cfg_tuple_get(control, "perm"));
 		owner = cfg_obj_asuint32(cfg_tuple_get(control, "owner"));
 		group = cfg_obj_asuint32(cfg_tuple_get(control, "group"));
@@ -1106,7 +1105,7 @@ update_listener(ns_controls_t *cp, controllistener_t **listenerp,
 			listener->owner = owner;
 			listener->group = group;
 		} else if (control != NULL)
-			cfg_obj_log(control, ns_g_lctx, ISC_LOG_WARNING,
+			cfg_obj_log(control, named_g_lctx, ISC_LOG_WARNING,
 				    "couldn't update ownership/permission for "
 				    "command channel %s", socktext);
 	}
@@ -1115,7 +1114,7 @@ update_listener(ns_controls_t *cp, controllistener_t **listenerp,
 }
 
 static void
-add_listener(ns_controls_t *cp, controllistener_t **listenerp,
+add_listener(named_controls_t *cp, controllistener_t **listenerp,
 	     const cfg_obj_t *control, const cfg_obj_t *config,
 	     isc_sockaddr_t *addr, cfg_aclconfctx_t *aclconfctx,
 	     const char *socktext, isc_sockettype_t type)
@@ -1139,14 +1138,14 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 		listener->task = cp->server->task;
 		listener->address = *addr;
 		listener->sock = NULL;
-		listener->listening = false;
-		listener->exiting = false;
+		listener->listening = ISC_FALSE;
+		listener->exiting = ISC_FALSE;
 		listener->acl = NULL;
 		listener->type = type;
 		listener->perm = 0;
 		listener->owner = 0;
 		listener->group = 0;
-		listener->readonly = false;
+		listener->readonly = ISC_FALSE;
 		ISC_LINK_INIT(listener, link);
 		ISC_LIST_INIT(listener->keys);
 		ISC_LIST_INIT(listener->connections);
@@ -1156,7 +1155,7 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 		 */
 		if (control != NULL && type == isc_sockettype_tcp) {
 			allow = cfg_tuple_get(control, "allow");
-			result = cfg_acl_fromconfig(allow, config, ns_g_lctx,
+			result = cfg_acl_fromconfig(allow, config, named_g_lctx,
 						    aclconfctx, mctx, 0,
 						    &new_acl);
 		} else {
@@ -1192,7 +1191,7 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 			result = get_rndckey(mctx, &listener->keys);
 
 		if (result != ISC_R_SUCCESS && control != NULL)
-			cfg_obj_log(control, ns_g_lctx, ISC_LOG_WARNING,
+			cfg_obj_log(control, named_g_lctx, ISC_LOG_WARNING,
 				    "couldn't install keys for "
 				    "command channel %s: %s",
 				    socktext, isc_result_totext(result));
@@ -1209,10 +1208,10 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 	}
 
 	if (result == ISC_R_SUCCESS && type == isc_sockettype_unix)
-		isc_socket_cleanunix(&listener->address, false);
+		isc_socket_cleanunix(&listener->address, ISC_FALSE);
 
 	if (result == ISC_R_SUCCESS)
-		result = isc_socket_create(ns_g_socketmgr,
+		result = isc_socket_create(named_g_socketmgr,
 					   isc_sockaddr_pf(&listener->address),
 					   type, &listener->sock);
 	if (result == ISC_R_SUCCESS)
@@ -1220,7 +1219,7 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 
 #ifndef ISC_ALLOW_MAPPED
 	if (result == ISC_R_SUCCESS)
-		isc_socket_ipv6only(listener->sock, true);
+		isc_socket_ipv6only(listener->sock, ISC_TRUE);
 #endif
 
 	if (result == ISC_R_SUCCESS)
@@ -1244,24 +1243,24 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 		result = control_accept(listener);
 
 	if (result == ISC_R_SUCCESS) {
-		isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-			      NS_LOGMODULE_CONTROL, ISC_LOG_NOTICE,
+		isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+			      NAMED_LOGMODULE_CONTROL, ISC_LOG_NOTICE,
 			      "command channel listening on %s", socktext);
 		*listenerp = listener;
 
 	} else {
 		if (listener != NULL) {
-			listener->exiting = true;
+			listener->exiting = ISC_TRUE;
 			free_listener(listener);
 		}
 
 		if (control != NULL)
-			cfg_obj_log(control, ns_g_lctx, ISC_LOG_WARNING,
+			cfg_obj_log(control, named_g_lctx, ISC_LOG_WARNING,
 				    "couldn't add command channel %s: %s",
 				    socktext, isc_result_totext(result));
 		else
-			isc_log_write(ns_g_lctx, NS_LOGCATEGORY_GENERAL,
-				      NS_LOGMODULE_CONTROL, ISC_LOG_NOTICE,
+			isc_log_write(named_g_lctx, NAMED_LOGCATEGORY_GENERAL,
+				      NAMED_LOGMODULE_CONTROL, ISC_LOG_NOTICE,
 				      "couldn't add command channel %s: %s",
 				      socktext, isc_result_totext(result));
 
@@ -1272,8 +1271,8 @@ add_listener(ns_controls_t *cp, controllistener_t **listenerp,
 }
 
 isc_result_t
-ns_controls_configure(ns_controls_t *cp, const cfg_obj_t *config,
-		      cfg_aclconfctx_t *aclconfctx)
+named_controls_configure(named_controls_t *cp, const cfg_obj_t *config,
+			 cfg_aclconfctx_t *aclconfctx)
 {
 	controllistener_t *listener;
 	controllistenerlist_t new_listeners;
@@ -1326,14 +1325,14 @@ ns_controls_configure(ns_controls_t *cp, const cfg_obj_t *config,
 				addr = *cfg_obj_assockaddr(obj);
 				if (isc_sockaddr_getport(&addr) == 0)
 					isc_sockaddr_setport(&addr,
-							     NS_CONTROL_PORT);
+						     NAMED_CONTROL_PORT);
 
 				isc_sockaddr_format(&addr, socktext,
 						    sizeof(socktext));
 
-				isc_log_write(ns_g_lctx,
-					      NS_LOGCATEGORY_GENERAL,
-					      NS_LOGMODULE_CONTROL,
+				isc_log_write(named_g_lctx,
+					      NAMED_LOGCATEGORY_GENERAL,
+					      NAMED_LOGMODULE_CONTROL,
 					      ISC_LOG_DEBUG(9),
 					      "processing control channel %s",
 					      socktext);
@@ -1393,9 +1392,9 @@ ns_controls_configure(ns_controls_t *cp, const cfg_obj_t *config,
 				result = isc_sockaddr_frompath(&addr,
 						      cfg_obj_asstring(path));
 				if (result != ISC_R_SUCCESS) {
-					isc_log_write(ns_g_lctx,
-					      NS_LOGCATEGORY_GENERAL,
-					      NS_LOGMODULE_CONTROL,
+					isc_log_write(named_g_lctx,
+					      NAMED_LOGCATEGORY_GENERAL,
+					      NAMED_LOGMODULE_CONTROL,
 					      ISC_LOG_DEBUG(9),
 					      "control channel '%s': %s",
 					      cfg_obj_asstring(path),
@@ -1403,9 +1402,9 @@ ns_controls_configure(ns_controls_t *cp, const cfg_obj_t *config,
 					continue;
 				}
 
-				isc_log_write(ns_g_lctx,
-					      NS_LOGCATEGORY_GENERAL,
-					      NS_LOGMODULE_CONTROL,
+				isc_log_write(named_g_lctx,
+					      NAMED_LOGCATEGORY_GENERAL,
+					      NAMED_LOGMODULE_CONTROL,
 					      ISC_LOG_DEBUG(9),
 					      "processing control channel '%s'",
 					      cfg_obj_asstring(path));
@@ -1455,7 +1454,7 @@ ns_controls_configure(ns_controls_t *cp, const cfg_obj_t *config,
 				isc_sockaddr_fromin6(&addr,
 						     &in6addr_loopback, 0);
 			}
-			isc_sockaddr_setport(&addr, NS_CONTROL_PORT);
+			isc_sockaddr_setport(&addr, NAMED_CONTROL_PORT);
 
 			isc_sockaddr_format(&addr, socktext, sizeof(socktext));
 
@@ -1485,7 +1484,7 @@ ns_controls_configure(ns_controls_t *cp, const cfg_obj_t *config,
 	}
 
 	/*
-	 * ns_control_shutdown() will stop whatever is on the global
+	 * named_control_shutdown() will stop whatever is on the global
 	 * listeners list, which currently only has whatever sockaddrs
 	 * were in the previous configuration (if any) that do not
 	 * remain in the current configuration.
@@ -1502,33 +1501,19 @@ ns_controls_configure(ns_controls_t *cp, const cfg_obj_t *config,
 }
 
 isc_result_t
-ns_controls_create(ns_server_t *server, ns_controls_t **ctrlsp) {
+named_controls_create(named_server_t *server, named_controls_t **ctrlsp) {
 	isc_mem_t *mctx = server->mctx;
 	isc_result_t result;
-	ns_controls_t *controls = isc_mem_get(mctx, sizeof(*controls));
+	named_controls_t *controls = isc_mem_get(mctx, sizeof(*controls));
 
-	if (controls == NULL) {
+	if (controls == NULL)
 		return (ISC_R_NOMEMORY);
-	}
-
-	*controls = (ns_controls_t){
-		.server = server,
-	};
-
+	controls->server = server;
 	ISC_LIST_INIT(controls->listeners);
-
-	result = isc_mutex_init(&controls->symtab_lock);
-	if (result != ISC_R_SUCCESS) {
-		isc_mem_put(server->mctx, controls, sizeof(*controls));
-		return (result);
-	}
-
-	LOCK(&controls->symtab_lock);
+	controls->shuttingdown = ISC_FALSE;
+	controls->symtab = NULL;
 	result = isccc_cc_createsymtab(&controls->symtab);
-	UNLOCK(&controls->symtab_lock);
-
 	if (result != ISC_R_SUCCESS) {
-		isc_mutex_destroy(&controls->symtab_lock);
 		isc_mem_put(server->mctx, controls, sizeof(*controls));
 		return (result);
 	}
@@ -1537,15 +1522,12 @@ ns_controls_create(ns_server_t *server, ns_controls_t **ctrlsp) {
 }
 
 void
-ns_controls_destroy(ns_controls_t **ctrlsp) {
-	ns_controls_t *controls = *ctrlsp;
+named_controls_destroy(named_controls_t **ctrlsp) {
+	named_controls_t *controls = *ctrlsp;
 
 	REQUIRE(ISC_LIST_EMPTY(controls->listeners));
 
-	LOCK(&controls->symtab_lock);
 	isccc_symtab_destroy(&controls->symtab);
-	UNLOCK(&controls->symtab_lock);
-	isc_mutex_destroy(&controls->symtab_lock);
 	isc_mem_put(controls->server->mctx, controls, sizeof(*controls));
 	*ctrlsp = NULL;
 }
