@@ -13,7 +13,6 @@
 
 #include <config.h>
 #include <stdarg.h>
-#include <stdbool.h>
 
 #include <sys/types.h>	/* dev_t FreeBSD 2.1 */
 #include <sys/stat.h>
@@ -108,13 +107,13 @@ static pid_t mainpid = 0;
 #endif
 
 static struct passwd *runas_pw = NULL;
-static bool done_setuid = false;
+static isc_boolean_t done_setuid = ISC_FALSE;
 static int dfd[2] = { -1, -1 };
 
 #ifdef HAVE_LINUX_CAPABILITY_H
 
-static bool non_root = false;
-static bool non_root_caps = false;
+static isc_boolean_t non_root = ISC_FALSE;
+static isc_boolean_t non_root_caps = ISC_FALSE;
 
 #ifdef HAVE_SYS_CAPABILITY_H
 #include <sys/capability.h>
@@ -232,47 +231,18 @@ linux_setcaps(cap_t caps) {
 		cap_free(curcaps); \
 	} while (0)
 #else
-#define SET_CAP(flag) \
-	do { \
-		if (curcaps & (1 << (flag))) { \
-			caps |= (1 << (flag)); \
-		} \
-	} while (0)
+#define SET_CAP(flag) do { caps |= (1 << (flag)); } while (0)
 #define INIT_CAP do { caps = 0; } while (0)
 #endif /* HAVE_LIBCAP */
 
-#ifndef HAVE_LIBCAP
-/*%
- * Store the bitmask representing the permitted capability set in 'capsp'.  To
- * match libcap-enabled behavior, capget() syscall errors are not reported,
- * they just cause 'capsp' to be set to 0, which effectively prevents any
- * capability from being subsequently requested.
- */
-static void
-linux_getpermittedcaps(cap_t *capsp) {
-	struct __user_cap_header_struct caphead;
-	struct __user_cap_data_struct curcaps;
-
-	memset(&caphead, 0, sizeof(caphead));
-	caphead.version = _LINUX_CAPABILITY_VERSION;
-	caphead.pid = 0;
-	memset(&curcaps, 0, sizeof(curcaps));
-	syscall(SYS_capget, &caphead, &curcaps);
-
-	*capsp = curcaps.permitted;
-}
-#endif /* HAVE_LIBCAP */
-
 static void
 linux_initialprivs(void) {
-	cap_t curcaps;
 	cap_t caps;
 #ifdef HAVE_LIBCAP
+	cap_t curcaps;
 	cap_value_t capval;
 	char strbuf[ISC_STRERRORSIZE];
 	int err;
-#else
-	linux_getpermittedcaps(&curcaps);
 #endif
 
 	/*%
@@ -337,14 +307,12 @@ linux_initialprivs(void) {
 
 static void
 linux_minprivs(void) {
-	cap_t curcaps;
 	cap_t caps;
 #ifdef HAVE_LIBCAP
+	cap_t curcaps;
 	cap_value_t capval;
 	char strbuf[ISC_STRERRORSIZE];
 	int err;
-#else
-	linux_getpermittedcaps(&curcaps);
 #endif
 
 	INIT_CAP;
@@ -389,9 +357,9 @@ linux_keepcaps(void) {
 			named_main_earlyfatal("prctl() failed: %s", strbuf);
 		}
 	} else {
-		non_root_caps = true;
+		non_root_caps = ISC_TRUE;
 		if (getuid() != 0)
-			non_root = true;
+			non_root = ISC_TRUE;
 	}
 }
 #endif
@@ -528,16 +496,16 @@ named_os_closedevnull(void) {
 	}
 }
 
-static bool
+static isc_boolean_t
 all_digits(const char *s) {
 	if (*s == '\0')
-		return (false);
+		return (ISC_FALSE);
 	while (*s != '\0') {
 		if (!isdigit((*s)&0xff))
-			return (false);
+			return (ISC_FALSE);
 		s++;
 	}
-	return (true);
+	return (ISC_TRUE);
 }
 
 void
@@ -596,7 +564,7 @@ named_os_changeuser(void) {
 	if (runas_pw == NULL || done_setuid)
 		return;
 
-	done_setuid = true;
+	done_setuid = ISC_TRUE;
 
 #ifdef HAVE_LINUXTHREADS
 #ifdef HAVE_LINUX_CAPABILITY_H
@@ -678,7 +646,7 @@ named_os_minprivs(void) {
 }
 
 static int
-safe_open(const char *filename, mode_t mode, bool append) {
+safe_open(const char *filename, mode_t mode, isc_boolean_t append) {
 	int fd;
 	struct stat sb;
 
@@ -835,7 +803,7 @@ setperms(uid_t uid, gid_t gid) {
 }
 
 FILE *
-named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
+named_os_openfile(const char *filename, mode_t mode, isc_boolean_t switch_user) {
 	char strbuf[ISC_STRERRORSIZE], *f;
 	FILE *fp;
 	int fd;
@@ -863,7 +831,7 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 		/* Set UID/GID to the one we'll be running with eventually */
 		setperms(runas_pw->pw_uid, runas_pw->pw_gid);
 
-		fd = safe_open(filename, mode, false);
+		fd = safe_open(filename, mode, ISC_FALSE);
 
 #ifndef HAVE_LINUXTHREADS
 		/* Restore UID/GID to root */
@@ -872,7 +840,7 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 
 		if (fd == -1) {
 #ifndef HAVE_LINUXTHREADS
-			fd = safe_open(filename, mode, false);
+			fd = safe_open(filename, mode, ISC_FALSE);
 			if (fd != -1) {
 				named_main_earlywarning("Required root "
 							"permissions to open "
@@ -893,7 +861,7 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 #endif /* HAVE_LINUXTHREADS */
 		}
 	} else {
-		fd = safe_open(filename, mode, false);
+		fd = safe_open(filename, mode, ISC_FALSE);
 	}
 
 	if (fd < 0) {
@@ -914,7 +882,7 @@ named_os_openfile(const char *filename, mode_t mode, bool switch_user) {
 }
 
 void
-named_os_writepidfile(const char *filename, bool first_time) {
+named_os_writepidfile(const char *filename, isc_boolean_t first_time) {
 	FILE *fh;
 	pid_t pid;
 	char strbuf[ISC_STRERRORSIZE];
@@ -964,16 +932,16 @@ named_os_writepidfile(const char *filename, bool first_time) {
 	(void)fclose(fh);
 }
 
-bool
+isc_boolean_t
 named_os_issingleton(const char *filename) {
 	char strbuf[ISC_STRERRORSIZE];
 	struct flock lock;
 
 	if (singletonfd != -1)
-		return (true);
+		return (ISC_TRUE);
 
 	if (strcasecmp(filename, "none") == 0)
-		return (true);
+		return (ISC_TRUE);
 
 	/*
 	 * Make the containing directory if it doesn't exist.
@@ -989,7 +957,7 @@ named_os_issingleton(const char *filename) {
 			named_main_earlywarning("couldn't create '%s'",
 						filename);
 			cleanup_lockfile();
-			return (false);
+			return (ISC_FALSE);
 		}
 	}
 
@@ -1001,7 +969,7 @@ named_os_issingleton(const char *filename) {
 			   S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH);
 	if (singletonfd == -1) {
 		cleanup_lockfile();
-		return (false);
+		return (ISC_FALSE);
 	}
 
 	memset(&lock, 0, sizeof(lock));
@@ -1014,10 +982,10 @@ named_os_issingleton(const char *filename) {
 	if (fcntl(singletonfd, F_SETLK, &lock) == -1) {
 		close(singletonfd);
 		singletonfd = -1;
-		return (false);
+		return (ISC_FALSE);
 	}
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 void
@@ -1035,36 +1003,24 @@ named_os_gethostname(char *buf, size_t len) {
 	return ((n == 0) ? ISC_R_SUCCESS : ISC_R_FAILURE);
 }
 
-static char *
-next_token(char **stringp, const char *delim) {
-	char *res;
-
-	do {
-		res = strsep(stringp, delim);
-		if (res == NULL)
-			break;
-	} while (*res == '\0');
-	return (res);
-}
-
 void
 named_os_shutdownmsg(char *command, isc_buffer_t *text) {
-	char *input, *ptr;
+	char *last, *ptr;
 	pid_t pid;
 
-	input = command;
 
 	/* Skip the command name. */
-	ptr = next_token(&input, " \t");
-	if (ptr == NULL)
+	if ((ptr = strtok_r(command, " \t", &last)) == NULL) {
 		return;
+	}
 
-	ptr = next_token(&input, " \t");
-	if (ptr == NULL)
+	if ((ptr = strtok_r(NULL, " \t", &last)) == NULL) {
 		return;
+	}
 
-	if (strcmp(ptr, "-p") != 0)
+	if (strcmp(ptr, "-p") != 0) {
 		return;
+	}
 
 #ifdef HAVE_LINUXTHREADS
 	pid = mainpid;
