@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -11,7 +11,6 @@
 
 #include <config.h>
 #include <stdarg.h>
-#include <stdbool.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -51,18 +50,16 @@ static char *version_error =
 	"named requires Windows 2000 Service Pack 2 or later to run correctly";
 
 void
-ns_paths_init(void) {
+named_paths_init(void) {
 	if (!Initialized)
 		isc_ntpaths_init();
 
-	lwresd_g_conffile = isc_ntpaths_get(LWRES_CONF_PATH);
-	lwresd_g_resolvconffile = isc_ntpaths_get(RESOLV_CONF_PATH);
-	ns_g_conffile = isc_ntpaths_get(NAMED_CONF_PATH);
-	ns_g_defaultpidfile = isc_ntpaths_get(NAMED_PID_PATH);
-	lwresd_g_defaultpidfile = isc_ntpaths_get(LWRESD_PID_PATH);
-	ns_g_defaultlockfile = isc_ntpaths_get(NAMED_LOCK_PATH);
-	ns_g_keyfile = isc_ntpaths_get(RNDC_KEY_PATH);
-	ns_g_defaultsessionkeyfile = isc_ntpaths_get(SESSION_KEY_PATH);
+	named_g_conffile = isc_ntpaths_get(NAMED_CONF_PATH);
+	named_g_defaultpidfile = isc_ntpaths_get(NAMED_PID_PATH);
+	named_g_defaultlockfile = isc_ntpaths_get(NAMED_LOCK_PATH);
+	named_g_keyfile = isc_ntpaths_get(RNDC_KEY_PATH);
+	named_g_defaultsessionkeyfile = isc_ntpaths_get(SESSION_KEY_PATH);
+	named_g_defaultdnstap = NULL;
 
 	Initialized = TRUE;
 }
@@ -98,12 +95,12 @@ setup_syslog(const char *progname) {
 }
 
 void
-ns_os_init(const char *progname) {
-	ns_paths_init();
+named_os_init(const char *progname) {
+	named_paths_init();
 	setup_syslog(progname);
 	/*
 	 * XXXMPA. We may need to split ntservice_init() in two and
-	 * just mark as running in ns_os_started().  If we do that
+	 * just mark as running in named_os_started().  If we do that
 	 * this is where the first part of ntservice_init() should be
 	 * called from.
 	 *
@@ -112,20 +109,10 @@ ns_os_init(const char *progname) {
 	 * ntservice_init();
 	 */
 	version_check(progname);
-	/*
-	 * If running in a Cygwin environment, clear the SEM_NOGPFAULTERRORBOX
-	 * bit in the process error mode to prevent Cygwin from concealing
-	 * non-abort() crashes, giving Windows Error Reporting a chance to
-	 * handle such crashes.  This is done to ensure all crashes triggered
-	 * by system tests can be detected.
-	 */
-	if (getenv("CYGWIN") != NULL) {
-		SetErrorMode(SetErrorMode(0) & ~SEM_NOGPFAULTERRORBOX);
-	}
 }
 
 void
-ns_os_daemonize(void) {
+named_os_daemonize(void) {
 	/*
 	 * Try to set stdin, stdout, and stderr to /dev/null, but press
 	 * on even if it fails.
@@ -147,12 +134,12 @@ ns_os_daemonize(void) {
 }
 
 void
-ns_os_opendevnull(void) {
+named_os_opendevnull(void) {
 	devnullfd = open("NUL", O_RDWR, 0);
 }
 
 void
-ns_os_closedevnull(void) {
+named_os_closedevnull(void) {
 	if (devnullfd != _fileno(stdin) &&
 	    devnullfd != _fileno(stdout) &&
 	    devnullfd != _fileno(stderr)) {
@@ -162,17 +149,17 @@ ns_os_closedevnull(void) {
 }
 
 void
-ns_os_chroot(const char *root) {
+named_os_chroot(const char *root) {
 	if (root != NULL)
-		ns_main_earlyfatal("chroot(): isn't supported by Win32 API");
+		named_main_earlyfatal("chroot(): isn't supported by Win32 API");
 }
 
 void
-ns_os_inituserinfo(const char *username) {
+named_os_inituserinfo(const char *username) {
 }
 
 void
-ns_os_changeuser(void) {
+named_os_changeuser(void) {
 }
 
 unsigned int
@@ -181,15 +168,15 @@ ns_os_uid(void) {
 }
 
 void
-ns_os_adjustnofile(void) {
+named_os_adjustnofile(void) {
 }
 
 void
-ns_os_minprivs(void) {
+named_os_minprivs(void) {
 }
 
 static int
-safe_open(const char *filename, int mode, bool append) {
+safe_open(const char *filename, int mode, isc_boolean_t append) {
 	int fd;
 	struct stat sb;
 
@@ -227,32 +214,33 @@ cleanup_lockfile(void) {
 	if (lockfile != NULL) {
 		int n = unlink(lockfile);
 		if (n == -1 && errno != ENOENT)
-			ns_main_earlywarning("unlink '%s': failed", lockfile);
+			named_main_earlywarning("unlink '%s': failed",
+						lockfile);
 		free(lockfile);
 		lockfile = NULL;
 	}
 }
 
 FILE *
-ns_os_openfile(const char *filename, int mode, bool switch_user) {
+named_os_openfile(const char *filename, int mode, isc_boolean_t switch_user) {
 	char strbuf[ISC_STRERRORSIZE];
 	FILE *fp;
 	int fd;
 
 	UNUSED(switch_user);
-	fd = safe_open(filename, mode, false);
+	fd = safe_open(filename, mode, ISC_FALSE);
 	if (fd < 0) {
 		isc__strerror(errno, strbuf, sizeof(strbuf));
-		ns_main_earlywarning("could not open file '%s': %s",
-				     filename, strbuf);
+		named_main_earlywarning("could not open file '%s': %s",
+					filename, strbuf);
 		return (NULL);
 	}
 
 	fp = fdopen(fd, "w");
 	if (fp == NULL) {
 		isc__strerror(errno, strbuf, sizeof(strbuf));
-		ns_main_earlywarning("could not fdopen() file '%s': %s",
-				     filename, strbuf);
+		named_main_earlywarning("could not fdopen() file '%s': %s",
+					filename, strbuf);
 		close(fd);
 	}
 
@@ -260,7 +248,7 @@ ns_os_openfile(const char *filename, int mode, bool switch_user) {
 }
 
 void
-ns_os_writepidfile(const char *filename, bool first_time) {
+named_os_writepidfile(const char *filename, isc_boolean_t first_time) {
 	FILE *pidlockfile;
 	pid_t pid;
 	char strbuf[ISC_STRERRORSIZE];
@@ -270,7 +258,7 @@ ns_os_writepidfile(const char *filename, bool first_time) {
 	 * The caller must ensure any required synchronization.
 	 */
 
-	report = first_time ? ns_main_earlyfatal : ns_main_earlywarning;
+	report = first_time ? named_main_earlyfatal : named_main_earlywarning;
 
 	cleanup_pidfile();
 
@@ -284,8 +272,9 @@ ns_os_writepidfile(const char *filename, bool first_time) {
 		return;
 	}
 
-	pidlockfile = ns_os_openfile(filename, S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH,
-				     false);
+	pidlockfile = named_os_openfile(filename,
+					S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH,
+					ISC_FALSE);
 	if (pidlockfile == NULL) {
 		free(pidfile);
 		pidfile = NULL;
@@ -309,33 +298,33 @@ ns_os_writepidfile(const char *filename, bool first_time) {
 	(void)fclose(pidlockfile);
 }
 
-bool
-ns_os_issingleton(const char *filename) {
+isc_boolean_t
+named_os_issingleton(const char *filename) {
 	char strbuf[ISC_STRERRORSIZE];
 	OVERLAPPED o;
 
 	if (lockfilefd != -1)
-		return (true);
+		return (ISC_TRUE);
 
 	if (strcasecmp(filename, "none") == 0)
-		return (true);
+		return (ISC_TRUE);
 
 	lockfile = strdup(filename);
 	if (lockfile == NULL) {
 		isc__strerror(errno, strbuf, sizeof(strbuf));
-		ns_main_earlyfatal("couldn't allocate memory for '%s': %s",
-				   filename, strbuf);
+		named_main_earlyfatal("couldn't allocate memory for '%s': %s",
+				      filename, strbuf);
 	}
 
 	/*
-	 * ns_os_openfile() uses safeopen() which removes any existing
+	 * named_os_openfile() uses safeopen() which removes any existing
 	 * files. We can't use that here.
 	 */
 	lockfilefd = open(filename, O_WRONLY | O_CREAT,
 			  S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH);
 	if (lockfilefd == -1) {
 		cleanup_lockfile();
-		return (false);
+		return (ISC_FALSE);
 	}
 
 	memset(&o, 0, sizeof(o));
@@ -344,29 +333,29 @@ ns_os_issingleton(const char *filename) {
 			LOCKFILE_EXCLUSIVE_LOCK | LOCKFILE_FAIL_IMMEDIATELY,
 			0, 0, 1, &o)) {
 		cleanup_lockfile();
-		return (false);
+		return (ISC_FALSE);
 	}
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 
 void
-ns_os_shutdown(void) {
+named_os_shutdown(void) {
 	closelog();
 	cleanup_pidfile();
 
 	if (lockfilefd != -1) {
 		(void) UnlockFile((HANDLE) _get_osfhandle(lockfilefd),
 				  0, 0, 0, 1);
+		close(lockfilefd);
+		lockfilefd = -1;
 	}
-	cleanup_lockfile();
-
 	ntservice_shutdown();	/* This MUST be the last thing done */
 }
 
 isc_result_t
-ns_os_gethostname(char *buf, size_t len) {
+named_os_gethostname(char *buf, size_t len) {
 	int n;
 
 	n = gethostname(buf, (int)len);
@@ -374,25 +363,25 @@ ns_os_gethostname(char *buf, size_t len) {
 }
 
 void
-ns_os_shutdownmsg(char *command, isc_buffer_t *text) {
+named_os_shutdownmsg(char *command, isc_buffer_t *text) {
 	UNUSED(command);
 	UNUSED(text);
 }
 
 void
-ns_os_tzset(void) {
+named_os_tzset(void) {
 #ifdef HAVE_TZSET
 	tzset();
 #endif
 }
 
 void
-ns_os_started(void) {
+named_os_started(void) {
 	ntservice_init();
 }
 
 static char unamebuf[BUFSIZ];
-static const char *unamep = NULL;
+static char *unamep = NULL;
 
 static void
 getuname(void) {
@@ -461,10 +450,9 @@ getuname(void) {
  * GetVersionEx() returns 6.2 (aka Windows 8.1) since it was obsoleted
  * so we had to switch to the recommended way to get the Windows version.
  */
-const char *
-ns_os_uname(void) {
-	if (unamep == NULL) {
+char *
+named_os_uname(void) {
+	if (unamep == NULL)
 		getuname();
-	}
 	return (unamep);
 }
