@@ -13,8 +13,6 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/app.h>
@@ -55,7 +53,7 @@
 #define SERVERADDRS 10
 
 const char *progname;
-bool verbose;
+isc_boolean_t verbose;
 
 static const char *admin_conffile;
 static const char *admin_keyfile;
@@ -63,26 +61,26 @@ static const char *version = VERSION;
 static const char *servername = NULL;
 static isc_sockaddr_t serveraddrs[SERVERADDRS];
 static isc_sockaddr_t local4, local6;
-static bool local4set = false, local6set = false;
+static isc_boolean_t local4set = ISC_FALSE, local6set = ISC_FALSE;
 static int nserveraddrs;
 static int currentaddr = 0;
 static unsigned int remoteport = 0;
 static isc_socketmgr_t *socketmgr = NULL;
 static isc_buffer_t *databuf;
 static isccc_ccmsg_t ccmsg;
-static uint32_t algorithm;
+static isc_uint32_t algorithm;
 static isccc_region_t secret;
-static bool failed = false;
-static bool c_flag = false;
+static isc_boolean_t failed = ISC_FALSE;
+static isc_boolean_t c_flag = ISC_FALSE;
 static isc_mem_t *rndc_mctx;
 static int sends, recvs, connects;
 static char *command;
 static char *args;
 static char program[256];
 static isc_socket_t *sock = NULL;
-static uint32_t serial;
-static bool quiet = false;
-static bool showresult = false;
+static isc_uint32_t serial;
+static isc_boolean_t quiet = ISC_FALSE;
+static isc_boolean_t showresult = ISC_FALSE;
 
 static void rndc_startconnect(isc_sockaddr_t *addr, isc_task_t *task);
 
@@ -218,7 +216,7 @@ Version: %s\n",
 
 static void
 preparse_args(int argc, char **argv) {
-	bool ipv4only = false, ipv6only = false;
+	isc_boolean_t ipv4only = ISC_FALSE, ipv6only = ISC_FALSE;
 	int ch;
 
 	while ((ch = isc_commandline_parse(argc, argv, CMDLINE_FLAGS)) != -1) {
@@ -227,20 +225,20 @@ preparse_args(int argc, char **argv) {
 			if (ipv6only) {
 				fatal("only one of -4 and -6 allowed");
 			}
-			ipv4only = true;
+			ipv4only = ISC_TRUE;
 			break;
 		case '6':
 			if (ipv4only) {
 				fatal("only one of -4 and -6 allowed");
 			}
-			ipv6only = true;
+			ipv6only = ISC_TRUE;
 			break;
 		default:
 			break;
 		}
 	}
 
-	isc_commandline_reset = true;
+	isc_commandline_reset = ISC_TRUE;
 	isc_commandline_index = 1;
 }
 
@@ -318,7 +316,7 @@ rndc_recvdone(isc_task_t *task, isc_event_t *event) {
 		fatal("bad or missing data section in response");
 	result = isccc_cc_lookupstring(data, "err", &errormsg);
 	if (result == ISC_R_SUCCESS) {
-		failed = true;
+		failed = ISC_TRUE;
 		fprintf(stderr, "%s: '%s' failed: %s\n",
 			progname, command, errormsg);
 	}
@@ -359,7 +357,7 @@ rndc_recvnonce(isc_task_t *task, isc_event_t *event) {
 	isccc_sexpr_t *_ctrl;
 	isccc_region_t source;
 	isc_result_t result;
-	uint32_t nonce;
+	isc_uint32_t nonce;
 	isccc_sexpr_t *request = NULL;
 	isccc_time_t now;
 	isc_region_t r;
@@ -567,7 +565,7 @@ parse_config(isc_mem_t *mctx, isc_log_t *log, const char *keyname,
 	const char *algorithmstr;
 	static char secretarray[1024];
 	const cfg_type_t *conftype = &cfg_type_rndcconf;
-	bool key_only = false;
+	isc_boolean_t key_only = ISC_FALSE;
 	const cfg_listelt_t *element;
 
 	if (! isc_file_exists(conffile)) {
@@ -580,7 +578,7 @@ parse_config(isc_mem_t *mctx, isc_log_t *log, const char *keyname,
 		if (! isc_file_exists(conffile))
 			fatal("neither %s nor %s was found",
 			      admin_conffile, admin_keyfile);
-		key_only = true;
+		key_only = ISC_TRUE;
 	} else if (! c_flag && isc_file_exists(admin_keyfile)) {
 		fprintf(stderr, "WARNING: key file (%s) exists, but using "
 			"default configuration file (%s)\n",
@@ -734,7 +732,7 @@ parse_config(isc_mem_t *mctx, isc_log_t *log, const char *keyname,
 				obj = cfg_tuple_get(address, "port");
 				if (cfg_obj_isuint32(obj)) {
 					myport = cfg_obj_asuint32(obj);
-					if (myport > UINT16_MAX ||
+					if (myport > ISC_UINT16_MAX ||
 					    myport == 0)
 						fatal("port %u out of range",
 						      myport);
@@ -769,7 +767,7 @@ parse_config(isc_mem_t *mctx, isc_log_t *log, const char *keyname,
 		cfg_map_get(server, "source-address", &address);
 		if (address != NULL) {
 			local4 = *cfg_obj_assockaddr(address);
-			local4set = true;
+			local4set = ISC_TRUE;
 		}
 	}
 	if (!local4set && options != NULL) {
@@ -777,7 +775,7 @@ parse_config(isc_mem_t *mctx, isc_log_t *log, const char *keyname,
 		cfg_map_get(options, "default-source-address", &address);
 		if (address != NULL) {
 			local4 = *cfg_obj_assockaddr(address);
-			local4set = true;
+			local4set = ISC_TRUE;
 		}
 	}
 
@@ -786,7 +784,7 @@ parse_config(isc_mem_t *mctx, isc_log_t *log, const char *keyname,
 		cfg_map_get(server, "source-address-v6", &address);
 		if (address != NULL) {
 			local6 = *cfg_obj_assockaddr(address);
-			local6set = true;
+			local6set = ISC_TRUE;
 		}
 	}
 	if (!local6set && options != NULL) {
@@ -794,7 +792,7 @@ parse_config(isc_mem_t *mctx, isc_log_t *log, const char *keyname,
 		cfg_map_get(options, "default-source-address-v6", &address);
 		if (address != NULL) {
 			local6 = *cfg_obj_assockaddr(address);
-			local6set = true;
+			local6set = ISC_TRUE;
 		}
 	}
 
@@ -804,7 +802,7 @@ parse_config(isc_mem_t *mctx, isc_log_t *log, const char *keyname,
 int
 main(int argc, char **argv) {
 	isc_result_t result = ISC_R_SUCCESS;
-	bool show_final_mem = false;
+	isc_boolean_t show_final_mem = ISC_FALSE;
 	isc_taskmgr_t *taskmgr = NULL;
 	isc_task_t *task = NULL;
 	isc_log_t *log = NULL;
@@ -835,7 +833,7 @@ main(int argc, char **argv) {
 	if (result != ISC_R_SUCCESS)
 		fatal("isc_app_start() failed: %s", isc_result_totext(result));
 
-	isc_commandline_errprint = false;
+	isc_commandline_errprint = ISC_FALSE;
 
 	preparse_args(argc, argv);
 
@@ -857,17 +855,17 @@ main(int argc, char **argv) {
 			if (inet_pton(AF_INET, isc_commandline_argument,
 				      &in) == 1) {
 				isc_sockaddr_fromin(&local4, &in, 0);
-				local4set = true;
+				local4set = ISC_TRUE;
 			} else if (inet_pton(AF_INET6, isc_commandline_argument,
 					     &in6) == 1) {
 				isc_sockaddr_fromin6(&local6, &in6, 0);
-				local6set = true;
+				local6set = ISC_TRUE;
 			}
 			break;
 
 		case 'c':
 			admin_conffile = isc_commandline_argument;
-			c_flag = true;
+			c_flag = ISC_TRUE;
 			break;
 
 		case 'k':
@@ -879,7 +877,7 @@ main(int argc, char **argv) {
 			break;
 
 		case 'm':
-			show_final_mem = true;
+			show_final_mem = ISC_TRUE;
 			break;
 
 		case 'p':
@@ -890,11 +888,11 @@ main(int argc, char **argv) {
 			break;
 
 		case 'q':
-			quiet = true;
+			quiet = ISC_TRUE;
 			break;
 
 		case 'r':
-			showresult = true;
+			showresult = ISC_TRUE;
 			break;
 
 		case 's':
@@ -902,7 +900,7 @@ main(int argc, char **argv) {
 			break;
 
 		case 'V':
-			verbose = true;
+			verbose = ISC_TRUE;
 			break;
 
 		case 'y':
@@ -932,7 +930,7 @@ main(int argc, char **argv) {
 	if (argc < 1)
 		usage(1);
 
-	isc_random_get(&serial);
+	serial = isc_random();
 
 	DO("create memory context", isc_mem_create(0, 0, &rndc_mctx));
 	DO("create socket manager", isc_socketmgr_create(rndc_mctx, &socketmgr));
