@@ -33,6 +33,7 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+
 /* random [-m module] [-s $slot] [-n count] */
 
 /*! \file */
@@ -139,8 +140,8 @@ main(int argc, char *argv[]) {
 	if (lib_name != NULL)
 		pk11_set_lib_name(lib_name);
 
-	result = pk11_get_session(&pctx, op_type, false, false,
-				  false, NULL, slot);
+	result = pk11_get_session(&pctx, op_type, ISC_FALSE, ISC_FALSE,
+				  ISC_FALSE, NULL, slot);
 	if ((result != ISC_R_SUCCESS) &&
 	    (result != PK11_R_NODIGESTSERVICE) &&
 	    (result != PK11_R_NOAESSERVICE)) {
