@@ -16,9 +16,7 @@
 
 #include <config.h>
 
-#include <stdbool.h>
 #include <stdio.h>
-#include <inttypes.h>
 #include <stdlib.h>
 #include <stdarg.h>
 
@@ -33,14 +31,6 @@
 
 #include "driver.h"
 
-#ifdef WIN32
-#define STRTOK_R(a, b, c)	strtok_s(a, b, c)
-#elif defined(_REENTRANT)
-#define STRTOK_R(a, b, c)       strtok_r(a, b, c)
-#else
-#define STRTOK_R(a, b, c)       strtok(a, b)
-#endif
-
 #define CHECK(x) \
 	do { \
 		result = (x); \
@@ -48,13 +38,6 @@
 			goto failure; \
 	} while (0)
 
-#define loginfo(...) \
-	({ if ((state != NULL) && (state->log != NULL)) \
-		 state->log(ISC_LOG_INFO, __VA_ARGS__); })
-#define logerr(...) \
-	({ if ((state != NULL) && (state->log != NULL)) \
-		 state->log(ISC_LOG_ERROR, __VA_ARGS__); })
-
 /* For this simple example, use fixed sized strings */
 struct record {
 	char name[100];
@@ -75,7 +58,7 @@ struct dlz_example_data {
 	struct record adds[MAX_RECORDS];
 	struct record deletes[MAX_RECORDS];
 
-	bool transaction_started;
+	isc_boolean_t transaction_started;
 
 	/* Helper functions from the dlz_dlopen driver */
 	log_t *log;
@@ -84,17 +67,17 @@ struct dlz_example_data {
 	dns_dlz_writeablezone_t *writeable_zone;
 };
 
-static bool
+static isc_boolean_t
 single_valued(const char *type) {
 	const char *single[] = { "soa", "cname", NULL };
 	int i;
 
 	for (i = 0; single[i]; i++) {
 		if (strcasecmp(single[i], type) == 0) {
-			return (true);
+			return (ISC_TRUE);
 		}
 	}
-	return (false);
+	return (ISC_FALSE);
 }
 
 /*
@@ -105,7 +88,7 @@ add_name(struct dlz_example_data *state, struct record *list,
 	 const char *name, const char *type, dns_ttl_t ttl, const char *data)
 {
 	int i;
-	bool single = single_valued(type);
+	isc_boolean_t single = single_valued(type);
 	int first_empty = -1;
 
 	for (i = 0; i < MAX_RECORDS; i++) {
@@ -124,7 +107,9 @@ add_name(struct dlz_example_data *state, struct record *list,
 		i = first_empty;
 	}
 	if (i == MAX_RECORDS) {
-		logerr("dlz_example: out of record space");
+		if (state->log != NULL)
+			state->log(ISC_LOG_ERROR,
+				   "dlz_example: out of record space");
 		return (ISC_R_FAILURE);
 	}
 
@@ -133,11 +118,14 @@ add_name(struct dlz_example_data *state, struct record *list,
 	    strlen(data) >= sizeof(list[i].data))
 		return (ISC_R_NOSPACE);
 
-	strlcpy(list[i].name, name, sizeof(list[i].name));
+	strncpy(list[i].name, name, sizeof(list[i].name));
+	list[i].name[sizeof(list[i].name) - 1] = '\0';
 
-	strlcpy(list[i].type, type, sizeof(list[i].type));
+	strncpy(list[i].type, type, sizeof(list[i].type));
+	list[i].type[sizeof(list[i].type) - 1] = '\0';
 
-	strlcpy(list[i].data, data, sizeof(list[i].data));
+	strncpy(list[i].data, data, sizeof(list[i].data));
+	list[i].data[sizeof(list[i].data) - 1] = '\0';
 
 	list[i].ttl = ttl;
 
@@ -175,7 +163,7 @@ static isc_result_t
 fmt_address(isc_sockaddr_t *addr, char *buffer, size_t size) {
 	char addr_buf[100];
 	const char *ret;
-	uint16_t port = 0;
+	isc_uint16_t port = 0;
 
 	switch (addr->type.sa.sa_family) {
 	case AF_INET:
@@ -254,7 +242,9 @@ dlz_create(const char *dlzname, unsigned int argc, char *argv[],
 	va_end(ap);
 
 	if (argc < 2 || argv[1][0] == '\0') {
-		logerr("dlz_example: please specify a zone name");
+		if (state->log != NULL)
+			state->log(ISC_LOG_ERROR,
+				   "dlz_example: please specify a zone name");
 		dlz_destroy(state);
 		return (ISC_R_FAILURE);
 	}
@@ -290,7 +280,9 @@ dlz_create(const char *dlzname, unsigned int argc, char *argv[],
 	add_name(state, &state->current[0], state->zone_name,
 		 "a", 1800, "10.53.0.1");
 
-	loginfo("dlz_example: started for zone %s", state->zone_name);
+	if (state->log != NULL)
+		state->log(ISC_LOG_INFO, "dlz_example: started for zone %s",
+			   state->zone_name);
 
 	*dbdata = state;
 	return (ISC_R_SUCCESS);
@@ -308,7 +300,10 @@ void
 dlz_destroy(void *dbdata) {
 	struct dlz_example_data *state = (struct dlz_example_data *)dbdata;
 
-	loginfo("dlz_example: shutting down zone %s", state->zone_name);
+	if (state->log != NULL)
+		state->log(ISC_LOG_INFO,
+			   "dlz_example: shutting down zone %s",
+			   state->zone_name);
 	free(state->zone_name);
 	free(state);
 }
@@ -336,8 +331,10 @@ dlz_findzonedb(void *dbdata, const char *name,
 		fmt_address(src, addrbuf, sizeof(addrbuf));
 	}
 
-	loginfo("dlz_example: dlz_findzonedb called with name '%s' "
-		"in zone DB '%s' from %s", name, state->zone_name, addrbuf);
+	state->log(ISC_LOG_INFO,
+		   "dlz_example: dlz_findzonedb called with name '%s' "
+		   "in zone DB '%s' from %s",
+		   name, state->zone_name, addrbuf);
 
 	/*
 	 * Returning ISC_R_NOTFOUND will cause the query logic to
@@ -395,7 +392,7 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
 {
 	isc_result_t result;
 	struct dlz_example_data *state = (struct dlz_example_data *)dbdata;
-	bool found = false;
+	isc_boolean_t found = ISC_FALSE;
 	void *dbversion = NULL;
 	isc_sockaddr_t *src;
 	char full_name[256];
@@ -437,7 +434,7 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
 		count = 1;
 		memcpy(last, full_name, size + 1);
 	}
-	loginfo("lookup #%d for %s", count, full_name);
+	state->log(ISC_LOG_INFO, "lookup #%d for %s", count, full_name);
 
 	/*
 	 * If we need to know the database version (as set in
@@ -457,9 +454,10 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
 	if (clientinfo != NULL &&
 	    clientinfo->version >= DNS_CLIENTINFO_VERSION) {
 		dbversion = clientinfo->dbversion;
-		if (dbversion != NULL && *(bool *)dbversion) {
-			loginfo("dlz_example: lookup against live transaction");
-		}
+		if (dbversion != NULL && *(isc_boolean_t *)dbversion)
+			state->log(ISC_LOG_INFO,
+				   "dlz_example: lookup against live "
+				   "transaction");
 	}
 
 	if (strcmp(name, "source-addr") == 0) {
@@ -474,9 +472,10 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
 			fmt_address(src, buf, sizeof(buf));
 		}
 
-		loginfo("dlz_example: lookup connection from %s", buf);
+		state->log(ISC_LOG_INFO,
+			   "dlz_example: lookup connection from %s", buf);
 
-		found = true;
+		found = ISC_TRUE;
 		result = state->putrr(lookup, "TXT", 0, buf);
 		if (result != ISC_R_SUCCESS)
 			return (result);
@@ -488,7 +487,7 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
 		for (i = 0; i < 511; i++)
 			buf[i] = 'x';
 		buf[i] = '\0';
-		found = true;
+		found = ISC_TRUE;
 		result = state->putrr(lookup, "TXT", 0, buf);
 		if (result != ISC_R_SUCCESS)
 			return (result);
@@ -497,7 +496,7 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
 	/* Tests for DLZ redirection zones */
 	if (strcmp(name, "*") == 0 && strcmp(zone, ".") == 0) {
 		result = state->putrr(lookup, "A", 0, "100.100.100.2");
-		found = true;
+		found = ISC_TRUE;
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
@@ -506,7 +505,7 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
 	    strcmp(zone, ".") == 0)
 	{
 		result = state->putrr(lookup, "A", 0, "100.100.100.3");
-		found = true;
+		found = ISC_TRUE;
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
@@ -514,7 +513,7 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
 	/* Answer from current records */
 	for (i = 0; i < MAX_RECORDS; i++) {
 		if (strcasecmp(state->current[i].name, full_name) == 0) {
-			found = true;
+			found = ISC_TRUE;
 			result = state->putrr(lookup, state->current[i].type,
 					      state->current[i].ttl,
 					      state->current[i].data);
@@ -535,30 +534,10 @@ dlz_lookup(const char *zone, const char *name, void *dbdata,
  */
 isc_result_t
 dlz_allowzonexfr(void *dbdata, const char *name, const char *client) {
-	struct dlz_example_data *state = (struct dlz_example_data *)dbdata;
-	isc_result_t result;
+	UNUSED(client);
 
-	loginfo("dlz_example: dlz_allowzonexfr called for %s", name);
-
-	result = dlz_findzonedb(dbdata, name, NULL, NULL);
-	if (result != ISC_R_SUCCESS) {
-		loginfo("dlz_example: findzonedb returned %s",
-			isc_result_totext(result));
-		return (result);
-	}
-
-	/*
-	 * Exception for 10.53.0.5 so we can test that allow-transfer
-	 * is effective.
-	 */
-	if (strcmp(client, "10.53.0.5") == 0) {
-		loginfo("dlz_example: disallow transfer to 10.53.0.5");
-		return (ISC_R_NOPERM);
-	}
-
-	loginfo("dlz_example: transfer allowed for %s", name);
-
-	return (ISC_R_SUCCESS);
+	/* Just say yes for all our zones */
+	return (dlz_findzonedb(dbdata, name, NULL, NULL));
 }
 
 /*
@@ -599,12 +578,14 @@ dlz_newversion(const char *zone, void *dbdata, void **versionp) {
 	struct dlz_example_data *state = (struct dlz_example_data *)dbdata;
 
 	if (state->transaction_started) {
-		loginfo("dlz_example: transaction already started for zone %s",
-			zone);
+		if (state->log != NULL)
+			state->log(ISC_LOG_INFO,
+				   "dlz_example: transaction already "
+				   "started for zone %s", zone);
 		return (ISC_R_FAILURE);
 	}
 
-	state->transaction_started = true;
+	state->transaction_started = ISC_TRUE;
 	*versionp = (void *) &state->transaction_started;
 
 	return (ISC_R_SUCCESS);
@@ -614,25 +595,28 @@ dlz_newversion(const char *zone, void *dbdata, void **versionp) {
  * End a transaction
  */
 void
-dlz_closeversion(const char *zone, bool commit,
+dlz_closeversion(const char *zone, isc_boolean_t commit,
 		 void *dbdata, void **versionp)
 {
 	struct dlz_example_data *state = (struct dlz_example_data *)dbdata;
 
 	if (!state->transaction_started) {
-		loginfo("dlz_example: transaction not started for zone %s",
-			zone);
+		if (state->log != NULL)
+			state->log(ISC_LOG_INFO, "dlz_example: transaction not "
+				   "started for zone %s", zone);
 		*versionp = NULL;
 		return;
 	}
 
-	state->transaction_started = false;
+	state->transaction_started = ISC_FALSE;
 
 	*versionp = NULL;
 
 	if (commit) {
 		int i;
-		loginfo("dlz_example: committing transaction on zone %s", zone);
+		if (state->log != NULL)
+			state->log(ISC_LOG_INFO, "dlz_example: committing "
+				   "transaction on zone %s", zone);
 		for (i = 0; i < MAX_RECORDS; i++) {
 			if (strlen(state->deletes[i].name) > 0U) {
 				(void)del_name(state, &state->current[0],
@@ -652,7 +636,9 @@ dlz_closeversion(const char *zone, bool commit,
 			}
 		}
 	} else {
-		loginfo("dlz_example: cancelling transaction on zone %s", zone);
+		if (state->log != NULL)
+			state->log(ISC_LOG_INFO, "dlz_example: cancelling "
+				   "transaction on zone %s", zone);
 	}
 	memset(state->adds, 0, sizeof(state->adds));
 	memset(state->deletes, 0, sizeof(state->deletes));
@@ -667,30 +653,36 @@ dlz_configure(dns_view_t *view, dns_dlzdb_t *dlzdb, void *dbdata) {
 	struct dlz_example_data *state = (struct dlz_example_data *)dbdata;
 	isc_result_t result;
 
-	loginfo("dlz_example: starting configure");
+	if (state->log != NULL)
+		state->log(ISC_LOG_INFO, "dlz_example: starting configure");
 
 	if (state->writeable_zone == NULL) {
-		loginfo("dlz_example: no writeable_zone method available");
+		if (state->log != NULL)
+			state->log(ISC_LOG_INFO, "dlz_example: no "
+				   "writeable_zone method available");
 		return (ISC_R_FAILURE);
 	}
 
 	result = state->writeable_zone(view, dlzdb, state->zone_name);
 	if (result != ISC_R_SUCCESS) {
-		loginfo("dlz_example: failed to configure zone %s",
-			state->zone_name);
+		if (state->log != NULL)
+			state->log(ISC_LOG_ERROR, "dlz_example: failed to "
+				   "configure zone %s", state->zone_name);
 		return (result);
 	}
 
-	loginfo("dlz_example: configured writeable zone %s", state->zone_name);
+	if (state->log != NULL)
+		state->log(ISC_LOG_INFO, "dlz_example: configured writeable "
+			   "zone %s", state->zone_name);
 	return (ISC_R_SUCCESS);
 }
 
 /*
  * Authorize a zone update
  */
-bool
+isc_boolean_t
 dlz_ssumatch(const char *signer, const char *name, const char *tcpaddr,
-	     const char *type, const char *key, uint32_t keydatalen,
+	     const char *type, const char *key, isc_uint32_t keydatalen,
 	     unsigned char *keydata, void *dbdata)
 {
 	struct dlz_example_data *state = (struct dlz_example_data *)dbdata;
@@ -702,12 +694,15 @@ dlz_ssumatch(const char *signer, const char *name, const char *tcpaddr,
 	UNUSED(keydata);
 
 	if (strncmp(name, "deny.", 5) == 0) {
-		loginfo("dlz_example: denying update of name=%s by %s",
-			name, signer);
-		return (false);
+		if (state->log != NULL)
+			state->log(ISC_LOG_INFO, "dlz_example: denying update "
+				   "of name=%s by %s", name, signer);
+		return (ISC_FALSE);
 	}
-	loginfo("dlz_example: allowing update of name=%s by %s", name, signer);
-	return (true);
+	if (state->log != NULL)
+		state->log(ISC_LOG_INFO, "dlz_example: allowing update of "
+			   "name=%s by %s", name, signer);
+	return (ISC_TRUE);
 }
 
 
@@ -718,9 +713,7 @@ modrdataset(struct dlz_example_data *state, const char *name,
 	char *full_name, *dclass, *type, *data, *ttlstr, *buf;
 	char absolute[1024];
 	isc_result_t result;
-#if defined(WIN32) || defined(_REENTRANT)
 	char *saveptr = NULL;
-#endif
 
 	buf = strdup(rdatastr);
 	if (buf == NULL)
@@ -734,23 +727,23 @@ modrdataset(struct dlz_example_data *state, const char *name,
 	 * for the type used by dig
 	 */
 
-	full_name = STRTOK_R(buf, "\t", &saveptr);
+	full_name = strtok_r(buf, "\t", &saveptr);
 	if (full_name == NULL)
 		goto error;
 
-	ttlstr = STRTOK_R(NULL, "\t", &saveptr);
+	ttlstr = strtok_r(NULL, "\t", &saveptr);
 	if (ttlstr == NULL)
 		goto error;
 
-	dclass = STRTOK_R(NULL, "\t", &saveptr);
+	dclass = strtok_r(NULL, "\t", &saveptr);
 	if (dclass == NULL)
 		goto error;
 
-	type = STRTOK_R(NULL, "\t", &saveptr);
+	type = strtok_r(NULL, "\t", &saveptr);
 	if (type == NULL)
 		goto error;
 
-	data = STRTOK_R(NULL, "\t", &saveptr);
+	data = strtok_r(NULL, "\t", &saveptr);
 	if (data == NULL)
 		goto error;
 
@@ -779,7 +772,9 @@ dlz_addrdataset(const char *name, const char *rdatastr,
 	if (version != (void *) &state->transaction_started)
 		return (ISC_R_FAILURE);
 
-	loginfo("dlz_example: adding rdataset %s '%s'", name, rdatastr);
+	if (state->log != NULL)
+		state->log(ISC_LOG_INFO, "dlz_example: adding rdataset %s '%s'",
+			   name, rdatastr);
 
 	return (modrdataset(state, name, rdatastr, &state->adds[0]));
 }
@@ -793,7 +788,9 @@ dlz_subrdataset(const char *name, const char *rdatastr,
 	if (version != (void *) &state->transaction_started)
 		return (ISC_R_FAILURE);
 
-	loginfo("dlz_example: subtracting rdataset %s '%s'", name, rdatastr);
+	if (state->log != NULL)
+		state->log(ISC_LOG_INFO, "dlz_example: subtracting rdataset "
+			   "%s '%s'", name, rdatastr);
 
 	return (modrdataset(state, name, rdatastr, &state->deletes[0]));
 }
@@ -807,7 +804,9 @@ dlz_delrdataset(const char *name, const char *type,
 	if (version != (void *) &state->transaction_started)
 		return (ISC_R_FAILURE);
 
-	loginfo("dlz_example: deleting rdataset %s of type %s", name, type);
+	if (state->log != NULL)
+		state->log(ISC_LOG_INFO, "dlz_example: deleting rdataset %s "
+			   "of type %s", name, type);
 
 	return (ISC_R_SUCCESS);
 }
