@@ -33,13 +33,15 @@ t=0
 
 DEBUG=
 SAVE_RESULTS=
+DNSRPS_TEST_MODE=       # "" to test with and then without DNSRPS
 ARGS=
 
-USAGE="$0: [-xS]"
-while getopts "xS:" c; do
+USAGE="$0: [-xS] [-D {1,2}]"
+while getopts "xSD:" c; do
     case $c in
 	x) set -x; DEBUG=-x; ARGS="$ARGS -x";;
 	S) SAVE_RESULTS=-S; ARGS="$ARGS -S";;
+	D) DNSRPS_TEST_MODE="$OPTARG";;  # with or without DNSRPZ
 	*) echo "$USAGE" 1>&2; exit 1;;
     esac
 done
@@ -128,7 +130,7 @@ get_sn_fast () {
 # $1=domain  $2=DNS server IP address
 FZONES=`sed -n -e 's/^zone "\(.*\)".*\(10.53.0..\).*/Z=\1;M=\2/p' dnsrpzd.conf`
 dnsrps_loaded() {
-    test "$mode" = dnsrps || return
+    test "$DNSRPS_TEST_MODE" = dnsrps || return
     n=0
     for V in $FZONES; do
 	eval "$V"
@@ -155,7 +157,7 @@ dnsrps_loaded() {
 ck_soa() {
     n=0
     while true; do
-	if test "$mode" = dnsrps; then
+	if test "$DNSRPS_TEST_MODE" = dnsrps; then
 	    get_sn_fast "$2"
 	    test "$RSN" -eq "$1" && return
 	else
@@ -206,7 +208,7 @@ restart () {
 	    cp -f ns$1/base.db $NM
 	done
     fi
-    $PERL $SYSTEMTESTTOP/start.pl --noclean --restart --port ${PORT} rpz ns$1
+    $PERL $SYSTEMTESTTOP/start.pl --noclean --restart --port ${PORT} . ns$1
     load_db
     dnsrps_loaded
 }
@@ -226,11 +228,6 @@ ckalive () {
     return 1
 }
 
-resetstats () {
-        NSDIR=$1
-        eval "${NSDIR}_CNT=''"
-}
-
 ckstats () {
     HOST=$1
     LABEL="$2"
@@ -358,7 +355,7 @@ addr () {
     digcmd $2 >$DIGNM
     #ckalive "$2" "server crashed by 'dig $2'" || return 1
     ADDR_ESC=`echo "$ADDR" | sed -e 's/\./\\\\./g'`
-    ADDR_TTL=`tr -d '\r' < $DIGNM | sed -n -e "s/^[-.a-z0-9]\{1,\}[	 ]*\([0-9]*\)	IN	AA*	${ADDR_ESC}\$/\1/p"`
+    ADDR_TTL=`sed -n -e "s/^[-.a-z0-9]\{1,\}[	 ]*\([0-9]*\)	IN	AA*	${ADDR_ESC}\$/\1/p" $DIGNM`
     if test -z "$ADDR_TTL"; then
 	setret "'dig $2' wrong; no address $ADDR record in $DIGNM"
 	return 1
@@ -413,46 +410,43 @@ EOF
   sleep 2
 }
 
-for mode in native dnsrps; do
+# make prototype files to check against rewritten results
+digcmd nonexistent @$ns2 >proto.nxdomain
+digcmd txt-only.tld2 @$ns2 >proto.nodata
+
+case "$DNSRPS_TEST_MODE" in
+''|native|dnsrps);;
+*)
+  echo "bad test mode'${DNSRPS_TEST_MODE}' should be 'native' or 'dnsrps'"
+  exit 1
+  ;;
+esac
+
+for mode in ${DNSRPS_TEST_MODE:-native dnsrps}
+do
   status=0
   case ${mode} in
   native)
-    if [ -e dnsrps-only ] ; then
-      echo_i "'dnsrps-only' found: skipping native RPZ sub-test"
-      continue
-    else
-      echo_i "running native RPZ sub-test"
+    if [ ${DNSRPS_TEST_MODE:-unset} = unset -a -e dnsrps-only ] ; then
+    echo_i "'dnsrps-only' found: skipping native RPZ sub-test"
+    continue
     fi
     ;;
   dnsrps)
-    if [ -e dnsrps-off ] ; then
+    if [ ${DNSRPS_TEST_MODE:-unset} = unset -a -e dnsrps-off ] ; then
       echo_i "'dnsrps-off' found: skipping DNSRPS sub-test"
       continue
     fi
-    echo_i "attempting to configure servers with DNSRPS..."
-    $PERL $SYSTEMTESTTOP/stop.pl --use-rndc --port ${CONTROLPORT} rpz
-    $SHELL ./setup.sh -N -D $DEBUG
-    for server in ns*; do
-      resetstats $server
-    done
-    sed -n 's/^## //p' dnsrps.conf | cat_i
-    if grep '^#fail' dnsrps.conf >/dev/null; then
-      echo_i "exit status: 1"
-      exit 1
-    fi
-    if grep '^#skip' dnsrps.conf > /dev/null; then
+    if grep '^#skip' dnsrps.conf > /dev/null ; then
       echo_i "DNSRPS sub-test skipped"
       continue
-    else
-      echo_i "running DNSRPS sub-test"
-      $PERL $SYSTEMTESTTOP/start.pl --noclean --restart --port ${PORT} rpz
     fi
+    $PERL $SYSTEMTESTTOP/stop.pl .
+    $SHELL ./setup.sh -N -D $DEBUG
+    $PERL $SYSTEMTESTTOP/start.pl --noclean --restart --port ${PORT} .
     ;;
   esac
-
-  # make prototype files to check against rewritten results
-  digcmd nonexistent @$ns2 >proto.nxdomain
-  digcmd txt-only.tld2 @$ns2 >proto.nodata
+  sed -n 's/^## //p' dnsrps.conf | cat_i
 
   start_group "QNAME rewrites" test1
   nochange .				# 1 do not crash or rewrite root
@@ -584,11 +578,11 @@ EOF
   addr 127.0.0.1 a3-1.sub3.tld2		# 10 prefer policy for largest NSDNAME
   addr 127.0.0.2 a3-1.subsub.sub3.tld2
   nxdomain xxx.crash1.tld2		# 12 dns_db_detachnode() crash
-  if [ "$mode" = dnsrps ]; then
+  if [ "$DNSRPS_TEST_MODE" = dnsrps ]; then
     addr 12.12.12.12 as-ns.tld5.	# 13 qname-as-ns
   fi
   end_group
-  if [ "$mode" = dnsrps ]; then
+  if [ "$DNSRPS_TEST_MODE" = dnsrps ]; then
     ckstats $ns3 test3 ns3 8
   else
     ckstats $ns3 test3 ns3 7
@@ -600,7 +594,7 @@ EOF
   nochange a3-2.tld2.			# 2 exempt rewrite by name
   nochange a0-1.tld2.			# 3 exempt rewrite by address block
   nochange a3-1.tld4			# 4 different NS IP address
-  if [ "$mode" = dnsrps ]; then
+  if [ "$DNSRPS_TEST_MODE" = dnsrps ]; then
       addr 12.12.12.12 as-ns.tld5.	# 5 ip-as-ns
   fi
   end_group
@@ -613,7 +607,7 @@ EOF
     a3-1.tld2.	    x	IN	TXT   "NSIP walled garden"
 EOF
   end_group
-  if [ "$mode" = dnsrps ]; then
+  if [ "$DNSRPS_TEST_MODE" = dnsrps ]; then
     ckstats $ns3 test4 ns3 5
   else
     ckstats $ns3 test4 ns3 4
@@ -718,7 +712,7 @@ EOF
     echo_i "performance not checked; queryperf not available"
   fi
 
-  if [ "$mode" = dnsrps ]; then
+  if [ "$DNSRPS_TEST_MODE" = dnsrps ]; then
     echo_i "checking that dnsrpzd is automatically restarted"
     OLD_PID=`cat dnsrpzd.pid`
     $KILL "$OLD_PID"
@@ -741,21 +735,19 @@ EOF
 
   # restart the main test RPZ server to see if that creates a core file
   if test -z "$HAVE_CORE"; then
-    $PERL $SYSTEMTESTTOP/stop.pl --use-rndc --port ${CONTROLPORT} rpz ns3
+    $PERL $SYSTEMTESTTOP/stop.pl . ns3
     restart 3
     HAVE_CORE=`find ns* -name '*core*' -print`
     test -z "$HAVE_CORE" || setret "found $HAVE_CORE; memory leak?"
   fi
 
   # look for complaints from lib/dns/rpz.c and bin/name/query.c
-  for runfile in ns*/named.run; do
-    EMSGS=`nextpart $runfile | egrep -l 'invalid rpz|rpz.*failed'`
-    if test -n "$EMSGS"; then
-      setret "error messages in $runfile starting with:"
-      egrep 'invalid rpz|rpz.*failed' ns*/named.run | \
-              sed -e '10,$d' -e 's/^//' | cat_i
-    fi
-  done
+  EMSGS=`egrep -l 'invalid rpz|rpz.*failed' ns*/named.run`
+  if test -n "$EMSGS"; then
+    setret "error messages in $EMSGS starting with:"
+    egrep 'invalid rpz|rpz.*failed' ns*/named.run | \
+            sed -e '10,$d' -e 's/^//' | cat_i
+  fi
 
   t=`expr $t + 1`
   echo_i "checking that ttl values are not zeroed when qtype is '*' (${t})"
@@ -764,17 +756,23 @@ EOF
   if test ${ttl:=0} -eq 0; then setret "failed"; fi
 
   t=`expr $t + 1`
-  echo_i "checking rpz updates/transfers with parent nodes added after children (${t})"
+  echo_i "checking rpz updates/transfers with parent nodes added after children" \
+    | tr -d '\n'
   # regression test for RT #36272: the success condition
   # is the slave server not crashing.
   for i in 1 2 3 4 5; do
     nsd $ns5 add example.com.policy1. '*.example.com.policy1.'
+    echo . | tr -d '\n'
     nsd $ns5 delete example.com.policy1. '*.example.com.policy1.'
+    echo . | tr -d '\n'
   done
   for i in 1 2 3 4 5; do
     nsd $ns5 add '*.example.com.policy1.' example.com.policy1.
+    echo . | tr -d '\n'
     nsd $ns5 delete '*.example.com.policy1.' example.com.policy1.
+    echo . | tr -d '\n'
   done
+  echo " (${t})"
 
   t=`expr $t + 1`
   echo_i "checking that going from an empty policy zone works (${t})"
@@ -786,7 +784,7 @@ EOF
 
   # dnsrps does not allow NS RRs in policy zones, so this check
   # with dnsrps results in no rewriting.
-  if [ "$mode" = native ]; then
+  if [ "$DNSRPS_TEST_MODE" = native ]; then
     t=`expr $t + 1`
     echo_i "checking rpz with delegation fails correctly (${t})"
     $DIG -p ${PORT} @$ns3 ns example.com > dig.out.$t
@@ -794,7 +792,7 @@ EOF
   fi
 
   [ $status -ne 0 ] && pf=fail || pf=pass
-  case $mode in
+  case $DNSRPS_TEST_MODE in
   native)
     native=$status
     echo_i "status (native RPZ sub-test): $status ($pf)";;
