@@ -17,11 +17,11 @@
 
 #include <isc/app.h>
 #include <isc/base64.h>
-#include <isc/entropy.h>
 #include <isc/hash.h>
 #include <isc/log.h>
 #include <isc/mem.h>
 #include <isc/print.h>
+#include <isc/random.h>
 #include <isc/sockaddr.h>
 #include <isc/socket.h>
 #include <isc/task.h>
@@ -173,7 +173,7 @@ sendquery(isc_task_t *task, isc_event_t *event) {
 				    DNS_TSIG_HMACMD5_NAME,
 				    isc_buffer_base(&keybuf),
 				    isc_buffer_usedlength(&keybuf),
-				    false, NULL, 0, 0, mctx, ring,
+				    ISC_FALSE, NULL, 0, 0, mctx, ring,
 				    &initialkey);
 	CHECK("dns_tsigkey_create", result);
 
@@ -203,7 +203,6 @@ sendquery(isc_task_t *task, isc_event_t *event) {
 int
 main(int argc, char *argv[]) {
 	char *ourkeyname;
-	char *randomfile;
 	isc_taskmgr_t *taskmgr;
 	isc_timermgr_t *timermgr;
 	isc_socketmgr_t *socketmgr;
@@ -213,7 +212,6 @@ main(int argc, char *argv[]) {
 	dns_dispatchmgr_t *dispatchmgr;
 	dns_dispatch_t *dispatchv4;
 	dns_view_t *view;
-	isc_entropy_t *ectx;
 	dns_tkeyctx_t *tctx;
 	isc_log_t *log;
 	isc_logconfig_t *logconfig;
@@ -223,20 +221,13 @@ main(int argc, char *argv[]) {
 
 	RUNCHECK(isc_app_start());
 
-	randomfile = NULL;
-
 	if (argc < 2) {
 		fprintf(stderr, "I:no DH key provided\n");
 		exit(-1);
 	}
 	if (strcmp(argv[1], "-r") == 0) {
-		if (argc < 4) {
-			fprintf(stderr, "I:no DH key provided\n");
-			exit(-1);
-		}
-		randomfile = argv[2];
-		argv += 2;
-		argc -= 2;
+		fprintf(stderr, "I:the -r option has been deprecated\n");
+		exit(-1);
 	}
 	ourkeyname = argv[1];
 
@@ -249,22 +240,11 @@ main(int argc, char *argv[]) {
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 	RUNCHECK(isc_mem_create(0, 0, &mctx));
 
-	ectx = NULL;
-	RUNCHECK(isc_entropy_create(mctx, &ectx));
-#ifdef ISC_PLATFORM_CRYPTORANDOM
-	if (randomfile == NULL) {
-		isc_entropy_usehook(ectx, true);
-	}
-#endif
-	if (randomfile != NULL)
-		RUNCHECK(isc_entropy_createfilesource(ectx, randomfile));
-
 	log = NULL;
 	logconfig = NULL;
 	RUNCHECK(isc_log_create(mctx, &log, &logconfig));
 
-	RUNCHECK(dst_lib_init(mctx, ectx, ISC_ENTROPY_GOODONLY));
-	RUNCHECK(isc_hash_create(mctx, ectx, DNS_NAME_MAXWIRE));
+	RUNCHECK(dst_lib_init(mctx, NULL));
 
 	taskmgr = NULL;
 	RUNCHECK(isc_taskmgr_create(mctx, 1, 0, &taskmgr));
@@ -275,7 +255,7 @@ main(int argc, char *argv[]) {
 	socketmgr = NULL;
 	RUNCHECK(isc_socketmgr_create(mctx, &socketmgr));
 	dispatchmgr = NULL;
-	RUNCHECK(dns_dispatchmgr_create(mctx, NULL, &dispatchmgr));
+	RUNCHECK(dns_dispatchmgr_create(mctx, &dispatchmgr));
 	isc_sockaddr_any(&bind_any);
 	attrs = DNS_DISPATCHATTR_UDP |
 		DNS_DISPATCHATTR_MAKEQUERY |
@@ -296,7 +276,7 @@ main(int argc, char *argv[]) {
 	ring = NULL;
 	RUNCHECK(dns_tsigkeyring_create(mctx, &ring));
 	tctx = NULL;
-	RUNCHECK(dns_tkeyctx_create(mctx, ectx, &tctx));
+	RUNCHECK(dns_tkeyctx_create(mctx, &tctx));
 
 	view = NULL;
 	RUNCHECK(dns_view_create(mctx, 0, "_test", &view));
@@ -315,9 +295,7 @@ main(int argc, char *argv[]) {
 	CHECK("dst_key_fromnamedfile", result);
 
 	isc_buffer_init(&nonce, noncedata, sizeof(noncedata));
-	result = isc_entropy_getdata(ectx, noncedata, sizeof(noncedata),
-				     NULL, ISC_ENTROPY_BLOCKING);
-	CHECK("isc_entropy_getdata", result);
+	isc_random_buf(noncedata, sizeof(noncedata));
 	isc_buffer_add(&nonce, sizeof(noncedata));
 
 	(void)isc_app_run();
@@ -343,9 +321,7 @@ main(int argc, char *argv[]) {
 
 	isc_log_destroy(&log);
 
-	isc_hash_destroy();
 	dst_lib_destroy();
-	isc_entropy_detach(&ectx);
 
 	isc_mem_destroy(&mctx);
 
