@@ -11,14 +11,12 @@
 
 #include <config.h>
 
-#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
 
 #include <isc/app.h>
 #include <isc/base64.h>
-#include <isc/entropy.h>
 #include <isc/hash.h>
 #include <isc/hex.h>
 #include <isc/log.h>
@@ -26,6 +24,7 @@
 #include <isc/net.h>
 #include <isc/parseint.h>
 #include <isc/print.h>
+#include <isc/random.h>
 #include <isc/sockaddr.h>
 #include <isc/socket.h>
 #include <isc/string.h>
@@ -86,27 +85,27 @@ static isc_mem_t *mctx;
 static dns_requestmgr_t *requestmgr;
 static const char *batchname;
 static FILE *batchfp;
-static bool have_ipv4 = false;
-static bool have_ipv6 = false;
-static bool have_src = false;
-static bool tcp_mode = false;
-static bool besteffort = true;
-static bool display_short_form = false;
-static bool display_headers = true;
-static bool display_comments = true;
-static bool display_rrcomments = true;
-static bool display_ttlunits = true;
-static bool display_ttl = true;
-static bool display_class = true;
-static bool display_crypto = true;
-static bool display_multiline = false;
-static bool display_question = true;
-static bool display_answer  = true;
-static bool display_authority = true;
-static bool display_additional = true;
-static bool display_unknown_format = false;
-static bool continue_on_error = false;
-static uint32_t display_splitwidth = 0xffffffff;
+static isc_boolean_t have_ipv4 = ISC_FALSE;
+static isc_boolean_t have_ipv6 = ISC_FALSE;
+static isc_boolean_t have_src = ISC_FALSE;
+static isc_boolean_t tcp_mode = ISC_FALSE;
+static isc_boolean_t besteffort = ISC_TRUE;
+static isc_boolean_t display_short_form = ISC_FALSE;
+static isc_boolean_t display_headers = ISC_TRUE;
+static isc_boolean_t display_comments = ISC_TRUE;
+static isc_boolean_t display_rrcomments = ISC_TRUE;
+static isc_boolean_t display_ttlunits = ISC_TRUE;
+static isc_boolean_t display_ttl = ISC_TRUE;
+static isc_boolean_t display_class = ISC_TRUE;
+static isc_boolean_t display_crypto = ISC_TRUE;
+static isc_boolean_t display_multiline = ISC_FALSE;
+static isc_boolean_t display_question = ISC_TRUE;
+static isc_boolean_t display_answer  = ISC_TRUE;
+static isc_boolean_t display_authority = ISC_TRUE;
+static isc_boolean_t display_additional = ISC_TRUE;
+static isc_boolean_t display_unknown_format = ISC_FALSE;
+static isc_boolean_t continue_on_error = ISC_FALSE;
+static isc_uint32_t display_splitwidth = 0xffffffff;
 static isc_sockaddr_t srcaddr;
 static char *server;
 static isc_sockaddr_t dstaddr;
@@ -118,21 +117,21 @@ static char hexcookie[81];
 
 struct query {
 	char textname[MXNAME]; /*% Name we're going to be looking up */
-	bool ip6_int;
-	bool recurse;
-	bool have_aaonly;
-	bool have_adflag;
-	bool have_cdflag;
-	bool have_zflag;
-	bool dnssec;
-	bool expire;
-	bool send_cookie;
+	isc_boolean_t ip6_int;
+	isc_boolean_t recurse;
+	isc_boolean_t have_aaonly;
+	isc_boolean_t have_adflag;
+	isc_boolean_t have_cdflag;
+	isc_boolean_t have_zflag;
+	isc_boolean_t dnssec;
+	isc_boolean_t expire;
+	isc_boolean_t send_cookie;
 	char *cookie;
-	bool nsid;
+	isc_boolean_t nsid;
 	dns_rdatatype_t rdtype;
 	dns_rdataclass_t rdclass;
-	uint16_t udpsize;
-	int16_t edns;
+	isc_uint16_t udpsize;
+	isc_int16_t edns;
 	dns_ednsopt_t *ednsopts;
 	unsigned int ednsoptscnt;
 	unsigned int ednsflags;
@@ -269,17 +268,17 @@ recvresponse(isc_task_t *task, isc_event_t *event) {
 		styleflags |= DNS_STYLEFLAG_RRCOMMENT;
 	}
 	if (display_multiline || (!display_ttl && !display_class))
-		result = dns_master_stylecreate2(&style, styleflags,
-						 24, 24, 24, 32, 80, 8,
-						 display_splitwidth, mctx);
+		result = dns_master_stylecreate(&style, styleflags,
+						24, 24, 24, 32, 80, 8,
+						display_splitwidth, mctx);
 	else if (!display_ttl || !display_class)
-		result = dns_master_stylecreate2(&style, styleflags,
-						 24, 24, 32, 40, 80, 8,
-						 display_splitwidth, mctx);
+		result = dns_master_stylecreate(&style, styleflags,
+						24, 24, 32, 40, 80, 8,
+						display_splitwidth, mctx);
 	else
-		result = dns_master_stylecreate2(&style, styleflags,
-						 24, 32, 40, 48, 80, 8,
-						 display_splitwidth, mctx);
+		result = dns_master_stylecreate(&style, styleflags,
+						24, 32, 40, 48, 80, 8,
+						display_splitwidth, mctx);
 	CHECK("dns_master_stylecreate2", result);
 
 	flags = 0;
@@ -492,7 +491,7 @@ cleanup:
  * (e.g., NSID, COOKIE, client-subnet)
  */
 static void
-add_opt(dns_message_t *msg, uint16_t udpsize, uint16_t edns,
+add_opt(dns_message_t *msg, isc_uint16_t udpsize, isc_uint16_t edns,
 	unsigned int flags, dns_ednsopt_t *opts, size_t count)
 {
 	dns_rdataset_t *rdataset = NULL;
@@ -589,8 +588,8 @@ sendquery(struct query *query, isc_task_t *task)
 		}
 
 		if (query->ecs_addr != NULL) {
-			uint8_t addr[16], family;
-			uint32_t plen;
+			isc_uint8_t addr[16], family;
+			isc_uint32_t plen;
 			struct sockaddr *sa;
 			struct sockaddr_in *sin;
 			struct sockaddr_in6 *sin6;
@@ -605,7 +604,7 @@ sendquery(struct query *query, isc_task_t *task)
 
 			INSIST(i < DNS_EDNSOPTIONS);
 			opts[i].code = DNS_OPT_CLIENT_SUBNET;
-			opts[i].length = (uint16_t) addrl + 4;
+			opts[i].length = (isc_uint16_t) addrl + 4;
 			CHECK("isc_buffer_allocate", result);
 			isc_buffer_init(&b, ecsbuf, sizeof(ecsbuf));
 			if (sa->sa_family == AF_INET) {
@@ -636,7 +635,7 @@ sendquery(struct query *query, isc_task_t *task)
 				isc_buffer_putmem(&b, addr,
 						  (unsigned)addrl);
 
-			opts[i].value = (uint8_t *) ecsbuf;
+			opts[i].value = (isc_uint8_t *) ecsbuf;
 			i++;
 		}
 
@@ -685,12 +684,12 @@ sendquery(struct query *query, isc_task_t *task)
 	if (tcp_mode)
 		options |= DNS_REQUESTOPT_TCP | DNS_REQUESTOPT_SHARE;
 	request = NULL;
-	result = dns_request_createvia4(requestmgr, message,
-					have_src ? &srcaddr : NULL, &dstaddr,
-					dscp, options, NULL,
-					query->timeout, query->udptimeout,
-					query->udpretries, task,
-					recvresponse, message, &request);
+	result = dns_request_createvia(requestmgr, message,
+				       have_src ? &srcaddr : NULL, &dstaddr,
+				       dscp, options, NULL,
+				       query->timeout, query->udptimeout,
+				       query->udpretries, task,
+				       recvresponse, message, &request);
 	CHECK("dns_request_createvia4", result);
 
 	return ISC_R_SUCCESS;
@@ -796,18 +795,6 @@ help(void) {
 	stdout);
 }
 
-static char *
-next_token(char **stringp, const char *delim) {
-	char *res;
-
-	do {
-		res = strsep(stringp, delim);
-		if (res == NULL)
-			break;
-	} while (*res == '\0');
-	return (res);
-}
-
 ISC_PLATFORM_NORETURN_PRE static void
 fatal(const char *format, ...)
 ISC_FORMAT_PRINTF(1, 2) ISC_PLATFORM_NORETURN_POST;
@@ -826,9 +813,9 @@ fatal(const char *format, ...) {
 }
 
 static isc_result_t
-parse_uint_helper(uint32_t *uip, const char *value, uint32_t max,
+parse_uint_helper(isc_uint32_t *uip, const char *value, isc_uint32_t max,
 		  const char *desc, int base) {
-	uint32_t n;
+	isc_uint32_t n;
 	isc_result_t result = isc_parse_uint32(&n, value, base);
 	if (result == ISC_R_SUCCESS && n > max)
 		result = ISC_R_RANGE;
@@ -842,72 +829,53 @@ parse_uint_helper(uint32_t *uip, const char *value, uint32_t max,
 }
 
 static isc_result_t
-parse_uint(uint32_t *uip, const char *value, uint32_t max,
+parse_uint(isc_uint32_t *uip, const char *value, isc_uint32_t max,
 	   const char *desc) {
 	return (parse_uint_helper(uip, value, max, desc, 10));
 }
 
 static isc_result_t
-parse_xint(uint32_t *uip, const char *value, uint32_t max,
+parse_xint(isc_uint32_t *uip, const char *value, isc_uint32_t max,
 	   const char *desc) {
 	return (parse_uint_helper(uip, value, max, desc, 0));
 }
 
-static void
-newopts(struct query *query) {
-	size_t len = sizeof(query->ednsopts[0]) * EDNSOPTS;
-	size_t i;
-
-	query->ednsopts = isc_mem_allocate(mctx, len);
-	if (query->ednsopts == NULL)
-		fatal("out of memory");
-
-	for (i = 0; i < EDNSOPTS; i++) {
-		query->ednsopts[i].code = 0;
-		query->ednsopts[i].length = 0;
-		query->ednsopts[i].value = NULL;
-	}
-}
+static dns_ednsopt_t ednsopts[EDNSOPTS];
+static unsigned char ednsoptscnt = 0;
 
 static void
 save_opt(struct query *query, char *code, char *value) {
-	uint32_t num;
+	isc_uint32_t num;
 	isc_buffer_t b;
 	isc_result_t result;
 
-	if (query->ednsopts == NULL) {
-		newopts(query);
-	}
-
-	if (query->ednsoptscnt == EDNSOPTS) {
+	if (ednsoptscnt == EDNSOPTS)
 		fatal("too many ednsopts");
-	}
 
 	result = parse_uint(&num, code, 65535, "ednsopt");
-	if (result != ISC_R_SUCCESS) {
+	if (result != ISC_R_SUCCESS)
 		fatal("bad edns code point: %s", code);
-	}
 
-	query->ednsopts[query->ednsoptscnt].code = num;
-	query->ednsopts[query->ednsoptscnt].length = 0;
-	query->ednsopts[query->ednsoptscnt].value = NULL;
+	ednsopts[ednsoptscnt].code = num;
+	ednsopts[ednsoptscnt].length = 0;
+	ednsopts[ednsoptscnt].value = NULL;
 
 	if (value != NULL) {
 		char *buf;
 		buf = isc_mem_allocate(mctx, strlen(value)/2 + 1);
-		if (buf == NULL) {
+		if (buf == NULL)
 			fatal("out of memory");
-		}
 		isc_buffer_init(&b, buf, strlen(value)/2 + 1);
 		result = isc_hex_decodestring(value, &b);
 		CHECK("isc_hex_decodestring", result);
-		query->ednsopts[query->ednsoptscnt].value =
-						isc_buffer_base(&b);
-		query->ednsopts[query->ednsoptscnt].length =
-						isc_buffer_usedlength(&b);
+		ednsopts[ednsoptscnt].value = isc_buffer_base(&b);
+		ednsopts[ednsoptscnt].length = isc_buffer_usedlength(&b);
 	}
 
+	if (query->ednsoptscnt == 0)
+		query->ednsopts = &ednsopts[ednsoptscnt];
 	query->ednsoptscnt++;
+	ednsoptscnt++;
 }
 
 static isc_result_t
@@ -916,9 +884,9 @@ parse_netprefix(isc_sockaddr_t **sap, const char *value) {
 	isc_sockaddr_t *sa = NULL;
 	struct in_addr in4;
 	struct in6_addr in6;
-	uint32_t netmask = 0xffffffff;
+	isc_uint32_t netmask = 0xffffffff;
 	char *slash = NULL;
-	bool parsed = false;
+	isc_boolean_t parsed = ISC_FALSE;
 	char buf[sizeof("xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:XXX.XXX.XXX.XXX/128")];
 
 	if (strlcpy(buf, value, sizeof(buf)) >= sizeof(buf))
@@ -940,12 +908,12 @@ parse_netprefix(isc_sockaddr_t **sap, const char *value) {
 	if (sa == NULL)
 		fatal("out of memory");
 	if (inet_pton(AF_INET6, buf, &in6) == 1) {
-		parsed = true;
+		parsed = ISC_TRUE;
 		isc_sockaddr_fromin6(sa, &in6, 0);
 		if (netmask > 128)
 			netmask = 128;
 	} else if (inet_pton(AF_INET, buf, &in4) == 1) {
-		parsed = true;
+		parsed = ISC_TRUE;
 		isc_sockaddr_fromin(sa, &in4, 0);
 		if (netmask > 32)
 			netmask = 32;
@@ -955,7 +923,7 @@ parse_netprefix(isc_sockaddr_t **sap, const char *value) {
 		for (i = 0; i < 3 && strlen(buf) < sizeof(buf) - 2; i++) {
 			strlcat(buf, ".0", sizeof(buf));
 			if (inet_pton(AF_INET, buf, &in4) == 1) {
-				parsed = true;
+				parsed = ISC_TRUE;
 				isc_sockaddr_fromin(sa, &in4, 0);
 				break;
 			}
@@ -1006,7 +974,7 @@ reverse_octets(const char *in, char **p, char *end) {
 
 static void
 get_reverse(char *reverse, size_t len, const char *value,
-	    bool ip6_int)
+	    isc_boolean_t ip6_int)
 {
 	int r;
 	isc_result_t result;
@@ -1023,7 +991,7 @@ get_reverse(char *reverse, size_t len, const char *value,
 		if (ip6_int)
 			options |= DNS_BYADDROPT_IPV6INT;
 		name = dns_fixedname_initname(&fname);
-		result = dns_byaddr_createptrname2(&addr, options, name);
+		result = dns_byaddr_createptrname(&addr, options, name);
 		CHECK("dns_byaddr_createptrname2", result);
 		dns_name_format(name, reverse, (unsigned int)len);
 		return;
@@ -1054,27 +1022,26 @@ get_reverse(char *reverse, size_t len, const char *value,
  */
 
 static void
-plus_option(char *option, struct query *query, bool global)
+plus_option(char *option, struct query *query, isc_boolean_t global)
 {
 	isc_result_t result;
-	char option_store[256];
-	char *cmd, *value, *ptr, *code;
-	uint32_t num;
-	bool state = true;
+	char *cmd, *value, *last = NULL, *code;
+	isc_uint32_t num;
+	isc_boolean_t state = ISC_TRUE;
 	size_t n;
 
-	strlcpy(option_store, option, sizeof(option_store));
-	ptr = option_store;
-	cmd = next_token(&ptr, "=");
-	if (cmd == NULL) {
-		printf(";; Invalid option %s\n", option_store);
+	INSIST(option != NULL);
+
+	if ((cmd = strtok_r(option, "=", &last)) == NULL) {
+		printf(";; Invalid option %s\n", option);
 		return;
 	}
-	value = ptr;
 	if (strncasecmp(cmd, "no", 2) == 0) {
 		cmd += 2;
-		state = false;
+		state = ISC_FALSE;
 	}
+	/* parse the rest of the string */
+	value = strtok_r(NULL, "", &last);
 
 #define FULLCHECK(A) \
 	do { \
@@ -1295,12 +1262,11 @@ plus_option(char *option, struct query *query, bool global)
 							query->ednsoptscnt = 0;
 							break;
 						}
-						code = next_token(&value, ":");
-						if (code == NULL) {
+						if (value == NULL)
 							fatal("ednsopt no "
 							      "code point "
 							      "specified");
-						}
+						code = strtok_r(value, ":", &last);
 						save_opt(query, code, value);
 						break;
 					default:
@@ -1380,12 +1346,12 @@ plus_option(char *option, struct query *query, bool global)
 			GLOBAL();
 			display_short_form = state;
 			if (state) {
-				display_question = false;
-				display_answer = true;
-				display_authority = false;
-				display_additional = false;
-				display_comments = false;
-				display_rrcomments = false;
+				display_question = ISC_FALSE;
+				display_answer = ISC_TRUE;
+				display_authority = ISC_FALSE;
+				display_additional = ISC_FALSE;
+				display_comments = ISC_FALSE;
+				display_rrcomments = ISC_FALSE;
 			}
 			break;
 		case 'p': /* split */
@@ -1484,7 +1450,7 @@ plus_option(char *option, struct query *query, bool global)
 				case 'u': /* ttlunits */
 					FULLCHECK("ttlunits");
 					GLOBAL();
-					display_ttl = true;
+					display_ttl = ISC_TRUE;
 					display_ttlunits = state;
 					break;
 				default:
@@ -1541,18 +1507,18 @@ plus_option(char *option, struct query *query, bool global)
 }
 
 /*%
- * #true returned if value was used
+ * #ISC_TRUE returned if value was used
  */
 static const char *single_dash_opts = "46himv";
-static const char *dash_opts = "46bcfhiptvx";
-static bool
+/*static const char *dash_opts = "46bcfhiptvx";*/
+static isc_boolean_t
 dash_option(const char *option, char *next, struct query *query,
-	    bool global, bool *setname)
+	    isc_boolean_t global, isc_boolean_t *setname)
 {
 	char opt;
 	const char *value;
 	isc_result_t result;
-	bool value_from_next;
+	isc_boolean_t value_from_next;
 	isc_consttextregion_t tr;
 	dns_rdatatype_t rdtype;
 	dns_rdataclass_t rdclass;
@@ -1561,7 +1527,7 @@ dash_option(const char *option, char *next, struct query *query,
 	struct in6_addr in6;
 	in_port_t srcport;
 	char *hash;
-	uint32_t num;
+	isc_uint32_t num;
 
 	while (strpbrk(option, single_dash_opts) == &option[0]) {
 		/*
@@ -1575,22 +1541,22 @@ dash_option(const char *option, char *next, struct query *query,
 			GLOBAL();
 			if (have_ipv4) {
 				isc_net_disableipv6();
-				have_ipv6 = false;
+				have_ipv6 = ISC_FALSE;
 			} else {
 				fatal("can't find IPv4 networking");
 				/* NOTREACHED */
-				return (false);
+				return (ISC_FALSE);
 			}
 			break;
 		case '6':
 			GLOBAL();
 			if (have_ipv6) {
 				isc_net_disableipv4();
-				have_ipv4 = false;
+				have_ipv4 = ISC_FALSE;
 			} else {
 				fatal("can't find IPv6 networking");
 				/* NOTREACHED */
-				return (false);
+				return (ISC_FALSE);
 			}
 			break;
 		case 'h':
@@ -1598,7 +1564,7 @@ dash_option(const char *option, char *next, struct query *query,
 			exit(0);
 			break;
 		case 'i':
-			query->ip6_int = true;
+			query->ip6_int = ISC_TRUE;
 			break;
 		case 'm':
 			/*
@@ -1613,14 +1579,14 @@ dash_option(const char *option, char *next, struct query *query,
 		if (strlen(option) > 1U)
 			option = &option[1];
 		else
-			return (false);
+			return (ISC_FALSE);
 	}
 	opt = option[0];
 	if (strlen(option) > 1U) {
-		value_from_next = false;
+		value_from_next = ISC_FALSE;
 		value = &option[1];
 	} else {
-		value_from_next = true;
+		value_from_next = ISC_TRUE;
 		value = next;
 	}
 	if (value == NULL)
@@ -1650,7 +1616,7 @@ dash_option(const char *option, char *next, struct query *query,
 		}
 		if (hash != NULL)
 			*hash = '#';
-		have_src = true;
+		have_src = ISC_TRUE;
 		return (value_from_next);
 	case 'c':
 		tr.base = value;
@@ -1682,7 +1648,7 @@ dash_option(const char *option, char *next, struct query *query,
 		strlcpy(query->textname, textname, sizeof(query->textname));
 		query->rdtype = dns_rdatatype_ptr;
 		query->rdclass = dns_rdataclass_in;
-		*setname = true;
+		*setname = ISC_TRUE;
 		return (value_from_next);
 	global_option:
 		fprintf(stderr, "Ignored late global option: -%s\n", option);
@@ -1693,7 +1659,7 @@ dash_option(const char *option, char *next, struct query *query,
 		usage();
 	}
 	/* NOTREACHED */
-	return (false);
+	return (ISC_FALSE);
 }
 
 static struct query *
@@ -1735,7 +1701,7 @@ preparse_args(int argc, char **argv) {
 	int rc;
 	char **rv;
 	char *option;
-	bool ipv4only = false, ipv6only = false;
+	isc_boolean_t ipv4only = ISC_FALSE, ipv6only = ISC_FALSE;
 
 	rc = argc;
 	rv = argv;
@@ -1753,36 +1719,22 @@ preparse_args(int argc, char **argv) {
 				if (ipv6only) {
 					fatal("only one of -4 and -6 allowed");
 				}
-				ipv4only = true;
+				ipv4only = ISC_TRUE;
 				break;
 			case '6':
 				if (ipv4only) {
 					fatal("only one of -4 and -6 allowed");
 				}
-				ipv6only = true;
+				ipv6only = ISC_TRUE;
 				break;
 			}
 			option = &option[1];
 		}
-		if (strlen(option) == 0U) {
-			continue;
-		}
-		/* Look for dash value option. */
-		if (strpbrk(option, dash_opts) != &option[0] ||
-		    strlen(option) > 1U) {
-			/* Error or value in option. */
-			continue;
-		}
-		/* Dash value is next argument so we need to skip it. */
-		rc--, rv++;
-		/* Handle missing argument */
-		if (rc == 0)
-			break;
 	}
 }
 
 static void
-parse_args(bool is_batchfile, int argc, char **argv)
+parse_args(isc_boolean_t is_batchfile, int argc, char **argv)
 {
 	struct query *query = NULL;
 	char batchline[MXNAME];
@@ -1790,8 +1742,8 @@ parse_args(bool is_batchfile, int argc, char **argv)
 	char *bargv[64];
 	int rc;
 	char **rv;
-	char *input;
-	bool global = true;
+	isc_boolean_t global = ISC_TRUE;
+	char *last;
 
 	/*
 	 * The semantics for parsing the args is a bit complex; if
@@ -1806,17 +1758,17 @@ parse_args(bool is_batchfile, int argc, char **argv)
 
 	if (!is_batchfile) {
 		default_query.textname[0] = 0;
-		default_query.ip6_int = false;
-		default_query.recurse = true;
-		default_query.have_aaonly = false;
-		default_query.have_adflag = true; /*XXX*/
-		default_query.have_cdflag = false;
-		default_query.have_zflag = false;
-		default_query.dnssec = false;
-		default_query.expire = false;
-		default_query.send_cookie = false;
+		default_query.ip6_int = ISC_FALSE;
+		default_query.recurse = ISC_TRUE;
+		default_query.have_aaonly = ISC_FALSE;
+		default_query.have_adflag = ISC_TRUE; /*XXX*/
+		default_query.have_cdflag = ISC_FALSE;
+		default_query.have_zflag = ISC_FALSE;
+		default_query.dnssec = ISC_FALSE;
+		default_query.expire = ISC_FALSE;
+		default_query.send_cookie = ISC_FALSE;
 		default_query.cookie = NULL;
-		default_query.nsid = false;
+		default_query.nsid = ISC_FALSE;
 		default_query.rdtype = dns_rdatatype_a;
 		default_query.rdclass = dns_rdataclass_in;
 		default_query.udpsize = 0;
@@ -1834,7 +1786,7 @@ parse_args(bool is_batchfile, int argc, char **argv)
 	if (is_batchfile) {
 		/* Processing '-f batchfile'. */
 		query = clone_default_query();
-		global = false;
+		global = ISC_FALSE;
 	} else
 		query = &default_query;
 
@@ -1850,7 +1802,7 @@ parse_args(bool is_batchfile, int argc, char **argv)
 		} else if (rv[0][0] == '+') {
 			plus_option(&rv[0][1], query, global);
 		} else if (rv[0][0] == '-') {
-			bool setname = false;
+			isc_boolean_t setname = ISC_FALSE;
 
 			if (rc <= 1) {
 				if (dash_option(&rv[0][1], NULL, query,
@@ -1872,7 +1824,7 @@ parse_args(bool is_batchfile, int argc, char **argv)
 
 				default_query.textname[0] = 0;
 				query = clone_default_query();
-				global = false;
+				global = ISC_FALSE;
 			}
 		} else {
 			/*
@@ -1885,7 +1837,7 @@ parse_args(bool is_batchfile, int argc, char **argv)
 			ISC_LIST_APPEND(queries, query, link);
 
 			query = clone_default_query();
-			global = false;
+			global = ISC_FALSE;
 			/* XXX Error message */
 		}
 	}
@@ -1903,19 +1855,18 @@ parse_args(bool is_batchfile, int argc, char **argv)
 			fatal("couldn't open batch file '%s'", batchname);
 		}
 		while (fgets(batchline, sizeof(batchline), batchfp) != 0) {
-			bargc = 1;
 			if (batchline[0] == '\r' || batchline[0] == '\n'
 			    || batchline[0] == '#' || batchline[0] == ';')
 				continue;
-			input = batchline;
-			bargv[bargc] = next_token(&input, " \t\r\n");
-			while ((bargc < 14) && (bargv[bargc] != NULL)) {
-				bargc++;
-				bargv[bargc] = next_token(&input, " \t\r\n");
+			for (bargc = 1, bargv[bargc] = strtok_r(batchline, " \t\r\n", &last);
+			     (bargc < 14) && bargv[bargc];
+			     bargc++, bargv[bargc] = strtok_r(NULL, " \t\r\n", &last))
+			{
+				/* empty body */
 			}
 
 			bargv[0] = argv[0];
-			parse_args(true, bargc, (char **)bargv);
+			parse_args(ISC_TRUE, bargc, (char **)bargv);
 		}
 		if (batchfp != stdin)
 			fclose(batchfp);
@@ -1935,7 +1886,6 @@ main(int argc, char *argv[]) {
 	isc_sockaddr_t bind_any;
 	isc_log_t *lctx;
 	isc_logconfig_t *lcfg;
-	isc_entropy_t *ectx;
 	isc_taskmgr_t *taskmgr;
 	isc_task_t *task;
 	isc_timermgr_t *timermgr;
@@ -1945,16 +1895,15 @@ main(int argc, char *argv[]) {
 	dns_dispatch_t *dispatchvx;
 	dns_view_t *view;
 	int ns;
-	unsigned int i;
 
 	RUNCHECK(isc_app_start());
 
 	dns_result_register();
 
 	if (isc_net_probeipv4() == ISC_R_SUCCESS)
-		have_ipv4 = true;
+		have_ipv4 = ISC_TRUE;
 	if (isc_net_probeipv6() == ISC_R_SUCCESS)
-		have_ipv6 = true;
+		have_ipv6 = ISC_TRUE;
 	if (!have_ipv4 && !have_ipv6)
 		fatal("could not find either IPv4 or IPv6");
 
@@ -1967,15 +1916,11 @@ main(int argc, char *argv[]) {
 	lcfg = NULL;
 	RUNCHECK(isc_log_create(mctx, &lctx, &lcfg));
 
-	ectx = NULL;
-	RUNCHECK(isc_entropy_create(mctx, &ectx));
-	RUNCHECK(dst_lib_init(mctx, ectx, ISC_ENTROPY_GOODONLY));
-	RUNCHECK(isc_hash_create(mctx, ectx, DNS_NAME_MAXWIRE));
-	RUNCHECK(isc_entropy_getdata(ectx, cookie_secret,
-				     sizeof(cookie_secret), NULL, 0));
+	RUNCHECK(dst_lib_init(mctx, NULL));
+	isc_random_buf(cookie_secret, sizeof(cookie_secret));
 
 	ISC_LIST_INIT(queries);
-	parse_args(false, argc, argv);
+	parse_args(ISC_FALSE, argc, argv);
 	if (server == NULL)
 		fatal("a server '@xxx' is required");
 
@@ -1988,10 +1933,10 @@ main(int argc, char *argv[]) {
 
 	if (isc_sockaddr_pf(&dstaddr) == PF_INET && have_ipv6) {
 		isc_net_disableipv6();
-		have_ipv6 = false;
+		have_ipv6 = ISC_FALSE;
 	} else if (isc_sockaddr_pf(&dstaddr) == PF_INET6 && have_ipv4) {
 		isc_net_disableipv4();
-		have_ipv4 = false;
+		have_ipv4 = ISC_FALSE;
 	}
 	if (have_ipv4 && have_ipv6)
 		fatal("can't choose between IPv4 and IPv6");
@@ -2006,7 +1951,7 @@ main(int argc, char *argv[]) {
 	socketmgr = NULL;
 	RUNCHECK(isc_socketmgr_create(mctx, &socketmgr));
 	dispatchmgr = NULL;
-	RUNCHECK(dns_dispatchmgr_create(mctx, ectx, &dispatchmgr));
+	RUNCHECK(dns_dispatchmgr_create(mctx, &dispatchmgr));
 
 	attrs = DNS_DISPATCHATTR_UDP |
 		DNS_DISPATCHATTR_MAKEQUERY;
@@ -2045,15 +1990,6 @@ main(int argc, char *argv[]) {
 	while (query != NULL) {
 		struct query *next = ISC_LIST_NEXT(query, link);
 
-		if (query->ednsopts != NULL) {
-			for (i = 0; i < EDNSOPTS; i++) {
-				if (query->ednsopts[i].value != NULL) {
-					isc_mem_free(mctx,
-						     query->ednsopts[i].value);
-				}
-			}
-			isc_mem_free(mctx, query->ednsopts);
-		}
 		if (query->ecs_addr != NULL) {
 			isc_mem_free(mctx, query->ecs_addr);
 			query->ecs_addr = NULL;
@@ -2081,8 +2017,6 @@ main(int argc, char *argv[]) {
 	isc_taskmgr_destroy(&taskmgr);
 
 	dst_lib_destroy();
-	isc_hash_destroy();
-	isc_entropy_detach(&ectx);
 
 	isc_log_destroy(&lctx);
 
