@@ -76,7 +76,7 @@ bdb_create(const char *zone, int argc, char **argv,
 		return ISC_R_FAILURE;
 	}
 
-	if (isc_file_exists(*argv) != true) {
+	if (isc_file_exists(*argv) != ISC_TRUE) {
 		isc_log_iwrite(dns_lctx, DNS_LOGCATEGORY_DATABASE,
 			       DNS_LOGMODULE_SDB, ISC_LOG_CRITICAL, isc_msgcat,
 			       ISC_MSGSET_GENERAL, ISC_MSG_FATALERROR,
@@ -112,6 +112,7 @@ bdb_lookup(const char *zone, const char *name, void *dbdata,
 	isc_consttextregion_t ttltext;
 	DBC *c;
 	DBT key, data;
+	char *last;
 
 	UNUSED(zone);
 #ifdef DNS_CLIENTINFO_VERSION
@@ -138,10 +139,10 @@ bdb_lookup(const char *zone, const char *name, void *dbdata,
 	while (ret == 0) {
 		((char *)key.data)[key.size] = 0;
 		((char *)data.data)[data.size] = 0;
-		ttltext.base = strtok((char *)data.data, " ");
+		ttltext.base = strtok_r((char *)data.data, " ", &last);
 		ttltext.length = strlen(ttltext.base);
 		dns_ttl_fromtext((isc_textregion_t *)&ttltext, &ttl);
-		type = strtok(NULL, " ");
+		type = strtok_r(NULL, " ", &last);
 		rdata = type + strlen(type) + 1;
 
 		if (dns_sdb_putrr(l, type, ttl, rdata) != ISC_R_SUCCESS) {
@@ -184,12 +185,13 @@ bdb_allnodes(const char *zone, void *dbdata, dns_sdballnodes_t *n)
 	memset(&data, 0, sizeof(DBT));
 
 	while (c->c_get(c, &key, &data, DB_NEXT) == 0) {
+		char *last;
 		((char *)key.data)[key.size] = 0;
 		((char *)data.data)[data.size] = 0;
-		ttltext.base = strtok((char *)data.data, " ");
+		ttltext.base = strtok_r((char *)data.data, " ", &last);
 		ttltext.length = strlen(ttltext.base);
 		dns_ttl_fromtext((isc_textregion_t *)&ttltext, &ttl);
-		type = strtok(NULL, " ");
+		type = strtok_r(NULL, " ", &last);
 		rdata = type + strlen(type) + 1;
 
 		if (dns_sdb_putnamedrr(n, key.data, type, ttl, rdata) !=
