@@ -12,8 +12,6 @@
 
 #include <config.h>
 
-#include <stdbool.h>
-
 #include <isc/list.h>
 #include <isc/mem.h>
 #include <isc/netaddr.h>
@@ -25,6 +23,7 @@
 #include <dns/rdata.h>
 #include <dns/rdataset.h>
 #include <dns/result.h>
+#include <string.h>
 
 struct dns_dns64 {
 	unsigned char		bits[16];	/*
@@ -139,8 +138,8 @@ dns_dns64_aaaafroma(const dns_dns64_t *dns64, const isc_netaddr_t *reqaddr,
 		return (DNS_R_DISALLOWED);
 
 	if (dns64->clients != NULL) {
-		result = dns_acl_match(reqaddr, reqsigner, dns64->clients, env,
-				       &match, NULL);
+		result = dns_acl_match(reqaddr, reqsigner, NULL, 0, NULL,
+				       dns64->clients, env, &match, NULL);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 		if (match <= 0)
@@ -153,8 +152,8 @@ dns_dns64_aaaafroma(const dns_dns64_t *dns64, const isc_netaddr_t *reqaddr,
 
 		memmove(&ina.s_addr, a, 4);
 		isc_netaddr_fromin(&netaddr, &ina);
-		result = dns_acl_match(&netaddr, NULL, dns64->mapped, env,
-				       &match, NULL);
+		result = dns_acl_match(&netaddr, NULL, NULL, 0, NULL,
+				       dns64->mapped, env, &match, NULL);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 		if (match <= 0)
@@ -196,18 +195,18 @@ dns_dns64_unlink(dns_dns64list_t *list, dns_dns64_t *dns64) {
 	ISC_LIST_UNLINK(*list, dns64, link);
 }
 
-bool
+isc_boolean_t
 dns_dns64_aaaaok(const dns_dns64_t *dns64, const isc_netaddr_t *reqaddr,
 		 const dns_name_t *reqsigner, const dns_aclenv_t *env,
 		 unsigned int flags, dns_rdataset_t *rdataset,
-		 bool *aaaaok, size_t aaaaoklen)
+		 isc_boolean_t *aaaaok, size_t aaaaoklen)
 {
 	struct in6_addr in6;
 	isc_netaddr_t netaddr;
 	isc_result_t result;
 	int match;
-	bool answer = false;
-	bool found = false;
+	isc_boolean_t answer = ISC_FALSE;
+	isc_boolean_t found = ISC_FALSE;
 	unsigned int i, ok;
 
 	REQUIRE(rdataset != NULL);
@@ -228,8 +227,8 @@ dns_dns64_aaaaok(const dns_dns64_t *dns64, const isc_netaddr_t *reqaddr,
 		 * Work out if this dns64 structure applies to this client.
 		 */
 		if (dns64->clients != NULL) {
-			result = dns_acl_match(reqaddr, reqsigner,
-					       dns64->clients, env,
+			result = dns_acl_match(reqaddr, reqsigner, NULL, 0,
+					       NULL, dns64->clients, env,
 					       &match, NULL);
 			if (result != ISC_R_SUCCESS)
 				continue;
@@ -239,20 +238,20 @@ dns_dns64_aaaaok(const dns_dns64_t *dns64, const isc_netaddr_t *reqaddr,
 
 		if (!found && aaaaok != NULL) {
 			for (i = 0; i < aaaaoklen; i++)
-				aaaaok[i] = false;
+				aaaaok[i] = ISC_FALSE;
 		}
-		found = true;
+		found = ISC_TRUE;
 
 		/*
 		 * If we are not excluding any addresses then any AAAA
 		 * will do.
 		 */
 		if (dns64->excluded == NULL) {
-			answer = true;
+			answer = ISC_TRUE;
 			if (aaaaok == NULL)
 				goto done;
 			for (i = 0; i < aaaaoklen; i++)
-				aaaaok[i] = true;
+				aaaaok[i] = ISC_TRUE;
 			goto done;
 		}
 
@@ -267,14 +266,15 @@ dns_dns64_aaaaok(const dns_dns64_t *dns64, const isc_netaddr_t *reqaddr,
 				memmove(&in6.s6_addr, rdata.data, 16);
 				isc_netaddr_fromin6(&netaddr, &in6);
 
-				result = dns_acl_match(&netaddr, NULL,
-						       dns64->excluded,
-						       env, &match, NULL);
+				result = dns_acl_match(&netaddr, NULL, NULL,
+						       0, NULL,
+						       dns64->excluded, env,
+						       &match, NULL);
 				if (result == ISC_R_SUCCESS && match <= 0) {
-					answer = true;
+					answer = ISC_TRUE;
 					if (aaaaok == NULL)
 						goto done;
-					aaaaok[i] = true;
+					aaaaok[i] = ISC_TRUE;
 					ok++;
 				}
 			} else
@@ -291,7 +291,7 @@ dns_dns64_aaaaok(const dns_dns64_t *dns64, const isc_netaddr_t *reqaddr,
  done:
 	if (!found && aaaaok != NULL) {
 		for (i = 0; i < aaaaoklen; i++)
-			aaaaok[i] = true;
+			aaaaok[i] = ISC_TRUE;
 	}
-	return (found ? answer : true);
+	return (found ? answer : ISC_TRUE);
 }
