@@ -27,14 +27,11 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-#include <stdbool.h>
 #include <stdlib.h>
 #include <time.h>
 
 #include <isc/buffer.h>
 #include <isc/dir.h>
-#include <isc/entropy.h>
 #include <isc/fsaccess.h>
 #include <isc/hmacsha.h>
 #include <isc/lex.h>
@@ -69,10 +66,8 @@
 #define DST_AS_STR(t) ((t).value.as_textregion.base)
 
 static dst_func_t *dst_t_func[DST_MAX_ALGS];
-static isc_entropy_t *dst_entropy_pool = NULL;
-static unsigned int dst_entropy_flags = 0;
 
-static bool dst_initialized = false;
+static isc_boolean_t dst_initialized = ISC_FALSE;
 
 void gss_log(int level, const char *fmt, ...) ISC_FORMAT_PRINTF(2, 3);
 
@@ -128,7 +123,7 @@ static isc_result_t	addsuffix(char *filename, int len,
 			return (_r);		\
 	} while (0);				\
 
-#if defined(OPENSSL)
+#if HAVE_OPENSSL
 static void *
 default_memalloc(void *arg, size_t size) {
 	UNUSED(arg);
@@ -145,25 +140,17 @@ default_memfree(void *arg, void *ptr) {
 #endif
 
 isc_result_t
-dst_lib_init(isc_mem_t *mctx, isc_entropy_t *ectx, unsigned int eflags) {
-	return (dst_lib_init2(mctx, ectx, NULL, eflags));
-}
-
-isc_result_t
-dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
-	      const char *engine, unsigned int eflags) {
+dst_lib_init(isc_mem_t *mctx, const char *engine) {
 	isc_result_t result;
 
 	REQUIRE(mctx != NULL);
-	REQUIRE(dst_initialized == false);
+	REQUIRE(dst_initialized == ISC_FALSE);
 
-#if !defined(OPENSSL) && !defined(PKCS11CRYPTO)
 	UNUSED(engine);
-#endif
 
 	dst__memory_pool = NULL;
 
-#if defined(OPENSSL)
+#if HAVE_OPENSSL
 	UNUSED(mctx);
 	/*
 	 * When using --with-openssl, there seems to be no good way of not
@@ -179,15 +166,11 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 		return (result);
 	isc_mem_setname(dst__memory_pool, "dst", NULL);
 #ifndef OPENSSL_LEAKS
-	isc_mem_setdestroycheck(dst__memory_pool, false);
+	isc_mem_setdestroycheck(dst__memory_pool, ISC_FALSE);
 #endif
-#else /* OPENSSL */
+#else /* HAVE_OPENSSL */
 	isc_mem_attach(mctx, &dst__memory_pool);
-#endif /* OPENSSL */
-	if (ectx != NULL) {
-		isc_entropy_attach(ectx, &dst_entropy_pool);
-		dst_entropy_flags = eflags;
-	}
+#endif /* HAVE_OPENSSL */
 
 	dst_result_register();
 
@@ -200,7 +183,7 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 	RETERR(dst__hmacsha256_init(&dst_t_func[DST_ALG_HMACSHA256]));
 	RETERR(dst__hmacsha384_init(&dst_t_func[DST_ALG_HMACSHA384]));
 	RETERR(dst__hmacsha512_init(&dst_t_func[DST_ALG_HMACSHA512]));
-#ifdef OPENSSL
+#if HAVE_OPENSSL
 	RETERR(dst__openssl_init(engine));
 #ifndef PK11_MD5_DISABLE
 	RETERR(dst__opensslrsa_init(&dst_t_func[DST_ALG_RSAMD5],
@@ -234,7 +217,7 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 #ifdef HAVE_OPENSSL_ED448
 	RETERR(dst__openssleddsa_init(&dst_t_func[DST_ALG_ED448]));
 #endif
-#elif PKCS11CRYPTO
+#elif HAVE_PKCS11
 	RETERR(dst__pkcs11_init(mctx, engine));
 #ifndef PK11_MD5_DISABLE
 	RETERR(dst__pkcs11rsa_init(&dst_t_func[DST_ALG_RSAMD5]));
@@ -263,23 +246,17 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 #ifdef HAVE_PKCS11_GOST
 	RETERR(dst__pkcs11gost_init(&dst_t_func[DST_ALG_ECCGOST]));
 #endif
-#endif /* if OPENSSL, elif PKCS11CRYPTO */
+#endif /* if HAVE_OPENSSL, elif HAVE_PKCS11 */
 #ifdef GSSAPI
 	RETERR(dst__gssapi_init(&dst_t_func[DST_ALG_GSSAPI]));
 #endif
-#if defined(OPENSSL) || defined(PKCS11CRYPTO)
-#ifdef ISC_PLATFORM_CRYPTORANDOM
-	if (dst_entropy_pool != NULL) {
-		isc_entropy_sethook(dst_random_getdata);
-	}
-#endif
-#endif /* defined(OPENSSL) || defined(PKCS11CRYPTO) */
-	dst_initialized = true;
+
+	dst_initialized = ISC_TRUE;
 	return (ISC_R_SUCCESS);
 
  out:
 	/* avoid immediate crash! */
-	dst_initialized = true;
+	dst_initialized = ISC_TRUE;
 	dst_lib_destroy();
 	return (result);
 }
@@ -287,81 +264,55 @@ dst_lib_init2(isc_mem_t *mctx, isc_entropy_t *ectx,
 void
 dst_lib_destroy(void) {
 	int i;
-	RUNTIME_CHECK(dst_initialized == true);
-	dst_initialized = false;
+	RUNTIME_CHECK(dst_initialized == ISC_TRUE);
+	dst_initialized = ISC_FALSE;
 
 	for (i = 0; i < DST_MAX_ALGS; i++)
 		if (dst_t_func[i] != NULL && dst_t_func[i]->cleanup != NULL)
 			dst_t_func[i]->cleanup();
-#if defined(OPENSSL) || defined(PKCS11CRYPTO)
-#ifdef ISC_PLATFORM_CRYPTORANDOM
-	if (dst_entropy_pool != NULL) {
-		isc_entropy_usehook(dst_entropy_pool, false);
-		isc_entropy_sethook(NULL);
-	}
-#endif
-#ifdef OPENSSL
+#if HAVE_OPENSSL
 	dst__openssl_destroy();
-#elif PKCS11CRYPTO
+#elif HAVE_PKCS11
 	(void) dst__pkcs11_destroy();
-#endif /* if OPENSSL, elif PKCS11CRYPTO */
-#endif /* defined(OPENSSL) || defined(PKCS11CRYPTO) */
+#else
+#error Either OpenSSL or PKCS#11 cryptographic provider needed.
+#endif /* if HAVE_OPENSSL, elif HAVE_PKCS11 */
 	if (dst__memory_pool != NULL)
 		isc_mem_detach(&dst__memory_pool);
-	if (dst_entropy_pool != NULL)
-		isc_entropy_detach(&dst_entropy_pool);
 }
 
-bool
+isc_boolean_t
 dst_algorithm_supported(unsigned int alg) {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 
 	if (alg >= DST_MAX_ALGS || dst_t_func[alg] == NULL)
-		return (false);
-	return (true);
+		return (ISC_FALSE);
+	return (ISC_TRUE);
 }
 
-bool
+isc_boolean_t
 dst_ds_digest_supported(unsigned int digest_type) {
-	return  (digest_type == DNS_DSDIGEST_SHA1 ||
-		 digest_type == DNS_DSDIGEST_SHA256 ||
 #if defined(HAVE_OPENSSL_GOST) || defined(HAVE_PKCS11_GOST)
-		 digest_type == DNS_DSDIGEST_GOST ||
+	return  (ISC_TF(digest_type == DNS_DSDIGEST_SHA1 ||
+			digest_type == DNS_DSDIGEST_SHA256 ||
+			digest_type == DNS_DSDIGEST_GOST ||
+			digest_type == DNS_DSDIGEST_SHA384));
+#else
+	return  (ISC_TF(digest_type == DNS_DSDIGEST_SHA1 ||
+			digest_type == DNS_DSDIGEST_SHA256 ||
+			digest_type == DNS_DSDIGEST_SHA384));
 #endif
-		 digest_type == DNS_DSDIGEST_SHA384);
 }
 
 isc_result_t
-dst_context_create(dst_key_t *key, isc_mem_t *mctx, dst_context_t **dctxp) {
-	return (dst_context_create4(key, mctx, DNS_LOGCATEGORY_GENERAL,
-				    true, 0, dctxp));
-}
-
-isc_result_t
-dst_context_create2(dst_key_t *key, isc_mem_t *mctx,
-		    isc_logcategory_t *category, dst_context_t **dctxp)
-{
-	return (dst_context_create4(key, mctx, category, true, 0, dctxp));
-}
-
-isc_result_t
-dst_context_create3(dst_key_t *key, isc_mem_t *mctx,
-		    isc_logcategory_t *category, bool useforsigning,
-		    dst_context_t **dctxp)
-{
-	return (dst_context_create4(key, mctx, category,
-				    useforsigning, 0, dctxp));
-}
-
-isc_result_t
-dst_context_create4(dst_key_t *key, isc_mem_t *mctx,
-		    isc_logcategory_t *category, bool useforsigning,
-		    int maxbits, dst_context_t **dctxp)
+dst_context_create(dst_key_t *key, isc_mem_t *mctx,
+		   isc_logcategory_t *category, isc_boolean_t useforsigning,
+		   int maxbits, dst_context_t **dctxp)
 {
 	dst_context_t *dctx;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(mctx != NULL);
 	REQUIRE(dctxp != NULL && *dctxp == NULL);
@@ -438,7 +389,7 @@ dst_context_sign(dst_context_t *dctx, isc_buffer_t *sig) {
 	if (key->func->sign == NULL)
 		return (DST_R_NOTPRIVATEKEY);
 	if (key->func->isprivate == NULL ||
-	    key->func->isprivate(key) == false)
+	    key->func->isprivate(key) == ISC_FALSE)
 		return (DST_R_NOTPRIVATEKEY);
 
 	return (key->func->sign(dctx, sig));
@@ -481,7 +432,7 @@ isc_result_t
 dst_key_computesecret(const dst_key_t *pub, const dst_key_t *priv,
 		      isc_buffer_t *secret)
 {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(pub) && VALID_KEY(priv));
 	REQUIRE(secret != NULL);
 
@@ -496,7 +447,7 @@ dst_key_computesecret(const dst_key_t *pub, const dst_key_t *priv,
 	    priv->func->computesecret == NULL)
 		return (DST_R_KEYCANNOTCOMPUTESECRET);
 
-	if (dst_key_isprivate(priv) == false)
+	if (dst_key_isprivate(priv) == ISC_FALSE)
 		return (DST_R_NOTPRIVATEKEY);
 
 	return (pub->func->computesecret(pub, priv, secret));
@@ -506,7 +457,7 @@ isc_result_t
 dst_key_tofile(const dst_key_t *key, int type, const char *directory) {
 	isc_result_t ret = ISC_R_SUCCESS;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 
@@ -515,13 +466,13 @@ dst_key_tofile(const dst_key_t *key, int type, const char *directory) {
 	if (key->func->tofile == NULL)
 		return (DST_R_UNSUPPORTEDALG);
 
-	if ((type & DST_TYPE_PUBLIC) != 0) {
+	if (type & DST_TYPE_PUBLIC) {
 		ret = write_public_key(key, type, directory);
 		if (ret != ISC_R_SUCCESS)
 			return (ret);
 	}
 
-	if (((type & DST_TYPE_PRIVATE) != 0) &&
+	if ((type & DST_TYPE_PRIVATE) &&
 	    (key->key_flags & DNS_KEYFLAG_TYPEMASK) != DNS_KEYTYPE_NOKEY)
 		return (key->func->tofile(key, directory));
 	else
@@ -529,11 +480,11 @@ dst_key_tofile(const dst_key_t *key, int type, const char *directory) {
 }
 
 void
-dst_key_setexternal(dst_key_t *key, bool value) {
+dst_key_setexternal(dst_key_t *key, isc_boolean_t value) {
 	key->external = value;
 }
 
-bool
+isc_boolean_t
 dst_key_isexternal(dst_key_t *key) {
 	return (key->external);
 }
@@ -545,7 +496,7 @@ dst_key_getfilename(dns_name_t *name, dns_keytag_t id,
 {
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -574,7 +525,7 @@ dst_key_fromfile(dns_name_t *name, dns_keytag_t id,
 	isc_buffer_t buf;
 	dst_key_t *key;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -623,7 +574,7 @@ dst_key_fromnamedfile(const char *filename, const char *dirname,
 	int newfilenamelen = 0;
 	isc_lex_t *lex = NULL;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(filename != NULL);
 	REQUIRE((type & (DST_TYPE_PRIVATE | DST_TYPE_PUBLIC)) != 0);
 	REQUIRE(mctx != NULL);
@@ -722,7 +673,7 @@ dst_key_fromnamedfile(const char *filename, const char *dirname,
 
 isc_result_t
 dst_key_todns(const dst_key_t *key, isc_buffer_t *target) {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(target != NULL);
 
@@ -733,15 +684,15 @@ dst_key_todns(const dst_key_t *key, isc_buffer_t *target) {
 
 	if (isc_buffer_availablelength(target) < 4)
 		return (ISC_R_NOSPACE);
-	isc_buffer_putuint16(target, (uint16_t)(key->key_flags & 0xffff));
-	isc_buffer_putuint8(target, (uint8_t)key->key_proto);
-	isc_buffer_putuint8(target, (uint8_t)key->key_alg);
+	isc_buffer_putuint16(target, (isc_uint16_t)(key->key_flags & 0xffff));
+	isc_buffer_putuint8(target, (isc_uint8_t)key->key_proto);
+	isc_buffer_putuint8(target, (isc_uint8_t)key->key_alg);
 
-	if ((key->key_flags & DNS_KEYFLAG_EXTENDED) != 0) {
+	if (key->key_flags & DNS_KEYFLAG_EXTENDED) {
 		if (isc_buffer_availablelength(target) < 2)
 			return (ISC_R_NOSPACE);
 		isc_buffer_putuint16(target,
-				     (uint16_t)((key->key_flags >> 16)
+				     (isc_uint16_t)((key->key_flags >> 16)
 						    & 0xffff));
 	}
 
@@ -755,8 +706,8 @@ isc_result_t
 dst_key_fromdns(const dns_name_t *name, dns_rdataclass_t rdclass,
 		isc_buffer_t *source, isc_mem_t *mctx, dst_key_t **keyp)
 {
-	uint8_t alg, proto;
-	uint32_t flags, extflags;
+	isc_uint8_t alg, proto;
+	isc_uint32_t flags, extflags;
 	dst_key_t *key = NULL;
 	dns_keytag_t id, rid;
 	isc_region_t r;
@@ -775,7 +726,7 @@ dst_key_fromdns(const dns_name_t *name, dns_rdataclass_t rdclass,
 	id = dst_region_computeid(&r, alg);
 	rid = dst_region_computerid(&r, alg);
 
-	if ((flags & DNS_KEYFLAG_EXTENDED) != 0) {
+	if (flags & DNS_KEYFLAG_EXTENDED) {
 		if (isc_buffer_remaininglength(source) < 2)
 			return (DST_R_INVALIDPUBLICKEY);
 		extflags = isc_buffer_getuint16(source);
@@ -821,7 +772,7 @@ dst_key_frombuffer(const dns_name_t *name, unsigned int alg,
 
 isc_result_t
 dst_key_tobuffer(const dst_key_t *key, isc_buffer_t *target) {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(target != NULL);
 
@@ -838,7 +789,7 @@ dst_key_privatefrombuffer(dst_key_t *key, isc_buffer_t *buffer) {
 	isc_lex_t *lex = NULL;
 	isc_result_t result = ISC_R_SUCCESS;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(!dst_key_isprivate(key));
 	REQUIRE(buffer != NULL);
@@ -892,9 +843,6 @@ dst_key_fromgssapi(const dns_name_t *name, gss_ctx_id_t gssctx,
 	*keyp = key;
 	result = ISC_R_SUCCESS;
 out:
-	if (result != ISC_R_SUCCESS) {
-		dst_key_free(&key);
-	}
 	return result;
 }
 
@@ -907,7 +855,7 @@ dst_key_buildinternal(const dns_name_t *name, unsigned int alg,
 	dst_key_t *key;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -941,7 +889,7 @@ dst_key_fromlabel(const dns_name_t *name, int alg, unsigned int flags,
 	dst_key_t *key;
 	isc_result_t result;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -979,24 +927,13 @@ dst_key_generate(const dns_name_t *name, unsigned int alg,
 		 unsigned int bits, unsigned int param,
 		 unsigned int flags, unsigned int protocol,
 		 dns_rdataclass_t rdclass,
-		 isc_mem_t *mctx, dst_key_t **keyp)
-{
-	return (dst_key_generate2(name, alg, bits, param, flags, protocol,
-				  rdclass, mctx, keyp, NULL));
-}
-
-isc_result_t
-dst_key_generate2(const dns_name_t *name, unsigned int alg,
-		  unsigned int bits, unsigned int param,
-		  unsigned int flags, unsigned int protocol,
-		  dns_rdataclass_t rdclass,
-		  isc_mem_t *mctx, dst_key_t **keyp,
-		  void (*callback)(int))
+		 isc_mem_t *mctx, dst_key_t **keyp,
+		 void (*callback)(int))
 {
 	dst_key_t *key;
 	isc_result_t ret;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(dns_name_isabsolute(name));
 	REQUIRE(mctx != NULL);
 	REQUIRE(keyp != NULL && *keyp == NULL);
@@ -1036,7 +973,7 @@ dst_key_generate2(const dns_name_t *name, unsigned int alg,
 }
 
 isc_result_t
-dst_key_getnum(const dst_key_t *key, int type, uint32_t *valuep)
+dst_key_getnum(const dst_key_t *key, int type, isc_uint32_t *valuep)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(valuep != NULL);
@@ -1048,12 +985,12 @@ dst_key_getnum(const dst_key_t *key, int type, uint32_t *valuep)
 }
 
 void
-dst_key_setnum(dst_key_t *key, int type, uint32_t value)
+dst_key_setnum(dst_key_t *key, int type, isc_uint32_t value)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_NUMERIC);
 	key->nums[type] = value;
-	key->numset[type] = true;
+	key->numset[type] = ISC_TRUE;
 }
 
 void
@@ -1061,7 +998,7 @@ dst_key_unsetnum(dst_key_t *key, int type)
 {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_NUMERIC);
-	key->numset[type] = false;
+	key->numset[type] = ISC_FALSE;
 }
 
 isc_result_t
@@ -1080,14 +1017,14 @@ dst_key_settime(dst_key_t *key, int type, isc_stdtime_t when) {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_TIMES);
 	key->times[type] = when;
-	key->timeset[type] = true;
+	key->timeset[type] = ISC_TRUE;
 }
 
 void
 dst_key_unsettime(dst_key_t *key, int type) {
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(type <= DST_MAX_TIMES);
-	key->timeset[type] = false;
+	key->timeset[type] = ISC_FALSE;
 }
 
 isc_result_t
@@ -1107,41 +1044,41 @@ dst_key_setprivateformat(dst_key_t *key, int major, int minor) {
 	key->fmt_minor = minor;
 }
 
-static bool
+static isc_boolean_t
 comparekeys(const dst_key_t *key1, const dst_key_t *key2,
-	    bool match_revoked_key,
-	    bool (*compare)(const dst_key_t *key1,
+	    isc_boolean_t match_revoked_key,
+	    isc_boolean_t (*compare)(const dst_key_t *key1,
 				     const dst_key_t *key2))
 {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key1));
 	REQUIRE(VALID_KEY(key2));
 
 	if (key1 == key2)
-		return (true);
+		return (ISC_TRUE);
 
 	if (key1->key_alg != key2->key_alg)
-		return (false);
+		return (ISC_FALSE);
 
 	if (key1->key_id != key2->key_id) {
 		if (!match_revoked_key)
-			return (false);
+			return (ISC_FALSE);
 #ifndef PK11_MD5_DISABLE
 		if (key1->key_alg == DST_ALG_RSAMD5)
-			return (false);
+			return (ISC_FALSE);
 #endif
 		if ((key1->key_flags & DNS_KEYFLAG_REVOKE) ==
 		    (key2->key_flags & DNS_KEYFLAG_REVOKE))
-			return (false);
+			return (ISC_FALSE);
 		if (key1->key_id != key2->key_rid &&
 		    key1->key_rid != key2->key_id)
-			return (false);
+			return (ISC_FALSE);
 	}
 
 	if (compare != NULL)
 		return (compare(key1, key2));
 	else
-		return (false);
+		return (ISC_FALSE);
 }
 
 
@@ -1149,7 +1086,7 @@ comparekeys(const dst_key_t *key1, const dst_key_t *key2,
  * Compares only the public portion of two keys, by converting them
  * both to wire format and comparing the results.
  */
-static bool
+static isc_boolean_t
 pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_result_t result;
 	unsigned char buf1[DST_KEY_MAXSIZE], buf2[DST_KEY_MAXSIZE];
@@ -1159,7 +1096,7 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_buffer_init(&b1, buf1, sizeof(buf1));
 	result = dst_key_todns(key1, &b1);
 	if (result != ISC_R_SUCCESS)
-		return (false);
+		return (ISC_FALSE);
 	/* Zero out flags. */
 	buf1[0] = buf1[1] = 0;
 	if ((key1->key_flags & DNS_KEYFLAG_EXTENDED) != 0)
@@ -1168,7 +1105,7 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	isc_buffer_init(&b2, buf2, sizeof(buf2));
 	result = dst_key_todns(key2, &b2);
 	if (result != ISC_R_SUCCESS)
-		return (false);
+		return (ISC_FALSE);
 	/* Zero out flags. */
 	buf2[0] = buf2[1] = 0;
 	if ((key2->key_flags & DNS_KEYFLAG_EXTENDED) != 0)
@@ -1187,42 +1124,42 @@ pub_compare(const dst_key_t *key1, const dst_key_t *key2) {
 		memmove(&buf2[4], &buf2[6], r2.length - 6);
 		r2.length -= 2;
 	}
-	return (isc_region_compare(&r1, &r2) == 0);
+	return (ISC_TF(isc_region_compare(&r1, &r2) == 0));
 }
 
-bool
+isc_boolean_t
 dst_key_compare(const dst_key_t *key1, const dst_key_t *key2) {
-	return (comparekeys(key1, key2, false, key1->func->compare));
+	return (comparekeys(key1, key2, ISC_FALSE, key1->func->compare));
 }
 
-bool
+isc_boolean_t
 dst_key_pubcompare(const dst_key_t *key1, const dst_key_t *key2,
-		   bool match_revoked_key)
+		   isc_boolean_t match_revoked_key)
 {
 	return (comparekeys(key1, key2, match_revoked_key, pub_compare));
 }
 
 
-bool
+isc_boolean_t
 dst_key_paramcompare(const dst_key_t *key1, const dst_key_t *key2) {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key1));
 	REQUIRE(VALID_KEY(key2));
 
 	if (key1 == key2)
-		return (true);
+		return (ISC_TRUE);
 	if (key1->key_alg == key2->key_alg &&
 	    key1->func->paramcompare != NULL &&
-	    key1->func->paramcompare(key1, key2) == true)
-		return (true);
+	    key1->func->paramcompare(key1, key2) == ISC_TRUE)
+		return (ISC_TRUE);
 	else
-		return (false);
+		return (ISC_FALSE);
 }
 
 void
 dst_key_attach(dst_key_t *source, dst_key_t **target) {
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(target != NULL && *target == NULL);
 	REQUIRE(VALID_KEY(source));
 
@@ -1236,7 +1173,7 @@ dst_key_free(dst_key_t **keyp) {
 	dst_key_t *key;
 	unsigned int refs;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(keyp != NULL && VALID_KEY(*keyp));
 
 	key = *keyp;
@@ -1265,7 +1202,7 @@ dst_key_free(dst_key_t **keyp) {
 	*keyp = NULL;
 }
 
-bool
+isc_boolean_t
 dst_key_isprivate(const dst_key_t *key) {
 	REQUIRE(VALID_KEY(key));
 	INSIST(key->func->isprivate != NULL);
@@ -1286,7 +1223,7 @@ dst_key_buildfilename(const dst_key_t *key, int type,
 
 isc_result_t
 dst_key_sigsize(const dst_key_t *key, unsigned int *n) {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(n != NULL);
 
@@ -1356,7 +1293,7 @@ dst_key_sigsize(const dst_key_t *key, unsigned int *n) {
 
 isc_result_t
 dst_key_secretsize(const dst_key_t *key, unsigned int *n) {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key));
 	REQUIRE(n != NULL);
 
@@ -1375,7 +1312,7 @@ dst_key_secretsize(const dst_key_t *key, unsigned int *n) {
  * Set the flags on a key, then recompute the key ID
  */
 isc_result_t
-dst_key_setflags(dst_key_t *key, uint32_t flags) {
+dst_key_setflags(dst_key_t *key, isc_uint32_t flags) {
 	REQUIRE(VALID_KEY(key));
 	key->key_flags = flags;
 	return (computeid(key));
@@ -1412,7 +1349,7 @@ dst_key_restore(dns_name_t *name, unsigned int alg, unsigned int flags,
 	isc_result_t result;
 	dst_key_t *key;
 
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(keyp != NULL && *keyp == NULL);
 
 	if (alg >= DST_MAX_ALGS || dst_t_func[alg] == NULL)
@@ -1491,14 +1428,14 @@ get_key_struct(const dns_name_t *name, unsigned int alg,
 	key->fmt_minor = 0;
 	for (i = 0; i < (DST_MAX_TIMES + 1); i++) {
 		key->times[i] = 0;
-		key->timeset[i] = false;
+		key->timeset[i] = ISC_FALSE;
 	}
-	key->inactive = false;
+	key->inactive = ISC_FALSE;
 	key->magic = KEY_MAGIC;
 	return (key);
 }
 
-bool
+isc_boolean_t
 dst_key_inactive(const dst_key_t *key) {
 
 	REQUIRE(VALID_KEY(key));
@@ -1507,7 +1444,7 @@ dst_key_inactive(const dst_key_t *key) {
 }
 
 void
-dst_key_setinactive(dst_key_t *key, bool inactive) {
+dst_key_setinactive(dst_key_t *key, isc_boolean_t inactive) {
 
 	REQUIRE(VALID_KEY(key));
 
@@ -1531,7 +1468,7 @@ dst_key_read_public(const char *filename, int type,
 	unsigned int opt = ISC_LEXOPT_DNSMULTILINE;
 	dns_rdataclass_t rdclass = dns_rdataclass_in;
 	isc_lexspecials_t specials;
-	uint32_t ttl = 0;
+	isc_uint32_t ttl = 0;
 	isc_result_t result;
 	dns_rdatatype_t keytype;
 
@@ -1623,7 +1560,7 @@ dst_key_read_public(const char *filename, int type,
 
 	isc_buffer_init(&b, rdatabuf, sizeof(rdatabuf));
 	ret = dns_rdata_fromtext(&rdata, rdclass, keytype, lex, NULL,
-				 false, mctx, &b, NULL);
+				 ISC_FALSE, mctx, &b, NULL);
 	if (ret != ISC_R_SUCCESS)
 		goto cleanup;
 
@@ -1640,9 +1577,9 @@ dst_key_read_public(const char *filename, int type,
 	return (ret);
 }
 
-static bool
+static isc_boolean_t
 issymmetric(const dst_key_t *key) {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 	REQUIRE(VALID_KEY(key));
 
 	/* XXXVIX this switch statement is too sparse to gen a jump table. */
@@ -1666,7 +1603,7 @@ issymmetric(const dst_key_t *key) {
 	case DST_ALG_ECDSA384:
 	case DST_ALG_ED25519:
 	case DST_ALG_ED448:
-		return (false);
+		return (ISC_FALSE);
 #ifndef PK11_MD5_DISABLE
 	case DST_ALG_HMACMD5:
 #endif
@@ -1676,9 +1613,9 @@ issymmetric(const dst_key_t *key) {
 	case DST_ALG_HMACSHA384:
 	case DST_ALG_HMACSHA512:
 	case DST_ALG_GSSAPI:
-		return (true);
+		return (ISC_TRUE);
 	default:
-		return (false);
+		return (ISC_FALSE);
 	}
 }
 
@@ -1870,7 +1807,7 @@ buildfilename(dns_name_t *name, dns_keytag_t id,
 	if (isc_buffer_availablelength(out) < 1)
 		return (ISC_R_NOSPACE);
 	isc_buffer_putstr(out, "K");
-	result = dns_name_tofilenametext(name, false, out);
+	result = dns_name_tofilenametext(name, ISC_FALSE, out);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
@@ -1936,21 +1873,11 @@ frombuffer(const dns_name_t *name, unsigned int alg, unsigned int flags,
 
 static isc_result_t
 algorithm_status(unsigned int alg) {
-	REQUIRE(dst_initialized == true);
+	REQUIRE(dst_initialized == ISC_TRUE);
 
-	if (dst_algorithm_supported(alg))
+	if (dst_algorithm_supported(alg)) {		
 		return (ISC_R_SUCCESS);
-#if !defined(OPENSSL) && !defined(PKCS11CRYPTO)
-	if (alg == DST_ALG_RSAMD5 || alg == DST_ALG_RSASHA1 ||
-	    alg == DST_ALG_DSA || alg == DST_ALG_DH ||
-	    alg == DST_ALG_HMACMD5 || alg == DST_ALG_NSEC3DSA ||
-	    alg == DST_ALG_NSEC3RSASHA1 ||
-	    alg == DST_ALG_RSASHA256 || alg == DST_ALG_RSASHA512 ||
-	    alg == DST_ALG_ECCGOST ||
-	    alg == DST_ALG_ECDSA256 || alg == DST_ALG_ECDSA384 ||
-	    alg == DST_ALG_ED25519 || alg == DST_ALG_ED448)
-		return (DST_R_NOCRYPTO);
-#endif
+	}
 	return (DST_R_UNSUPPORTEDALG);
 }
 
@@ -1980,65 +1907,6 @@ addsuffix(char *filename, int len, const char *odirname,
 	return (ISC_R_SUCCESS);
 }
 
-isc_result_t
-dst__entropy_getdata(void *buf, unsigned int len, bool pseudo) {
-	unsigned int flags = dst_entropy_flags;
-
-	if (dst_entropy_pool == NULL)
-		return (ISC_R_FAILURE);
-
-	if (len == 0)
-		return (ISC_R_SUCCESS);
-
-#ifdef PKCS11CRYPTO
-	UNUSED(pseudo);
-	UNUSED(flags);
-	return (pk11_rand_bytes(buf, len));
-#else /* PKCS11CRYPTO */
-	if (pseudo)
-		flags &= ~ISC_ENTROPY_GOODONLY;
-	else
-		flags |= ISC_ENTROPY_BLOCKING;
-#ifdef ISC_PLATFORM_CRYPTORANDOM
-	/* get entropy directly from crypto provider */
-	return (dst_random_getdata(buf, len, NULL, flags));
-#else
-	/* get entropy from entropy source or hook function */
-	return (isc_entropy_getdata(dst_entropy_pool, buf, len, NULL, flags));
-#endif /* ISC_PLATFORM_CRYPTORANDOM */
-#endif /* PKCS11CRYPTO */
-}
-
-unsigned int
-dst__entropy_status(void) {
-#if !defined(PKCS11CRYPTO) && !defined(ISC_PLATFORM_CRYPTORANDOM)
-#ifdef GSSAPI
-	unsigned int flags = dst_entropy_flags;
-	isc_result_t ret;
-	unsigned char buf[32];
-	static bool first = true;
-
-	if (dst_entropy_pool == NULL)
-		return (0);
-
-	if (first) {
-		/* Someone believes RAND_status() initializes the PRNG */
-		flags &= ~ISC_ENTROPY_GOODONLY;
-		ret = isc_entropy_getdata(dst_entropy_pool, buf,
-					  sizeof(buf), NULL, flags);
-		INSIST(ret == ISC_R_SUCCESS);
-		isc_entropy_putdata(dst_entropy_pool, buf,
-				    sizeof(buf), 2 * sizeof(buf));
-		first = false;
-	}
-#endif
-	return (isc_entropy_status(dst_entropy_pool));
-#else
-	/* Doesn't matter as it is not used in this case. */
-	return (0);
-#endif
-}
-
 isc_buffer_t *
 dst_key_tkeytoken(const dst_key_t *key) {
 	REQUIRE(VALID_KEY(key));
