@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -26,8 +26,6 @@
  *** Imports
  ***/
 
-#include <inttypes.h>
-
 #include <isc/lang.h>
 #include <isc/types.h>
 
@@ -38,11 +36,11 @@ ISC_LANG_BEGINDECLS
 #define DNS_SOA_BUFFERSIZE      ((2 * DNS_NAME_MAXWIRE) + (4 * 5))
 
 isc_result_t
-dns_soa_buildrdata(dns_name_t *origin, dns_name_t *contact,
+dns_soa_buildrdata(const dns_name_t *origin, const dns_name_t *contact,
 		   dns_rdataclass_t rdclass,
-		   uint32_t serial, uint32_t refresh,
-		   uint32_t retry, uint32_t expire,
-		   uint32_t minimum, unsigned char *buffer,
+		   isc_uint32_t serial, isc_uint32_t refresh,
+		   isc_uint32_t retry, isc_uint32_t expire,
+		   isc_uint32_t minimum, unsigned char *buffer,
 		   dns_rdata_t *rdata);
 /*%<
  * Build the rdata of an SOA record.
@@ -57,15 +55,15 @@ dns_soa_buildrdata(dns_name_t *origin, dns_name_t *contact,
  *  			refers to 'buffer'.
  */
 
-uint32_t
+isc_uint32_t
 dns_soa_getserial(dns_rdata_t *rdata);
-uint32_t
+isc_uint32_t
 dns_soa_getrefresh(dns_rdata_t *rdata);
-uint32_t
+isc_uint32_t
 dns_soa_getretry(dns_rdata_t *rdata);
-uint32_t
+isc_uint32_t
 dns_soa_getexpire(dns_rdata_t *rdata);
-uint32_t
+isc_uint32_t
 dns_soa_getminimum(dns_rdata_t *rdata);
 /*
  * Extract an integer field from the rdata of a SOA record.
@@ -75,15 +73,15 @@ dns_soa_getminimum(dns_rdata_t *rdata);
  */
 
 void
-dns_soa_setserial(uint32_t val, dns_rdata_t *rdata);
+dns_soa_setserial(isc_uint32_t val, dns_rdata_t *rdata);
 void
-dns_soa_setrefresh(uint32_t val, dns_rdata_t *rdata);
+dns_soa_setrefresh(isc_uint32_t val, dns_rdata_t *rdata);
 void
-dns_soa_setretry(uint32_t val, dns_rdata_t *rdata);
+dns_soa_setretry(isc_uint32_t val, dns_rdata_t *rdata);
 void
-dns_soa_setexpire(uint32_t val, dns_rdata_t *rdata);
+dns_soa_setexpire(isc_uint32_t val, dns_rdata_t *rdata);
 void
-dns_soa_setminimum(uint32_t val, dns_rdata_t *rdata);
+dns_soa_setminimum(isc_uint32_t val, dns_rdata_t *rdata);
 /*
  * Change an integer field of a SOA record by modifying the
  * rdata in-place.
