@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -15,8 +15,6 @@
 
 /*! \file dns/zt.h */
 
-#include <stdbool.h>
-
 #include <isc/lang.h>
 
 #include <dns/types.h>
@@ -140,21 +138,17 @@ dns_zt_attach(dns_zt_t *zt, dns_zt_t **ztp);
  */
 
 isc_result_t
-dns_zt_load(dns_zt_t *zt, bool stop);
+dns_zt_load(dns_zt_t *zt, isc_boolean_t stop);
 
 isc_result_t
-dns_zt_loadnew(dns_zt_t *zt, bool stop);
+dns_zt_loadnew(dns_zt_t *zt, isc_boolean_t stop);
 
 isc_result_t
 dns_zt_asyncload(dns_zt_t *zt, dns_zt_allloaded_t alldone, void *arg);
-
-isc_result_t
-dns_zt_asyncload2(dns_zt_t *zt, dns_zt_allloaded_t alldone, void *arg,
-		  bool newonly);
 /*%<
- * Load all zones in the table.  If 'stop' is true,
+ * Load all zones in the table.  If 'stop' is ISC_TRUE,
  * stop on the first error and return it.  If 'stop'
- * is false, ignore errors.
+ * is ISC_FALSE, ignore errors.
  *
  * dns_zt_loadnew() only loads zones that are not yet loaded.
  * dns_zt_load() also loads zones that are already loaded and
@@ -169,7 +163,7 @@ dns_zt_asyncload2(dns_zt_t *zt, dns_zt_allloaded_t alldone, void *arg,
  */
 
 isc_result_t
-dns_zt_freezezones(dns_zt_t *zt, bool freeze);
+dns_zt_freezezones(dns_zt_t *zt, isc_boolean_t freeze);
 /*%<
  * Freeze/thaw updates to master zones.
  * Any pending updates will be flushed.
@@ -177,15 +171,11 @@ dns_zt_freezezones(dns_zt_t *zt, bool freeze);
  */
 
 isc_result_t
-dns_zt_apply(dns_zt_t *zt, bool stop,
+dns_zt_apply(dns_zt_t *zt, isc_boolean_t stop, isc_result_t *sub,
 	     isc_result_t (*action)(dns_zone_t *, void *), void *uap);
-
-isc_result_t
-dns_zt_apply2(dns_zt_t *zt, bool stop, isc_result_t *sub,
-	      isc_result_t (*action)(dns_zone_t *, void *), void *uap);
 /*%<
  * Apply a given 'action' to all zone zones in the table.
- * If 'stop' is 'true' then walking the zone tree will stop if
+ * If 'stop' is 'ISC_TRUE' then walking the zone tree will stop if
  * 'action' does not return ISC_R_SUCCESS.
  *
  * Requires:
@@ -194,15 +184,15 @@ dns_zt_apply2(dns_zt_t *zt, bool stop, isc_result_t *sub,
  *
  * Returns:
  * \li	ISC_R_SUCCESS if action was applied to all nodes.  If 'stop' is
- *	false and 'sub' is non NULL then the first error (if any)
+ *	ISC_FALSE and 'sub' is non NULL then the first error (if any)
  *	reported by 'action' is returned in '*sub';
  *	any error code from 'action'.
  */
 
-bool
+isc_boolean_t
 dns_zt_loadspending(dns_zt_t *zt);
 /*%<
- * Returns true if and only if there are zones still waiting to
+ * Returns ISC_TRUE if and only if there are zones still waiting to
  * be loaded in zone table 'zt'.
  *
  * Requires:
