@@ -1,13 +1,14 @@
 /*
- * Copyright (C) 1999-2009, 2011-2018  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
-/* $Id$ */
-
 /*! \file */
 
 #include <config.h>
@@ -595,8 +596,7 @@ loadctx_create(dns_masterformat_t format, isc_mem_t *mctx,
 	lctx->include_arg = include_arg;
 	isc_stdtime_get(&lctx->now);
 
-	dns_fixedname_init(&lctx->fixed_top);
-	lctx->top = dns_fixedname_name(&lctx->fixed_top);
+	lctx->top = dns_fixedname_initname(&lctx->fixed_top);
 	dns_name_toregion(top, &r);
 	dns_name_fromregion(lctx->top, &r);
 
@@ -794,8 +794,7 @@ generate(dns_loadctx_t *lctx, char *range, char *lhs, char *gtype, char *rhs,
 
 	ictx = lctx->inc;
 	callbacks = lctx->callbacks;
-	dns_fixedname_init(&ownerfixed);
-	owner = dns_fixedname_name(&ownerfixed);
+	owner = dns_fixedname_initname(&ownerfixed);
 	ISC_LIST_INIT(head);
 
 	target_mem = isc_mem_get(lctx->mctx, target_size);
@@ -975,7 +974,7 @@ check_ns(dns_loadctx_t *lctx, isc_token_t *token, const char *source,
 		 */
 		if (tmp[strlen(tmp) - 1] == '.')
 			tmp[strlen(tmp) - 1] = '\0';
-		if (inet_aton(tmp, &addr) == 1 ||
+		if (inet_pton(AF_INET, tmp, &addr) == 1 ||
 		    inet_pton(AF_INET6, tmp, &addr6) == 1)
 			result = DNS_R_NSISADDRESS;
 	}
@@ -1339,8 +1338,9 @@ load_text(dns_loadctx_t *lctx) {
 					if (MANYERRS(lctx, result)) {
 						SETRESULT(lctx, result);
 						lctx->ttl = 0;
-					} else if (result != ISC_R_SUCCESS)
+					} else {
 						goto insist_and_cleanup;
+					}
 				} else if (!explicit_ttl &&
 					   lctx->default_ttl_known) {
 					lctx->ttl = lctx->default_ttl;
@@ -1371,8 +1371,9 @@ load_text(dns_loadctx_t *lctx) {
 				result = DNS_R_SYNTAX;
 				if (MANYERRS(lctx, result)) {
 					SETRESULT(lctx, result);
-				} else if (result != ISC_R_SUCCESS)
+				} else {
 					goto insist_and_cleanup;
+				}
 			}
 
 			/*
@@ -1384,8 +1385,8 @@ load_text(dns_loadctx_t *lctx) {
 				if (!ictx->in_use[new_in_use])
 					break;
 			INSIST(new_in_use < NBUFS);
-			dns_fixedname_init(&ictx->fixed[new_in_use]);
-			new_name = dns_fixedname_name(&ictx->fixed[new_in_use]);
+			new_name =
+			      dns_fixedname_initname(&ictx->fixed[new_in_use]);
 			isc_buffer_init(&buffer, token.value.as_region.base,
 					token.value.as_region.length);
 			isc_buffer_add(&buffer, token.value.as_region.length);
@@ -1543,8 +1544,9 @@ load_text(dns_loadctx_t *lctx) {
 				SETRESULT(lctx, result);
 				LOGIT(result);
 				continue;
-			} else if (result != ISC_R_SUCCESS)
+			} else {
 				goto insist_and_cleanup;
+			}
 		}
 
 		/*
@@ -1583,8 +1585,9 @@ load_text(dns_loadctx_t *lctx) {
 					SETRESULT(lctx, result);
 					read_till_eol = ISC_TRUE;
 					continue;
-				} else if (result != ISC_R_SUCCESS)
+				} else {
 					goto insist_and_cleanup;
+				}
 			}
 
 			if (ictx->origin_changed) {
@@ -1627,8 +1630,9 @@ load_text(dns_loadctx_t *lctx) {
 				SETRESULT(lctx, result);
 				read_till_eol = ISC_TRUE;
 				continue;
-			} else if (result != ISC_R_SUCCESS)
+			} else {
 				goto insist_and_cleanup;
+			}
 		}
 
 		if (rdclass == 0 &&
@@ -1645,8 +1649,9 @@ load_text(dns_loadctx_t *lctx) {
 				SETRESULT(lctx, result);
 				read_till_eol = ISC_TRUE;
 				continue;
-			} else if (result != ISC_R_SUCCESS)
+			} else {
 				goto insist_and_cleanup;
+			}
 		}
 
 		result = dns_rdatatype_fromtext(&type,
@@ -1686,8 +1691,9 @@ load_text(dns_loadctx_t *lctx) {
 				SETRESULT(lctx, result);
 				read_till_eol = ISC_TRUE;
 				continue;
-			} else if (result != ISC_R_SUCCESS)
+			} else {
 				goto insist_and_cleanup;
+			}
 		}
 
 		if (type == dns_rdatatype_ns && ictx->glue == NULL)
@@ -1799,8 +1805,9 @@ load_text(dns_loadctx_t *lctx) {
 							    namebuf, desc);
 					if (MANYERRS(lctx, result)) {
 						SETRESULT(lctx, result);
-					} else if (result != ISC_R_SUCCESS)
+					} else {
 						goto cleanup;
+					}
 				} else {
 					(*callbacks->warn)(callbacks,
 							   "%s:%lu: %s: %s",
@@ -1851,8 +1858,9 @@ load_text(dns_loadctx_t *lctx) {
 				read_till_eol = ISC_TRUE;
 				target = target_ft;
 				continue;
-			} else if (result != ISC_R_SUCCESS)
+			} else {
 				goto insist_and_cleanup;
+			}
 		}
 
 		if (type == dns_rdatatype_rrsig ||
@@ -2330,8 +2338,7 @@ load_raw(dns_loadctx_t *lctx) {
 	}
 	isc_buffer_init(&target, target_mem, target_size);
 
-	dns_fixedname_init(&fixed);
-	name = dns_fixedname_name(&fixed);
+	name = dns_fixedname_initname(&fixed);
 
 	/*
 	 * In the following loop, we regard any error fatal regardless of
@@ -2585,61 +2592,12 @@ load_raw(dns_loadctx_t *lctx) {
 
 isc_result_t
 dns_master_loadfile(const char *master_file, dns_name_t *top,
-		    dns_name_t *origin,
-		    dns_rdataclass_t zclass, unsigned int options,
-		    dns_rdatacallbacks_t *callbacks, isc_mem_t *mctx)
-{
-	return (dns_master_loadfile5(master_file, top, origin, zclass,
-				     options, 0, callbacks, NULL, NULL,
-				     mctx, dns_masterformat_text, 0));
-}
-
-isc_result_t
-dns_master_loadfile2(const char *master_file, dns_name_t *top,
-		     dns_name_t *origin,
-		     dns_rdataclass_t zclass, unsigned int options,
-		     dns_rdatacallbacks_t *callbacks, isc_mem_t *mctx,
-		     dns_masterformat_t format)
-{
-	return (dns_master_loadfile5(master_file, top, origin, zclass,
-				     options, 0, callbacks, NULL, NULL,
-				     mctx, format, 0));
-}
-
-isc_result_t
-dns_master_loadfile3(const char *master_file, dns_name_t *top,
-		     dns_name_t *origin, dns_rdataclass_t zclass,
-		     unsigned int options, isc_uint32_t resign,
-		     dns_rdatacallbacks_t *callbacks, isc_mem_t *mctx,
-		     dns_masterformat_t format)
-{
-	return (dns_master_loadfile5(master_file, top, origin, zclass,
-				     options, resign, callbacks, NULL, NULL,
-				     mctx, format, 0));
-}
-
-isc_result_t
-dns_master_loadfile4(const char *master_file, dns_name_t *top,
-		     dns_name_t *origin, dns_rdataclass_t zclass,
-		     unsigned int options, isc_uint32_t resign,
-		     dns_rdatacallbacks_t *callbacks,
-		     dns_masterincludecb_t include_cb, void *include_arg,
-		     isc_mem_t *mctx, dns_masterformat_t format)
-{
-	return (dns_master_loadfile5(master_file, top, origin, zclass,
-				     options, resign, callbacks,
-				     include_cb, include_arg,
-				     mctx, format, 0));
-}
-
-isc_result_t
-dns_master_loadfile5(const char *master_file, dns_name_t *top,
-		     dns_name_t *origin, dns_rdataclass_t zclass,
-		     unsigned int options, isc_uint32_t resign,
-		     dns_rdatacallbacks_t *callbacks,
-		     dns_masterincludecb_t include_cb, void *include_arg,
-		     isc_mem_t *mctx, dns_masterformat_t format,
-		     dns_ttl_t maxttl)
+		    dns_name_t *origin, dns_rdataclass_t zclass,
+		    unsigned int options, isc_uint32_t resign,
+		    dns_rdatacallbacks_t *callbacks,
+		    dns_masterincludecb_t include_cb, void *include_arg,
+		    isc_mem_t *mctx, dns_masterformat_t format,
+		    dns_ttl_t maxttl)
 {
 	dns_loadctx_t *lctx = NULL;
 	isc_result_t result;
@@ -2667,72 +2625,13 @@ dns_master_loadfile5(const char *master_file, dns_name_t *top,
 isc_result_t
 dns_master_loadfileinc(const char *master_file, dns_name_t *top,
 		       dns_name_t *origin, dns_rdataclass_t zclass,
-		       unsigned int options, dns_rdatacallbacks_t *callbacks,
+		       unsigned int options, isc_uint32_t resign,
+		       dns_rdatacallbacks_t *callbacks,
 		       isc_task_t *task, dns_loaddonefunc_t done,
-		       void *done_arg, dns_loadctx_t **lctxp, isc_mem_t *mctx)
-{
-	return (dns_master_loadfileinc4(master_file, top, origin, zclass,
-					options, 0, callbacks, task, done,
-					done_arg, lctxp, NULL, NULL, mctx,
-					dns_masterformat_text));
-}
-
-isc_result_t
-dns_master_loadfileinc2(const char *master_file, dns_name_t *top,
-			dns_name_t *origin, dns_rdataclass_t zclass,
-			unsigned int options, dns_rdatacallbacks_t *callbacks,
-			isc_task_t *task, dns_loaddonefunc_t done,
-			void *done_arg, dns_loadctx_t **lctxp, isc_mem_t *mctx,
-			dns_masterformat_t format)
-{
-	return (dns_master_loadfileinc4(master_file, top, origin, zclass,
-					options, 0, callbacks, task, done,
-					done_arg, lctxp, NULL, NULL, mctx,
-					format));
-}
-
-isc_result_t
-dns_master_loadfileinc3(const char *master_file, dns_name_t *top,
-			dns_name_t *origin, dns_rdataclass_t zclass,
-			unsigned int options, isc_uint32_t resign,
-			dns_rdatacallbacks_t *callbacks, isc_task_t *task,
-			dns_loaddonefunc_t done, void *done_arg,
-			dns_loadctx_t **lctxp, isc_mem_t *mctx,
-			dns_masterformat_t format)
-{
-	return (dns_master_loadfileinc4(master_file, top, origin, zclass,
-					options, resign, callbacks, task,
-					done, done_arg, lctxp, NULL, NULL,
-					mctx, format));
-}
-
-isc_result_t
-dns_master_loadfileinc4(const char *master_file, dns_name_t *top,
-			dns_name_t *origin, dns_rdataclass_t zclass,
-			unsigned int options, isc_uint32_t resign,
-			dns_rdatacallbacks_t *callbacks,
-			isc_task_t *task, dns_loaddonefunc_t done,
-			void *done_arg, dns_loadctx_t **lctxp,
-			dns_masterincludecb_t include_cb, void *include_arg,
-			isc_mem_t *mctx, dns_masterformat_t format)
-{
-	options &= ~DNS_MASTER_CHECKTTL;
-	return (dns_master_loadfileinc5(master_file, top, origin, zclass,
-					options, resign, callbacks, task,
-					done, done_arg, lctxp, include_cb,
-					include_arg, mctx, format, 0));
-}
-
-isc_result_t
-dns_master_loadfileinc5(const char *master_file, dns_name_t *top,
-			dns_name_t *origin, dns_rdataclass_t zclass,
-			unsigned int options, isc_uint32_t resign,
-			dns_rdatacallbacks_t *callbacks,
-			isc_task_t *task, dns_loaddonefunc_t done,
-			void *done_arg, dns_loadctx_t **lctxp,
-			dns_masterincludecb_t include_cb, void *include_arg,
-			isc_mem_t *mctx, dns_masterformat_t format,
-			isc_uint32_t maxttl)
+		       void *done_arg, dns_loadctx_t **lctxp,
+		       dns_masterincludecb_t include_cb, void *include_arg,
+		       isc_mem_t *mctx, dns_masterformat_t format,
+		       isc_uint32_t maxttl)
 {
 	dns_loadctx_t *lctx = NULL;
 	isc_result_t result;
