@@ -9,18 +9,16 @@
  * information regarding copyright ownership.
  */
 
-#ifdef PKCS11CRYPTO
-
 #include <config.h>
 
+#if HAVE_PKCS11
+
 #include <pk11/site.h>
 
 #ifndef PK11_DSA_DISABLE
 
 #include <string.h>
-#include <stdbool.h>
 
-#include <isc/entropy.h>
 #include <isc/mem.h>
 #include <isc/safe.h>
 #include <isc/sha1.h>
@@ -107,7 +105,7 @@ pkcs11dsa_createctx_sign(dst_key_t *key, dst_context_t *dctx) {
 						  sizeof(*pk11_ctx));
 	if (pk11_ctx == NULL)
 		return (ISC_R_NOMEMORY);
-	ret = pk11_get_session(pk11_ctx, OP_DSA, true, false,
+	ret = pk11_get_session(pk11_ctx, OP_DSA, ISC_TRUE, ISC_FALSE,
 			       dsa->reqlogon, NULL,
 			       pk11_get_best_token(OP_DSA));
 	if (ret != ISC_R_SUCCESS)
@@ -165,7 +163,7 @@ pkcs11dsa_createctx_sign(dst_key_t *key, dst_context_t *dctx) {
 			break;
 		}
 	pk11_ctx->object = CK_INVALID_HANDLE;
-	pk11_ctx->ontoken = false;
+	pk11_ctx->ontoken = ISC_FALSE;
 	PK11_RET(pkcs_C_CreateObject,
 		 (pk11_ctx->session,
 		  keyTemplate, (CK_ULONG) 10,
@@ -239,7 +237,7 @@ pkcs11dsa_createctx_verify(dst_key_t *key, dst_context_t *dctx) {
 						  sizeof(*pk11_ctx));
 	if (pk11_ctx == NULL)
 		return (ISC_R_NOMEMORY);
-	ret = pk11_get_session(pk11_ctx, OP_DSA, true, false,
+	ret = pk11_get_session(pk11_ctx, OP_DSA, ISC_TRUE, ISC_FALSE,
 			       dsa->reqlogon, NULL,
 			       pk11_get_best_token(OP_DSA));
 	if (ret != ISC_R_SUCCESS)
@@ -297,7 +295,7 @@ pkcs11dsa_createctx_verify(dst_key_t *key, dst_context_t *dctx) {
 			break;
 		}
 	pk11_ctx->object = CK_INVALID_HANDLE;
-	pk11_ctx->ontoken = false;
+	pk11_ctx->ontoken = ISC_FALSE;
 	PK11_RET(pkcs_C_CreateObject,
 		 (pk11_ctx->session,
 		  keyTemplate, (CK_ULONG) 9,
@@ -429,7 +427,7 @@ pkcs11dsa_verify(dst_context_t *dctx, const isc_region_t *sig) {
 	return (ret);
 }
 
-static bool
+static isc_boolean_t
 pkcs11dsa_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	pk11_object_t *dsa1, *dsa2;
 	CK_ATTRIBUTE *attr1, *attr2;
@@ -438,49 +436,49 @@ pkcs11dsa_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	dsa2 = key2->keydata.pkey;
 
 	if ((dsa1 == NULL) && (dsa2 == NULL))
-		return (true);
+		return (ISC_TRUE);
 	else if ((dsa1 == NULL) || (dsa2 == NULL))
-		return (false);
+		return (ISC_FALSE);
 
 	attr1 = pk11_attribute_bytype(dsa1, CKA_PRIME);
 	attr2 = pk11_attribute_bytype(dsa2, CKA_PRIME);
 	if ((attr1 == NULL) && (attr2 == NULL))
-		return (true);
+		return (ISC_TRUE);
 	else if ((attr1 == NULL) || (attr2 == NULL) ||
 		 (attr1->ulValueLen != attr2->ulValueLen) ||
 		 !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				    attr1->ulValueLen))
-		return (false);
+		return (ISC_FALSE);
 
 	attr1 = pk11_attribute_bytype(dsa1, CKA_SUBPRIME);
 	attr2 = pk11_attribute_bytype(dsa2, CKA_SUBPRIME);
 	if ((attr1 == NULL) && (attr2 == NULL))
-		return (true);
+		return (ISC_TRUE);
 	else if ((attr1 == NULL) || (attr2 == NULL) ||
 		 (attr1->ulValueLen != attr2->ulValueLen) ||
 		 !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				    attr1->ulValueLen))
-		return (false);
+		return (ISC_FALSE);
 
 	attr1 = pk11_attribute_bytype(dsa1, CKA_BASE);
 	attr2 = pk11_attribute_bytype(dsa2, CKA_BASE);
 	if ((attr1 == NULL) && (attr2 == NULL))
-		return (true);
+		return (ISC_TRUE);
 	else if ((attr1 == NULL) || (attr2 == NULL) ||
 		 (attr1->ulValueLen != attr2->ulValueLen) ||
 		 !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				    attr1->ulValueLen))
-		return (false);
+		return (ISC_FALSE);
 
 	attr1 = pk11_attribute_bytype(dsa1, CKA_VALUE);
 	attr2 = pk11_attribute_bytype(dsa2, CKA_VALUE);
 	if ((attr1 == NULL) && (attr2 == NULL))
-		return (true);
+		return (ISC_TRUE);
 	else if ((attr1 == NULL) || (attr2 == NULL) ||
 		 (attr1->ulValueLen != attr2->ulValueLen) ||
 		 !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				    attr1->ulValueLen))
-		return (false);
+		return (ISC_FALSE);
 
 	attr1 = pk11_attribute_bytype(dsa1, CKA_VALUE2);
 	attr2 = pk11_attribute_bytype(dsa2, CKA_VALUE2);
@@ -489,15 +487,15 @@ pkcs11dsa_compare(const dst_key_t *key1, const dst_key_t *key2) {
 	     (attr1->ulValueLen != attr2->ulValueLen) ||
 	     !isc_safe_memequal(attr1->pValue, attr2->pValue,
 				attr1->ulValueLen)))
-		return (false);
+		return (ISC_FALSE);
 
 	if (!dsa1->ontoken && !dsa2->ontoken)
-		return (true);
+		return (ISC_TRUE);
 	else if (dsa1->ontoken || dsa2->ontoken ||
 		 (dsa1->object != dsa2->object))
-		return (false);
+		return (ISC_FALSE);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static isc_result_t
@@ -554,8 +552,8 @@ pkcs11dsa_generate(dst_key_t *key, int unused, void (*callback)(int)) {
 						  sizeof(*pk11_ctx));
 	if (pk11_ctx == NULL)
 		return (ISC_R_NOMEMORY);
-	ret = pk11_get_session(pk11_ctx, OP_DSA, true, false,
-			       false, NULL, pk11_get_best_token(OP_DSA));
+	ret = pk11_get_session(pk11_ctx, OP_DSA, ISC_TRUE, ISC_FALSE,
+			       ISC_FALSE, NULL, pk11_get_best_token(OP_DSA));
 	if (ret != ISC_R_SUCCESS)
 		goto err;
 
@@ -661,15 +659,15 @@ pkcs11dsa_generate(dst_key_t *key, int unused, void (*callback)(int)) {
 	return (ret);
 }
 
-static bool
+static isc_boolean_t
 pkcs11dsa_isprivate(const dst_key_t *key) {
 	pk11_object_t *dsa = key->keydata.pkey;
 	CK_ATTRIBUTE *attr;
 
 	if (dsa == NULL)
-		return (false);
+		return (ISC_FALSE);
 	attr = pk11_attribute_bytype(dsa, CKA_VALUE2);
-	return (attr != NULL || dsa->ontoken);
+	return (ISC_TF((attr != NULL) || dsa->ontoken));
 }
 
 static void
@@ -983,7 +981,6 @@ pkcs11dsa_parse(dst_key_t *key, isc_lex_t *lexer, dst_key_t *pub) {
 	dst_private_t priv;
 	isc_result_t ret;
 	int i;
-	unsigned int bits;
 	pk11_object_t *dsa = NULL;
 	CK_ATTRIBUTE *attr;
 	isc_mem_t *mctx = key->mctx;
@@ -1073,12 +1070,7 @@ pkcs11dsa_parse(dst_key_t *key, isc_lex_t *lexer, dst_key_t *pub) {
 
 	attr = pk11_attribute_bytype(dsa, CKA_PRIME);
 	INSIST(attr != NULL);
-
-	ret = pk11_numbits(attr->pValue, attr->ulValueLen, &bits);
-	if (ret != ISC_R_SUCCESS) {
-		goto err;
-	}
-	key->key_size = bits;
+	key->key_size = pk11_numbits(attr->pValue, attr->ulValueLen);
 
 	return (ISC_R_SUCCESS);
 
@@ -1122,11 +1114,11 @@ dst__pkcs11dsa_init(dst_func_t **funcp) {
 }
 #endif /* !PK11_DSA_DISABLE */
 
-#else /* PKCS11CRYPTO */
+#else /* HAVE_PKCS11 */
 
 #include <isc/util.h>
 
 EMPTY_TRANSLATION_UNIT
 
-#endif /* PKCS11CRYPTO */
+#endif /* HAVE_PKCS11 */
 /*! \file */
