@@ -14,8 +14,9 @@
 #include <config.h>
 
 #include <sys/stat.h>
+#ifdef HAVE_INTTYPES_H
 #include <inttypes.h> /* uintptr_t */
-#include <stdbool.h>
+#endif
 
 #include <isc/crc64.h>
 #include <isc/file.h>
@@ -100,16 +101,16 @@ static char FILE_VERSION[32] = "\0";
 
 struct file_header {
 	char version1[32];
-	uint64_t first_node_offset;	/* usually 1024 */
+	isc_uint64_t first_node_offset;	/* usually 1024 */
 	/*
 	 * information about the system on which the map file was generated
 	 * will be used to tell if we can load the map file or not
 	 */
-	uint32_t ptrsize;
+	isc_uint32_t ptrsize;
 	unsigned int bigendian:1;	/* big or little endian system */
 	unsigned int rdataset_fixed:1;	/* compiled with --enable-rrset-fixed */
 	unsigned int nodecount;		/* shadow from rbt structure */
-	uint64_t crc;
+	isc_uint64_t crc;
 	char version2[32];  		/* repeated; must match version1 */
 };
 
@@ -136,21 +137,21 @@ static isc_result_t
 dns_rbt_zero_header(FILE *file);
 
 static isc_result_t
-write_header(FILE *file, dns_rbt_t *rbt, uint64_t first_node_offset,
-	     uint64_t crc);
+write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
+	     isc_uint64_t crc);
 
-static bool
+static isc_boolean_t
 match_header_version(file_header_t *header);
 
 static isc_result_t
 serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	       uintptr_t right, uintptr_t down, uintptr_t parent,
-	       uintptr_t data, uint64_t *crc);
+	       uintptr_t data, isc_uint64_t *crc);
 
 static isc_result_t
 serialize_nodes(FILE *file, dns_rbtnode_t *node, uintptr_t parent,
 		dns_rbtdatawriter_t datawriter, void *writer_arg,
-		uintptr_t *where, uint64_t *crc);
+		uintptr_t *where, isc_uint64_t *crc);
 /*
  * The following functions allow you to get the actual address of a pointer
  * without having to use an if statement to check to see if that address is
@@ -215,8 +216,8 @@ getdata(dns_rbtnode_t *node, file_header_t *header) {
 #define OLDNAMELEN(node)        ((node)->oldnamelen)
 #define OFFSETLEN(node)         ((node)->offsetlen)
 #define ATTRS(node)             ((node)->attributes)
-#define IS_ROOT(node)           ((node)->is_root == 1)
-#define FINDCALLBACK(node)      ((node)->find_callback == 1)
+#define IS_ROOT(node)           ISC_TF((node)->is_root == 1)
+#define FINDCALLBACK(node)      ISC_TF((node)->find_callback == 1)
 
 /*%
  * Structure elements from the rbtdb.c, not
@@ -453,14 +454,14 @@ static isc_result_t
 treefix(dns_rbt_t *rbt, void *base, size_t size,
 	dns_rbtnode_t *n, const dns_name_t *name,
 	dns_rbtdatafixer_t datafixer, void *fixer_arg,
-	uint64_t *crc);
+	isc_uint64_t *crc);
 
 static void
-deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, bool unhash,
+deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, isc_boolean_t unhash,
 	       dns_rbtnode_t **nodep);
 
 static void
-printnodename(dns_rbtnode_t *node, bool quoted, FILE *f);
+printnodename(dns_rbtnode_t *node, isc_boolean_t quoted, FILE *f);
 
 static void
 freenode(dns_rbt_t *rbt, dns_rbtnode_t **nodep);
@@ -507,8 +508,8 @@ init_file_version(void) {
  * here.
  */
 static isc_result_t
-write_header(FILE *file, dns_rbt_t *rbt, uint64_t first_node_offset,
-	     uint64_t crc)
+write_header(FILE *file, dns_rbt_t *rbt, isc_uint64_t first_node_offset,
+	     isc_uint64_t crc)
 {
 	file_header_t header;
 	isc_result_t result;
@@ -520,7 +521,7 @@ write_header(FILE *file, dns_rbt_t *rbt, uint64_t first_node_offset,
 	memmove(header.version1, FILE_VERSION, sizeof(header.version1));
 	memmove(header.version2, FILE_VERSION, sizeof(header.version2));
 	header.first_node_offset = first_node_offset;
-	header.ptrsize = (uint32_t) sizeof(void *);
+	header.ptrsize = (isc_uint32_t) sizeof(void *);
 	header.bigendian = (1 == htonl(1)) ? 1 : 0;
 
 #ifdef DNS_RDATASET_FIXED
@@ -546,7 +547,7 @@ write_header(FILE *file, dns_rbt_t *rbt, uint64_t first_node_offset,
 	return (result);
 }
 
-static bool
+static isc_boolean_t
 match_header_version(file_header_t *header) {
 	RUNTIME_CHECK(isc_once_do(&once, init_file_version) == ISC_R_SUCCESS);
 
@@ -555,16 +556,16 @@ match_header_version(file_header_t *header) {
 	    memcmp(header->version2, FILE_VERSION,
 		   sizeof(header->version1)) != 0)
 	{
-		return (false);
+		return (ISC_FALSE);
 	}
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static isc_result_t
 serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	       uintptr_t right, uintptr_t down, uintptr_t parent,
-	       uintptr_t data, uint64_t *crc)
+	       uintptr_t data, isc_uint64_t *crc)
 {
 	dns_rbtnode_t temp_node;
 	off_t file_position;
@@ -634,9 +635,9 @@ serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 	hexdump("node data", node_data, datasize);
 #endif
 
-	isc_crc64_update(crc, (const uint8_t *) &temp_node,
+	isc_crc64_update(crc, (const isc_uint8_t *) &temp_node,
 			 sizeof(dns_rbtnode_t));
-	isc_crc64_update(crc, (const uint8_t *) node_data, datasize);
+	isc_crc64_update(crc, (const isc_uint8_t *) node_data, datasize);
 
  cleanup:
 	return (result);
@@ -645,7 +646,7 @@ serialize_node(FILE *file, dns_rbtnode_t *node, uintptr_t left,
 static isc_result_t
 serialize_nodes(FILE *file, dns_rbtnode_t *node, uintptr_t parent,
 		dns_rbtdatawriter_t datawriter, void *writer_arg,
-		uintptr_t *where, uint64_t *crc)
+		uintptr_t *where, isc_uint64_t *crc)
 {
 	uintptr_t left = 0, right = 0, down = 0, data = 0;
 	off_t location = 0, offset_adjust;
@@ -722,7 +723,7 @@ dns_rbt_serialize_tree(FILE *file, dns_rbt_t *rbt,
 {
 	isc_result_t result;
 	off_t header_position, node_position, end_position;
-	uint64_t crc;
+	isc_uint64_t crc;
 
 	REQUIRE(file != NULL);
 
@@ -774,7 +775,7 @@ dns_rbt_serialize_tree(FILE *file, dns_rbt_t *rbt,
 static isc_result_t
 treefix(dns_rbt_t *rbt, void *base, size_t filesize, dns_rbtnode_t *n,
 	const dns_name_t *name, dns_rbtdatafixer_t datafixer,
-	void *fixer_arg, uint64_t *crc)
+	void *fixer_arg, isc_uint64_t *crc)
 {
 	isc_result_t result = ISC_R_SUCCESS;
 	dns_fixedname_t fixed;
@@ -874,9 +875,9 @@ treefix(dns_rbt_t *rbt, void *base, size_t filesize, dns_rbtnode_t *n,
 		sizeof(dns_rbtnode_t));
 	hexdump("node data", node_data, datasize);
 #endif
-	isc_crc64_update(crc, (const uint8_t *) &header,
+	isc_crc64_update(crc, (const isc_uint8_t *) &header,
 			sizeof(dns_rbtnode_t));
-	isc_crc64_update(crc, (const uint8_t *) node_data,
+	isc_crc64_update(crc, (const isc_uint8_t *) node_data,
 			datasize);
 
  cleanup:
@@ -893,7 +894,7 @@ dns_rbt_deserialize_tree(void *base_address, size_t filesize,
 	isc_result_t result = ISC_R_SUCCESS;
 	file_header_t *header;
 	dns_rbt_t *rbt = NULL;
-	uint64_t crc;
+	isc_uint64_t crc;
 	unsigned int host_big_endian;
 
 	REQUIRE(originp == NULL || *originp == NULL);
@@ -924,7 +925,7 @@ dns_rbt_deserialize_tree(void *base_address, size_t filesize,
 	}
 #endif
 
-	if (header->ptrsize != (uint32_t) sizeof(void *)) {
+	if (header->ptrsize != (isc_uint32_t) sizeof(void *)) {
 		result = ISC_R_INVALIDFILE;
 		goto cleanup;
 	}
@@ -1043,7 +1044,7 @@ dns_rbt_destroy2(dns_rbt_t **rbtp, unsigned int quantum) {
 
 	rbt = *rbtp;
 
-	deletetreeflat(rbt, quantum, false, &rbt->root);
+	deletetreeflat(rbt, quantum, ISC_FALSE, &rbt->root);
 	if (rbt->root != NULL)
 		return (ISC_R_QUOTA);
 
@@ -1080,7 +1081,7 @@ dns_rbt_hashsize(dns_rbt_t *rbt) {
 
 static inline isc_result_t
 chain_name(dns_rbtnodechain_t *chain, dns_name_t *name,
-	   bool include_chain_end)
+	   isc_boolean_t include_chain_end)
 {
 	dns_name_t nodename;
 	isc_result_t result = ISC_R_SUCCESS;
@@ -1188,6 +1189,7 @@ dns_rbt_addnode(dns_rbt_t *rbt, const dns_name_t *name, dns_rbtnode_t **nodep) {
 	 * not modified.
 	 */
 	add_name = dns_fixedname_initname(&fixedcopy);
+	INSIST(add_name != NULL);
 	dns_name_clone(name, add_name);
 
 	if (ISC_UNLIKELY(rbt->root == NULL)) {
@@ -1210,6 +1212,9 @@ dns_rbt_addnode(dns_rbt_t *rbt, const dns_name_t *name, dns_rbtnode_t **nodep) {
 	prefix = dns_fixedname_initname(&fixedprefix);
 	suffix = dns_fixedname_initname(&fixedsuffix);
 
+	INSIST(prefix != NULL);
+	INSIST(suffix != NULL);
+
 	root = &rbt->root;
 	INSIST(IS_ROOT(*root));
 	parent = NULL;
@@ -1531,6 +1536,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 	 * the lack of bitstring labels.
 	 */
 	search_name = dns_fixedname_initname(&fixedsearchname);
+	INSIST(search_name != NULL);
 	dns_name_clone(name, search_name);
 
 	dns_name_init(&current_name, NULL);
@@ -1605,7 +1611,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 						  nlabels - tlabels,
 						  hlabels + tlabels,
 						  &hash_name);
-			hash = dns_name_fullhash(&hash_name, false);
+			hash = dns_name_fullhash(&hash_name, ISC_FALSE);
 			dns_name_getlabelsequence(search_name,
 						  nlabels - tlabels,
 						  tlabels, &hash_name);
@@ -1733,7 +1739,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 				    FINDCALLBACK(current)) {
 					result = chain_name(chain,
 							    callback_name,
-							    false);
+							    ISC_FALSE);
 					if (result != ISC_R_SUCCESS) {
 						dns_rbtnodechain_reset(chain);
 						return (result);
@@ -1787,7 +1793,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 		chain->level_matches = chain->level_count;
 
 		if (foundname != NULL)
-			result = chain_name(chain, foundname, true);
+			result = chain_name(chain, foundname, ISC_TRUE);
 		else
 			result = ISC_R_SUCCESS;
 
@@ -1824,7 +1830,7 @@ dns_rbt_findnode(dns_rbt_t *rbt, const dns_name_t *name, dns_name_t *foundname,
 				chain->level_count = chain->level_matches + 1;
 
 				result = chain_name(chain, foundname,
-						    false);
+						    ISC_FALSE);
 
 				chain->level_count = saved_count;
 			} else
@@ -2030,7 +2036,7 @@ dns_rbt_findname(dns_rbt_t *rbt, const dns_name_t *name, unsigned int options,
  */
 isc_result_t
 dns_rbt_deletename(dns_rbt_t *rbt, const dns_name_t *name,
-		   bool recurse)
+		   isc_boolean_t recurse)
 {
 	dns_rbtnode_t *node = NULL;
 	isc_result_t result;
@@ -2104,7 +2110,7 @@ dns_rbt_deletename(dns_rbt_t *rbt, const dns_name_t *name,
  * succeeds. It still returns isc_result_t, though, so the API wouldn't change.
  */
 isc_result_t
-dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, bool recurse)
+dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, isc_boolean_t recurse)
 {
 	dns_rbtnode_t *parent;
 
@@ -2115,7 +2121,7 @@ dns_rbt_deletenode(dns_rbt_t *rbt, dns_rbtnode_t *node, bool recurse)
 	if (DOWN(node) != NULL) {
 		if (recurse) {
 			PARENT(DOWN(node)) = NULL;
-			deletetreeflat(rbt, 0, true, &DOWN(node));
+			deletetreeflat(rbt, 0, ISC_TRUE, &DOWN(node));
 		} else {
 			if (DATA(node) != NULL && rbt->data_deleter != NULL)
 				rbt->data_deleter(DATA(node), rbt->deleter_arg);
@@ -2310,7 +2316,7 @@ hash_add_node(dns_rbt_t *rbt, dns_rbtnode_t *node, const dns_name_t *name) {
 
 	REQUIRE(name != NULL);
 
-	HASHVAL(node) = dns_name_fullhash(name, false);
+	HASHVAL(node) = dns_name_fullhash(name, ISC_FALSE);
 
 	hash = HASHVAL(node) % rbt->hashsize;
 	HASHNEXT(node) = rbt->hashtable[hash];
@@ -2655,8 +2661,8 @@ deletefromlevel(dns_rbtnode_t *item, dns_rbtnode_t **rootp) {
 
 		if (IS_ROOT(item)) {
 			*rootp = successor;
-			successor->is_root = true;
-			item->is_root = false;
+			successor->is_root = ISC_TRUE;
+			item->is_root = ISC_FALSE;
 
 		} else
 			if (LEFT(PARENT(item)) == item)
@@ -2826,7 +2832,7 @@ freenode(dns_rbt_t *rbt, dns_rbtnode_t **nodep) {
 }
 
 static void
-deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, bool unhash,
+deletetreeflat(dns_rbt_t *rbt, unsigned int quantum, isc_boolean_t unhash,
 	       dns_rbtnode_t **nodep)
 {
 	dns_rbtnode_t *root = *nodep;
@@ -2899,31 +2905,31 @@ dns__rbt_getheight(dns_rbt_t *rbt) {
 	return (getheight_helper(rbt->root));
 }
 
-static bool
+static isc_boolean_t
 check_properties_helper(dns_rbtnode_t *node) {
 	if (node == NULL)
-		return (true);
+		return (ISC_TRUE);
 
 	if (IS_RED(node)) {
 		/* Root nodes must be BLACK. */
 		if (IS_ROOT(node))
-			return (false);
+			return (ISC_FALSE);
 
 		/* Both children of RED nodes must be BLACK. */
 		if (IS_RED(LEFT(node)) || IS_RED(RIGHT(node)))
-			return (false);
+			return (ISC_FALSE);
 	}
 
 	if ((DOWN(node) != NULL) && (!IS_ROOT(DOWN(node))))
-		return (false);
+		return (ISC_FALSE);
 
 	if (IS_ROOT(node)) {
 		if ((PARENT(node) != NULL) &&
 		    (DOWN(PARENT(node)) != node))
-			return (false);
+			return (ISC_FALSE);
 
 		if (get_upper_node(node) != PARENT(node))
-			return (false);
+			return (ISC_FALSE);
 	}
 
 	/* If node is assigned to the down_ pointer of its parent, it is
@@ -2933,7 +2939,7 @@ check_properties_helper(dns_rbtnode_t *node) {
 	     (DOWN(PARENT(node)) == node)) &&
 	    (!IS_ROOT(node)))
 	{
-		return (false);
+		return (ISC_FALSE);
 	}
 
 	/* Repeat tests with this node's children. */
@@ -2942,42 +2948,42 @@ check_properties_helper(dns_rbtnode_t *node) {
 		check_properties_helper(DOWN(node)));
 }
 
-static bool
+static isc_boolean_t
 check_black_distance_helper(dns_rbtnode_t *node, size_t *distance) {
 	size_t dl, dr, dd;
 
 	if (node == NULL) {
 		*distance = 1;
-		return (true);
+		return (ISC_TRUE);
 	}
 
 	if (!check_black_distance_helper(LEFT(node), &dl))
-		return (false);
+		return (ISC_FALSE);
 
 	if (!check_black_distance_helper(RIGHT(node), &dr))
-		return (false);
+		return (ISC_FALSE);
 
 	if (!check_black_distance_helper(DOWN(node), &dd))
-		return (false);
+		return (ISC_FALSE);
 
 	/* Left and right side black node counts must match. */
 	if (dl != dr)
-		return (false);
+		return (ISC_FALSE);
 
 	if (IS_BLACK(node))
 		dl++;
 
 	*distance = dl;
 
-	return (true);
+	return (ISC_TRUE);
 }
 
-bool
+isc_boolean_t
 dns__rbt_checkproperties(dns_rbt_t *rbt) {
 	size_t dd;
 
 	if (!check_properties_helper(rbt->root))
-		return (false);
+		return (ISC_FALSE);
 
 	/* Path from a given node to all its leaves must contain the
 	 * same number of BLACK child nodes. This is done separately
@@ -3000,7 +3006,7 @@ dns_rbt_indent(FILE *f, int depth) {
 void
 dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
 	fprintf(f, "Node info for nodename: ");
-	printnodename(n, true, f);
+	printnodename(n, ISC_TRUE, f);
 	fprintf(f, "\n");
 
 	fprintf(f, "n = %p\n", n);
@@ -3022,7 +3028,7 @@ dns_rbt_printnodeinfo(dns_rbtnode_t *n, FILE *f) {
 }
 
 static void
-printnodename(dns_rbtnode_t *node, bool quoted, FILE *f) {
+printnodename(dns_rbtnode_t *node, isc_boolean_t quoted, FILE *f) {
 	isc_region_t r;
 	dns_name_t name;
 	char buffer[DNS_NAME_FORMATSIZE];
@@ -3050,7 +3056,7 @@ print_text_helper(dns_rbtnode_t *root, dns_rbtnode_t *parent,
 	dns_rbt_indent(f, depth);
 
 	if (root != NULL) {
-		printnodename(root, true, f);
+		printnodename(root, ISC_TRUE, f);
 		fprintf(f, " (%s, %s", direction,
 			IS_RED(root) ? "RED" : "BLACK");
 
@@ -3060,7 +3066,7 @@ print_text_helper(dns_rbtnode_t *root, dns_rbtnode_t *parent,
 
 			fprintf(f, " (BAD parent pointer! -> ");
 			if (PARENT(root) != NULL)
-				printnodename(PARENT(root), true, f);
+				printnodename(PARENT(root), ISC_TRUE, f);
 			else
 				fprintf(f, "NULL");
 			fprintf(f, ")");
@@ -3104,7 +3110,7 @@ dns_rbt_printtext(dns_rbt_t *rbt,
 
 static int
 print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
-		 bool show_pointers, FILE *f)
+		 isc_boolean_t show_pointers, FILE *f)
 {
 	unsigned int l, r, d;
 
@@ -3118,7 +3124,7 @@ print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
 	*nodecount += 1;
 
 	fprintf(f, "node%u[label = \"<f0> |<f1> ", *nodecount);
-	printnodename(node, false, f);
+	printnodename(node, ISC_FALSE, f);
 	fprintf(f, "|<f2>");
 
 	if (show_pointers)
@@ -3156,7 +3162,7 @@ print_dot_helper(dns_rbtnode_t *node, unsigned int *nodecount,
 }
 
 void
-dns_rbt_printdot(dns_rbt_t *rbt, bool show_pointers, FILE *f) {
+dns_rbt_printdot(dns_rbt_t *rbt, isc_boolean_t show_pointers, FILE *f) {
 	unsigned int nodecount = 0;
 
 	REQUIRE(VALID_RBT(rbt));
@@ -3223,7 +3229,7 @@ dns_rbtnodechain_current(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 	if (origin != NULL) {
 		if (chain->level_count > 0)
-			result = chain_name(chain, origin, false);
+			result = chain_name(chain, origin, ISC_FALSE);
 		else
 			result = dns_name_copy(dns_rootname, origin, NULL);
 	}
@@ -3237,7 +3243,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *previous, *predecessor;
 	isc_result_t result = ISC_R_SUCCESS;
-	bool new_origin = false;
+	isc_boolean_t new_origin = ISC_FALSE;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3305,7 +3311,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 			/* XXX DCL probably needs work on the concept */
 			if (origin != NULL)
-				new_origin = true;
+				new_origin = ISC_TRUE;
 		}
 
 	} else if (chain->level_count > 0) {
@@ -3326,7 +3332,7 @@ dns_rbtnodechain_prev(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (origin != NULL &&
 		    (chain->level_count > 0 || OFFSETLEN(predecessor) > 1))
-			new_origin = true;
+			new_origin = ISC_TRUE;
 	}
 
 	if (predecessor != NULL) {
@@ -3354,7 +3360,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *successor;
 	isc_result_t result = ISC_R_SUCCESS;
-	bool new_origin = false;
+	isc_boolean_t new_origin = ISC_FALSE;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3370,7 +3376,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (chain->level_count > 0 ||
 		    OFFSETLEN(current) > 1)
-			new_origin = true;
+			new_origin = ISC_TRUE;
 
 		ADD_LEVEL(chain, current);
 		current = DOWN(current);
@@ -3398,7 +3404,7 @@ dns_rbtnodechain_down(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 		if (new_origin) {
 			if (origin != NULL)
-				result = chain_name(chain, origin, false);
+				result = chain_name(chain, origin, ISC_FALSE);
 
 			if (result == ISC_R_SUCCESS)
 				result = DNS_R_NEWORIGIN;
@@ -3461,7 +3467,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 {
 	dns_rbtnode_t *current, *previous, *successor;
 	isc_result_t result = ISC_R_SUCCESS;
-	bool new_origin = false;
+	isc_boolean_t new_origin = ISC_FALSE;
 
 	REQUIRE(VALID_CHAIN(chain) && chain->end != NULL);
 
@@ -3481,7 +3487,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 		 */
 		if (chain->level_count > 0 ||
 		    OFFSETLEN(current) > 1)
-			new_origin = true;
+			new_origin = ISC_TRUE;
 
 		ADD_LEVEL(chain, current);
 		current = DOWN(current);
@@ -3536,7 +3542,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 				}
 
 				current = chain->levels[--chain->level_count];
-				new_origin = true;
+				new_origin = ISC_TRUE;
 
 				if (RIGHT(current) != NULL)
 					break;
@@ -3576,7 +3582,7 @@ dns_rbtnodechain_next(dns_rbtnodechain_t *chain, dns_name_t *name,
 
 		if (new_origin) {
 			if (origin != NULL)
-				result = chain_name(chain, origin, false);
+				result = chain_name(chain, origin, ISC_FALSE);
 
 			if (result == ISC_R_SUCCESS)
 				result = DNS_R_NEWORIGIN;
