@@ -13,9 +13,7 @@
 /*! \file */
 
 #include <config.h>
-
 #include <ctype.h>
-#include <inttypes.h>
 
 #include <isc/base64.h>
 #include <isc/hex.h>
@@ -97,7 +95,7 @@
 #define ARGS_FROMSTRUCT	int rdclass, dns_rdatatype_t type, \
 			void *source, isc_buffer_t *target
 
-#define ARGS_TOSTRUCT	const dns_rdata_t *rdata, void *target, isc_mem_t *mctx
+#define ARGS_TOSTRUCT	dns_rdata_t *rdata, void *target, isc_mem_t *mctx
 
 #define ARGS_FREESTRUCT void *source
 
@@ -107,7 +105,7 @@
 #define ARGS_DIGEST	dns_rdata_t *rdata, dns_digestfunc_t digest, void *arg
 
 #define ARGS_CHECKOWNER const dns_name_t *name, dns_rdataclass_t rdclass, \
-			dns_rdatatype_t type, bool wildcard
+			dns_rdatatype_t type, isc_boolean_t wildcard
 
 #define ARGS_CHECKNAMES dns_rdata_t *rdata, const dns_name_t *owner, \
 			dns_name_t *bad
@@ -126,7 +124,7 @@ typedef struct dns_rdata_textctx {
 } dns_rdata_textctx_t;
 
 static isc_result_t
-txt_totext(isc_region_t *source, bool quote, isc_buffer_t *target);
+txt_totext(isc_region_t *source, isc_boolean_t quote, isc_buffer_t *target);
 
 static isc_result_t
 txt_fromtext(isc_textregion_t *source, isc_buffer_t *target);
@@ -140,7 +138,7 @@ multitxt_totext(isc_region_t *source, isc_buffer_t *target);
 static isc_result_t
 multitxt_fromtext(isc_textregion_t *source, isc_buffer_t *target);
 
-static bool
+static isc_boolean_t
 name_prefix(dns_name_t *name, const dns_name_t *origin, dns_name_t *target);
 
 static unsigned int
@@ -152,34 +150,34 @@ str_totext(const char *source, isc_buffer_t *target);
 static isc_result_t
 inet_totext(int af, isc_region_t *src, isc_buffer_t *target);
 
-static bool
+static isc_boolean_t
 buffer_empty(isc_buffer_t *source);
 
 static void
 buffer_fromregion(isc_buffer_t *buffer, isc_region_t *region);
 
 static isc_result_t
-uint32_tobuffer(uint32_t, isc_buffer_t *target);
+uint32_tobuffer(isc_uint32_t, isc_buffer_t *target);
 
 static isc_result_t
-uint16_tobuffer(uint32_t, isc_buffer_t *target);
+uint16_tobuffer(isc_uint32_t, isc_buffer_t *target);
 
 static isc_result_t
-uint8_tobuffer(uint32_t, isc_buffer_t *target);
+uint8_tobuffer(isc_uint32_t, isc_buffer_t *target);
 
 static isc_result_t
 name_tobuffer(const dns_name_t *name, isc_buffer_t *target);
 
-static uint32_t
+static isc_uint32_t
 uint32_fromregion(isc_region_t *region);
 
-static uint16_t
+static isc_uint16_t
 uint16_fromregion(isc_region_t *region);
 
-static uint8_t
+static isc_uint8_t
 uint8_fromregion(isc_region_t *region);
 
-static uint8_t
+static isc_uint8_t
 uint8_consume_fromregion(isc_region_t *region);
 
 static isc_result_t
@@ -221,7 +219,7 @@ static void
 warn_badmx(isc_token_t *token, isc_lex_t *lexer,
 	   dns_rdatacallbacks_t *callbacks);
 
-static uint16_t
+static isc_uint16_t
 uint16_consume_fromregion(isc_region_t *region);
 
 static isc_result_t
@@ -379,26 +377,6 @@ locator_pton(const char *src, unsigned char *dst) {
 	return (1);
 }
 
-static inline int
-getquad(const void *src, struct in_addr *dst,
-	isc_lex_t *lexer, dns_rdatacallbacks_t *callbacks)
-{
-	int result;
-	struct in_addr tmp;
-
-	result = inet_aton(src, dst);
-	if (result == 1 && callbacks != NULL &&
-	    inet_pton(AF_INET, src, &tmp) != 1) {
-		const char *name = isc_lex_getsourcename(lexer);
-		if (name == NULL)
-			name = "UNKNOWN";
-		(*callbacks->warn)(callbacks, "%s:%lu: \"%s\" "
-				   "is not a decimal dotted quad", name,
-				   isc_lex_getsourceline(lexer), src);
-	}
-	return (result);
-}
-
 static inline isc_result_t
 name_duporclone(const dns_name_t *source, isc_mem_t *mctx, dns_name_t *target) {
 
@@ -423,7 +401,7 @@ mem_maybedup(isc_mem_t *mctx, void *source, size_t length) {
 
 static inline isc_result_t
 typemap_fromtext(isc_lex_t *lexer, isc_buffer_t *target,
-		 bool allow_empty)
+		 isc_boolean_t allow_empty)
 {
 	isc_token_t token;
 	unsigned char bm[8*1024]; /* 64k bits */
@@ -431,7 +409,7 @@ typemap_fromtext(isc_lex_t *lexer, isc_buffer_t *target,
 	int octet;
 	unsigned int max_octet, newend, end;
 	int window;
-	bool first = true;
+	isc_boolean_t first = ISC_TRUE;
 
 	max_used = 0;
 	bm[0] = 0;
@@ -439,7 +417,7 @@ typemap_fromtext(isc_lex_t *lexer, isc_buffer_t *target,
 
 	do {
 		RETERR(isc_lex_getmastertoken(lexer, &token,
-					      isc_tokentype_string, true));
+					      isc_tokentype_string, ISC_TRUE));
 		if (token.type != isc_tokentype_string)
 			break;
 		RETTOK(dns_rdatatype_fromtext(&covered,
@@ -453,7 +431,7 @@ typemap_fromtext(isc_lex_t *lexer, isc_buffer_t *target,
 			max_used = covered;
 		}
 		bm[covered/8] |= (0x80>>(covered%8));
-		first = false;
+		first = ISC_FALSE;
 	} while (1);
 	isc_lex_ungettoken(lexer, &token);
 	if (!allow_empty && first)
@@ -491,13 +469,13 @@ typemap_totext(isc_region_t *sr, dns_rdata_textctx_t *tctx,
 {
 	unsigned int i, j, k;
 	unsigned int window, len;
-	bool first = true;
+	isc_boolean_t first = ISC_FALSE;
 
 	for (i = 0; i < sr->length; i += len) {
 		if (tctx != NULL &&
 		    (tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0) {
 			RETERR(str_totext(tctx->linebreak, target));
-			first = true;
+			first = ISC_TRUE;
 		}
 		INSIST(i + 2 <= sr->length);
 		window = sr->base[i];
@@ -515,7 +493,7 @@ typemap_totext(isc_region_t *sr, dns_rdata_textctx_t *tctx,
 				t = window * 256 + j * 8 + k;
 				if (!first)
 					RETERR(str_totext(" ", target));
-				first = false;
+				first = ISC_FALSE;
 				if (dns_rdatatype_isknown(t)) {
 					RETERR(dns_rdatatype_totext(t, target));
 				} else {
@@ -530,10 +508,10 @@ typemap_totext(isc_region_t *sr, dns_rdata_textctx_t *tctx,
 }
 
 static isc_result_t
-typemap_test(isc_region_t *sr, bool allow_empty) {
+typemap_test(isc_region_t *sr, isc_boolean_t allow_empty) {
 	unsigned int window, lastwindow = 0;
 	unsigned int len;
-	bool first = true;
+	isc_boolean_t first = ISC_TRUE;
 	unsigned int i;
 
 	for (i = 0; i < sr->length; i += len) {
@@ -566,7 +544,7 @@ typemap_test(isc_region_t *sr, bool allow_empty) {
 		if (sr->base[i + len - 1] == 0)
 			RETERR(DNS_R_FORMERR);
 		lastwindow = window;
-		first = false;
+		first = ISC_FALSE;
 	}
 	if (i != sr->length)
 		return (DNS_R_EXTRADATA);
@@ -646,7 +624,7 @@ dns_rdata_clone(const dns_rdata_t *src, dns_rdata_t *target) {
 int
 dns_rdata_compare(const dns_rdata_t *rdata1, const dns_rdata_t *rdata2) {
 	int result = 0;
-	bool use_default = false;
+	isc_boolean_t use_default = ISC_FALSE;
 
 	REQUIRE(rdata1 != NULL);
 	REQUIRE(rdata2 != NULL);
@@ -677,7 +655,7 @@ dns_rdata_compare(const dns_rdata_t *rdata1, const dns_rdata_t *rdata2) {
 int
 dns_rdata_casecompare(const dns_rdata_t *rdata1, const dns_rdata_t *rdata2) {
 	int result = 0;
-	bool use_default = false;
+	isc_boolean_t use_default = ISC_FALSE;
 
 	REQUIRE(rdata1 != NULL);
 	REQUIRE(rdata2 != NULL);
@@ -748,8 +726,8 @@ dns_rdata_fromwire(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 	isc_region_t region;
 	isc_buffer_t ss;
 	isc_buffer_t st;
-	bool use_default = false;
-	uint32_t activelength;
+	isc_boolean_t use_default = ISC_FALSE;
+	isc_uint32_t activelength;
 	unsigned int length;
 
 	REQUIRE(dctx != NULL);
@@ -814,7 +792,7 @@ dns_rdata_towire(dns_rdata_t *rdata, dns_compress_t *cctx,
 		 isc_buffer_t *target)
 {
 	isc_result_t result = ISC_R_NOTIMPLEMENTED;
-	bool use_default = false;
+	isc_boolean_t use_default = ISC_FALSE;
 	isc_region_t tr;
 	isc_buffer_t st;
 
@@ -844,7 +822,7 @@ dns_rdata_towire(dns_rdata_t *rdata, dns_compress_t *cctx,
 	if (result != ISC_R_SUCCESS) {
 		*target = st;
 		INSIST(target->used < 65536);
-		dns_compress_rollback(cctx, (uint16_t)target->used);
+		dns_compress_rollback(cctx, (isc_uint16_t)target->used);
 	}
 	return (result);
 }
@@ -881,23 +859,20 @@ unknown_fromtext(dns_rdataclass_t rdclass, dns_rdatatype_t type,
 		return (DNS_R_METATYPE);
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-					false));
+					ISC_FALSE));
 	if (token.value.as_ulong > 65535U)
 		return (ISC_R_RANGE);
 	result = isc_buffer_allocate(mctx, &buf, token.value.as_ulong);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
-	if (token.value.as_ulong != 0U) {
-		result = isc_hex_tobuffer(lexer, buf,
-					  (unsigned int)token.value.as_ulong);
-		if (result != ISC_R_SUCCESS) {
-		       goto failure;
-		}
-		if (isc_buffer_usedlength(buf) != token.value.as_ulong) {
-			result = ISC_R_UNEXPECTEDEND;
-			goto failure;
-		}
+	result = isc_hex_tobuffer(lexer, buf,
+				  (unsigned int)token.value.as_ulong);
+	if (result != ISC_R_SUCCESS)
+	       goto failure;
+	if (isc_buffer_usedlength(buf) != token.value.as_ulong) {
+		result = ISC_R_UNEXPECTEDEND;
+		goto failure;
 	}
 
 	if (dns_rdatatype_isknown(type)) {
@@ -936,9 +911,9 @@ dns_rdata_fromtext(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 	void (*callback)(dns_rdatacallbacks_t *, const char *, ...);
 	isc_result_t tresult;
 	unsigned int length;
-	bool unknown;
+	isc_boolean_t unknown;
 
-	REQUIRE(origin == NULL || dns_name_isabsolute(origin) == true);
+	REQUIRE(origin == NULL || dns_name_isabsolute(origin) == ISC_TRUE);
 	if (rdata != NULL) {
 		REQUIRE(DNS_RDATA_INITIALIZED(rdata));
 		REQUIRE(DNS_RDATA_VALIDFLAGS(rdata));
@@ -956,7 +931,7 @@ dns_rdata_fromtext(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 		callback = default_fromtext_callback;
 
 	result = isc_lex_getmastertoken(lexer, &token, isc_tokentype_qstring,
-					true);
+					ISC_FALSE);
 	if (result != ISC_R_SUCCESS) {
 		name = isc_lex_getsourcename(lexer);
 		line = isc_lex_getsourceline(lexer);
@@ -964,7 +939,7 @@ dns_rdata_fromtext(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 		return (result);
 	}
 
-	unknown = false;
+	unknown = ISC_FALSE;
 	if (token.type == isc_tokentype_string &&
 	    strcmp(DNS_AS_STR(token), "\\#") == 0) {
 		/*
@@ -975,13 +950,13 @@ dns_rdata_fromtext(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 		if (type == dns_rdatatype_txt) {
 			result = isc_lex_getmastertoken(lexer, &token,
 							isc_tokentype_number,
-							false);
+							ISC_FALSE);
 			if (result == ISC_R_SUCCESS)
 				isc_lex_ungettoken(lexer, &token);
 		}
 
 		if (result == ISC_R_SUCCESS) {
-			unknown = true;
+			unknown = ISC_TRUE;
 			result = unknown_fromtext(rdclass, type, lexer,
 						  mctx, target);
 		} else
@@ -1090,12 +1065,12 @@ rdata_totext(dns_rdata_t *rdata, dns_rdata_textctx_t *tctx,
 	     isc_buffer_t *target)
 {
 	isc_result_t result = ISC_R_NOTIMPLEMENTED;
-	bool use_default = false;
+	isc_boolean_t use_default = ISC_FALSE;
 	unsigned int cur;
 
 	REQUIRE(rdata != NULL);
 	REQUIRE(tctx->origin == NULL ||
-		dns_name_isabsolute(tctx->origin) == true);
+		dns_name_isabsolute(tctx->origin) == ISC_TRUE);
 
 	/*
 	 * Some DynDNS meta-RRs have empty rdata.
@@ -1179,7 +1154,7 @@ dns_rdata_fromstruct(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 	isc_result_t result = ISC_R_NOTIMPLEMENTED;
 	isc_buffer_t st;
 	isc_region_t region;
-	bool use_default = false;
+	isc_boolean_t use_default = ISC_FALSE;
 	unsigned int length;
 
 	REQUIRE(source != NULL);
@@ -1210,9 +1185,9 @@ dns_rdata_fromstruct(dns_rdata_t *rdata, dns_rdataclass_t rdclass,
 }
 
 isc_result_t
-dns_rdata_tostruct(const dns_rdata_t *rdata, void *target, isc_mem_t *mctx) {
+dns_rdata_tostruct(dns_rdata_t *rdata, void *target, isc_mem_t *mctx) {
 	isc_result_t result = ISC_R_NOTIMPLEMENTED;
-	bool use_default = false;
+	isc_boolean_t use_default = ISC_FALSE;
 
 	REQUIRE(rdata != NULL);
 	REQUIRE(DNS_RDATA_VALIDFLAGS(rdata));
@@ -1238,7 +1213,7 @@ dns_rdata_additionaldata(dns_rdata_t *rdata, dns_additionaldatafunc_t add,
 			 void *arg)
 {
 	isc_result_t result = ISC_R_NOTIMPLEMENTED;
-	bool use_default = false;
+	isc_boolean_t use_default = ISC_FALSE;
 
 	/*
 	 * Call 'add' for each name and type from 'rdata' which is subject to
@@ -1261,7 +1236,7 @@ dns_rdata_additionaldata(dns_rdata_t *rdata, dns_additionaldatafunc_t add,
 isc_result_t
 dns_rdata_digest(dns_rdata_t *rdata, dns_digestfunc_t digest, void *arg) {
 	isc_result_t result = ISC_R_NOTIMPLEMENTED;
-	bool use_default = false;
+	isc_boolean_t use_default = ISC_FALSE;
 	isc_region_t r;
 
 	/*
@@ -1282,21 +1257,21 @@ dns_rdata_digest(dns_rdata_t *rdata, dns_digestfunc_t digest, void *arg) {
 	return (result);
 }
 
-bool
+isc_boolean_t
 dns_rdata_checkowner(const dns_name_t *name, dns_rdataclass_t rdclass,
-		     dns_rdatatype_t type, bool wildcard)
+		     dns_rdatatype_t type, isc_boolean_t wildcard)
 {
-	bool result;
+	isc_boolean_t result;
 
 	CHECKOWNERSWITCH
 	return (result);
 }
 
-bool
+isc_boolean_t
 dns_rdata_checknames(dns_rdata_t *rdata, const dns_name_t *owner,
 		     dns_name_t *bad)
 {
-	bool result;
+	isc_boolean_t result;
 
 	CHECKNAMESSWITCH
 	return (result);
@@ -1406,7 +1381,7 @@ name_length(const dns_name_t *name) {
 }
 
 static isc_result_t
-txt_totext(isc_region_t *source, bool quote, isc_buffer_t *target) {
+txt_totext(isc_region_t *source, isc_boolean_t quote, isc_buffer_t *target) {
 	unsigned int tl;
 	unsigned int n;
 	unsigned char *sp;
@@ -1422,7 +1397,7 @@ txt_totext(isc_region_t *source, bool quote, isc_buffer_t *target) {
 
 	REQUIRE(n + 1 <= source->length);
 	if (n == 0U)
-		REQUIRE(quote == true);
+		REQUIRE(quote == ISC_TRUE);
 
 	if (quote) {
 		if (tl < 1)
@@ -1477,7 +1452,7 @@ txt_totext(isc_region_t *source, bool quote, isc_buffer_t *target) {
 static isc_result_t
 txt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 	isc_region_t tregion;
-	bool escape;
+	isc_boolean_t escape;
 	unsigned int n, nrem;
 	char *s;
 	unsigned char *t;
@@ -1489,7 +1464,7 @@ txt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 	n = source->length;
 	t = tregion.base;
 	nrem = tregion.length;
-	escape = false;
+	escape = ISC_FALSE;
 	if (nrem < 1)
 		return (ISC_R_NOSPACE);
 	/*
@@ -1523,10 +1498,10 @@ txt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 			if (c > 255)
 				return (DNS_R_SYNTAX);
 		} else if (!escape && c == '\\') {
-			escape = true;
+			escape = ISC_TRUE;
 			continue;
 		}
-		escape = false;
+		escape = ISC_FALSE;
 		if (nrem == 0)
 			return ((tregion.length <= 256U) ?
 				ISC_R_NOSPACE : DNS_R_SYNTAX);
@@ -1626,7 +1601,7 @@ multitxt_totext(isc_region_t *source, isc_buffer_t *target) {
 static isc_result_t
 multitxt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 	isc_region_t tregion;
-	bool escape;
+	isc_boolean_t escape;
 	unsigned int n, nrem;
 	char *s;
 	unsigned char *t0, *t;
@@ -1635,7 +1610,7 @@ multitxt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 
 	s = source->base;
 	n = source->length;
-	escape = false;
+	escape = ISC_FALSE;
 
 	do {
 		isc_buffer_availableregion(target, &tregion);
@@ -1666,10 +1641,10 @@ multitxt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 				if (c > 255)
 					return (DNS_R_SYNTAX);
 			} else if (!escape && c == '\\') {
-				escape = true;
+				escape = ISC_TRUE;
 				continue;
 			}
-			escape = false;
+			escape = ISC_FALSE;
 			*t++ = c;
 			nrem--;
 			if (nrem == 0)
@@ -1683,7 +1658,7 @@ multitxt_fromtext(isc_textregion_t *source, isc_buffer_t *target) {
 	return (ISC_R_SUCCESS);
 }
 
-static bool
+static isc_boolean_t
 name_prefix(dns_name_t *name, const dns_name_t *origin, dns_name_t *target) {
 	int l1, l2;
 
@@ -1708,11 +1683,11 @@ name_prefix(dns_name_t *name, const dns_name_t *origin, dns_name_t *target) {
 		goto return_false;
 
 	dns_name_getlabelsequence(name, 0, l1 - l2, target);
-	return (true);
+	return (ISC_TRUE);
 
 return_false:
 	*target = *name;
-	return (false);
+	return (ISC_FALSE);
 }
 
 static isc_result_t
@@ -1744,9 +1719,9 @@ inet_totext(int af, isc_region_t *src, isc_buffer_t *target) {
 	return (ISC_R_SUCCESS);
 }
 
-static bool
+static isc_boolean_t
 buffer_empty(isc_buffer_t *source) {
-	return((source->current == source->active) ? true : false);
+	return((source->current == source->active) ? ISC_TRUE : ISC_FALSE);
 }
 
 static void
@@ -1757,7 +1732,7 @@ buffer_fromregion(isc_buffer_t *buffer, isc_region_t *region) {
 }
 
 static isc_result_t
-uint32_tobuffer(uint32_t value, isc_buffer_t *target) {
+uint32_tobuffer(isc_uint32_t value, isc_buffer_t *target) {
 	isc_region_t region;
 
 	isc_buffer_availableregion(target, &region);
@@ -1768,7 +1743,7 @@ uint32_tobuffer(uint32_t value, isc_buffer_t *target) {
 }
 
 static isc_result_t
-uint16_tobuffer(uint32_t value, isc_buffer_t *target) {
+uint16_tobuffer(isc_uint32_t value, isc_buffer_t *target) {
 	isc_region_t region;
 
 	if (value > 0xffff)
@@ -1776,12 +1751,12 @@ uint16_tobuffer(uint32_t value, isc_buffer_t *target) {
 	isc_buffer_availableregion(target, &region);
 	if (region.length < 2)
 		return (ISC_R_NOSPACE);
-	isc_buffer_putuint16(target, (uint16_t)value);
+	isc_buffer_putuint16(target, (isc_uint16_t)value);
 	return (ISC_R_SUCCESS);
 }
 
 static isc_result_t
-uint8_tobuffer(uint32_t value, isc_buffer_t *target) {
+uint8_tobuffer(isc_uint32_t value, isc_buffer_t *target) {
 	isc_region_t region;
 
 	if (value > 0xff)
@@ -1789,7 +1764,7 @@ uint8_tobuffer(uint32_t value, isc_buffer_t *target) {
 	isc_buffer_availableregion(target, &region);
 	if (region.length < 1)
 		return (ISC_R_NOSPACE);
-	isc_buffer_putuint8(target, (uint8_t)value);
+	isc_buffer_putuint8(target, (isc_uint8_t)value);
 	return (ISC_R_SUCCESS);
 }
 
@@ -1800,27 +1775,27 @@ name_tobuffer(const dns_name_t *name, isc_buffer_t *target) {
 	return (isc_buffer_copyregion(target, &r));
 }
 
-static uint32_t
+static isc_uint32_t
 uint32_fromregion(isc_region_t *region) {
-	uint32_t value;
+	isc_uint32_t value;
 
 	REQUIRE(region->length >= 4);
-	value = (uint32_t)region->base[0] << 24;
-	value |= (uint32_t)region->base[1] << 16;
-	value |= (uint32_t)region->base[2] << 8;
-	value |= (uint32_t)region->base[3];
+	value = (isc_uint32_t)region->base[0] << 24;
+	value |= (isc_uint32_t)region->base[1] << 16;
+	value |= (isc_uint32_t)region->base[2] << 8;
+	value |= (isc_uint32_t)region->base[3];
 	return(value);
 }
 
-static uint16_t
+static isc_uint16_t
 uint16_consume_fromregion(isc_region_t *region) {
-	uint16_t r = uint16_fromregion(region);
+	isc_uint16_t r = uint16_fromregion(region);
 
 	isc_region_consume(region, 2);
 	return r;
 }
 
-static uint16_t
+static isc_uint16_t
 uint16_fromregion(isc_region_t *region) {
 
 	REQUIRE(region->length >= 2);
@@ -1828,7 +1803,7 @@ uint16_fromregion(isc_region_t *region) {
 	return ((region->base[0] << 8) | region->base[1]);
 }
 
-static uint8_t
+static isc_uint8_t
 uint8_fromregion(isc_region_t *region) {
 
 	REQUIRE(region->length >= 1);
@@ -1836,9 +1811,9 @@ uint8_fromregion(isc_region_t *region) {
 	return (region->base[0]);
 }
 
-static uint8_t
+static isc_uint8_t
 uint8_consume_fromregion(isc_region_t *region) {
-	uint8_t r = uint8_fromregion(region);
+	isc_uint8_t r = uint8_fromregion(region);
 
 	isc_region_consume(region, 1);
 	return r;
@@ -1910,11 +1885,11 @@ static const char atob_digits[86] =
 
 
 struct state {
-	int32_t Ceor;
-	int32_t Csum;
-	int32_t Crot;
-	int32_t word;
-	int32_t bcount;
+	isc_int32_t Ceor;
+	isc_int32_t Csum;
+	isc_int32_t Crot;
+	isc_int32_t word;
+	isc_int32_t bcount;
 };
 
 #define Ceor state->Ceor
@@ -1948,15 +1923,15 @@ byte_atob(int c, isc_buffer_t *target, struct state *state) {
 		}
 	} else if ((s = strchr(atob_digits, c)) != NULL) {
 		if (bcount == 0) {
-			word = (int32_t)(s - atob_digits);
+			word = (isc_int32_t)(s - atob_digits);
 			++bcount;
 		} else if (bcount < 4) {
 			word = times85(word);
-			word += (int32_t)(s - atob_digits);
+			word += (isc_int32_t)(s - atob_digits);
 			++bcount;
 		} else {
 			word = times85(word);
-			word += (int32_t)(s - atob_digits);
+			word += (isc_int32_t)(s - atob_digits);
 			RETERR(putbyte((word >> 24) & 0xff, target, state));
 			RETERR(putbyte((word >> 16) & 0xff, target, state));
 			RETERR(putbyte((word >> 8) & 0xff, target, state));
@@ -2018,7 +1993,7 @@ atob_tobuffer(isc_lex_t *lexer, isc_buffer_t *target) {
 	Ceor = Csum = Crot = word = bcount = 0;
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	while (token.value.as_textregion.length != 0) {
 		if ((c = token.value.as_textregion.base[0]) == 'x') {
 			break;
@@ -2031,7 +2006,7 @@ atob_tobuffer(isc_lex_t *lexer, isc_buffer_t *target) {
 	 * Number of bytes.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	if ((token.value.as_ulong % 4) != 0U) {
 		unsigned long padding = 4 - (token.value.as_ulong % 4);
 		if (isc_buffer_usedlength(target) < padding)
@@ -2043,7 +2018,7 @@ atob_tobuffer(isc_lex_t *lexer, isc_buffer_t *target) {
 	 * Checksum.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	oeor = strtol(DNS_AS_STR(token), &e, 16);
 	if (*e != 0)
 		return (DNS_R_SYNTAX);
@@ -2052,7 +2027,7 @@ atob_tobuffer(isc_lex_t *lexer, isc_buffer_t *target) {
 	 * Checksum.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	osum = strtol(DNS_AS_STR(token), &e, 16);
 	if (*e != 0)
 		return (DNS_R_SYNTAX);
@@ -2061,7 +2036,7 @@ atob_tobuffer(isc_lex_t *lexer, isc_buffer_t *target) {
 	 * Checksum.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	orot = strtol(DNS_AS_STR(token), &e, 16);
 	if (*e != 0)
 		return (DNS_R_SYNTAX);
@@ -2101,25 +2076,25 @@ byte_btoa(int c, isc_buffer_t *target, struct state *state) {
 			isc_buffer_add(target, 1);
 		} else {
 		    register int tmp = 0;
-		    register int32_t tmpword = word;
+		    register isc_int32_t tmpword = word;
 
 		    if (tmpword < 0) {
 			   /*
 			    * Because some don't support u_long.
 			    */
 			tmp = 32;
-			tmpword -= (int32_t)(85 * 85 * 85 * 85 * 32);
+			tmpword -= (isc_int32_t)(85 * 85 * 85 * 85 * 32);
 		    }
 		    if (tmpword < 0) {
 			tmp = 64;
-			tmpword -= (int32_t)(85 * 85 * 85 * 85 * 32);
+			tmpword -= (isc_int32_t)(85 * 85 * 85 * 85 * 32);
 		    }
 			if (tr.length < 5)
 				return (ISC_R_NOSPACE);
 			tr.base[0] = atob_digits[(tmpword /
-					      (int32_t)(85 * 85 * 85 * 85))
+					      (isc_int32_t)(85 * 85 * 85 * 85))
 						+ tmp];
-			tmpword %= (int32_t)(85 * 85 * 85 * 85);
+			tmpword %= (isc_int32_t)(85 * 85 * 85 * 85);
 			tr.base[1] = atob_digits[tmpword / (85 * 85 * 85)];
 			tmpword %= (85 * 85 * 85);
 			tr.base[2] = atob_digits[tmpword / (85 * 85)];
@@ -2275,86 +2250,77 @@ dns_rdata_covers(dns_rdata_t *rdata) {
 	return (covers_sig(rdata));
 }
 
-bool
+isc_boolean_t
 dns_rdatatype_ismeta(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_META) != 0)
-		return (true);
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
-bool
+isc_boolean_t
 dns_rdatatype_issingleton(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_SINGLETON)
 	    != 0)
-		return (true);
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
-bool
+isc_boolean_t
 dns_rdatatype_notquestion(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_NOTQUESTION)
 	    != 0)
-		return (true);
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
-bool
+isc_boolean_t
 dns_rdatatype_questiononly(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_QUESTIONONLY)
 	    != 0)
-		return (true);
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
-bool
-dns_rdatatype_atcname(dns_rdatatype_t type) {
-	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_ATCNAME) != 0) {
-		return (true);
-	}
-	return (false);
-}
-
-bool
+isc_boolean_t
 dns_rdatatype_atparent(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_ATPARENT) != 0)
-		return (true);
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
-bool
+isc_boolean_t
 dns_rdataclass_ismeta(dns_rdataclass_t rdclass) {
 
 	if (rdclass == dns_rdataclass_reserved0
 	    || rdclass == dns_rdataclass_none
 	    || rdclass == dns_rdataclass_any)
-		return (true);
+		return (ISC_TRUE);
 
-	return (false);  /* Assume it is not a meta class. */
+	return (ISC_FALSE);  /* Assume it is not a meta class. */
 }
 
-bool
+isc_boolean_t
 dns_rdatatype_isdnssec(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_DNSSEC) != 0)
-		return (true);
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
-bool
+isc_boolean_t
 dns_rdatatype_iszonecutauth(dns_rdatatype_t type) {
-	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_ZONECUTAUTH)
+	if ((dns_rdatatype_attributes(type)
+	     & (DNS_RDATATYPEATTR_DNSSEC | DNS_RDATATYPEATTR_ZONECUTAUTH))
 	    != 0)
-	{
-		return (true);
-	}
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
-bool
+isc_boolean_t
 dns_rdatatype_isknown(dns_rdatatype_t type) {
 	if ((dns_rdatatype_attributes(type) & DNS_RDATATYPEATTR_UNKNOWN)
 	    == 0)
-		return (true);
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
 void
