@@ -19,7 +19,7 @@ static inline isc_result_t
 fromtext_any_tsig(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
-	uint64_t sigtime;
+	isc_uint64_t sigtime;
 	isc_buffer_t buffer;
 	dns_rcode_t rcode;
 	long i;
@@ -36,7 +36,7 @@ fromtext_any_tsig(ARGS_FROMTEXT) {
 	 * Algorithm Name.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
 	if (origin == NULL)
@@ -47,20 +47,20 @@ fromtext_any_tsig(ARGS_FROMTEXT) {
 	 * Time Signed: 48 bits.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
-	sigtime = isc_string_touint64(DNS_AS_STR(token), &e, 10);
+				      ISC_FALSE));
+	sigtime = strtoull(DNS_AS_STR(token), &e, 10);
 	if (*e != 0)
 		RETTOK(DNS_R_SYNTAX);
 	if ((sigtime >> 48) != 0)
 		RETTOK(ISC_R_RANGE);
-	RETERR(uint16_tobuffer((uint16_t)(sigtime >> 32), target));
-	RETERR(uint32_tobuffer((uint32_t)(sigtime & 0xffffffffU), target));
+	RETERR(uint16_tobuffer((isc_uint16_t)(sigtime >> 32), target));
+	RETERR(uint32_tobuffer((isc_uint32_t)(sigtime & 0xffffffffU), target));
 
 	/*
 	 * Fudge.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
 	RETERR(uint16_tobuffer(token.value.as_ulong, target));
@@ -69,7 +69,7 @@ fromtext_any_tsig(ARGS_FROMTEXT) {
 	 * Signature Size.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
 	RETERR(uint16_tobuffer(token.value.as_ulong, target));
@@ -83,7 +83,7 @@ fromtext_any_tsig(ARGS_FROMTEXT) {
 	 * Original ID.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
 	RETERR(uint16_tobuffer(token.value.as_ulong, target));
@@ -92,7 +92,7 @@ fromtext_any_tsig(ARGS_FROMTEXT) {
 	 * Error.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	if (dns_tsigrcode_fromtext(&rcode, &token.value.as_textregion)
 				!= ISC_R_SUCCESS)
 	{
@@ -109,7 +109,7 @@ fromtext_any_tsig(ARGS_FROMTEXT) {
 	 * Other Len.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
 	RETERR(uint16_tobuffer(token.value.as_ulong, target));
@@ -128,8 +128,8 @@ totext_any_tsig(ARGS_TOTEXT) {
 	char *bufp;
 	dns_name_t name;
 	dns_name_t prefix;
-	bool sub;
-	uint64_t sigtime;
+	isc_boolean_t sub;
+	isc_uint64_t sigtime;
 	unsigned short n;
 
 	REQUIRE(rdata->type == dns_rdatatype_tsig);
@@ -151,12 +151,12 @@ totext_any_tsig(ARGS_TOTEXT) {
 	/*
 	 * Time Signed.
 	 */
-	sigtime = ((uint64_t)sr.base[0] << 40) |
-		  ((uint64_t)sr.base[1] << 32) |
-		  ((uint64_t)sr.base[2] << 24) |
-		  ((uint64_t)sr.base[3] << 16) |
-		  ((uint64_t)sr.base[4] << 8) |
-		  (uint64_t)sr.base[5];
+	sigtime = ((isc_uint64_t)sr.base[0] << 40) |
+		  ((isc_uint64_t)sr.base[1] << 32) |
+		  ((isc_uint64_t)sr.base[2] << 24) |
+		  ((isc_uint64_t)sr.base[3] << 16) |
+		  ((isc_uint64_t)sr.base[4] << 8) |
+		  (isc_uint64_t)sr.base[5];
 	isc_region_consume(&sr, 6);
 	bufp = &buf[sizeof(buf) - 1];
 	*bufp-- = 0;
@@ -187,26 +187,22 @@ totext_any_tsig(ARGS_TOTEXT) {
 	/*
 	 * Signature.
 	 */
-	if (n != 0U) {
-		REQUIRE(n <= sr.length);
-		sigr = sr;
-		sigr.length = n;
-		if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0)
-			RETERR(str_totext(" (", target));
-		RETERR(str_totext(tctx->linebreak, target));
-		if (tctx->width == 0)   /* No splitting */
-			RETERR(isc_base64_totext(&sigr, 60, "", target));
-		else
-			RETERR(isc_base64_totext(&sigr, tctx->width - 2,
-						 tctx->linebreak, target));
-		if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0)
-			RETERR(str_totext(" ) ", target));
-		else
-			RETERR(str_totext(" ", target));
-		isc_region_consume(&sr, n);
-	} else {
+	REQUIRE(n <= sr.length);
+	sigr = sr;
+	sigr.length = n;
+	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0)
+		RETERR(str_totext(" (", target));
+	RETERR(str_totext(tctx->linebreak, target));
+	if (tctx->width == 0)   /* No splitting */
+		RETERR(isc_base64_totext(&sigr, 60, "", target));
+	else
+		RETERR(isc_base64_totext(&sigr, tctx->width - 2,
+					 tctx->linebreak, target));
+	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0)
+		RETERR(str_totext(" ) ", target));
+	else
 		RETERR(str_totext(" ", target));
-	}
+	isc_region_consume(&sr, n);
 
 	/*
 	 * Original ID.
@@ -377,9 +373,9 @@ fromstruct_any_tsig(ARGS_FROMSTRUCT) {
 	/*
 	 * Time Signed: 48 bits.
 	 */
-	RETERR(uint16_tobuffer((uint16_t)(tsig->timesigned >> 32),
+	RETERR(uint16_tobuffer((isc_uint16_t)(tsig->timesigned >> 32),
 			       target));
-	RETERR(uint32_tobuffer((uint32_t)(tsig->timesigned & 0xffffffffU),
+	RETERR(uint32_tobuffer((isc_uint32_t)(tsig->timesigned & 0xffffffffU),
 			       target));
 
 	/*
@@ -453,12 +449,12 @@ tostruct_any_tsig(ARGS_TOSTRUCT) {
 	 * Time Signed.
 	 */
 	INSIST(sr.length >= 6);
-	tsig->timesigned = ((uint64_t)sr.base[0] << 40) |
-			   ((uint64_t)sr.base[1] << 32) |
-			   ((uint64_t)sr.base[2] << 24) |
-			   ((uint64_t)sr.base[3] << 16) |
-			   ((uint64_t)sr.base[4] << 8) |
-			   (uint64_t)sr.base[5];
+	tsig->timesigned = ((isc_uint64_t)sr.base[0] << 40) |
+			   ((isc_uint64_t)sr.base[1] << 32) |
+			   ((isc_uint64_t)sr.base[2] << 24) |
+			   ((isc_uint64_t)sr.base[3] << 16) |
+			   ((isc_uint64_t)sr.base[4] << 8) |
+			   (isc_uint64_t)sr.base[5];
 	isc_region_consume(&sr, 6);
 
 	/*
@@ -563,7 +559,7 @@ digest_any_tsig(ARGS_DIGEST) {
 	return (ISC_R_NOTIMPLEMENTED);
 }
 
-static inline bool
+static inline isc_boolean_t
 checkowner_any_tsig(ARGS_CHECKOWNER) {
 
 	REQUIRE(type == dns_rdatatype_tsig);
@@ -574,10 +570,10 @@ checkowner_any_tsig(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
-static inline bool
+static inline isc_boolean_t
 checknames_any_tsig(ARGS_CHECKNAMES) {
 
 	REQUIRE(rdata->type == dns_rdatatype_tsig);
@@ -587,7 +583,7 @@ checknames_any_tsig(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static inline int
