@@ -30,18 +30,18 @@ fromtext_csync(ARGS_FROMTEXT) {
 
 	/* Serial. */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	RETERR(uint32_tobuffer(token.value.as_ulong, target));
 
 	/* Flags. */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
 	RETERR(uint16_tobuffer(token.value.as_ulong, target));
 
 	/* Type Map */
-	return (typemap_fromtext(lexer, target, true));
+	return (typemap_fromtext(lexer, target, ISC_TRUE));
 }
 
 static inline isc_result_t
@@ -69,12 +69,6 @@ totext_csync(ARGS_TOTEXT) {
 	snprintf(buf, sizeof(buf), "%lu", num);
 	RETERR(str_totext(buf, target));
 
-	/*
-	 * Don't leave a trailing space when there's no typemap present.
-	 */
-	if (sr.length > 0) {
-		RETERR(str_totext(" ", target));
-	}
 	return (typemap_totext(&sr, NULL, target));
 }
 
@@ -100,7 +94,7 @@ fromwire_csync(ARGS_FROMWIRE) {
 	isc_buffer_forward(source, 6);
 	isc_region_consume(&sr, 6);
 
-	RETERR(typemap_test(&sr, true));
+	RETERR(typemap_test(&sr, ISC_TRUE));
 
 	RETERR(mem_tobuffer(target, sr.base, sr.length));
 	isc_buffer_forward(source, sr.length);
@@ -140,7 +134,7 @@ fromstruct_csync(ARGS_FROMSTRUCT) {
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_csync);
-	REQUIRE(csync != NULL);
+	REQUIRE(source != NULL);
 	REQUIRE(csync->common.rdtype == type);
 	REQUIRE(csync->common.rdclass == rdclass);
 	REQUIRE(csync->typebits != NULL || csync->len == 0);
@@ -153,7 +147,7 @@ fromstruct_csync(ARGS_FROMSTRUCT) {
 
 	region.base = csync->typebits;
 	region.length = csync->len;
-	RETERR(typemap_test(&region, true));
+	RETERR(typemap_test(&region, ISC_TRUE));
 	return (mem_tobuffer(target, csync->typebits, csync->len));
 }
 
@@ -163,7 +157,7 @@ tostruct_csync(ARGS_TOSTRUCT) {
 	dns_rdata_csync_t *csync = target;
 
 	REQUIRE(rdata->type == dns_rdatatype_csync);
-	REQUIRE(csync != NULL);
+	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
 	csync->common.rdclass = rdata->rdclass;
@@ -194,7 +188,7 @@ static inline void
 freestruct_csync(ARGS_FREESTRUCT) {
 	dns_rdata_csync_t *csync = source;
 
-	REQUIRE(csync != NULL);
+	REQUIRE(source != NULL);
 	REQUIRE(csync->common.rdtype == dns_rdatatype_csync);
 
 	if (csync->mctx == NULL)
@@ -226,7 +220,7 @@ digest_csync(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline bool
+static inline isc_boolean_t
 checkowner_csync(ARGS_CHECKOWNER) {
 
        REQUIRE(type == dns_rdatatype_csync);
@@ -236,10 +230,10 @@ checkowner_csync(ARGS_CHECKOWNER) {
        UNUSED(rdclass);
        UNUSED(wildcard);
 
-       return (true);
+       return (ISC_TRUE);
 }
 
-static inline bool
+static inline isc_boolean_t
 checknames_csync(ARGS_CHECKNAMES) {
 
 	REQUIRE(rdata->type == dns_rdatatype_csync);
@@ -248,7 +242,7 @@ checknames_csync(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static inline int
