@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -19,7 +19,7 @@ fromtext_ns(ARGS_FROMTEXT) {
 	isc_token_t token;
 	dns_name_t name;
 	isc_buffer_t buffer;
-	bool ok;
+	isc_boolean_t ok;
 
 	REQUIRE(type == dns_rdatatype_ns);
 
@@ -28,16 +28,16 @@ fromtext_ns(ARGS_FROMTEXT) {
 	UNUSED(callbacks);
 
 	RETERR(isc_lex_getmastertoken(lexer, &token,isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
 	if (origin == NULL)
 		origin = dns_rootname;
 	RETTOK(dns_name_fromtext(&name, &buffer, origin, options, target));
-	ok = true;
+	ok = ISC_TRUE;
 	if ((options & DNS_RDATA_CHECKNAMES) != 0)
-		ok = dns_name_ishostname(&name, false);
+		ok = dns_name_ishostname(&name, ISC_FALSE);
 	if (!ok && (options & DNS_RDATA_CHECKNAMESFAIL) != 0)
 		RETTOK(DNS_R_BADNAME);
 	if (!ok && callbacks != NULL)
@@ -50,7 +50,7 @@ totext_ns(ARGS_TOTEXT) {
 	isc_region_t region;
 	dns_name_t name;
 	dns_name_t prefix;
-	bool sub;
+	isc_boolean_t sub;
 
 	REQUIRE(rdata->type == dns_rdatatype_ns);
 	REQUIRE(rdata->length != 0);
@@ -126,15 +126,13 @@ compare_ns(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_ns(ARGS_FROMSTRUCT) {
-	dns_rdata_ns_t *ns;
+	dns_rdata_ns_t *ns = source;
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_ns);
-	REQUIRE(((dns_rdata_ns_t *)source) != NULL);
-	REQUIRE(((dns_rdata_ns_t *)source)->common.rdtype == type);
-	REQUIRE(((dns_rdata_ns_t *)source)->common.rdclass == rdclass);
-
-	ns = source;
+	REQUIRE(source != NULL);
+	REQUIRE(ns->common.rdtype == type);
+	REQUIRE(ns->common.rdclass == rdclass);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -146,15 +144,13 @@ fromstruct_ns(ARGS_FROMSTRUCT) {
 static inline isc_result_t
 tostruct_ns(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_ns_t *ns;
+	dns_rdata_ns_t *ns = target;
 	dns_name_t name;
 
-	REQUIRE(((dns_rdata_ns_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_ns);
+	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
-	ns = target;
-
 	ns->common.rdclass = rdata->rdclass;
 	ns->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&ns->common, link);
@@ -170,11 +166,9 @@ tostruct_ns(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_ns(ARGS_FREESTRUCT) {
-	dns_rdata_ns_t *ns;
+	dns_rdata_ns_t *ns = source;
 
-	REQUIRE(((dns_rdata_ns_t *)source) != NULL);
-
-	ns = source;
+	REQUIRE(source != NULL);
 
 	if (ns->mctx == NULL)
 		return;
@@ -212,7 +206,7 @@ digest_ns(ARGS_DIGEST) {
 	return (dns_name_digest(&name, digest, arg));
 }
 
-static inline bool
+static inline isc_boolean_t
 checkowner_ns(ARGS_CHECKOWNER) {
 
 	REQUIRE(type == dns_rdatatype_ns);
@@ -222,10 +216,10 @@ checkowner_ns(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 	UNUSED(wildcard);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
-static inline bool
+static inline isc_boolean_t
 checknames_ns(ARGS_CHECKNAMES) {
 	isc_region_t region;
 	dns_name_t name;
@@ -237,12 +231,12 @@ checknames_ns(ARGS_CHECKNAMES) {
 	dns_rdata_toregion(rdata, &region);
 	dns_name_init(&name, NULL);
 	dns_name_fromregion(&name, &region);
-	if (!dns_name_ishostname(&name, false)) {
+	if (!dns_name_ishostname(&name, ISC_FALSE)) {
 		if (bad != NULL)
 			dns_name_clone(&name, bad);
-		return (false);
+		return (ISC_FALSE);
 	}
-	return (true);
+	return (ISC_TRUE);
 }
 
 static inline int
