@@ -54,13 +54,13 @@ fromtext_nsec3(ARGS_FROMTEXT) {
 
 	/* Hash. */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	RETTOK(dns_hashalg_fromtext(&hashalg, &token.value.as_textregion));
 	RETERR(uint8_tobuffer(hashalg, target));
 
 	/* Flags. */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	flags = token.value.as_ulong;
 	if (flags > 255U)
 		RETTOK(ISC_R_RANGE);
@@ -68,14 +68,14 @@ fromtext_nsec3(ARGS_FROMTEXT) {
 
 	/* Iterations. */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_number,
-				      false));
+				      ISC_FALSE));
 	if (token.value.as_ulong > 0xffffU)
 		RETTOK(ISC_R_RANGE);
 	RETERR(uint16_tobuffer(token.value.as_ulong, target));
 
 	/* salt */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	if (token.value.as_textregion.length > (255*2))
 		RETTOK(DNS_R_TEXTTOOLONG);
 	if (strcmp(DNS_AS_STR(token), "-") == 0) {
@@ -89,7 +89,7 @@ fromtext_nsec3(ARGS_FROMTEXT) {
 	 * Next hash a single base32hex word.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	isc_buffer_init(&b, buf, sizeof(buf));
 	RETTOK(isc_base32hexnp_decodestring(DNS_AS_STR(token), &b));
 	if (isc_buffer_usedlength(&b) > 0xffU)
@@ -97,7 +97,7 @@ fromtext_nsec3(ARGS_FROMTEXT) {
 	RETERR(uint8_tobuffer(isc_buffer_usedlength(&b), target));
 	RETERR(mem_tobuffer(target, &buf, isc_buffer_usedlength(&b)));
 
-	return (typemap_fromtext(lexer, target, true));
+	return (typemap_fromtext(lexer, target, ISC_TRUE));
 }
 
 static inline isc_result_t
@@ -107,7 +107,7 @@ totext_nsec3(ARGS_TOTEXT) {
 	unsigned char hash;
 	unsigned char flags;
 	char buf[sizeof("TYPE65535")];
-	uint32_t iterations;
+	isc_uint32_t iterations;
 
 	REQUIRE(rdata->type == dns_rdatatype_nsec3);
 	REQUIRE(rdata->length != 0);
@@ -162,9 +162,9 @@ totext_nsec3(ARGS_TOTEXT) {
 	/*
 	 * Don't leave a trailing space when there's no typemap present.
 	 */
-	if (((tctx->flags & DNS_STYLEFLAG_MULTILINE) == 0) && (sr.length > 0)) {
+	if (((tctx->flags & DNS_STYLEFLAG_MULTILINE) == 0) && (sr.length > 0))
 		RETERR(str_totext(" ", target));
-	}
+
 	RETERR(typemap_totext(&sr, tctx, target));
 
 	if ((tctx->flags & DNS_STYLEFLAG_MULTILINE) != 0)
@@ -203,12 +203,11 @@ fromwire_nsec3(ARGS_FROMWIRE) {
 	hashlen = sr.base[0];
 	isc_region_consume(&sr, 1);
 
-	if (hashlen < 1 || sr.length < hashlen) {
+	if (sr.length < hashlen)
 		RETERR(DNS_R_FORMERR);
-	}
 	isc_region_consume(&sr, hashlen);
 
-	RETERR(typemap_test(&sr, true));
+	RETERR(typemap_test(&sr, ISC_TRUE));
 
 	RETERR(mem_tobuffer(target, rr.base, rr.length));
 	isc_buffer_forward(source, rr.length);
@@ -246,18 +245,15 @@ compare_nsec3(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_nsec3(ARGS_FROMSTRUCT) {
-	dns_rdata_nsec3_t *nsec3;
+	dns_rdata_nsec3_t *nsec3 = source;
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_nsec3);
-	REQUIRE(((dns_rdata_nsec3_t *)source) != NULL);
-	REQUIRE(((dns_rdata_nsec3_t *)source)->common.rdtype == type);
-	REQUIRE(((dns_rdata_nsec3_t *)source)->common.rdclass == rdclass);
-	REQUIRE(((dns_rdata_nsec3_t *)source)->typebits != NULL ||
-		((dns_rdata_nsec3_t *)source)->len == 0);
-	REQUIRE(((dns_rdata_nsec3_t *)source)->hash == dns_hash_sha1);
-
-	nsec3 = source;
+	REQUIRE(source != NULL);
+	REQUIRE(nsec3->common.rdtype == type);
+	REQUIRE(nsec3->common.rdclass == rdclass);
+	REQUIRE(nsec3->typebits != NULL || nsec3->len == 0);
+	REQUIRE(nsec3->hash == dns_hash_sha1);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -272,21 +268,19 @@ fromstruct_nsec3(ARGS_FROMSTRUCT) {
 
 	region.base = nsec3->typebits;
 	region.length = nsec3->len;
-	RETERR(typemap_test(&region, true));
+	RETERR(typemap_test(&region, ISC_TRUE));
 	return (mem_tobuffer(target, nsec3->typebits, nsec3->len));
 }
 
 static inline isc_result_t
 tostruct_nsec3(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_nsec3_t *nsec3;
+	dns_rdata_nsec3_t *nsec3 = target;
 
-	REQUIRE(((dns_rdata_nsec3_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_nsec3);
+	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
-	nsec3 = target;
-
 	nsec3->common.rdclass = rdata->rdclass;
 	nsec3->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&nsec3->common, link);
@@ -326,13 +320,10 @@ tostruct_nsec3(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_nsec3(ARGS_FREESTRUCT) {
-	dns_rdata_nsec3_t *nsec3;
+	dns_rdata_nsec3_t *nsec3 = source;
 
-	REQUIRE(((dns_rdata_nsec3_t *)source) != NULL);
-	REQUIRE(((dns_rdata_nsec3_t *)source)->common.rdtype ==
-		dns_rdatatype_nsec3);
-
-	nsec3 = source;
+	REQUIRE(source != NULL);
+	REQUIRE(nsec3->common.rdtype == dns_rdatatype_nsec3);
 
 	if (nsec3->mctx == NULL)
 		return;
@@ -367,7 +358,7 @@ digest_nsec3(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline bool
+static inline isc_boolean_t
 checkowner_nsec3(ARGS_CHECKOWNER) {
 	unsigned char owner[NSEC3_MAX_HASH_LENGTH];
 	isc_buffer_t buffer;
@@ -386,12 +377,12 @@ checkowner_nsec3(ARGS_CHECKOWNER) {
 	isc_region_consume(&label, 1);
 	isc_buffer_init(&buffer, owner, sizeof(owner));
 	if (isc_base32hexnp_decoderegion(&label, &buffer) == ISC_R_SUCCESS)
-		return (true);
+		return (ISC_TRUE);
 
-	return (false);
+	return (ISC_FALSE);
 }
 
-static inline bool
+static inline isc_boolean_t
 checknames_nsec3(ARGS_CHECKNAMES) {
 
 	REQUIRE(rdata->type == dns_rdatatype_nsec3);
@@ -400,7 +391,7 @@ checknames_nsec3(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static inline int
