@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -18,9 +18,7 @@
  * The attributes do not include DNS_RDATATYPEATTR_SINGLETON
  * because we must be able to handle a parent/child NSEC pair.
  */
-#define RRTYPE_NSEC_ATTRIBUTES \
-	( DNS_RDATATYPEATTR_DNSSEC | DNS_RDATATYPEATTR_ZONECUTAUTH | \
-	  DNS_RDATATYPEATTR_ATCNAME )
+#define RRTYPE_NSEC_ATTRIBUTES (DNS_RDATATYPEATTR_DNSSEC)
 
 static inline isc_result_t
 fromtext_nsec(ARGS_FROMTEXT) {
@@ -38,14 +36,14 @@ fromtext_nsec(ARGS_FROMTEXT) {
 	 * Next domain.
 	 */
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 	dns_name_init(&name, NULL);
 	buffer_fromregion(&buffer, &token.value.as_region);
 	if (origin == NULL)
 		origin = dns_rootname;
 	RETTOK(dns_name_fromtext(&name, &buffer, origin, options, target));
 
-	return (typemap_fromtext(lexer, target, false));
+	return (typemap_fromtext(lexer, target, ISC_FALSE));
 }
 
 static inline isc_result_t
@@ -62,13 +60,7 @@ totext_nsec(ARGS_TOTEXT) {
 	dns_rdata_toregion(rdata, &sr);
 	dns_name_fromregion(&name, &sr);
 	isc_region_consume(&sr, name_length(&name));
-	RETERR(dns_name_totext(&name, false, target));
-	/*
-	 * Don't leave a trailing space when there's no typemap present.
-	 */
-	if (sr.length > 0) {
-		RETERR(str_totext(" ", target));
-	}
+	RETERR(dns_name_totext(&name, ISC_FALSE, target));
 	return (typemap_totext(&sr, NULL, target));
 }
 
@@ -88,7 +80,7 @@ fromwire_nsec(ARGS_FROMWIRE) {
 	RETERR(dns_name_fromwire(&name, source, dctx, options, target));
 
 	isc_buffer_activeregion(source, &sr);
-	RETERR(typemap_test(&sr, false));
+	RETERR(typemap_test(&sr, ISC_FALSE));
 	RETERR(mem_tobuffer(target, sr.base, sr.length));
 	isc_buffer_forward(source, sr.length);
 	return (ISC_R_SUCCESS);
@@ -131,17 +123,14 @@ compare_nsec(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_nsec(ARGS_FROMSTRUCT) {
-	dns_rdata_nsec_t *nsec;
+	dns_rdata_nsec_t *nsec = source;
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_nsec);
-	REQUIRE(((dns_rdata_nsec_t *)source) != NULL);
-	REQUIRE(((dns_rdata_nsec_t *)source)->common.rdtype == type);
-	REQUIRE(((dns_rdata_nsec_t *)source)->common.rdclass == rdclass);
-	REQUIRE(((dns_rdata_nsec_t *)source)->typebits != NULL ||
-		((dns_rdata_nsec_t *)source)->len == 0);
-
-	nsec = source;
+	REQUIRE(source != NULL);
+	REQUIRE(nsec->common.rdtype == type);
+	REQUIRE(nsec->common.rdclass == rdclass);
+	REQUIRE(nsec->typebits != NULL || nsec->len == 0);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -151,22 +140,20 @@ fromstruct_nsec(ARGS_FROMSTRUCT) {
 
 	region.base = nsec->typebits;
 	region.length = nsec->len;
-	RETERR(typemap_test(&region, false));
+	RETERR(typemap_test(&region, ISC_FALSE));
 	return (mem_tobuffer(target, nsec->typebits, nsec->len));
 }
 
 static inline isc_result_t
 tostruct_nsec(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_nsec_t *nsec;
+	dns_rdata_nsec_t *nsec = target;
 	dns_name_t name;
 
-	REQUIRE(((dns_rdata_nsec_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_nsec);
+	REQUIRE(target != NULL);
 	REQUIRE(rdata->length != 0);
 
-	nsec = target;
-
 	nsec->common.rdclass = rdata->rdclass;
 	nsec->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&nsec->common, link);
@@ -194,13 +181,10 @@ tostruct_nsec(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_nsec(ARGS_FREESTRUCT) {
-	dns_rdata_nsec_t *nsec;
+	dns_rdata_nsec_t *nsec = source;
 
-	REQUIRE(((dns_rdata_nsec_t *)source) != NULL);
-	REQUIRE(((dns_rdata_nsec_t *)source)->common.rdtype ==
-		dns_rdatatype_nsec);
-
-	nsec = source;
+	REQUIRE(source != NULL);
+	REQUIRE(nsec->common.rdtype == dns_rdatatype_nsec);
 
 	if (nsec->mctx == NULL)
 		return;
@@ -232,7 +216,7 @@ digest_nsec(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline bool
+static inline isc_boolean_t
 checkowner_nsec(ARGS_CHECKOWNER) {
 
        REQUIRE(type == dns_rdatatype_nsec);
@@ -242,10 +226,10 @@ checkowner_nsec(ARGS_CHECKOWNER) {
        UNUSED(rdclass);
        UNUSED(wildcard);
 
-       return (true);
+       return (ISC_TRUE);
 }
 
-static inline bool
+static inline isc_boolean_t
 checknames_nsec(ARGS_CHECKNAMES) {
 
 	REQUIRE(rdata->type == dns_rdatatype_nsec);
@@ -254,7 +238,7 @@ checknames_nsec(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static inline int
