@@ -31,11 +31,12 @@ fromtext_in_a(ARGS_FROMTEXT) {
 	UNUSED(origin);
 	UNUSED(options);
 	UNUSED(rdclass);
+	UNUSED(callbacks);
 
 	RETERR(isc_lex_getmastertoken(lexer, &token, isc_tokentype_string,
-				      false));
+				      ISC_FALSE));
 
-	if (getquad(DNS_AS_STR(token), &addr, lexer, callbacks) != 1)
+	if (inet_pton(AF_INET, DNS_AS_STR(token), &addr) != 1)
 		RETTOK(DNS_R_BADDOTTEDQUAD);
 	isc_buffer_availableregion(target, &region);
 	if (region.length < 4)
@@ -56,7 +57,7 @@ totext_in_a(ARGS_TOTEXT) {
 	UNUSED(tctx);
 
 	dns_rdata_toregion(rdata, &region);
-	return (inet_totext(AF_INET, tctx->flags, &region, target));
+	return (inet_totext(AF_INET, &region, target));
 }
 
 static inline isc_result_t
@@ -122,16 +123,14 @@ compare_in_a(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_in_a(ARGS_FROMSTRUCT) {
-	dns_rdata_in_a_t *a;
-	uint32_t n;
+	dns_rdata_in_a_t *a = source;
+	isc_uint32_t n;
 
 	REQUIRE(type == dns_rdatatype_a);
 	REQUIRE(rdclass == dns_rdataclass_in);
-	REQUIRE(((dns_rdata_in_a_t *)source) != NULL);
-	REQUIRE(((dns_rdata_in_a_t *)source)->common.rdtype == type);
-	REQUIRE(((dns_rdata_in_a_t *)source)->common.rdclass == rdclass);
-
-	a = source;
+	REQUIRE(source != NULL);
+	REQUIRE(a->common.rdtype == type);
+	REQUIRE(a->common.rdclass == rdclass);
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -144,17 +143,14 @@ fromstruct_in_a(ARGS_FROMSTRUCT) {
 
 static inline isc_result_t
 tostruct_in_a(ARGS_TOSTRUCT) {
-	dns_rdata_in_a_t *a;
-	uint32_t n;
+	dns_rdata_in_a_t *a = target;
+	isc_uint32_t n;
 	isc_region_t region;
 
-	REQUIRE(((dns_rdata_in_a_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_a);
 	REQUIRE(rdata->rdclass == dns_rdataclass_in);
 	REQUIRE(rdata->length == 4);
 
-	a = target;
-
 	UNUSED(mctx);
 
 	a->common.rdclass = rdata->rdclass;
@@ -170,14 +166,11 @@ tostruct_in_a(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_in_a(ARGS_FREESTRUCT) {
-	dns_rdata_in_a_t *a;
+	dns_rdata_in_a_t *a = source;
 
-	REQUIRE(((dns_rdata_in_a_t *)source) != NULL);
-	REQUIRE(((dns_rdata_in_a_t *)source)->common.rdtype == dns_rdatatype_a);
-	REQUIRE(((dns_rdata_in_a_t *)source)->common.rdclass ==
-		dns_rdataclass_in);
-
-	a = source;
+	REQUIRE(source != NULL);
+	REQUIRE(a->common.rdtype == dns_rdatatype_a);
+	REQUIRE(a->common.rdclass == dns_rdataclass_in);
 
 	UNUSED(a);
 }
@@ -206,7 +199,7 @@ digest_in_a(ARGS_DIGEST) {
 	return ((digest)(arg, &r));
 }
 
-static inline bool
+static inline isc_boolean_t
 checkowner_in_a(ARGS_CHECKOWNER) {
 	dns_name_t prefix, suffix;
 
@@ -217,7 +210,7 @@ checkowner_in_a(ARGS_CHECKOWNER) {
 	UNUSED(rdclass);
 
 	/*
-	 * Handle Active Directory gc._msdcs.<forest> name.
+	 * Handle Active Diretory gc._msdcs.<forest> name.
 	 */
 	if (dns_name_countlabels(name) > 2U) {
 		dns_name_init(&prefix, NULL);
@@ -225,14 +218,14 @@ checkowner_in_a(ARGS_CHECKOWNER) {
 		dns_name_split(name, dns_name_countlabels(name) - 2,
 			       &prefix, &suffix);
 		if (dns_name_equal(&gc_msdcs, &prefix) &&
-		    dns_name_ishostname(&suffix, false))
-			return (true);
+		    dns_name_ishostname(&suffix, ISC_FALSE))
+			return (ISC_TRUE);
 	}
 
 	return (dns_name_ishostname(name, wildcard));
 }
 
-static inline bool
+static inline isc_boolean_t
 checknames_in_a(ARGS_CHECKNAMES) {
 
 	REQUIRE(rdata->type == dns_rdatatype_a);
@@ -242,7 +235,7 @@ checknames_in_a(ARGS_CHECKNAMES) {
 	UNUSED(owner);
 	UNUSED(bad);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static inline int
