@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -19,7 +19,7 @@
 typedef struct dns_rdata_in_px {
 	dns_rdatacommon_t	common;
 	isc_mem_t		*mctx;
-	uint16_t		preference;
+	isc_uint16_t		preference;
 	dns_name_t		map822;
 	dns_name_t		mapx400;
 } dns_rdata_in_px_t;
