@@ -14,9 +14,6 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-#include <stdbool.h>
-
 #include <isc/magic.h>
 #include <isc/mem.h>
 #include <isc/task.h>
@@ -51,15 +48,15 @@ struct dns_requestmgr {
 	isc_mem_t		       *mctx;
 
 	/* locked */
-	int32_t			eref;
-	int32_t			iref;
+	isc_int32_t			eref;
+	isc_int32_t			iref;
 	isc_timermgr_t		       *timermgr;
 	isc_socketmgr_t		       *socketmgr;
 	isc_taskmgr_t		       *taskmgr;
 	dns_dispatchmgr_t	       *dispatchmgr;
 	dns_dispatch_t		       *dispatchv4;
 	dns_dispatch_t		       *dispatchv6;
-	bool			exiting;
+	isc_boolean_t			exiting;
 	isc_eventlist_t			whenshutdown;
 	unsigned int			hash;
 	isc_mutex_t			locks[DNS_REQUEST_NLOCKS];
@@ -70,7 +67,7 @@ struct dns_request {
 	unsigned int			magic;
 	unsigned int			hash;
 	isc_mem_t		       *mctx;
-	int32_t			flags;
+	isc_int32_t			flags;
 	ISC_LINK(dns_request_t) 	link;
 	isc_buffer_t		       *query;
 	isc_buffer_t		       *answer;
@@ -82,7 +79,7 @@ struct dns_request {
 	isc_buffer_t		       *tsig;
 	dns_tsigkey_t		       *tsigkey;
 	isc_event_t			ctlevent;
-	bool			canceling; /* ctlevent outstanding */
+	isc_boolean_t			canceling; /* ctlevent outstanding */
 	isc_sockaddr_t			destaddr;
 	unsigned int			udpcount;
 	isc_dscp_t			dscp;
@@ -141,6 +138,7 @@ dns_requestmgr_create(isc_mem_t *mctx,
 		      dns_requestmgr_t **requestmgrp)
 {
 	dns_requestmgr_t *requestmgr;
+	isc_socket_t *sock;
 	isc_result_t result;
 	int i;
 	unsigned int dispattr;
@@ -152,7 +150,7 @@ dns_requestmgr_create(isc_mem_t *mctx,
 	REQUIRE(socketmgr != NULL);
 	REQUIRE(taskmgr != NULL);
 	REQUIRE(dispatchmgr != NULL);
-
+	UNUSED(sock);
 	if (dispatchv4 != NULL) {
 		dispattr = dns_dispatch_getattributes(dispatchv4);
 		REQUIRE((dispattr & DNS_DISPATCHATTR_UDP) != 0);
@@ -197,7 +195,7 @@ dns_requestmgr_create(isc_mem_t *mctx,
 	requestmgr->iref = 0;
 	ISC_LIST_INIT(requestmgr->whenshutdown);
 	ISC_LIST_INIT(requestmgr->requests);
-	requestmgr->exiting = false;
+	requestmgr->exiting = ISC_FALSE;
 	requestmgr->hash = 0;
 	requestmgr->magic = REQUESTMGR_MAGIC;
 
@@ -259,7 +257,7 @@ mgr_shutdown(dns_requestmgr_t *requestmgr) {
 	 * Caller holds lock.
 	 */
 	if (!requestmgr->exiting) {
-		requestmgr->exiting = true;
+		requestmgr->exiting = ISC_TRUE;
 		for (request = ISC_LIST_HEAD(requestmgr->requests);
 		     request != NULL;
 		     request = ISC_LIST_NEXT(request, link)) {
@@ -294,7 +292,7 @@ requestmgr_attach(dns_requestmgr_t *source, dns_requestmgr_t **targetp) {
 static void
 requestmgr_detach(dns_requestmgr_t **requestmgrp) {
 	dns_requestmgr_t *requestmgr;
-	bool need_destroy = false;
+	isc_boolean_t need_destroy = ISC_FALSE;
 
 	REQUIRE(requestmgrp != NULL);
 	requestmgr = *requestmgrp;
@@ -312,7 +310,7 @@ requestmgr_detach(dns_requestmgr_t **requestmgrp) {
 		INSIST(ISC_LIST_HEAD(requestmgr->requests) == NULL);
 		send_shutdown_events(requestmgr);
 		if (requestmgr->eref == 0)
-			need_destroy = true;
+			need_destroy = ISC_TRUE;
 	}
 	UNLOCK(&requestmgr->lock);
 
@@ -339,7 +337,7 @@ dns_requestmgr_attach(dns_requestmgr_t *source, dns_requestmgr_t **targetp) {
 void
 dns_requestmgr_detach(dns_requestmgr_t **requestmgrp) {
 	dns_requestmgr_t *requestmgr;
-	bool need_destroy = false;
+	isc_boolean_t need_destroy = ISC_FALSE;
 
 	REQUIRE(requestmgrp != NULL);
 	requestmgr = *requestmgrp;
@@ -355,7 +353,7 @@ dns_requestmgr_detach(dns_requestmgr_t **requestmgrp) {
 	if (requestmgr->eref == 0 && requestmgr->iref == 0) {
 		INSIST(requestmgr->exiting &&
 		       ISC_LIST_HEAD(requestmgr->requests) == NULL);
-		need_destroy = true;
+		need_destroy = ISC_TRUE;
 	}
 	UNLOCK(&requestmgr->lock);
 
@@ -420,7 +418,9 @@ mgr_gethash(dns_requestmgr_t *requestmgr) {
 }
 
 static inline isc_result_t
-req_send(dns_request_t *request, isc_task_t *task, isc_sockaddr_t *address) {
+req_send(dns_request_t *request, isc_task_t *task,
+	 const isc_sockaddr_t *address)
+{
 	isc_region_t r;
 	isc_socket_t *sock;
 	isc_socketevent_t *sendevent;
@@ -452,8 +452,7 @@ req_send(dns_request_t *request, isc_task_t *task, isc_sockaddr_t *address) {
 	request->flags |= DNS_REQUEST_F_SENDING;
 	result = isc_socket_sendto2(sock, &r, task, address, NULL,
 				    sendevent, 0);
-	if (result != ISC_R_SUCCESS)
-		request->flags &= ~DNS_REQUEST_F_SENDING;
+	INSIST(result == ISC_R_SUCCESS);
 	return (result);
 }
 
@@ -486,7 +485,7 @@ new_request(isc_mem_t *mctx, dns_request_t **requestp)
 	ISC_EVENT_INIT(&request->ctlevent, sizeof(request->ctlevent), 0, NULL,
 		       DNS_EVENT_REQUESTCONTROL, do_cancel, request, NULL,
 		       NULL, NULL);
-	request->canceling = false;
+	request->canceling = ISC_FALSE;
 	request->udpcount = 0;
 
 	isc_mem_attach(mctx, &request->mctx);
@@ -497,21 +496,21 @@ new_request(isc_mem_t *mctx, dns_request_t **requestp)
 }
 
 
-static bool
-isblackholed(dns_dispatchmgr_t *dispatchmgr, isc_sockaddr_t *destaddr) {
+static isc_boolean_t
+isblackholed(dns_dispatchmgr_t *dispatchmgr, const isc_sockaddr_t *destaddr) {
 	dns_acl_t *blackhole;
 	isc_netaddr_t netaddr;
 	int match;
-	bool drop = false;
+	isc_boolean_t drop = ISC_FALSE;
 	char netaddrstr[ISC_NETADDR_FORMATSIZE];
 
 	blackhole = dns_dispatchmgr_getblackhole(dispatchmgr);
 	if (blackhole != NULL) {
 		isc_netaddr_fromsockaddr(&netaddr, destaddr);
-		if (dns_acl_match(&netaddr, NULL, blackhole,
+		if (dns_acl_match(&netaddr, NULL, NULL, 0, NULL, blackhole,
 				  NULL, &match, NULL) == ISC_R_SUCCESS &&
 		    match > 0)
-			drop = true;
+			drop = ISC_TRUE;
 	}
 	if (drop) {
 		isc_netaddr_format(&netaddr, netaddrstr, sizeof(netaddrstr));
@@ -521,11 +520,11 @@ isblackholed(dns_dispatchmgr_t *dispatchmgr, isc_sockaddr_t *destaddr) {
 }
 
 static isc_result_t
-create_tcp_dispatch(bool newtcp, bool share,
+create_tcp_dispatch(isc_boolean_t newtcp, isc_boolean_t share,
 		    dns_requestmgr_t *requestmgr,
-		    isc_sockaddr_t *srcaddr,
-		    isc_sockaddr_t *destaddr, isc_dscp_t dscp,
-		    bool *connected, dns_dispatch_t **dispatchp)
+		    const isc_sockaddr_t *srcaddr,
+		    const isc_sockaddr_t *destaddr, isc_dscp_t dscp,
+		    isc_boolean_t *connected, dns_dispatch_t **dispatchp)
 {
 	isc_result_t result;
 	isc_socket_t *sock = NULL;
@@ -534,9 +533,9 @@ create_tcp_dispatch(bool newtcp, bool share,
 	isc_sockaddr_t bind_any;
 
 	if (!newtcp && share) {
-		result = dns_dispatch_gettcp2(requestmgr->dispatchmgr,
-					      destaddr, srcaddr,
-					      connected, dispatchp);
+		result = dns_dispatch_gettcp(requestmgr->dispatchmgr,
+					     destaddr, srcaddr,
+					     connected, dispatchp);
 		if (result == ISC_R_SUCCESS) {
 			char peer[ISC_SOCKADDR_FORMATSIZE];
 
@@ -548,11 +547,11 @@ create_tcp_dispatch(bool newtcp, bool share,
 		}
 	} else if (!newtcp) {
 		result = dns_dispatch_gettcp(requestmgr->dispatchmgr, destaddr,
-					     srcaddr, dispatchp);
+					    srcaddr, NULL, dispatchp);
 		if (result == ISC_R_SUCCESS) {
 			char peer[ISC_SOCKADDR_FORMATSIZE];
 
-			*connected = true;
+			*connected = ISC_TRUE;
 			isc_sockaddr_format(destaddr, peer, sizeof(peer));
 			req_log(ISC_LOG_DEBUG(1), "attached to existing TCP "
 				"connection to %s", peer);
@@ -588,19 +587,19 @@ create_tcp_dispatch(bool newtcp, bool share,
 	attrs |= DNS_DISPATCHATTR_MAKEQUERY;
 
 	isc_socket_dscp(sock, dscp);
-	result = dns_dispatch_createtcp2(requestmgr->dispatchmgr,
-					 sock, requestmgr->taskmgr,
-					 srcaddr, destaddr,
-					 4096, 32768, 32768, 16411, 16433,
-					 attrs, dispatchp);
+	result = dns_dispatch_createtcp(requestmgr->dispatchmgr,
+					sock, requestmgr->taskmgr,
+					srcaddr, destaddr,
+					4096, 32768, 32768, 16411, 16433,
+					attrs, dispatchp);
 cleanup:
 	isc_socket_detach(&sock);
 	return (result);
 }
 
 static isc_result_t
-find_udp_dispatch(dns_requestmgr_t *requestmgr, isc_sockaddr_t *srcaddr,
-		  isc_sockaddr_t *destaddr, dns_dispatch_t **dispatchp)
+find_udp_dispatch(dns_requestmgr_t *requestmgr, const isc_sockaddr_t *srcaddr,
+		  const isc_sockaddr_t *destaddr, dns_dispatch_t **dispatchp)
 {
 	dns_dispatch_t *disp = NULL;
 	unsigned int attrs, attrmask;
@@ -652,10 +651,10 @@ find_udp_dispatch(dns_requestmgr_t *requestmgr, isc_sockaddr_t *srcaddr,
 }
 
 static isc_result_t
-get_dispatch(bool tcp, bool newtcp, bool share,
+get_dispatch(isc_boolean_t tcp, isc_boolean_t newtcp, isc_boolean_t share,
 	     dns_requestmgr_t *requestmgr,
-	     isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-	     isc_dscp_t dscp, bool *connected,
+	     const isc_sockaddr_t *srcaddr, const isc_sockaddr_t *destaddr,
+	     isc_dscp_t dscp, isc_boolean_t *connected,
 	     dns_dispatch_t **dispatchp)
 {
 	isc_result_t result;
@@ -684,63 +683,19 @@ set_timer(isc_timer_t *timer, unsigned int timeout, unsigned int udpresend) {
 	timertype = udpresend != 0 ? isc_timertype_limited : isc_timertype_once;
 	if (result == ISC_R_SUCCESS)
 		result = isc_timer_reset(timer, timertype, &expires,
-					 &interval, false);
+					 &interval, ISC_FALSE);
 	return (result);
 }
 
 isc_result_t
 dns_request_createraw(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
-		      isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-		      unsigned int options, unsigned int timeout,
-		      isc_task_t *task, isc_taskaction_t action, void *arg,
+		      const isc_sockaddr_t *srcaddr,
+		      const isc_sockaddr_t *destaddr,
+		      isc_dscp_t dscp, unsigned int options,
+		      unsigned int timeout, unsigned int udptimeout,
+		      unsigned int udpretries, isc_task_t *task,
+		      isc_taskaction_t action, void *arg,
 		      dns_request_t **requestp)
-{
-	return(dns_request_createraw4(requestmgr, msgbuf, srcaddr, destaddr,
-				      -1, options, timeout, 0, 0, task, action,
-				      arg, requestp));
-}
-
-isc_result_t
-dns_request_createraw2(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
-		       isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-		       unsigned int options, unsigned int timeout,
-		       unsigned int udptimeout, isc_task_t *task,
-		       isc_taskaction_t action, void *arg,
-		       dns_request_t **requestp)
-{
-	unsigned int udpretries = 0;
-
-	if (udptimeout != 0)
-		udpretries = timeout / udptimeout;
-
-	return (dns_request_createraw4(requestmgr, msgbuf, srcaddr, destaddr,
-				       -1, options, timeout, udptimeout,
-				       udpretries, task, action, arg,
-				       requestp));
-}
-
-isc_result_t
-dns_request_createraw3(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
-		       isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-		       unsigned int options, unsigned int timeout,
-		       unsigned int udptimeout, unsigned int udpretries,
-		       isc_task_t *task, isc_taskaction_t action, void *arg,
-		       dns_request_t **requestp)
-{
-	return (dns_request_createraw4(requestmgr, msgbuf, srcaddr, destaddr,
-				       -1, options, timeout, udptimeout,
-				       udpretries, task, action, arg,
-				       requestp));
-}
-
-isc_result_t
-dns_request_createraw4(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
-		       isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-		       isc_dscp_t dscp, unsigned int options,
-		       unsigned int timeout, unsigned int udptimeout,
-		       unsigned int udpretries, isc_task_t *task,
-		       isc_taskaction_t action, void *arg,
-		       dns_request_t **requestp)
 {
 	dns_request_t *request = NULL;
 	isc_task_t *tclone = NULL;
@@ -748,11 +703,11 @@ dns_request_createraw4(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
 	isc_result_t result;
 	isc_mem_t *mctx;
 	dns_messageid_t	id;
-	bool tcp = false;
-	bool newtcp = false;
-	bool share = false;
+	isc_boolean_t tcp = ISC_FALSE;
+	isc_boolean_t newtcp = ISC_FALSE;
+	isc_boolean_t share = ISC_FALSE;
 	isc_region_t r;
-	bool connected = false;
+	isc_boolean_t connected = ISC_FALSE;
 	unsigned int dispopt = 0;
 
 	REQUIRE(VALID_REQUESTMGR(requestmgr));
@@ -813,8 +768,8 @@ dns_request_createraw4(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
 	}
 
 	if ((options & DNS_REQUESTOPT_TCP) != 0 || r.length > 512)
-		tcp = true;
-	share = (options & DNS_REQUESTOPT_SHARE);
+		tcp = ISC_TRUE;
+	share = ISC_TF((options & DNS_REQUESTOPT_SHARE) != 0);
 
  again:
 	result = get_dispatch(tcp, newtcp, share, requestmgr,
@@ -828,14 +783,14 @@ dns_request_createraw4(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
 		dispopt |= DNS_DISPATCHOPT_FIXEDID;
 	}
 
-	result = dns_dispatch_addresponse3(request->dispatch, dispopt,
-					   destaddr, task, req_response,
-					   request, &id, &request->dispentry,
-					   requestmgr->socketmgr);
+	result = dns_dispatch_addresponse(request->dispatch, dispopt,
+					  destaddr, task, req_response,
+					  request, &id, &request->dispentry,
+					  requestmgr->socketmgr);
 	if (result != ISC_R_SUCCESS) {
 		if ((options & DNS_REQUESTOPT_FIXEDID) != 0 && !newtcp) {
-			newtcp = true;
-			connected = false;
+			newtcp = ISC_TRUE;
+			connected = ISC_FALSE;
 			dns_dispatch_detach(&request->dispatch);
 			goto again;
 		}
@@ -850,7 +805,7 @@ dns_request_createraw4(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 	if (tcp)
-		isc_buffer_putuint16(request->query, (uint16_t)r.length);
+		isc_buffer_putuint16(request->query, (isc_uint16_t)r.length);
 	result = isc_buffer_copyregion(request->query, &r);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
@@ -911,71 +866,26 @@ dns_request_createraw4(dns_requestmgr_t *requestmgr, isc_buffer_t *msgbuf,
 
 isc_result_t
 dns_request_create(dns_requestmgr_t *requestmgr, dns_message_t *message,
-		   isc_sockaddr_t *address, unsigned int options,
+		   const isc_sockaddr_t *address, unsigned int options,
 		   dns_tsigkey_t *key,
 		   unsigned int timeout, isc_task_t *task,
 		   isc_taskaction_t action, void *arg,
 		   dns_request_t **requestp)
 {
-	return (dns_request_createvia4(requestmgr, message, NULL, address,
-				       -1, options, key, timeout, 0, 0, task,
-				       action, arg, requestp));
-}
-
-isc_result_t
-dns_request_createvia(dns_requestmgr_t *requestmgr, dns_message_t *message,
-		      isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-		      unsigned int options, dns_tsigkey_t *key,
-		      unsigned int timeout, isc_task_t *task,
-		      isc_taskaction_t action, void *arg,
-		      dns_request_t **requestp)
-{
-	return(dns_request_createvia4(requestmgr, message, srcaddr, destaddr,
+	return (dns_request_createvia(requestmgr, message, NULL, address,
 				      -1, options, key, timeout, 0, 0, task,
 				      action, arg, requestp));
 }
 
 isc_result_t
-dns_request_createvia2(dns_requestmgr_t *requestmgr, dns_message_t *message,
-		       isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-		       unsigned int options, dns_tsigkey_t *key,
-		       unsigned int timeout, unsigned int udptimeout,
-		       isc_task_t *task, isc_taskaction_t action, void *arg,
-		       dns_request_t **requestp)
-{
-	unsigned int udpretries = 0;
-
-	if (udptimeout != 0)
-		udpretries = timeout / udptimeout;
-	return (dns_request_createvia4(requestmgr, message, srcaddr, destaddr,
-				       -1, options, key, timeout, udptimeout,
-				       udpretries, task, action, arg,
-				       requestp));
-}
-
-isc_result_t
-dns_request_createvia3(dns_requestmgr_t *requestmgr, dns_message_t *message,
-		       isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-		       unsigned int options, dns_tsigkey_t *key,
-		       unsigned int timeout, unsigned int udptimeout,
-		       unsigned int udpretries, isc_task_t *task,
-		       isc_taskaction_t action, void *arg,
-		       dns_request_t **requestp)
-{
-	return (dns_request_createvia4(requestmgr, message, srcaddr, destaddr,
-				       -1, options, key, timeout, udptimeout,
-				       udpretries, task, action, arg,
-				       requestp));
-}
-
-isc_result_t
-dns_request_createvia4(dns_requestmgr_t *requestmgr, dns_message_t *message,
-		       isc_sockaddr_t *srcaddr, isc_sockaddr_t *destaddr,
-		       isc_dscp_t dscp, unsigned int options,
-		       dns_tsigkey_t *key, unsigned int timeout,
-		       unsigned int udptimeout, unsigned int udpretries,
-		       isc_task_t *task, isc_taskaction_t action, void *arg,
-		       dns_request_t **requestp)
+dns_request_createvia(dns_requestmgr_t *requestmgr, dns_message_t *message,
+		      const isc_sockaddr_t *srcaddr,
+		      const isc_sockaddr_t *destaddr,
+		      isc_dscp_t dscp, unsigned int options,
+		      dns_tsigkey_t *key, unsigned int timeout,
+		      unsigned int udptimeout, unsigned int udpretries,
+		      isc_task_t *task, isc_taskaction_t action, void *arg,
+		      dns_request_t **requestp)
 {
 	dns_request_t *request = NULL;
 	isc_task_t *tclone = NULL;
@@ -983,10 +893,10 @@ dns_request_createvia4(dns_requestmgr_t *requestmgr, dns_message_t *message,
 	isc_result_t result;
 	isc_mem_t *mctx;
 	dns_messageid_t	id;
-	bool tcp;
-	bool share;
-	bool settsigkey = true;
-	bool connected = false;
+	isc_boolean_t tcp;
+	isc_boolean_t share;
+	isc_boolean_t settsigkey = ISC_TRUE;
+	isc_boolean_t connected = ISC_FALSE;
 
 	REQUIRE(VALID_REQUESTMGR(requestmgr));
 	REQUIRE(message != NULL);
@@ -1044,18 +954,18 @@ dns_request_createvia4(dns_requestmgr_t *requestmgr, dns_message_t *message,
 		dns_tsigkey_attach(key, &request->tsigkey);
 
  use_tcp:
-	tcp = ((options & DNS_REQUESTOPT_TCP) != 0);
-	share = ((options & DNS_REQUESTOPT_SHARE) != 0);
-	result = get_dispatch(tcp, false, share,
+	tcp = ISC_TF((options & DNS_REQUESTOPT_TCP) != 0);
+	share = ISC_TF((options & DNS_REQUESTOPT_SHARE) != 0);
+	result = get_dispatch(tcp, ISC_FALSE, share,
 			      requestmgr, srcaddr, destaddr,
 			      dscp, &connected, &request->dispatch);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 
-	result = dns_dispatch_addresponse2(request->dispatch, destaddr, task,
-					   req_response, request, &id,
-					   &request->dispentry,
-					   requestmgr->socketmgr);
+	result = dns_dispatch_addresponse(request->dispatch, 0, destaddr,
+					  task, req_response, request, &id,
+					  &request->dispentry,
+					  requestmgr->socketmgr);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 	sock = req_getsocket(request);
@@ -1078,7 +988,7 @@ dns_request_createvia4(dns_requestmgr_t *requestmgr, dns_message_t *message,
 		dns_dispatch_detach(&request->dispatch);
 		sock = NULL;
 		options |= DNS_REQUESTOPT_TCP;
-		settsigkey = false;
+		settsigkey = ISC_FALSE;
 		goto use_tcp;
 	}
 	if (result != ISC_R_SUCCESS)
@@ -1143,9 +1053,9 @@ req_render(dns_message_t *message, isc_buffer_t **bufferp,
 	isc_buffer_t *buf2 = NULL;
 	isc_result_t result;
 	isc_region_t r;
-	bool tcp = false;
+	isc_boolean_t tcp = ISC_FALSE;
 	dns_compress_t cctx;
-	bool cleanup_cctx = false;
+	isc_boolean_t cleanup_cctx = ISC_FALSE;
 
 	REQUIRE(bufferp != NULL && *bufferp == NULL);
 
@@ -1161,10 +1071,10 @@ req_render(dns_message_t *message, isc_buffer_t **bufferp,
 	result = dns_compress_init(&cctx, -1, mctx);
 	if (result != ISC_R_SUCCESS)
 		return (result);
-	cleanup_cctx = true;
+	cleanup_cctx = ISC_TRUE;
 
 	if ((options & DNS_REQUESTOPT_CASE) != 0)
-		dns_compress_setsensitive(&cctx, true);
+		dns_compress_setsensitive(&cctx, ISC_TRUE);
 
 	/*
 	 * Render message.
@@ -1189,14 +1099,14 @@ req_render(dns_message_t *message, isc_buffer_t **bufferp,
 		goto cleanup;
 
 	dns_compress_invalidate(&cctx);
-	cleanup_cctx = false;
+	cleanup_cctx = ISC_FALSE;
 
 	/*
 	 * Copy rendered message to exact sized buffer.
 	 */
 	isc_buffer_usedregion(buf1, &r);
 	if ((options & DNS_REQUESTOPT_TCP) != 0) {
-		tcp = true;
+		tcp = ISC_TRUE;
 	} else if (r.length > 512) {
 		result = DNS_R_USETCP;
 		goto cleanup;
@@ -1205,7 +1115,7 @@ req_render(dns_message_t *message, isc_buffer_t **bufferp,
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 	if (tcp)
-		isc_buffer_putuint16(buf2, (uint16_t)r.length);
+		isc_buffer_putuint16(buf2, (isc_uint16_t)r.length);
 	result = isc_buffer_copyregion(buf2, &r);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
@@ -1252,7 +1162,7 @@ do_cancel(isc_task_t *task, isc_event_t *event) {
 	UNUSED(task);
 	INSIST(event->ev_type == DNS_EVENT_REQUESTCONTROL);
 	LOCK(&request->requestmgr->locks[request->hash]);
-	request->canceling = false;
+	request->canceling = ISC_FALSE;
 	if (!DNS_REQUEST_CANCELED(request))
 		req_cancel(request);
 	send_if_done(request, ISC_R_CANCELED);
@@ -1271,7 +1181,7 @@ dns_request_cancel(dns_request_t *request) {
 	if (!request->canceling && !DNS_REQUEST_CANCELED(request)) {
 		isc_event_t *ev =  &request->ctlevent;
 		isc_task_send(request->event->ev_sender, &ev);
-		request->canceling = true;
+		request->canceling = ISC_TRUE;
 	}
 	UNLOCK(&request->requestmgr->locks[request->hash]);
 }
@@ -1302,11 +1212,11 @@ dns_request_getresponse(dns_request_t *request, dns_message_t *message,
 	return (result);
 }
 
-bool
+isc_boolean_t
 dns_request_usedtcp(dns_request_t *request) {
 	REQUIRE(VALID_REQUEST(request));
 
-	return ((request->flags & DNS_REQUEST_F_TCP) != 0);
+	return (ISC_TF((request->flags & DNS_REQUEST_F_TCP) != 0));
 }
 
 void
