@@ -13,10 +13,6 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-#include <stdbool.h>
-#include <stdlib.h>
-
 #include <isc/buffer.h>
 #include <isc/mem.h>
 #include <isc/net.h>
@@ -105,7 +101,7 @@ dns_rpz_update_taskaction(isc_task_t *task, isc_event_t *event);
  * Use a private definition of IPv6 addresses because s6_addr32 is not
  * always defined and our IPv6 addresses are in non-standard byte order
  */
-typedef uint32_t		dns_rpz_cidr_word_t;
+typedef isc_uint32_t		dns_rpz_cidr_word_t;
 #define DNS_RPZ_CIDR_WORD_BITS	((int)sizeof(dns_rpz_cidr_word_t)*8)
 #define DNS_RPZ_CIDR_KEY_BITS	((int)sizeof(dns_rpz_cidr_key_t)*8)
 #define DNS_RPZ_CIDR_WORDS	(128/DNS_RPZ_CIDR_WORD_BITS)
@@ -269,8 +265,9 @@ dns_rpz_policy2str(dns_rpz_policy_t policy) {
 		str = "MISS";
 		break;
 	default:
+		str = "";
+		POST(str);
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 	return (str);
 }
@@ -285,12 +282,10 @@ zbit_to_num(dns_rpz_zbits_t zbit) {
 
 	REQUIRE(zbit != 0);
 	rpz_num = 0;
-#if DNS_RPZ_MAX_ZONES > 32
-	if ((zbit & 0xffffffff00000000L) != 0) {
+	if ((zbit & 0xffffffff00000000ULL) != 0) {
 		zbit >>= 32;
 		rpz_num += 32;
 	}
-#endif
 	if ((zbit & 0xffff0000) != 0) {
 		zbit >>= 16;
 		rpz_num += 16;
@@ -337,7 +332,7 @@ make_addr_set(dns_rpz_addr_zbits_t *tgt_set, dns_rpz_zbits_t zbits,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
+		break;
 	}
 }
 
@@ -356,7 +351,7 @@ make_nm_set(dns_rpz_nm_zbits_t *tgt_set,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
+		break;
 	}
 }
 
@@ -507,9 +502,7 @@ fix_qname_skip_recurse(dns_rpz_zones_t *rpzs) {
 		req_mask |= req_mask >> 4;
 		req_mask |= req_mask >> 8;
 		req_mask |= req_mask >> 16;
-#if DNS_RPZ_MAX_ZONES > 32
 		req_mask |= req_mask >> 32;
-#endif
 
 		/*
 		 * There's no point in skipping recursion for a later
@@ -560,8 +553,8 @@ fix_qname_skip_recurse(dns_rpz_zones_t *rpzs) {
  set:
 	isc_log_write(dns_lctx, DNS_LOGCATEGORY_RPZ, DNS_LOGMODULE_RBTDB,
 		      DNS_RPZ_DEBUG_QUIET,
-		      "computed RPZ qname_skip_recurse mask=0x%" PRIx64,
-		      (uint64_t) mask);
+		      "computed RPZ qname_skip_recurse mask=0x%llx",
+		      (isc_uint64_t) mask);
 	rpzs->have.qname_skip_recurse = mask;
 }
 
@@ -569,10 +562,10 @@ static void
 adj_trigger_cnt(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 		dns_rpz_type_t rpz_type,
 		const dns_rpz_cidr_key_t *tgt_ip, dns_rpz_prefix_t tgt_prefix,
-		bool inc)
+		isc_boolean_t inc)
 {
-	dns_rpz_trigger_counter_t *cnt = NULL;
-	dns_rpz_zbits_t *have = NULL;
+	dns_rpz_trigger_counter_t *cnt;
+	dns_rpz_zbits_t *have;
 
 	switch (rpz_type) {
 	case DNS_RPZ_TYPE_CLIENT_IP:
@@ -615,7 +608,6 @@ adj_trigger_cnt(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 
 	if (inc) {
@@ -857,11 +849,6 @@ name2ipkey(int log_level,
 			"; invalid leading prefix length", "");
 		return (ISC_R_FAILURE);
 	}
-	/*
-	 * Patch in trailing nul character to print just the length
-	 * label (for various cases below).
-	 */
-	*cp2 = '\0';
 	if (prefix_num < 1U || prefix_num > 128U) {
 		badname(log_level, src_name,
 			"; invalid prefix length of ", prefix_str);
@@ -1119,12 +1106,12 @@ trim_zbits(dns_rpz_zbits_t zbits, dns_rpz_zbits_t found) {
  *
  * Return ISC_R_SUCCESS, DNS_R_PARTIALMATCH, ISC_R_NOTFOUND,
  *	    and *found=longest match node
- *	or with create==true, ISC_R_EXISTS or ISC_R_NOMEMORY
+ *	or with create==ISC_TRUE, ISC_R_EXISTS or ISC_R_NOMEMORY
  */
 static isc_result_t
 search(dns_rpz_zones_t *rpzs,
        const dns_rpz_cidr_key_t *tgt_ip, dns_rpz_prefix_t tgt_prefix,
-       const dns_rpz_addr_zbits_t *tgt_set, bool create,
+       const dns_rpz_addr_zbits_t *tgt_set, isc_boolean_t create,
        dns_rpz_cidr_node_t **found)
 {
 	dns_rpz_cidr_node_t *cur, *parent, *child, *new_parent, *sibling;
@@ -1323,7 +1310,7 @@ add_cidr(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 	if (result != ISC_R_SUCCESS)
 		return (ISC_R_SUCCESS);
 
-	result = search(rpzs, &tgt_ip, tgt_prefix, &set, true, &found);
+	result = search(rpzs, &tgt_ip, tgt_prefix, &set, ISC_TRUE, &found);
 	if (result != ISC_R_SUCCESS) {
 		char namebuf[DNS_NAME_FORMATSIZE];
 
@@ -1345,7 +1332,7 @@ add_cidr(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 		return (result);
 	}
 
-	adj_trigger_cnt(rpzs, rpz_num, rpz_type, &tgt_ip, tgt_prefix, true);
+	adj_trigger_cnt(rpzs, rpz_num, rpz_type, &tgt_ip, tgt_prefix, ISC_TRUE);
 	return (result);
 }
 
@@ -1418,7 +1405,7 @@ add_name(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 	if (result == ISC_R_EXISTS)
 		return (ISC_R_SUCCESS);
 	if (result == ISC_R_SUCCESS)
-		adj_trigger_cnt(rpzs, rpz_num, rpz_type, NULL, 0, true);
+		adj_trigger_cnt(rpzs, rpz_num, rpz_type, NULL, 0, ISC_TRUE);
 	return (result);
 }
 
@@ -1555,15 +1542,15 @@ dns_rpz_new_zone(dns_rpz_zones_t *rpzs, dns_rpz_zone_t **rpzp) {
 	dns_name_init(&zone->cname, NULL);
 
 	isc_time_settoepoch(&zone->lastupdated);
-	zone->updatepending = false;
-	zone->updaterunning = false;
+	zone->updatepending = ISC_FALSE;
+	zone->updaterunning = ISC_FALSE;
 	zone->db = NULL;
 	zone->dbversion = NULL;
 	zone->updb = NULL;
 	zone->updbversion = NULL;
 	zone->updbit = NULL;
 	zone->rpzs = rpzs;
-	zone->db_registered = false;
+	zone->db_registered = ISC_FALSE;
 	ISC_EVENT_INIT(&zone->updateevent, sizeof(zone->updateevent),
 		       0, NULL, 0, NULL, NULL, NULL, NULL, NULL);
 
@@ -1591,7 +1578,7 @@ isc_result_t
 dns_rpz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 	dns_rpz_zone_t *zone = (dns_rpz_zone_t *) fn_arg;
 	isc_time_t now;
-	uint64_t tdiff;
+	isc_uint64_t tdiff;
 	isc_result_t result = ISC_R_SUCCESS;
 	char dname[DNS_NAME_FORMATSIZE];
 
@@ -1607,7 +1594,7 @@ dns_rpz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 		/* We need to clean up the old DB */
 		if (zone->dbversion != NULL)
 			dns_db_closeversion(zone->db, &zone->dbversion,
-					    false);
+					    ISC_FALSE);
 		dns_db_updatenotify_unregister(zone->db,
 					       dns_rpz_dbupdate_callback,
 					       zone);
@@ -1620,11 +1607,11 @@ dns_rpz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 	}
 
 	if (!zone->updatepending && !zone->updaterunning) {
-		zone->updatepending = true;
+		zone->updatepending = ISC_TRUE;
 		isc_time_now(&now);
 		tdiff = isc_time_microdiff(&now, &zone->lastupdated) / 1000000;
 		if (tdiff < zone->min_update_interval) {
-			uint64_t defer = zone->min_update_interval - tdiff;
+			isc_uint64_t defer = zone->min_update_interval - tdiff;
 			isc_interval_t interval;
 			dns_name_format(&zone->origin, dname,
 					DNS_NAME_FORMATSIZE);
@@ -1632,12 +1619,12 @@ dns_rpz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 				      DNS_LOGMODULE_MASTER, ISC_LOG_INFO,
 				      "rpz: %s: new zone version came "
 				      "too soon, deferring update for "
-				      "%" PRIu64 " seconds", dname, defer);
+				      "%llu seconds", dname, defer);
 			isc_interval_set(&interval, (unsigned int)defer, 0);
 			dns_db_currentversion(zone->db, &zone->dbversion);
 			result = isc_timer_reset(zone->updatetimer,
 						 isc_timertype_once,
-						 NULL, &interval, true);
+						 NULL, &interval, ISC_TRUE);
 			if (result != ISC_R_SUCCESS)
 				goto cleanup;
 		} else {
@@ -1654,14 +1641,14 @@ dns_rpz_dbupdate_callback(dns_db_t *db, void *fn_arg) {
 			isc_task_send(zone->rpzs->updater, &event);
 		}
 	} else {
-		zone->updatepending = true;
+		zone->updatepending = ISC_TRUE;
 		dns_name_format(&zone->origin, dname, DNS_NAME_FORMATSIZE);
 		isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
 			      DNS_LOGMODULE_MASTER, ISC_LOG_DEBUG(3),
 			      "rpz: %s: update already queued or running", dname);
 		if (zone->dbversion != NULL)
 			dns_db_closeversion(zone->db, &zone->dbversion,
-					    false);
+					    ISC_FALSE);
 		dns_db_currentversion(zone->db, &zone->dbversion);
 	}
 
@@ -1683,11 +1670,11 @@ dns_rpz_update_taskaction(isc_task_t *task, isc_event_t *event) {
 	zone = (dns_rpz_zone_t *) event->ev_arg;
 	isc_event_free(&event);
 	LOCK(&zone->rpzs->maint_lock);
-	zone->updatepending = false;
-	zone->updaterunning = true;
+	zone->updatepending = ISC_FALSE;
+	zone->updaterunning = ISC_TRUE;
 	dns_rpz_update_from_db(zone);
 	result = isc_timer_reset(zone->updatetimer, isc_timertype_inactive,
-				 NULL, NULL, true);
+				 NULL, NULL, ISC_TRUE);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 	result = isc_time_now(&zone->lastupdated);
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
@@ -1699,7 +1686,7 @@ setup_update(dns_rpz_zone_t *rpz) {
 	isc_result_t result;
 	char domain[DNS_NAME_FORMATSIZE];
 	unsigned int nodecount;
-	uint32_t hashsize;
+	isc_uint32_t hashsize;
 
 	dns_name_format(&rpz->origin, domain, DNS_NAME_FORMATSIZE);
 	isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
@@ -1719,7 +1706,7 @@ setup_update(dns_rpz_zone_t *rpz) {
 		hashsize -= DNS_RPZ_HTSIZE_DIV;
 
 	isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
-			      DNS_LOGMODULE_MASTER, ISC_LOG_DEBUG(1),
+			      DNS_LOGMODULE_MASTER, ISC_LOG_INFO,
 			      "rpz: %s: using hashtable size %d",
 			      domain, hashsize);
 
@@ -1756,7 +1743,7 @@ setup_update(dns_rpz_zone_t *rpz) {
 			dns_dbiterator_destroy(&rpz->updbit);
 		if (rpz->newnodes != NULL)
 			isc_ht_destroy(&rpz->newnodes);
-		dns_db_closeversion(rpz->updb, &rpz->updbversion, false);
+		dns_db_closeversion(rpz->updb, &rpz->updbversion, ISC_FALSE);
 	}
 
 	return (result);
@@ -1794,7 +1781,7 @@ finish_update(dns_rpz_zone_t *rpz) {
 	     result = isc_ht_iter_delcurrent_next(iter))
 	{
 		isc_region_t region;
-		unsigned char *key = NULL;
+		unsigned char *key;
 		size_t keysize;
 
 		isc_ht_iter_currentkey(iter, &key, &keysize);
@@ -1809,35 +1796,23 @@ finish_update(dns_rpz_zone_t *rpz) {
 	rpz->newnodes = tmpht;
 
 	LOCK(&rpz->rpzs->maint_lock);
-	rpz->updaterunning = false;
+	rpz->updaterunning = ISC_FALSE;
 	/*
 	 * If there's an update pending schedule it
 	 */
-	if (rpz->updatepending == true) {
-		if (rpz->min_update_interval > 0) {
-			uint64_t defer = rpz->min_update_interval;
-			isc_interval_t interval;
-			dns_name_format(&rpz->origin, dname,
-					DNS_NAME_FORMATSIZE);
-			isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
-				      DNS_LOGMODULE_MASTER, ISC_LOG_INFO,
-				      "rpz: %s: new zone version came "
-				      "too soon, deferring update for "
-				      "%" PRIu64 " seconds", dname, defer);
-			isc_interval_set(&interval, (unsigned int)defer, 0);
-			isc_timer_reset(rpz->updatetimer, isc_timertype_once,
-					NULL, &interval, true);
-		} else {
-			isc_event_t *event;
-			INSIST(!ISC_LINK_LINKED(&rpz->updateevent, ev_link));
-			ISC_EVENT_INIT(&rpz->updateevent,
-				       sizeof(rpz->updateevent), 0, NULL,
-				       DNS_EVENT_RPZUPDATED,
-				       dns_rpz_update_taskaction,
-				       rpz, rpz, NULL, NULL);
-			event = &rpz->updateevent;
-			isc_task_send(rpz->rpzs->updater, &event);
-		}
+	if (rpz->updatepending == ISC_TRUE) {
+		isc_uint64_t defer = rpz->min_update_interval;
+		isc_interval_t interval;
+		dns_name_format(&rpz->origin, dname,
+				DNS_NAME_FORMATSIZE);
+		isc_log_write(dns_lctx, DNS_LOGCATEGORY_GENERAL,
+			      DNS_LOGMODULE_MASTER, ISC_LOG_INFO,
+			      "rpz: %s: new zone version came "
+			      "too soon, deferring update for "
+			      "%llu seconds", dname, defer);
+		isc_interval_set(&interval, (unsigned int)defer, 0);
+		isc_timer_reset(rpz->updatetimer, isc_timertype_once,
+				NULL, &interval, ISC_TRUE);
 	}
 	UNLOCK(&rpz->rpzs->maint_lock);
 
@@ -1992,7 +1967,7 @@ update_quantum(isc_task_t *task, isc_event_t *event) {
 		dns_dbiterator_destroy(&rpz->updbit);
 	if (rpz->newnodes != NULL)
 		isc_ht_destroy(&rpz->newnodes);
-	dns_db_closeversion(rpz->updb, &rpz->updbversion, false);
+	dns_db_closeversion(rpz->updb, &rpz->updbversion, ISC_FALSE);
 	dns_db_detach(&rpz->updb);
 }
 
@@ -2030,7 +2005,7 @@ dns_rpz_update_from_db(dns_rpz_zone_t *rpz) {
 		dns_dbiterator_destroy(&rpz->updbit);
 	if (rpz->newnodes != NULL)
 		isc_ht_destroy(&rpz->newnodes);
-	dns_db_closeversion(rpz->updb, &rpz->updbversion, false);
+	dns_db_closeversion(rpz->updb, &rpz->updbversion, ISC_FALSE);
 	dns_db_detach(&rpz->updb);
 }
 
@@ -2075,72 +2050,42 @@ rpz_detach(dns_rpz_zone_t **rpzp, dns_rpz_zones_t *rpzs) {
 	dns_rpz_zone_t *rpz;
 	unsigned int refs;
 
-	REQUIRE(rpzp != NULL && *rpzp != NULL);
-
 	rpz = *rpzp;
 	*rpzp = NULL;
-
 	isc_refcount_decrement(&rpz->refs, &refs);
-	if (refs != 0) {
+	if (refs != 0)
 		return;
-	}
-
 	isc_refcount_destroy(&rpz->refs);
 
-	if (dns_name_dynamic(&rpz->origin)) {
+	if (dns_name_dynamic(&rpz->origin))
 		dns_name_free(&rpz->origin, rpzs->mctx);
-	}
-	if (dns_name_dynamic(&rpz->client_ip)) {
+	if (dns_name_dynamic(&rpz->client_ip))
 		dns_name_free(&rpz->client_ip, rpzs->mctx);
-	}
-	if (dns_name_dynamic(&rpz->ip)) {
+	if (dns_name_dynamic(&rpz->ip))
 		dns_name_free(&rpz->ip, rpzs->mctx);
-	}
-	if (dns_name_dynamic(&rpz->nsdname)) {
+	if (dns_name_dynamic(&rpz->nsdname))
 		dns_name_free(&rpz->nsdname, rpzs->mctx);
-	}
-	if (dns_name_dynamic(&rpz->nsip)) {
+	if (dns_name_dynamic(&rpz->nsip))
 		dns_name_free(&rpz->nsip, rpzs->mctx);
-	}
-	if (dns_name_dynamic(&rpz->passthru)) {
+	if (dns_name_dynamic(&rpz->passthru))
 		dns_name_free(&rpz->passthru, rpzs->mctx);
-	}
-	if (dns_name_dynamic(&rpz->drop)) {
+	if (dns_name_dynamic(&rpz->drop))
 		dns_name_free(&rpz->drop, rpzs->mctx);
-	}
-	if (dns_name_dynamic(&rpz->tcp_only)) {
+	if (dns_name_dynamic(&rpz->tcp_only))
 		dns_name_free(&rpz->tcp_only, rpzs->mctx);
-	}
-	if (dns_name_dynamic(&rpz->cname)) {
+	if (dns_name_dynamic(&rpz->cname))
 		dns_name_free(&rpz->cname, rpzs->mctx);
-	}
-	if (rpz->db_registered) {
+	if (rpz->db_registered)
 		dns_db_updatenotify_unregister(rpz->db,
 					       dns_rpz_dbupdate_callback, rpz);
-	}
-	if (rpz->dbversion != NULL) {
-		dns_db_closeversion(rpz->db, &rpz->dbversion, false);
-	}
-	if (rpz->db != NULL) {
+	if (rpz->dbversion != NULL)
+		dns_db_closeversion(rpz->db, &rpz->dbversion,
+				    ISC_FALSE);
+	if (rpz->db)
 		dns_db_detach(&rpz->db);
-	}
-	if (rpz->updaterunning) {
-		isc_task_purgeevent(rpz->rpzs->updater, &rpz->updateevent);
-		if (rpz->updbit != NULL) {
-			dns_dbiterator_destroy(&rpz->updbit);
-		}
-		if (rpz->newnodes != NULL) {
-			isc_ht_destroy(&rpz->newnodes);
-		}
-		dns_db_closeversion(rpz->updb, &rpz->updbversion, false);
-		dns_db_detach(&rpz->updb);
-	}
-
-	isc_timer_reset(rpz->updatetimer, isc_timertype_inactive,
-			NULL, NULL, true);
+	isc_ht_destroy(&rpz->nodes);
 	isc_timer_detach(&rpz->updatetimer);
 
-	isc_ht_destroy(&rpz->nodes);
 	isc_mem_put(rpzs->mctx, rpz, sizeof(*rpz));
 }
 
@@ -2289,7 +2234,7 @@ del_cidr(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 	if (result != ISC_R_SUCCESS)
 		return;
 
-	result = search(rpzs, &tgt_ip, tgt_prefix, &tgt_set, false, &tgt);
+	result = search(rpzs, &tgt_ip, tgt_prefix, &tgt_set, ISC_FALSE, &tgt);
 	if (result != ISC_R_SUCCESS) {
 		INSIST(result == ISC_R_NOTFOUND ||
 		       result == DNS_R_PARTIALMATCH);
@@ -2315,7 +2260,7 @@ del_cidr(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 	set_sum_pair(tgt);
 
 	adj_trigger_cnt(rpzs, rpz_num, rpz_type, &tgt_ip, tgt_prefix,
-			false);
+			ISC_FALSE);
 
 	/*
 	 * We might need to delete 2 nodes.
@@ -2367,7 +2312,7 @@ del_name(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 	dns_rbtnode_t *nmnode;
 	dns_rpz_nm_data_t *nm_data, del_data;
 	isc_result_t result;
-	bool exists;
+	isc_boolean_t exists;
 
 	/*
 	 * We need a summary database of names even with 1 policy zone,
@@ -2410,10 +2355,8 @@ del_name(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 	del_data.wild.qname &= nm_data->wild.qname;
 	del_data.wild.ns &= nm_data->wild.ns;
 
-	exists = (del_data.set.qname != 0 ||
-		  del_data.set.ns != 0 ||
-		  del_data.wild.qname != 0 ||
-		  del_data.wild.ns != 0);
+	exists = ISC_TF(del_data.set.qname != 0 || del_data.set.ns != 0 ||
+			del_data.wild.qname != 0 || del_data.wild.ns != 0);
 
 	nm_data->set.qname &= ~del_data.set.qname;
 	nm_data->set.ns &= ~del_data.set.ns;
@@ -2422,7 +2365,7 @@ del_name(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 
 	if (nm_data->set.qname == 0 && nm_data->set.ns == 0 &&
 	    nm_data->wild.qname == 0 && nm_data->wild.ns == 0) {
-		result = dns_rbt_deletenode(rpzs->rbt, nmnode, false);
+		result = dns_rbt_deletenode(rpzs->rbt, nmnode, ISC_FALSE);
 		if (result != ISC_R_SUCCESS) {
 			/*
 			 * bin/tests/system/rpz/tests.sh looks for
@@ -2437,7 +2380,7 @@ del_name(dns_rpz_zones_t *rpzs, dns_rpz_num_t rpz_num,
 	}
 
 	if (exists)
-		adj_trigger_cnt(rpzs, rpz_num, rpz_type, NULL, 0, false);
+		adj_trigger_cnt(rpzs, rpz_num, rpz_type, NULL, 0, ISC_FALSE);
 }
 
 /*
@@ -2492,7 +2435,7 @@ dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 	dns_rpz_addr_zbits_t tgt_set;
 	dns_rpz_cidr_node_t *found;
 	isc_result_t result;
-	dns_rpz_num_t rpz_num = 0;
+	dns_rpz_num_t rpz_num;
 	dns_rpz_have_t have;
 	int i;
 
@@ -2520,7 +2463,7 @@ dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 			break;
 		default:
 			INSIST(0);
-			ISC_UNREACHABLE();
+			break;
 		}
 	} else if (netaddr->family == AF_INET6) {
 		dns_rpz_cidr_key_t src_ip6;
@@ -2546,7 +2489,7 @@ dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 			break;
 		default:
 			INSIST(0);
-			ISC_UNREACHABLE();
+			break;
 		}
 	} else {
 		return (DNS_RPZ_INVALID_NUM);
@@ -2557,7 +2500,7 @@ dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 	make_addr_set(&tgt_set, zbits, rpz_type);
 
 	RWLOCK(&rpzs->search_lock, isc_rwlocktype_read);
-	result = search(rpzs, &tgt_ip, 128, &tgt_set, false, &found);
+	result = search(rpzs, &tgt_ip, 128, &tgt_set, ISC_FALSE, &found);
 	if (result == ISC_R_NOTFOUND) {
 		/*
 		 * There are no eligible zones for this IP address.
@@ -2583,7 +2526,7 @@ dns_rpz_find_ip(dns_rpz_zones_t *rpzs, dns_rpz_type_t rpz_type,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
+		break;
 	}
 	result = ip2name(&found->ip, found->prefix, dns_rootname, ip_name);
 	RWUNLOCK(&rpzs->search_lock, isc_rwlocktype_read);
