@@ -18,10 +18,6 @@
 /* #define ISC_LIST_CHECKINIT */
 
 #include <config.h>
-
-#include <inttypes.h>
-#include <stdbool.h>
-
 #include <isc/mem.h>
 #include <isc/net.h>
 #include <isc/netaddr.h>
@@ -37,7 +33,7 @@
 #include <dns/view.h>
 
 static void
-log_end(dns_rrl_t *rrl, dns_rrl_entry_t *e, bool early,
+log_end(dns_rrl_t *rrl, dns_rrl_entry_t *e, isc_boolean_t early,
 	char *log_buf, unsigned int log_buf_len);
 
 /*
@@ -50,7 +46,7 @@ log_end(dns_rrl_t *rrl, dns_rrl_entry_t *e, bool early,
  */
 static int
 hash_divisor(unsigned int initial) {
-	static uint16_t primes[] = {
+	static isc_uint16_t primes[] = {
 		  3,   5,   7,  11,  13,  17,  19,  23,  29,  31,  37,  41,
 		 43,  47,  53,  59,  61,  67,  71,  73,  79,  83,  89,  97,
 #if 0
@@ -70,7 +66,7 @@ hash_divisor(unsigned int initial) {
 	};
 	int divisions, tries;
 	unsigned int result;
-	uint16_t *pp, p;
+	isc_uint16_t *pp, p;
 
 	result = initial;
 
@@ -171,7 +167,7 @@ set_age(dns_rrl_t *rrl, dns_rrl_entry_t *e, isc_stdtime_t now) {
 				       !ISC_LINK_LINKED(e_old, hlink));
 		     e_old = ISC_LIST_PREV(e_old, lru), ++i)
 		{
-			e_old->ts_valid = false;
+			e_old->ts_valid = ISC_FALSE;
 		}
 		if (i != 0)
 			isc_log_write(dns_lctx, DNS_LOGCATEGORY_RRL,
@@ -192,7 +188,7 @@ set_age(dns_rrl_t *rrl, dns_rrl_entry_t *e, isc_stdtime_t now) {
 
 	e->ts_gen = ts_gen;
 	e->ts = ts;
-	e->ts_valid = true;
+	e->ts_valid = ISC_TRUE;
 }
 
 static isc_result_t
@@ -363,16 +359,16 @@ ref_entry(dns_rrl_t *rrl, dns_rrl_entry_t *e, int probes, isc_stdtime_t now) {
 	}
 }
 
-static inline bool
+static inline isc_boolean_t
 key_cmp(const dns_rrl_key_t *a, const dns_rrl_key_t *b) {
 	if (memcmp(a, b, sizeof(dns_rrl_key_t)) == 0)
-		return (true);
-	return (false);
+		return (ISC_TRUE);
+	return (ISC_FALSE);
 }
 
-static inline uint32_t
+static inline isc_uint32_t
 hash_key(const dns_rrl_key_t *key) {
-	uint32_t hval;
+	isc_uint32_t hval;
 	int i;
 
 	hval = key->w[0];
@@ -426,10 +422,10 @@ make_key(const dns_rrl_t *rrl, dns_rrl_key_t *key,
 			dns_name_init(&base, base_offsets);
 			dns_name_getlabelsequence(qname, 1, labels-1, &base);
 			key->s.qname_hash =
-				dns_name_fullhash(&base, false);
+				dns_name_fullhash(&base, ISC_FALSE);
 		} else {
 			key->s.qname_hash =
-				dns_name_fullhash(qname, false);
+				dns_name_fullhash(qname, ISC_FALSE);
 		}
 	}
 
@@ -439,7 +435,7 @@ make_key(const dns_rrl_t *rrl, dns_rrl_key_t *key,
 			      rrl->ipv4_mask);
 		break;
 	case AF_INET6:
-		key->s.ipv6 = true;
+		key->s.ipv6 = ISC_TRUE;
 		memmove(key->s.ip, &client_addr->type.sin6.sin6_addr,
 			sizeof(key->s.ip));
 		for (i = 0; i < DNS_RRL_MAX_PREFIX/32; ++i)
@@ -465,8 +461,8 @@ get_rate(dns_rrl_t *rrl, dns_rrl_rtype_t rtype) {
 		return (&rrl->all_per_second);
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
+	return (NULL);
 }
 
 static int
@@ -494,10 +490,10 @@ static dns_rrl_entry_t *
 get_entry(dns_rrl_t *rrl, const isc_sockaddr_t *client_addr,
 	  dns_rdataclass_t qclass, dns_rdatatype_t qtype,
 	  const dns_name_t *qname, dns_rrl_rtype_t rtype, isc_stdtime_t now,
-	  bool create, char *log_buf, unsigned int log_buf_len)
+	  isc_boolean_t create, char *log_buf, unsigned int log_buf_len)
 {
 	dns_rrl_key_t key;
-	uint32_t hval;
+	isc_uint32_t hval;
 	dns_rrl_entry_t *e;
 	dns_rrl_hash_t *hash;
 	dns_rrl_bin_t *new_bin, *old_bin;
@@ -574,7 +570,7 @@ get_entry(dns_rrl_t *rrl, const isc_sockaddr_t *client_addr,
 		e = ISC_LIST_TAIL(rrl->lru);
 	}
 	if (e->logged)
-		log_end(rrl, e, true, log_buf, log_buf_len);
+		log_end(rrl, e, ISC_TRUE, log_buf, log_buf_len);
 	if (ISC_LINK_LINKED(e, hlink)) {
 		if (e->hash_gen == rrl->hash_gen)
 			hash = rrl->hash;
@@ -586,7 +582,7 @@ get_entry(dns_rrl_t *rrl, const isc_sockaddr_t *client_addr,
 	ISC_LIST_PREPEND(*new_bin, e, hlink);
 	e->hash_gen = rrl->hash_gen;
 	e->key = key;
-	e->ts_valid = false;
+	e->ts_valid = ISC_FALSE;
 	ref_entry(rrl, e, probes, now);
 	return (e);
 }
@@ -632,7 +628,7 @@ debit_rrl_entry(dns_rrl_t *rrl, dns_rrl_entry_t *e, double qps, double scale,
 		 */
 		credit_e = get_entry(rrl, client_addr,
 				     0, dns_rdatatype_none, NULL,
-				     DNS_RRL_RTYPE_TCP, now, false,
+				     DNS_RRL_RTYPE_TCP, now, ISC_FALSE,
 				     log_buf, log_buf_len);
 		if (credit_e != NULL) {
 			age = get_age(rrl, e, now);
@@ -788,8 +784,8 @@ add_log_str(isc_buffer_t *lb, const char *str, unsigned int str_len) {
  */
 static void
 make_log_buf(dns_rrl_t *rrl, dns_rrl_entry_t *e,
-	     const char *str1, const char *str2, bool plural,
-	     const dns_name_t *qname, bool save_qname,
+	     const char *str1, const char *str2, isc_boolean_t plural,
+	     const dns_name_t *qname, isc_boolean_t save_qname,
 	     dns_rrl_result_t rrl_result, isc_result_t resp_result,
 	     char *log_buf, unsigned int log_buf_len)
 {
@@ -823,7 +819,7 @@ make_log_buf(dns_rrl_t *rrl, dns_rrl_entry_t *e,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
+		break;
 	}
 
 	switch (e->key.s.rtype) {
@@ -852,7 +848,6 @@ make_log_buf(dns_rrl_t *rrl, dns_rrl_entry_t *e,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 
 	if (plural)
@@ -919,7 +914,7 @@ make_log_buf(dns_rrl_t *rrl, dns_rrl_entry_t *e,
 			qname = dns_fixedname_name(&qbuf->qname);
 		if (qname != NULL) {
 			ADD_LOG_CSTR(&lb, " for ");
-			(void)dns_name_totext(qname, true, &lb);
+			(void)dns_name_totext(qname, ISC_TRUE, &lb);
 		} else {
 			ADD_LOG_CSTR(&lb, " for (?)");
 		}
@@ -943,7 +938,7 @@ make_log_buf(dns_rrl_t *rrl, dns_rrl_entry_t *e,
 }
 
 static void
-log_end(dns_rrl_t *rrl, dns_rrl_entry_t *e, bool early,
+log_end(dns_rrl_t *rrl, dns_rrl_entry_t *e, isc_boolean_t early,
 	char *log_buf, unsigned int log_buf_len)
 {
 	if (e->logged) {
@@ -951,14 +946,14 @@ log_end(dns_rrl_t *rrl, dns_rrl_entry_t *e, bool early,
 			     early ? "*" : NULL,
 			     rrl->log_only ? "would stop limiting "
 					   : "stop limiting ",
-			     true, NULL, false,
+			     ISC_TRUE, NULL, ISC_FALSE,
 			     DNS_RRL_RESULT_OK, ISC_R_SUCCESS,
 			     log_buf, log_buf_len);
 		isc_log_write(dns_lctx, DNS_LOGCATEGORY_RRL,
 			      DNS_LOGMODULE_REQUEST, DNS_RRL_LOG_DROP,
 			      "%s", log_buf);
 		free_qname(rrl, e);
-		e->logged = false;
+		e->logged = ISC_FALSE;
 		--rrl->num_logged;
 	}
 }
@@ -1007,10 +1002,10 @@ log_stops(dns_rrl_t *rrl, isc_stdtime_t now, int limit,
  */
 dns_rrl_result_t
 dns_rrl(dns_view_t *view,
-	const isc_sockaddr_t *client_addr, bool is_tcp,
+	const isc_sockaddr_t *client_addr, isc_boolean_t is_tcp,
 	dns_rdataclass_t qclass, dns_rdatatype_t qtype,
 	const dns_name_t *qname, isc_result_t resp_result, isc_stdtime_t now,
-	bool wouldlog, char *log_buf, unsigned int log_buf_len)
+	isc_boolean_t wouldlog, char *log_buf, unsigned int log_buf_len)
 {
 	dns_rrl_t *rrl;
 	dns_rrl_rtype_t rtype;
@@ -1027,8 +1022,9 @@ dns_rrl(dns_view_t *view,
 	rrl = view->rrl;
 	if (rrl->exempt != NULL) {
 		isc_netaddr_fromsockaddr(&netclient, client_addr);
-		result = dns_acl_match(&netclient, NULL, rrl->exempt,
-				       &view->aclenv, &exempt_match, NULL);
+		result = dns_acl_match(&netclient, NULL, NULL, 0, NULL,
+				       rrl->exempt, &view->aclenv,
+				       &exempt_match, NULL);
 		if (result == ISC_R_SUCCESS && exempt_match > 0)
 			return (DNS_RRL_RESULT_OK);
 	}
@@ -1083,7 +1079,7 @@ dns_rrl(dns_view_t *view,
 		if (scale < 1.0) {
 			e = get_entry(rrl, client_addr,
 				      0, dns_rdatatype_none, NULL,
-				      DNS_RRL_RTYPE_TCP, now, true,
+				      DNS_RRL_RTYPE_TCP, now, ISC_TRUE,
 				      log_buf, log_buf_len);
 			if (e != NULL) {
 				e->responses = -(rrl->window+1);
@@ -1116,7 +1112,7 @@ dns_rrl(dns_view_t *view,
 		break;
 	}
 	e = get_entry(rrl, client_addr, qclass, qtype, qname, rtype,
-		      now, true, log_buf, log_buf_len);
+		      now, ISC_TRUE, log_buf, log_buf_len);
 	if (e == NULL) {
 		UNLOCK(&rrl->lock);
 		return (DNS_RRL_RESULT_OK);
@@ -1127,8 +1123,8 @@ dns_rrl(dns_view_t *view,
 		 * Do not worry about speed or releasing the lock.
 		 * This message appears before messages from debit_rrl_entry().
 		 */
-		make_log_buf(rrl, e, "consider limiting ", NULL, false,
-			     qname, false, DNS_RRL_RESULT_OK, resp_result,
+		make_log_buf(rrl, e, "consider limiting ", NULL, ISC_FALSE,
+			     qname, ISC_FALSE, DNS_RRL_RESULT_OK, resp_result,
 			     log_buf, log_buf_len);
 		isc_log_write(dns_lctx, DNS_LOGCATEGORY_RRL,
 			      DNS_LOGMODULE_REQUEST, DNS_RRL_LOG_DEBUG1,
@@ -1152,7 +1148,7 @@ dns_rrl(dns_view_t *view,
 
 		e_all = get_entry(rrl, client_addr,
 				  0, dns_rdatatype_none, NULL,
-				  DNS_RRL_RTYPE_ALL, now, true,
+				  DNS_RRL_RTYPE_ALL, now, ISC_TRUE,
 				  log_buf, log_buf_len);
 		if (e_all == NULL) {
 			UNLOCK(&rrl->lock);
@@ -1167,7 +1163,7 @@ dns_rrl(dns_view_t *view,
 			if (isc_log_wouldlog(dns_lctx, DNS_RRL_LOG_DEBUG1)) {
 				make_log_buf(rrl, e,
 					     "prefer all-per-second limiting ",
-					     NULL, true, qname, false,
+					     NULL, ISC_TRUE, qname, ISC_FALSE,
 					     DNS_RRL_RESULT_OK, resp_result,
 					     log_buf, log_buf_len);
 				isc_log_write(dns_lctx, DNS_LOGCATEGORY_RRL,
@@ -1190,11 +1186,11 @@ dns_rrl(dns_view_t *view,
 	    isc_log_wouldlog(dns_lctx, DNS_RRL_LOG_DROP)) {
 		make_log_buf(rrl, e, rrl->log_only ? "would " : NULL,
 			     e->logged ? "continue limiting " : "limit ",
-			     true, qname, true,
+			     ISC_TRUE, qname, ISC_TRUE,
 			     DNS_RRL_RESULT_OK, resp_result,
 			     log_buf, log_buf_len);
 		if (!e->logged) {
-			e->logged = true;
+			e->logged = ISC_TRUE;
 			if (++rrl->num_logged <= 1)
 				rrl->last_logged = e;
 		}
@@ -1218,7 +1214,7 @@ dns_rrl(dns_view_t *view,
 	if (wouldlog)
 		make_log_buf(rrl, e,
 			     rrl->log_only ? "would rate limit " : "rate limit ",
-			     NULL, false, qname, false,
+			     NULL, ISC_FALSE, qname, ISC_FALSE,
 			     rrl_result, resp_result, log_buf, log_buf_len);
 
 	if (e != NULL) {
@@ -1252,7 +1248,7 @@ dns_rrl_view_destroy(dns_view_t *view) {
 	 */
 
 	if (rrl->num_logged > 0)
-		log_stops(rrl, 0, INT32_MAX, log_buf, sizeof(log_buf));
+		log_stops(rrl, 0, ISC_INT32_MAX, log_buf, sizeof(log_buf));
 
 	for (i = 0; i < DNS_RRL_QNAMES; ++i) {
 		if (rrl->qnames[i] == NULL)
