@@ -47,9 +47,6 @@
 /*! \file */
 
 #include <config.h>
-
-#include <inttypes.h>
-#include <stdbool.h>
 #include <string.h>
 
 #include <isc/buffer.h>
@@ -183,8 +180,8 @@ typedef struct sdlz_rdatasetiter {
 /*
  * Forward references.
  */
-static isc_result_t getnodedata(dns_db_t *db, dns_name_t *name,
-				bool create, unsigned int options,
+static isc_result_t getnodedata(dns_db_t *db, const dns_name_t *name,
+				isc_boolean_t create, unsigned int options,
 				dns_clientinfomethods_t *methods,
 				dns_clientinfo_t *clientinfo,
 				dns_dbnode_t **nodep);
@@ -199,7 +196,7 @@ static void		dbiterator_destroy(dns_dbiterator_t **iteratorp);
 static isc_result_t	dbiterator_first(dns_dbiterator_t *iterator);
 static isc_result_t	dbiterator_last(dns_dbiterator_t *iterator);
 static isc_result_t	dbiterator_seek(dns_dbiterator_t *iterator,
-					dns_name_t *name);
+					const dns_name_t *name);
 static isc_result_t	dbiterator_prev(dns_dbiterator_t *iterator);
 static isc_result_t	dbiterator_next(dns_dbiterator_t *iterator);
 static isc_result_t	dbiterator_current(dns_dbiterator_t *iterator,
@@ -347,14 +344,14 @@ destroy(dns_sdlz_db_t *sdlz) {
 static void
 detach(dns_db_t **dbp) {
 	dns_sdlz_db_t *sdlz = (dns_sdlz_db_t *)(*dbp);
-	bool need_destroy = false;
+	isc_boolean_t need_destroy = ISC_FALSE;
 
 	REQUIRE(VALID_SDLZDB(sdlz));
 	LOCK(&sdlz->refcnt_lock);
 	REQUIRE(sdlz->references > 0);
 	sdlz->references--;
 	if (sdlz->references == 0)
-		need_destroy = true;
+		need_destroy = ISC_TRUE;
 	UNLOCK(&sdlz->refcnt_lock);
 
 	if (need_destroy)
@@ -437,7 +434,7 @@ attachversion(dns_db_t *db, dns_dbversion_t *source, dns_dbversion_t **targetp)
 }
 
 static void
-closeversion(dns_db_t *db, dns_dbversion_t **versionp, bool commit) {
+closeversion(dns_db_t *db, dns_dbversion_t **versionp, isc_boolean_t commit) {
 	dns_sdlz_db_t *sdlz = (dns_sdlz_db_t *)db;
 	char origin[DNS_NAME_MAXTEXT + 1];
 
@@ -536,7 +533,7 @@ destroynode(dns_sdlznode_t *node) {
 }
 
 static isc_result_t
-getnodedata(dns_db_t *db, dns_name_t *name, bool create,
+getnodedata(dns_db_t *db, const dns_name_t *name, isc_boolean_t create,
 	    unsigned int options, dns_clientinfomethods_t *methods,
 	    dns_clientinfo_t *clientinfo, dns_dbnode_t **nodep)
 {
@@ -547,14 +544,14 @@ getnodedata(dns_db_t *db, dns_name_t *name, bool create,
 	char namestr[DNS_NAME_MAXTEXT + 1];
 	isc_buffer_t b2;
 	char zonestr[DNS_NAME_MAXTEXT + 1];
-	bool isorigin;
+	isc_boolean_t isorigin;
 	dns_sdlzauthorityfunc_t authority;
 
 	REQUIRE(VALID_SDLZDB(sdlz));
 	REQUIRE(nodep != NULL && *nodep == NULL);
 
 	if (sdlz->dlzimp->methods->newversion == NULL) {
-		REQUIRE(create == false);
+		REQUIRE(create == ISC_FALSE);
 	}
 
 	isc_buffer_init(&b, namestr, sizeof(namestr));
@@ -566,18 +563,18 @@ getnodedata(dns_db_t *db, dns_name_t *name, bool create,
 			 dns_name_countlabels(&sdlz->common.origin);
 		dns_name_init(&relname, NULL);
 		dns_name_getlabelsequence(name, 0, labels, &relname);
-		result = dns_name_totext(&relname, true, &b);
+		result = dns_name_totext(&relname, ISC_TRUE, &b);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	} else {
-		result = dns_name_totext(name, true, &b);
+		result = dns_name_totext(name, ISC_TRUE, &b);
 		if (result != ISC_R_SUCCESS)
 			return (result);
 	}
 	isc_buffer_putuint8(&b, 0);
 
 	isc_buffer_init(&b2, zonestr, sizeof(zonestr));
-	result = dns_name_totext(&sdlz->common.origin, true, &b2);
+	result = dns_name_totext(&sdlz->common.origin, ISC_TRUE, &b2);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 	isc_buffer_putuint8(&b2, 0);
@@ -618,24 +615,27 @@ getnodedata(dns_db_t *db, dns_name_t *name, bool create,
 		for (i = 0; i < dlabels; i++) {
 			char wildstr[DNS_NAME_MAXTEXT + 1];
 			dns_fixedname_t fixed;
-			dns_name_t *wild;
+			const dns_name_t *wild;
 
 			dns_fixedname_init(&fixed);
 			if (i == dlabels)
 				wild = dns_wildcardname;
 			else {
-				wild = dns_fixedname_name(&fixed);
+				dns_name_t *fname;
+				fname = dns_fixedname_name(&fixed);
 				dns_name_getlabelsequence(name, i + 1,
 							  dlabels - i - 1,
-							  wild);
+							  fname);
 				result = dns_name_concatenate(dns_wildcardname,
-							      wild, wild, NULL);
+							      fname, fname,
+							      NULL);
 				if (result != ISC_R_SUCCESS)
 					return (result);
+				wild = fname;
 			}
 
 			isc_buffer_init(&b, wildstr, sizeof(wildstr));
-			result = dns_name_totext(wild, true, &b);
+			result = dns_name_totext(wild, ISC_TRUE, &b);
 			if (result != ISC_R_SUCCESS)
 				return (result);
 			isc_buffer_putuint8(&b, 0);
@@ -695,7 +695,7 @@ getnodedata(dns_db_t *db, dns_name_t *name, bool create,
 }
 
 static isc_result_t
-findnodeext(dns_db_t *db, dns_name_t *name, bool create,
+findnodeext(dns_db_t *db, const dns_name_t *name, isc_boolean_t create,
 	    dns_clientinfomethods_t *methods, dns_clientinfo_t *clientinfo,
 	    dns_dbnode_t **nodep)
 {
@@ -703,14 +703,14 @@ findnodeext(dns_db_t *db, dns_name_t *name, bool create,
 }
 
 static isc_result_t
-findnode(dns_db_t *db, dns_name_t *name, bool create,
+findnode(dns_db_t *db, const dns_name_t *name, isc_boolean_t create,
 	 dns_dbnode_t **nodep)
 {
 	return (getnodedata(db, name, create, 0, NULL, NULL, nodep));
 }
 
 static isc_result_t
-findzonecut(dns_db_t *db, dns_name_t *name, unsigned int options,
+findzonecut(dns_db_t *db, const dns_name_t *name, unsigned int options,
 	    isc_stdtime_t now, dns_dbnode_t **nodep, dns_name_t *foundname,
 	    dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset)
 {
@@ -748,7 +748,7 @@ static void
 detachnode(dns_db_t *db, dns_dbnode_t **targetp) {
 	dns_sdlz_db_t *sdlz = (dns_sdlz_db_t *)db;
 	dns_sdlznode_t *node;
-	bool need_destroy = false;
+	isc_boolean_t need_destroy = ISC_FALSE;
 
 	REQUIRE(VALID_SDLZDB(sdlz));
 	REQUIRE(targetp != NULL && *targetp != NULL);
@@ -761,7 +761,7 @@ detachnode(dns_db_t *db, dns_dbnode_t **targetp) {
 	INSIST(node->references > 0);
 	node->references--;
 	if (node->references == 0)
-		need_destroy = true;
+		need_destroy = ISC_TRUE;
 	UNLOCK(&node->lock);
 
 	if (need_destroy)
@@ -776,7 +776,7 @@ expirenode(dns_db_t *db, dns_dbnode_t *node, isc_stdtime_t now) {
 	UNUSED(node);
 	UNUSED(now);
 	INSIST(0);
-	ISC_UNREACHABLE();
+	return (ISC_R_UNEXPECTED);
 }
 
 static void
@@ -806,7 +806,7 @@ createiterator(dns_db_t *db, unsigned int options, dns_dbiterator_t **iteratorp)
 		 return (ISC_R_NOTIMPLEMENTED);
 
 	isc_buffer_init(&b, zonestr, sizeof(zonestr));
-	result = dns_name_totext(&sdlz->common.origin, true, &b);
+	result = dns_name_totext(&sdlz->common.origin, ISC_TRUE, &b);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 	isc_buffer_putuint8(&b, 0);
@@ -818,8 +818,7 @@ createiterator(dns_db_t *db, unsigned int options, dns_dbiterator_t **iteratorp)
 	sdlziter->common.methods = &dbiterator_methods;
 	sdlziter->common.db = NULL;
 	dns_db_attach(db, &sdlziter->common.db);
-	sdlziter->common.relative_names =
-		((options & DNS_DB_RELATIVENAMES) != 0);
+	sdlziter->common.relative_names = ISC_TF(options & DNS_DB_RELATIVENAMES);
 	sdlziter->common.magic = DNS_DBITERATOR_MAGIC;
 	ISC_LIST_INIT(sdlziter->nodelist);
 	sdlziter->current = NULL;
@@ -884,7 +883,7 @@ findrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 }
 
 static isc_result_t
-findext(dns_db_t *db, dns_name_t *name, dns_dbversion_t *version,
+findext(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
 	dns_rdatatype_t type, unsigned int options, isc_stdtime_t now,
 	dns_dbnode_t **nodep, dns_name_t *foundname,
 	dns_clientinfomethods_t *methods, dns_clientinfo_t *clientinfo,
@@ -937,7 +936,7 @@ findext(dns_db_t *db, dns_name_t *name, dns_dbversion_t *version,
 		 * Look up the next label.
 		 */
 		dns_name_getlabelsequence(name, nlabels - i, i, xname);
-		result = getnodedata(db, xname, false, options,
+		result = getnodedata(db, xname, ISC_FALSE, options,
 				     methods, clientinfo, &node);
 		if (result == ISC_R_NOTFOUND) {
 			result = DNS_R_NXDOMAIN;
@@ -1053,7 +1052,7 @@ findext(dns_db_t *db, dns_name_t *name, dns_dbversion_t *version,
 }
 
 static isc_result_t
-find(dns_db_t *db, dns_name_t *name, dns_dbversion_t *version,
+find(dns_db_t *db, const dns_name_t *name, dns_dbversion_t *version,
      dns_rdatatype_t type, unsigned int options, isc_stdtime_t now,
      dns_dbnode_t **nodep, dns_name_t *foundname,
      dns_rdataset_t *rdataset, dns_rdataset_t *sigrdataset)
@@ -1126,7 +1125,8 @@ modrdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	if (result != ISC_R_SUCCESS)
 		return (result);
 
-	result = dns_master_stylecreate(&style, 0, 0, 0, 0, 0, 0, 1, mctx);
+	result = dns_master_stylecreate(&style, 0, 0, 0, 0, 0, 0, 1,
+					0xffffffff, mctx);
 	if (result != ISC_R_SUCCESS)
 		goto cleanup;
 
@@ -1231,11 +1231,11 @@ deleterdataset(dns_db_t *db, dns_dbnode_t *node, dns_dbversion_t *version,
 	return (result);
 }
 
-static bool
+static isc_boolean_t
 issecure(dns_db_t *db) {
 	UNUSED(db);
 
-	return (false);
+	return (ISC_FALSE);
 }
 
 static unsigned int
@@ -1245,14 +1245,14 @@ nodecount(dns_db_t *db) {
 	return (0);
 }
 
-static bool
+static isc_boolean_t
 ispersistent(dns_db_t *db) {
 	UNUSED(db);
-	return (true);
+	return (ISC_TRUE);
 }
 
 static void
-overmem(dns_db_t *db, bool over) {
+overmem(dns_db_t *db, isc_boolean_t over) {
 	UNUSED(db);
 	UNUSED(over);
 }
@@ -1276,7 +1276,7 @@ getoriginnode(dns_db_t *db, dns_dbnode_t **nodep) {
 	if (sdlz->dlzimp->methods->newversion == NULL)
 		return (ISC_R_NOTIMPLEMENTED);
 
-	result = getnodedata(db, &sdlz->common.origin, false,
+	result = getnodedata(db, &sdlz->common.origin, ISC_FALSE,
 			     0, NULL, NULL, nodep);
 	if (result != ISC_R_SUCCESS)
 		sdlz_log(ISC_LOG_ERROR, "sdlz getoriginnode failed: %s",
@@ -1289,7 +1289,7 @@ static dns_dbmethods_t sdlzdb_methods = {
 	detach,
 	beginload,
 	endload,
-	NULL,
+	NULL,			/* serialize */
 	dump,
 	currentversion,
 	newversion,
@@ -1329,7 +1329,10 @@ static dns_dbmethods_t sdlzdb_methods = {
 	NULL,			/* setcachestats */
 	NULL,			/* hashsize */
 	NULL,			/* nodefullname */
-	NULL			/* getsize */
+	NULL,			/* getsize */
+	NULL,			/* setservestalettl */
+	NULL,			/* getservestalettl */
+	NULL			/* setgluecachestats */
 };
 
 /*
@@ -1378,7 +1381,7 @@ dbiterator_last(dns_dbiterator_t *iterator) {
 }
 
 static isc_result_t
-dbiterator_seek(dns_dbiterator_t *iterator, dns_name_t *name) {
+dbiterator_seek(dns_dbiterator_t *iterator, const dns_name_t *name) {
 	sdlz_dbiterator_t *sdlziter = (sdlz_dbiterator_t *)iterator;
 
 	sdlziter->current = ISC_LIST_HEAD(sdlziter->nodelist);
@@ -1472,16 +1475,14 @@ static dns_rdatasetmethods_t rdataset_methods = {
 	isc__rdatalist_count,
 	isc__rdatalist_addnoqname,
 	isc__rdatalist_getnoqname,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL
+	NULL, /* addclosest */
+	NULL, /* getclosest */
+	NULL, /* settrust */
+	NULL, /* expire */
+	NULL, /* clearprefetch */
+	NULL, /* setownercase */
+	NULL, /* getownercase */
+	NULL  /* addglue */
 };
 
 static void
@@ -1517,7 +1518,8 @@ list_tordataset(dns_rdatalist_t *rdatalist,
 
 static isc_result_t
 dns_sdlzcreateDBP(isc_mem_t *mctx, void *driverarg, void *dbdata,
-		  dns_name_t *name, dns_rdataclass_t rdclass, dns_db_t **dbp)
+		  const dns_name_t *name, dns_rdataclass_t rdclass,
+		  dns_db_t **dbp)
 {
 	isc_result_t result;
 	dns_sdlz_db_t *sdlzdb;
@@ -1578,8 +1580,8 @@ dns_sdlzcreateDBP(isc_mem_t *mctx, void *driverarg, void *dbdata,
 
 static isc_result_t
 dns_sdlzallowzonexfr(void *driverarg, void *dbdata, isc_mem_t *mctx,
-		     dns_rdataclass_t rdclass, dns_name_t *name,
-		     isc_sockaddr_t *clientaddr, dns_db_t **dbp)
+		     dns_rdataclass_t rdclass, const dns_name_t *name,
+		     const isc_sockaddr_t *clientaddr, dns_db_t **dbp)
 {
 	isc_buffer_t b;
 	isc_buffer_t b2;
@@ -1602,7 +1604,7 @@ dns_sdlzallowzonexfr(void *driverarg, void *dbdata, isc_mem_t *mctx,
 
 	/* Convert DNS name to ascii text */
 	isc_buffer_init(&b, namestr, sizeof(namestr));
-	result = dns_name_totext(name, true, &b);
+	result = dns_name_totext(name, ISC_TRUE, &b);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 	isc_buffer_putuint8(&b, 0);
@@ -1695,7 +1697,7 @@ dns_sdlzdestroy(void *driverdata, void **dbdata) {
 
 static isc_result_t
 dns_sdlzfindzone(void *driverarg, void *dbdata, isc_mem_t *mctx,
-		 dns_rdataclass_t rdclass, dns_name_t *name,
+		 dns_rdataclass_t rdclass, const dns_name_t *name,
 		 dns_clientinfomethods_t *methods,
 		 dns_clientinfo_t *clientinfo,
 		 dns_db_t **dbp)
@@ -1716,7 +1718,7 @@ dns_sdlzfindzone(void *driverarg, void *dbdata, isc_mem_t *mctx,
 
 	/* Convert DNS name to ascii text */
 	isc_buffer_init(&b, namestr, sizeof(namestr));
-	result = dns_name_totext(name, true, &b);
+	result = dns_name_totext(name, ISC_TRUE, &b);
 	if (result != ISC_R_SUCCESS)
 		return (result);
 	isc_buffer_putuint8(&b, 0);
@@ -1766,10 +1768,10 @@ dns_sdlzconfigure(void *driverarg, void *dbdata,
 	return (result);
 }
 
-static bool
-dns_sdlzssumatch(dns_name_t *signer, dns_name_t *name, isc_netaddr_t *tcpaddr,
-		 dns_rdatatype_t type, const dst_key_t *key, void *driverarg,
-		 void *dbdata)
+static isc_boolean_t
+dns_sdlzssumatch(const dns_name_t *signer, const dns_name_t *name,
+		 const isc_netaddr_t *tcpaddr, dns_rdatatype_t type,
+		 const dst_key_t *key, void *driverarg, void *dbdata)
 {
 	dns_sdlzimplementation_t *imp;
 	char b_signer[DNS_NAME_FORMATSIZE];
@@ -1779,14 +1781,14 @@ dns_sdlzssumatch(dns_name_t *signer, dns_name_t *name, isc_netaddr_t *tcpaddr,
 	char b_key[DST_KEY_FORMATSIZE];
 	isc_buffer_t *tkey_token = NULL;
 	isc_region_t token_region = { NULL, 0 };
-	uint32_t token_len = 0;
-	bool ret;
+	isc_uint32_t token_len = 0;
+	isc_boolean_t ret;
 
 	REQUIRE(driverarg != NULL);
 
 	imp = (dns_sdlzimplementation_t *) driverarg;
 	if (imp->methods->ssumatch == NULL)
-		return (false);
+		return (ISC_FALSE);
 
 	/*
 	 * Format the request elements. sdlz operates on strings, not
@@ -1853,7 +1855,7 @@ dns_sdlz_putrr(dns_sdlzlookup_t *lookup, const char *type, dns_ttl_t ttl,
 	isc_result_t result;
 	unsigned int size;
 	isc_mem_t *mctx;
-	dns_name_t *origin;
+	const dns_name_t *origin;
 
 	REQUIRE(VALID_SDLZLOOKUP(lookup));
 	REQUIRE(type != NULL);
@@ -1926,7 +1928,7 @@ dns_sdlz_putrr(dns_sdlzlookup_t *lookup, const char *type, dns_ttl_t ttl,
 
 		result = dns_rdata_fromtext(rdata, rdatalist->rdclass,
 					    rdatalist->type, lex,
-					    origin, false,
+					    origin, ISC_FALSE,
 					    mctx, rdatabuf,
 					    &lookup->callbacks);
 		if (result != ISC_R_SUCCESS)
@@ -1963,7 +1965,8 @@ isc_result_t
 dns_sdlz_putnamedrr(dns_sdlzallnodes_t *allnodes, const char *name,
 		    const char *type, dns_ttl_t ttl, const char *data)
 {
-	dns_name_t *newname, *origin;
+	dns_name_t *newname;
+	const dns_name_t *origin;
 	dns_fixedname_t fnewname;
 	dns_sdlz_db_t *sdlz = (dns_sdlz_db_t *)allnodes->common.db;
 	dns_sdlznode_t *sdlznode;
@@ -2019,7 +2022,7 @@ dns_sdlz_putnamedrr(dns_sdlzallnodes_t *allnodes, const char *name,
 
 isc_result_t
 dns_sdlz_putsoa(dns_sdlzlookup_t *lookup, const char *mname, const char *rname,
-		uint32_t serial)
+		isc_uint32_t serial)
 {
 	char str[2 * DNS_NAME_MAXTEXT + 5 * (sizeof("2147483647")) + 7];
 	int n;
@@ -2162,7 +2165,7 @@ dns_sdlzunregister(dns_sdlzimplementation_t **sdlzimp) {
 
 isc_result_t
 dns_sdlz_setdb(dns_dlzdb_t *dlzdatabase, dns_rdataclass_t rdclass,
-	       dns_name_t *name, dns_db_t **dbp)
+	       const dns_name_t *name, dns_db_t **dbp)
 {
 	isc_result_t result;
 
