@@ -13,11 +13,10 @@
 
 #include <config.h>
 
-#include <stdbool.h>
-
 #include <isc/magic.h>
 #include <isc/mem.h>
 #include <isc/netaddr.h>
+#include <isc/print.h>
 #include <isc/result.h>
 #include <isc/string.h>
 #include <isc/util.h>
@@ -38,7 +37,7 @@
 
 struct dns_ssurule {
 	unsigned int magic;
-	bool grant;		/*%< is this a grant or a deny? */
+	isc_boolean_t grant;		/*%< is this a grant or a deny? */
 	dns_ssumatchtype_t matchtype;	/*%< which type of pattern match? */
 	dns_name_t *identity;		/*%< the identity to match */
 	dns_name_t *name;		/*%< the name being updated */
@@ -131,7 +130,7 @@ dns_ssutable_attach(dns_ssutable_t *source, dns_ssutable_t **targetp) {
 void
 dns_ssutable_detach(dns_ssutable_t **tablep) {
 	dns_ssutable_t *table;
-	bool done = false;
+	isc_boolean_t done = ISC_FALSE;
 
 	REQUIRE(tablep != NULL);
 	table = *tablep;
@@ -141,7 +140,7 @@ dns_ssutable_detach(dns_ssutable_t **tablep) {
 
 	INSIST(table->references > 0);
 	if (--table->references == 0)
-		done = true;
+		done = ISC_TRUE;
 	UNLOCK(&table->lock);
 
 	*tablep = NULL;
@@ -151,7 +150,7 @@ dns_ssutable_detach(dns_ssutable_t **tablep) {
 }
 
 isc_result_t
-dns_ssutable_addrule(dns_ssutable_t *table, bool grant,
+dns_ssutable_addrule(dns_ssutable_t *table, isc_boolean_t grant,
 		     const dns_name_t *identity, dns_ssumatchtype_t matchtype,
 		     const dns_name_t *name, unsigned int ntypes,
 		     dns_rdatatype_t *types)
@@ -238,11 +237,11 @@ dns_ssutable_addrule(dns_ssutable_t *table, bool grant,
 	return (result);
 }
 
-static inline bool
+static inline isc_boolean_t
 isusertype(dns_rdatatype_t type) {
-	return (type != dns_rdatatype_ns &&
-		type != dns_rdatatype_soa &&
-		type != dns_rdatatype_rrsig);
+	return (ISC_TF(type != dns_rdatatype_ns &&
+		       type != dns_rdatatype_soa &&
+		       type != dns_rdatatype_rrsig));
 }
 
 static void
@@ -256,41 +255,40 @@ reverse_from_address(dns_name_t *tcpself, const isc_netaddr_t *tcpaddr) {
 	switch (tcpaddr->family) {
 	case AF_INET:
 		l = ntohl(tcpaddr->type.in.s_addr);
-		result = isc_string_printf(buf, sizeof(buf),
-					   "%lu.%lu.%lu.%lu.IN-ADDR.ARPA.",
-					   (l >> 0) & 0xff, (l >> 8) & 0xff,
-					   (l >> 16) & 0xff, (l >> 24) & 0xff);
-		RUNTIME_CHECK(result == ISC_R_SUCCESS);
+		result = snprintf(buf, sizeof(buf),
+				  "%lu.%lu.%lu.%lu.IN-ADDR.ARPA.",
+				  (l >> 0) & 0xff, (l >> 8) & 0xff,
+				  (l >> 16) & 0xff, (l >> 24) & 0xff);
+		RUNTIME_CHECK(result < sizeof(buf));
 		break;
 	case AF_INET6:
 		ap = tcpaddr->type.in6.s6_addr;
-		result = isc_string_printf(buf, sizeof(buf),
-					   "%x.%x.%x.%x.%x.%x.%x.%x."
-					   "%x.%x.%x.%x.%x.%x.%x.%x."
-					   "%x.%x.%x.%x.%x.%x.%x.%x."
-					   "%x.%x.%x.%x.%x.%x.%x.%x."
-					   "IP6.ARPA.",
-					   ap[15] & 0x0f, (ap[15] >> 4) & 0x0f,
-					   ap[14] & 0x0f, (ap[14] >> 4) & 0x0f,
-					   ap[13] & 0x0f, (ap[13] >> 4) & 0x0f,
-					   ap[12] & 0x0f, (ap[12] >> 4) & 0x0f,
-					   ap[11] & 0x0f, (ap[11] >> 4) & 0x0f,
-					   ap[10] & 0x0f, (ap[10] >> 4) & 0x0f,
-					   ap[9] & 0x0f, (ap[9] >> 4) & 0x0f,
-					   ap[8] & 0x0f, (ap[8] >> 4) & 0x0f,
-					   ap[7] & 0x0f, (ap[7] >> 4) & 0x0f,
-					   ap[6] & 0x0f, (ap[6] >> 4) & 0x0f,
-					   ap[5] & 0x0f, (ap[5] >> 4) & 0x0f,
-					   ap[4] & 0x0f, (ap[4] >> 4) & 0x0f,
-					   ap[3] & 0x0f, (ap[3] >> 4) & 0x0f,
-					   ap[2] & 0x0f, (ap[2] >> 4) & 0x0f,
-					   ap[1] & 0x0f, (ap[1] >> 4) & 0x0f,
-					   ap[0] & 0x0f, (ap[0] >> 4) & 0x0f);
-		RUNTIME_CHECK(result == ISC_R_SUCCESS);
+		result = snprintf(buf, sizeof(buf),
+				  "%x.%x.%x.%x.%x.%x.%x.%x."
+				  "%x.%x.%x.%x.%x.%x.%x.%x."
+				  "%x.%x.%x.%x.%x.%x.%x.%x."
+				  "%x.%x.%x.%x.%x.%x.%x.%x."
+				  "IP6.ARPA.",
+				  ap[15] & 0x0f, (ap[15] >> 4) & 0x0f,
+				  ap[14] & 0x0f, (ap[14] >> 4) & 0x0f,
+				  ap[13] & 0x0f, (ap[13] >> 4) & 0x0f,
+				  ap[12] & 0x0f, (ap[12] >> 4) & 0x0f,
+				  ap[11] & 0x0f, (ap[11] >> 4) & 0x0f,
+				  ap[10] & 0x0f, (ap[10] >> 4) & 0x0f,
+				  ap[9] & 0x0f, (ap[9] >> 4) & 0x0f,
+				  ap[8] & 0x0f, (ap[8] >> 4) & 0x0f,
+				  ap[7] & 0x0f, (ap[7] >> 4) & 0x0f,
+				  ap[6] & 0x0f, (ap[6] >> 4) & 0x0f,
+				  ap[5] & 0x0f, (ap[5] >> 4) & 0x0f,
+				  ap[4] & 0x0f, (ap[4] >> 4) & 0x0f,
+				  ap[3] & 0x0f, (ap[3] >> 4) & 0x0f,
+				  ap[2] & 0x0f, (ap[2] >> 4) & 0x0f,
+				  ap[1] & 0x0f, (ap[1] >> 4) & 0x0f,
+				  ap[0] & 0x0f, (ap[0] >> 4) & 0x0f);
+		RUNTIME_CHECK(result < sizeof(buf));
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 	isc_buffer_init(&b, buf, strlen(buf));
 	isc_buffer_add(&b, strlen(buf));
@@ -309,31 +307,30 @@ stf_from_address(dns_name_t *stfself, const isc_netaddr_t *tcpaddr) {
 	switch(tcpaddr->family) {
 	case AF_INET:
 		l = ntohl(tcpaddr->type.in.s_addr);
-		result = isc_string_printf(buf, sizeof(buf),
-					   "%lx.%lx.%lx.%lx.%lx.%lx.%lx.%lx"
-					   "2.0.0.2.IP6.ARPA.",
-					   l & 0xf, (l >> 4) & 0xf,
-					   (l >> 8) & 0xf, (l >> 12) & 0xf,
-					   (l >> 16) & 0xf, (l >> 20) & 0xf,
-					   (l >> 24) & 0xf, (l >> 28) & 0xf);
-		RUNTIME_CHECK(result == ISC_R_SUCCESS);
+		result = snprintf(buf, sizeof(buf),
+				  "%lx.%lx.%lx.%lx.%lx.%lx.%lx.%lx"
+				  "2.0.0.2.IP6.ARPA.",
+				  l & 0xf, (l >> 4) & 0xf,
+				  (l >> 8) & 0xf, (l >> 12) & 0xf,
+				  (l >> 16) & 0xf, (l >> 20) & 0xf,
+				  (l >> 24) & 0xf, (l >> 28) & 0xf);
+		RUNTIME_CHECK(result < sizeof(buf));
 		break;
 	case AF_INET6:
 		ap = tcpaddr->type.in6.s6_addr;
-		result = isc_string_printf(buf, sizeof(buf),
-					   "%x.%x.%x.%x.%x.%x.%x.%x."
-					   "%x.%x.%x.%x.IP6.ARPA.",
-					   ap[5] & 0x0f, (ap[5] >> 4) & 0x0f,
-					   ap[4] & 0x0f, (ap[4] >> 4) & 0x0f,
-					   ap[3] & 0x0f, (ap[3] >> 4) & 0x0f,
-					   ap[2] & 0x0f, (ap[2] >> 4) & 0x0f,
-					   ap[1] & 0x0f, (ap[1] >> 4) & 0x0f,
-					   ap[0] & 0x0f, (ap[0] >> 4) & 0x0f);
-		RUNTIME_CHECK(result == ISC_R_SUCCESS);
+		result = snprintf(buf, sizeof(buf),
+				  "%x.%x.%x.%x.%x.%x.%x.%x."
+				  "%x.%x.%x.%x.IP6.ARPA.",
+				  ap[5] & 0x0f, (ap[5] >> 4) & 0x0f,
+				  ap[4] & 0x0f, (ap[4] >> 4) & 0x0f,
+				  ap[3] & 0x0f, (ap[3] >> 4) & 0x0f,
+				  ap[2] & 0x0f, (ap[2] >> 4) & 0x0f,
+				  ap[1] & 0x0f, (ap[1] >> 4) & 0x0f,
+				  ap[0] & 0x0f, (ap[0] >> 4) & 0x0f);
+		RUNTIME_CHECK(result < sizeof(buf));
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 	isc_buffer_init(&b, buf, strlen(buf));
 	isc_buffer_add(&b, strlen(buf));
@@ -341,21 +338,11 @@ stf_from_address(dns_name_t *stfself, const isc_netaddr_t *tcpaddr) {
 	RUNTIME_CHECK(result == ISC_R_SUCCESS);
 }
 
-bool
+isc_boolean_t
 dns_ssutable_checkrules(dns_ssutable_t *table, const dns_name_t *signer,
-			const dns_name_t *name, const isc_netaddr_t *tcpaddr,
+			const dns_name_t *name, const isc_netaddr_t *addr,
+			isc_boolean_t tcp, const dns_aclenv_t *env,
 			dns_rdatatype_t type, const dst_key_t *key)
-{
-	return (dns_ssutable_checkrules2
-		(table, signer, name, tcpaddr,
-		 tcpaddr == NULL ? false : true,
-		 NULL, type, key));
-}
-bool
-dns_ssutable_checkrules2(dns_ssutable_t *table, const dns_name_t *signer,
-			 const dns_name_t *name, const isc_netaddr_t *addr,
-			 bool tcp, const dns_aclenv_t *env,
-			 dns_rdatatype_t type, const dst_key_t *key)
 {
 	dns_ssurule_t *rule;
 	unsigned int i;
@@ -372,7 +359,7 @@ dns_ssutable_checkrules2(dns_ssutable_t *table, const dns_name_t *signer,
 	REQUIRE(addr == NULL || env != NULL);
 
 	if (signer == NULL && addr == NULL)
-		return (false);
+		return (ISC_FALSE);
 
 	for (rule = ISC_LIST_HEAD(table->rules);
 	     rule != NULL;
@@ -399,8 +386,6 @@ dns_ssutable_checkrules2(dns_ssutable_t *table, const dns_name_t *signer,
 			break;
 		case dns_ssumatchtype_selfkrb5:
 		case dns_ssumatchtype_selfms:
-		case dns_ssumatchtype_selfsubkrb5:
-		case dns_ssumatchtype_selfsubms:
 		case dns_ssumatchtype_subdomainkrb5:
 		case dns_ssumatchtype_subdomainms:
 			if (signer == NULL)
@@ -432,8 +417,9 @@ dns_ssutable_checkrules2(dns_ssutable_t *table, const dns_name_t *signer,
 			if (!dns_name_issubdomain(name, rule->name)) {
 				continue;
 			}
-			dns_acl_match(addr, NULL, env->localhost,
-				      NULL, &match, NULL);
+				dns_acl_match(addr, NULL, NULL, 0, NULL,
+					      env->localhost, NULL, &match,
+					      NULL);
 			if (match == 0) {
 				if (signer != NULL) {
 					isc_log_write(dns_lctx,
@@ -470,55 +456,29 @@ dns_ssutable_checkrules2(dns_ssutable_t *table, const dns_name_t *signer,
 				continue;
 			break;
 		case dns_ssumatchtype_selfkrb5:
-			if (dst_gssapi_identitymatchesrealmkrb5(signer, name,
-								rule->identity,
-								false))
-			{
-				break;
-			}
-			continue;
+			if (!dst_gssapi_identitymatchesrealmkrb5(signer, name,
+							       rule->identity))
+				continue;
+			break;
 		case dns_ssumatchtype_selfms:
-			if (dst_gssapi_identitymatchesrealmms(signer, name,
-							      rule->identity,
-							      false))
-			{
-				break;
-			}
-			continue;
-		case dns_ssumatchtype_selfsubkrb5:
-			if (dst_gssapi_identitymatchesrealmkrb5(signer, name,
-								rule->identity,
-								true))
-			{
-				break;
-			}
-			continue;
-		case dns_ssumatchtype_selfsubms:
-			if (dst_gssapi_identitymatchesrealmms(signer, name,
-							      rule->identity,
-							      true))
-				break;
-			continue;
+			if (!dst_gssapi_identitymatchesrealmms(signer, name,
+							       rule->identity))
+				continue;
+			break;
 		case dns_ssumatchtype_subdomainkrb5:
 			if (!dns_name_issubdomain(name, rule->name))
 				continue;
-			if (dst_gssapi_identitymatchesrealmkrb5(signer, NULL,
-								rule->identity,
-								false))
-			{
-				break;
-			}
-			continue;
+			if (!dst_gssapi_identitymatchesrealmkrb5(signer, NULL,
+							       rule->identity))
+				continue;
+			break;
 		case dns_ssumatchtype_subdomainms:
 			if (!dns_name_issubdomain(name, rule->name))
 				continue;
-			if (dst_gssapi_identitymatchesrealmms(signer, NULL,
-							      rule->identity,
-							      false))
-			{
-				break;
-			}
-			continue;
+			if (!dst_gssapi_identitymatchesrealmms(signer, NULL,
+							       rule->identity))
+				continue;
+			break;
 		case dns_ssumatchtype_tcpself:
 			tcpself = dns_fixedname_initname(&fixed);
 			reverse_from_address(tcpself, addr);
@@ -581,10 +541,10 @@ dns_ssutable_checkrules2(dns_ssutable_t *table, const dns_name_t *signer,
 		return (rule->grant);
 	}
 
-	return (false);
+	return (ISC_FALSE);
 }
 
-bool
+isc_boolean_t
 dns_ssurule_isgrant(const dns_ssurule_t *rule) {
 	REQUIRE(VALID_SSURULE(rule));
 	return (rule->grant);
@@ -660,7 +620,7 @@ dns_ssutable_createdlz(isc_mem_t *mctx, dns_ssutable_t **tablep,
 	rule->identity = NULL;
 	rule->name = NULL;
 	rule->types = NULL;
-	rule->grant = true;
+	rule->grant = ISC_TRUE;
 	rule->matchtype = dns_ssumatchtype_dlz;
 	rule->ntypes = 0;
 	rule->types = NULL;
@@ -691,12 +651,8 @@ dns_ssu_mtypefromstring(const char *str, dns_ssumatchtype_t *mtype) {
 		*mtype = dns_ssumatchtype_selfwild;
 	} else if (strcasecmp(str, "ms-self") == 0) {
 		*mtype = dns_ssumatchtype_selfms;
-	} else if (strcasecmp(str, "ms-selfsub") == 0) {
-		*mtype = dns_ssumatchtype_selfsubms;
 	} else if (strcasecmp(str, "krb5-self") == 0) {
 		*mtype = dns_ssumatchtype_selfkrb5;
-	} else if (strcasecmp(str, "krb5-selfsub") == 0) {
-		*mtype = dns_ssumatchtype_selfsubkrb5;
 	} else if (strcasecmp(str, "ms-subdomain") == 0) {
 		*mtype = dns_ssumatchtype_subdomainms;
 	} else if (strcasecmp(str, "krb5-subdomain") == 0) {
