@@ -30,7 +30,7 @@
 
 #include "dnstest.h"
 
-#if defined(OPENSSL) && !defined(PK11_DH_DISABLE)
+#if HAVE_OPENSSL && !defined(PK11_DH_DISABLE)
 
 ATF_TC(isc_dh_computesecret);
 ATF_TC_HEAD(isc_dh_computesecret, tc) {
@@ -46,7 +46,7 @@ ATF_TC_BODY(isc_dh_computesecret, tc) {
 
 	UNUSED(tc);
 
-	ret = dns_test_begin(NULL, false);
+	ret = dns_test_begin(NULL, ISC_FALSE);
 	ATF_REQUIRE_EQ(ret, ISC_R_SUCCESS);
 
 	name = dns_fixedname_initname(&fname);
@@ -83,7 +83,7 @@ ATF_TC_BODY(untested, tc) {
  * Main
  */
 ATF_TP_ADD_TCS(tp) {
-#if defined(OPENSSL) && !defined(PK11_DH_DISABLE)
+#if HAVE_OPENSSL && !defined(PK11_DH_DISABLE)
 	ATF_TP_ADD_TC(tp, isc_dh_computesecret);
 #else
 	ATF_TP_ADD_TC(tp, untested);
