@@ -10,81 +10,51 @@
  */
 
 
+/* ! \file */
+
 #include <config.h>
-
-#if HAVE_CMOCKA
-
-#include <stdarg.h>
-#include <stddef.h>
-#include <setjmp.h>
-
+#include <atf-c.h>
+#include <isc/mem.h>
+#include <isc/print.h>
+#include <isc/random.h>
+#include <isc/string.h>
 #include <fcntl.h>
-#include <inttypes.h>
-#include <sched.h> /* IWYU pragma: keep */
-#include <stdlib.h>
-#include <sys/mman.h>
 #include <unistd.h>
+#include <sys/mman.h>
 
-#define UNIT_TESTING
-#include <cmocka.h>
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h> /* uintptr_t */
+#endif
+
+#include <dns/rbt.h>
+#include <dns/fixedname.h>
+#include <dns/result.h>
+#include <dns/compress.h>
+#include "dnstest.h"
 
 #include <isc/app.h>
 #include <isc/buffer.h>
-#include <isc/commandline.h>
-#include <isc/entropy.h>
 #include <isc/file.h>
 #include <isc/hash.h>
 #include <isc/mem.h>
 #include <isc/os.h>
-#include <isc/print.h>
-#include <isc/random.h>
+#include <isc/string.h>
 #include <isc/socket.h>
 #include <isc/stdio.h>
-#include <isc/string.h>
 #include <isc/task.h>
 #include <isc/timer.h>
 #include <isc/util.h>
 
-#include <dns/compress.h>
-#include <dns/fixedname.h>
 #include <dns/log.h>
 #include <dns/name.h>
-#include <dns/rbt.h>
-#include <dns/result.h>
 #include <dns/result.h>
 
 #include <dst/dst.h>
 
-#include "dnstest.h"
-
 #ifndef MAP_FILE
 #define MAP_FILE 0
 #endif
 
-/* Set to true (or use -v option) for verbose output */
-static bool verbose = false;
-
-static int
-_setup(void **state) {
-	isc_result_t result;
-
-	UNUSED(state);
-
-	result = dns_test_begin(NULL, false);
-	assert_int_equal(result, ISC_R_SUCCESS);
-
-	return (0);
-}
-
-static int
-_teardown(void **state) {
-	UNUSED(state);
-
-	dns_test_end();
-
-	return (0);
-}
-
 typedef struct data_holder {
 	int len;
 	const char *data;
@@ -131,10 +101,10 @@ delete_data(void *data, void *arg) {
 }
 
 static isc_result_t
-write_data(FILE *file, unsigned char *datap, void *arg, uint64_t *crc) {
+write_data(FILE *file, unsigned char *datap, void *arg, isc_uint64_t *crc) {
 	isc_result_t result;
 	size_t ret = 0;
-	data_holder_t *data;
+	data_holder_t *data = (data_holder_t *)datap;
 	data_holder_t temp;
 	off_t where;
 
@@ -142,15 +112,13 @@ write_data(FILE *file, unsigned char *datap, void *arg, uint64_t *crc) {
 
 	REQUIRE(file != NULL);
 	REQUIRE(crc != NULL);
-	REQUIRE(datap != NULL);
-	data = (data_holder_t *)datap;
+	REQUIRE(data != NULL);
 	REQUIRE((data->len == 0 && data->data == NULL) ||
 		(data->len != 0 && data->data != NULL));
 
 	result = isc_stdio_tell(file, &where);
-	if (result != ISC_R_SUCCESS) {
+	if (result != ISC_R_SUCCESS)
 		return (result);
-	}
 
 	temp = *data;
 	temp.data = (data->len == 0
@@ -159,23 +127,23 @@ write_data(FILE *file, unsigned char *datap, void *arg, uint64_t *crc) {
 
 	isc_crc64_update(crc, (void *)&temp, sizeof(temp));
 	ret = fwrite(&temp, sizeof(data_holder_t), 1, file);
-	if (ret != 1) {
+	if (ret != 1)
 		return (ISC_R_FAILURE);
-	}
 	if (data->len > 0) {
 		isc_crc64_update(crc, (const void *)data->data, data->len);
 		ret = fwrite(data->data, data->len, 1, file);
-		if (ret != 1) {
+		if (ret != 1)
 			return (ISC_R_FAILURE);
-		}
 	}
 
 	return (ISC_R_SUCCESS);
 }
 
 static isc_result_t
-fix_data(dns_rbtnode_t *p, void *base, size_t max, void *arg, uint64_t *crc) {
-	data_holder_t *data;
+fix_data(dns_rbtnode_t *p, void *base, size_t max, void *arg,
+	 isc_uint64_t *crc)
+{
+	data_holder_t *data = p->data;
 	size_t size;
 
 	UNUSED(base);
@@ -185,31 +153,32 @@ fix_data(dns_rbtnode_t *p, void *base, size_t max, void *arg, uint64_t *crc) {
 	REQUIRE(crc != NULL);
 	REQUIRE(p != NULL);
 
-	data = p->data;
+
+	if (data == NULL)
+		printf("fixing data: data NULL\n");
+	else
+		printf("fixing data: len %d, data %p\n", data->len, data->data);
 
 	if (data == NULL ||
 	    (data->len == 0 && data->data != NULL) ||
 	    (data->len != 0 && data->data == NULL))
-	{
 		return (ISC_R_INVALIDFILE);
-	}
 
 	size = max - ((char *)p - (char *)base);
 
 	if (data->len > (int) size || data->data > (const char *) max) {
+		printf("data invalid\n");
 		return (ISC_R_INVALIDFILE);
 	}
 
 	isc_crc64_update(crc, (void *)data, sizeof(*data));
 
-	data->data = NULL;
-	if (data->len != 0) {
-		data->data = (char *)data + sizeof(data_holder_t);
-	}
+	data->data = (data->len == 0)
+		? NULL
+		: (char *)data + sizeof(data_holder_t);
 
-	if (data->len > 0) {
+	if (data->len > 0)
 		isc_crc64_update(crc, (const void *)data->data, data->len);
-	}
 
 	return (ISC_R_SUCCESS);
 }
@@ -243,7 +212,7 @@ add_test_data(isc_mem_t *mymctx, dns_rbt_t *rbt) {
 
 		if (name != NULL) {
 			result = dns_rbt_addname(rbt, name, &testdatap->data);
-			assert_int_equal(result, ISC_R_SUCCESS);
+			ATF_CHECK_STREQ(dns_result_totext(result), "success");
 		}
 		testdatap++;
 	}
@@ -285,22 +254,25 @@ check_test_data(dns_rbt_t *rbt) {
 		data = NULL;
 		result = dns_rbt_findname(rbt, name, 0, foundname,
 					  (void *) &data);
-		assert_int_equal(result, ISC_R_SUCCESS);
+		ATF_CHECK_STREQ(dns_result_totext(result), "success");
 
 		testdatap++;
 	}
 }
 
 static void
-data_printer(FILE *out, void *datap) {
+data_printer(FILE *out, void *datap)
+{
 	data_holder_t *data = (data_holder_t *)datap;
 
 	fprintf(out, "%d bytes, %s", data->len, data->data);
 }
 
-/* Test writing an rbt to file */
-static void
-serialize_test(void **state) {
+ATF_TC(serialize);
+ATF_TC_HEAD(serialize, tc) {
+	atf_tc_set_md_var(tc, "descr", "Test writing an rbt to file");
+}
+ATF_TC_BODY(serialize, tc) {
 	dns_rbt_t *rbt = NULL;
 	isc_result_t result;
 	FILE *rbtfile = NULL;
@@ -310,39 +282,44 @@ serialize_test(void **state) {
 	off_t filesize = 0;
 	char *base;
 
-	UNUSED(state);
+	UNUSED(tc);
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
+	result = dns_test_begin(NULL, ISC_TRUE);
+	ATF_CHECK_STREQ(dns_result_totext(result), "success");
 	result = dns_rbt_create(mctx, delete_data, NULL, &rbt);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	ATF_CHECK_STREQ(dns_result_totext(result), "success");
 
 	add_test_data(mctx, rbt);
 
-	if (verbose) {
-		dns_rbt_printtext(rbt, data_printer, stdout);
-	}
+	dns_rbt_printtext(rbt, data_printer, stdout);
 
 	/*
 	 * Serialize the tree.
 	 */
+	printf("serialization begins.\n");
 	rbtfile = fopen("./zone.bin", "w+b");
-	assert_non_null(rbtfile);
+	ATF_REQUIRE(rbtfile != NULL);
 	result = dns_rbt_serialize_tree(rbtfile, rbt, write_data, NULL,
 					&offset);
-	assert_true(result == ISC_R_SUCCESS);
+	ATF_REQUIRE(result == ISC_R_SUCCESS);
 	dns_rbt_destroy(&rbt);
 
 	/*
-	 * Deserialize the tree.
+	 * Deserialize the tree
+	 */
+	printf("deserialization begins.\n");
+
+	/*
 	 * Map in the whole file in one go
 	 */
 	fd = open("zone.bin", O_RDWR);
-	assert_int_not_equal(fd, -1);
 	isc_file_getsizefd(fd, &filesize);
-	base = mmap(NULL, filesize, PROT_READ|PROT_WRITE,
+	base = mmap(NULL, filesize,
+		    PROT_READ|PROT_WRITE,
 		    MAP_FILE|MAP_PRIVATE, fd, 0);
-	assert_true(base != NULL && base != MAP_FAILED);
+	ATF_REQUIRE(base != NULL && base != MAP_FAILED);
 	close(fd);
 
 	result = dns_rbt_deserialize_tree(base, filesize, 0, mctx,
@@ -350,25 +327,25 @@ serialize_test(void **state) {
 					  NULL, &rbt_deserialized);
 
 	/* Test to make sure we have a valid tree */
-	assert_true(result == ISC_R_SUCCESS);
-	if (rbt_deserialized == NULL) {
-		fail_msg("deserialized rbt is null!"); /* Abort execution. */
-	}
+	ATF_REQUIRE(result == ISC_R_SUCCESS);
+	if (rbt_deserialized == NULL)
+		atf_tc_fail("deserialized rbt is null!"); /* Abort execution. */
 
 	check_test_data(rbt_deserialized);
 
-	if (verbose) {
-		dns_rbt_printtext(rbt_deserialized, data_printer, stdout);
-	}
+	dns_rbt_printtext(rbt_deserialized, data_printer, stdout);
 
 	dns_rbt_destroy(&rbt_deserialized);
 	munmap(base, filesize);
 	unlink("zone.bin");
+	dns_test_end();
 }
 
-/* Test reading a corrupt map file */
-static void
-deserialize_corrupt_test(void **state) {
+ATF_TC(deserialize_corrupt);
+ATF_TC_HEAD(deserialize_corrupt, tc) {
+	atf_tc_set_md_var(tc, "descr", "Test reading a corrupt map file");
+}
+ATF_TC_BODY(deserialize_corrupt, tc) {
 	dns_rbt_t *rbt = NULL;
 	isc_result_t result;
 	FILE *rbtfile = NULL;
@@ -376,23 +353,25 @@ deserialize_corrupt_test(void **state) {
 	int fd;
 	off_t filesize = 0;
 	char *base, *p, *q;
-	uint32_t r;
 	int i;
 
-	UNUSED(state);
+	UNUSED(tc);
 
 	isc_mem_debugging = ISC_MEM_DEBUGRECORD;
 
+	result = dns_test_begin(NULL, ISC_TRUE);
+	ATF_REQUIRE_EQ(result, ISC_R_SUCCESS);
+
 	/* Set up map file */
 	result = dns_rbt_create(mctx, delete_data, NULL, &rbt);
-	assert_int_equal(result, ISC_R_SUCCESS);
+	ATF_CHECK_EQ(result, ISC_R_SUCCESS);
 
 	add_test_data(mctx, rbt);
 	rbtfile = fopen("./zone.bin", "w+b");
-	assert_non_null(rbtfile);
+	ATF_REQUIRE(rbtfile != NULL);
 	result = dns_rbt_serialize_tree(rbtfile, rbt, write_data, NULL,
 					&offset);
-	assert_true(result == ISC_R_SUCCESS);
+	ATF_REQUIRE(result == ISC_R_SUCCESS);
 	dns_rbt_destroy(&rbt);
 
 	/* Read back with random fuzzing */
@@ -400,99 +379,73 @@ deserialize_corrupt_test(void **state) {
 		dns_rbt_t *rbt_deserialized = NULL;
 
 		fd = open("zone.bin", O_RDWR);
-		assert_int_not_equal(fd, -1);
 		isc_file_getsizefd(fd, &filesize);
-		base = mmap(NULL, filesize, PROT_READ|PROT_WRITE,
+		base = mmap(NULL, filesize,
+			    PROT_READ|PROT_WRITE,
 			    MAP_FILE|MAP_PRIVATE, fd, 0);
-		assert_true(base != NULL && base != MAP_FAILED);
+		ATF_REQUIRE(base != NULL && base != MAP_FAILED);
 		close(fd);
 
 		/* Randomly fuzz a portion of the memory */
-		isc_random_get(&r);
-		/* cppcheck-suppress nullPointerArithmeticRedundantCheck */
-		p = base + (r % filesize);
-		/* cppcheck-suppress nullPointerArithmeticRedundantCheck */
+		p = base + (isc_random() % filesize);
 		q = base + filesize;
-		isc_random_get(&r);
-		q -= (r % (q - p));
+		q -= (isc_random() % (q - p));
 		while (p++ < q) {
-			isc_random_get(&r);
-			*p = r & 0xff;
+			*p = isc_random() & 0xff;
 		}
 
 		result = dns_rbt_deserialize_tree(base, filesize, 0, mctx,
 						  delete_data, NULL,
 						  fix_data, NULL,
 						  NULL, &rbt_deserialized);
+		printf("%d: %s\n", i, isc_result_totext(result));
 
 		/* Test to make sure we have a valid tree */
-		assert_true(result == ISC_R_SUCCESS ||
+		ATF_REQUIRE(result == ISC_R_SUCCESS ||
 			    result == ISC_R_INVALIDFILE);
-		if (result != ISC_R_SUCCESS) {
-			assert_null(rbt_deserialized);
-		}
+		if (result != ISC_R_SUCCESS)
+			ATF_REQUIRE(rbt_deserialized == NULL);
 
-		if (rbt_deserialized != NULL) {
+		if (rbt_deserialized != NULL)
 			dns_rbt_destroy(&rbt_deserialized);
-		}
 
 		munmap(base, filesize);
 	}
 
 	unlink("zone.bin");
+	dns_test_end();
 }
 
-/* Test the dns_rbt_serialize_align() function */
-static void
-serialize_align_test(void **state) {
-	UNUSED(state);
 
-	assert_true(dns_rbt_serialize_align(0) == 0);
-	assert_true(dns_rbt_serialize_align(1) == 8);
-	assert_true(dns_rbt_serialize_align(2) == 8);
-	assert_true(dns_rbt_serialize_align(3) == 8);
-	assert_true(dns_rbt_serialize_align(4) == 8);
-	assert_true(dns_rbt_serialize_align(5) == 8);
-	assert_true(dns_rbt_serialize_align(6) == 8);
-	assert_true(dns_rbt_serialize_align(7) == 8);
-	assert_true(dns_rbt_serialize_align(8) == 8);
-	assert_true(dns_rbt_serialize_align(9) == 16);
-	assert_true(dns_rbt_serialize_align(0xff) == 0x100);
-	assert_true(dns_rbt_serialize_align(0x301) == 0x308);
+ATF_TC(serialize_align);
+ATF_TC_HEAD(serialize_align, tc) {
+	atf_tc_set_md_var(tc, "descr",
+			  "Test the dns_rbt_serialize_align() function.");
+}
+ATF_TC_BODY(serialize_align, tc) {
+	UNUSED(tc);
+
+	ATF_CHECK(dns_rbt_serialize_align(0) == 0);
+	ATF_CHECK(dns_rbt_serialize_align(1) == 8);
+	ATF_CHECK(dns_rbt_serialize_align(2) == 8);
+	ATF_CHECK(dns_rbt_serialize_align(3) == 8);
+	ATF_CHECK(dns_rbt_serialize_align(4) == 8);
+	ATF_CHECK(dns_rbt_serialize_align(5) == 8);
+	ATF_CHECK(dns_rbt_serialize_align(6) == 8);
+	ATF_CHECK(dns_rbt_serialize_align(7) == 8);
+	ATF_CHECK(dns_rbt_serialize_align(8) == 8);
+	ATF_CHECK(dns_rbt_serialize_align(9) == 16);
+	ATF_CHECK(dns_rbt_serialize_align(0xff) == 0x100);
+	ATF_CHECK(dns_rbt_serialize_align(0x301) == 0x308);
 }
 
-int
-main(int argc, char **argv) {
-	const struct CMUnitTest tests[] = {
-		cmocka_unit_test_setup_teardown(serialize_test,
-						_setup, _teardown),
-		cmocka_unit_test_setup_teardown(deserialize_corrupt_test,
-						_setup, _teardown),
-		cmocka_unit_test(serialize_align_test),
-	};
-	int c;
+/*
+ * Main
+ */
+ATF_TP_ADD_TCS(tp) {
+	ATF_TP_ADD_TC(tp, serialize);
+	ATF_TP_ADD_TC(tp, deserialize_corrupt);
+	ATF_TP_ADD_TC(tp, serialize_align);
 
-	while ((c = isc_commandline_parse(argc, argv, "v")) != -1) {
-		switch (c) {
-		case 'v':
-			verbose = true;
-			break;
-		default:
-			break;
-		}
-	}
-
-	return (cmocka_run_group_tests(tests, dns_test_init, dns_test_final));
+	return (atf_no_error());
 }
-
-#else /* HAVE_CMOCKA */
-
-#include <stdio.h>
-
-int
-main(void) {
-	printf("1..0 # Skipped: cmocka not available\n");
-	return (0);
-}
-
-#endif
