@@ -11,9 +11,6 @@
 
 /*! \file */
 #include <config.h>
-
-#include <inttypes.h>
-#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/buffer.h>
@@ -137,16 +134,18 @@ cleanup_ring(dns_tsig_keyring_t *ring);
 static void
 tsigkey_free(dns_tsigkey_t *key);
 
-bool
+isc_boolean_t
 dns__tsig_algvalid(unsigned int alg) {
-	return (alg == DST_ALG_HMACSHA1 ||
 #ifndef PK11_MD5_DISABLE
-		alg == DST_ALG_HMACMD5 ||
+	if (alg == DST_ALG_HMACMD5) {
+		return (ISC_TRUE);
+	}
 #endif
-		alg == DST_ALG_HMACSHA224 ||
-		alg == DST_ALG_HMACSHA256 ||
-		alg == DST_ALG_HMACSHA384 ||
-		alg == DST_ALG_HMACSHA512);
+	return (ISC_TF(alg == DST_ALG_HMACSHA1 ||
+		       alg == DST_ALG_HMACSHA224 ||
+		       alg == DST_ALG_HMACSHA256 ||
+		       alg == DST_ALG_HMACSHA384 ||
+		       alg == DST_ALG_HMACSHA512));
 }
 
 static void
@@ -156,7 +155,7 @@ tsig_log(dns_tsigkey_t *key, int level, const char *fmt, ...) {
 	char namestr[DNS_NAME_FORMATSIZE];
 	char creatorstr[DNS_NAME_FORMATSIZE];
 
-	if (isc_log_wouldlog(dns_lctx, level) == false)
+	if (isc_log_wouldlog(dns_lctx, level) == ISC_FALSE)
 		return;
 	if (key != NULL) {
 		dns_name_format(&key->name, namestr, sizeof(namestr));
@@ -191,7 +190,7 @@ remove_fromring(dns_tsigkey_t *tkey) {
 		ISC_LIST_UNLINK(tkey->ring->lru, tkey, link);
 		tkey->ring->generated--;
 	}
-	(void)dns_rbt_deletename(tkey->ring->keys, &tkey->name, false);
+	(void)dns_rbt_deletename(tkey->ring->keys, &tkey->name, ISC_FALSE);
 }
 
 static void
@@ -254,7 +253,7 @@ keyring_add(dns_tsig_keyring_t *ring, const dns_name_t *name,
 
 isc_result_t
 dns_tsigkey_createfromkey(const dns_name_t *name, const dns_name_t *algorithm,
-			  dst_key_t *dstkey, bool generated,
+			  dst_key_t *dstkey, isc_boolean_t generated,
 			  const dns_name_t *creator, isc_stdtime_t inception,
 			  isc_stdtime_t expire, isc_mem_t *mctx,
 			  dns_tsig_keyring_t *ring, dns_tsigkey_t **key)
@@ -506,17 +505,17 @@ dns__tsig_algnamefromname(const dns_name_t *algorithm) {
  * This will return an incorrect result if passed a dynamically allocated
  * dns_name_t that happens to match one of the pre-defined names.
  */
-bool
+isc_boolean_t
 dns__tsig_algallocated(const dns_name_t *algorithm) {
 	int i;
 	int n = sizeof(known_algs) / sizeof(*known_algs);
 	for (i = 0; i < n; ++i) {
 		const dns_name_t *name = known_algs[i].name;
 		if (algorithm == name) {
-			return (false);
+			return (ISC_FALSE);
 		}
 	}
-	return (true);
+	return (ISC_TRUE);
 }
 
 static isc_result_t
@@ -576,7 +575,7 @@ restore_key(dns_tsig_keyring_t *ring, isc_stdtime_t now, FILE *fp) {
 		return (result);
 
 	result = dns_tsigkey_createfromkey(name, algorithm, dstkey,
-					   true, creator, inception,
+					   ISC_TRUE, creator, inception,
 					   expire, ring->mctx, ring, NULL);
 	if (dstkey != NULL)
 		dst_key_free(&dstkey);
@@ -668,7 +667,7 @@ dns_tsigkeyring_dumpanddetach(dns_tsig_keyring_t **ringp, FILE *fp) {
 
 isc_result_t
 dns_tsigkey_create(const dns_name_t *name, const dns_name_t *algorithm,
-		   unsigned char *secret, int length, bool generated,
+		   unsigned char *secret, int length, isc_boolean_t generated,
 		   const dns_name_t *creator, isc_stdtime_t inception,
 		   isc_stdtime_t expire, isc_mem_t *mctx,
 		   dns_tsig_keyring_t *ring, dns_tsigkey_t **key)
@@ -784,7 +783,7 @@ dns_tsig_sign(dns_message_t *msg) {
 	isc_result_t ret;
 	unsigned char badtimedata[BADTIMELEN];
 	unsigned int sigsize = 0;
-	bool response;
+	isc_boolean_t response;
 
 	REQUIRE(msg != NULL);
 	key = dns_message_gettsigkey(msg);
@@ -839,16 +838,16 @@ dns_tsig_sign(dns_message_t *msg) {
 	{
 		unsigned char header[DNS_MESSAGE_HEADERLEN];
 		isc_buffer_t headerbuf;
-		uint16_t digestbits;
+		isc_uint16_t digestbits;
 
 		/*
 		 * If it is a response, we assume that the request MAC
 		 * has validated at this point. This is why we include a
 		 * MAC length > 0 in the reply.
 		 */
-		ret = dst_context_create3(key->key, mctx,
-					  DNS_LOGCATEGORY_DNSSEC,
-					  true, &ctx);
+		ret = dst_context_create(key->key, mctx,
+					 DNS_LOGCATEGORY_DNSSEC,
+					 ISC_TRUE, 0, &ctx);
 		if (ret != ISC_R_SUCCESS)
 			return (ret);
 
@@ -1092,10 +1091,10 @@ dns_tsig_verify(isc_buffer_t *source, dns_message_t *msg,
 	unsigned char header[DNS_MESSAGE_HEADERLEN];
 	dst_context_t *ctx = NULL;
 	isc_mem_t *mctx;
-	uint16_t addcount, id;
+	isc_uint16_t addcount, id;
 	unsigned int siglen;
 	unsigned int alg;
-	bool response;
+	isc_boolean_t response;
 
 	REQUIRE(source != NULL);
 	REQUIRE(DNS_MESSAGE_VALID(msg));
@@ -1191,7 +1190,7 @@ dns_tsig_verify(isc_buffer_t *source, dns_message_t *msg,
 		if (ret != ISC_R_SUCCESS) {
 			msg->tsigstatus = dns_tsigerror_badkey;
 			ret = dns_tsigkey_create(keyname, &tsig.algorithm,
-						 NULL, 0, false, NULL,
+						 NULL, 0, ISC_FALSE, NULL,
 						 now, now,
 						 mctx, NULL, &msg->tsigkey);
 			if (ret != ISC_R_SUCCESS)
@@ -1226,14 +1225,14 @@ dns_tsig_verify(isc_buffer_t *source, dns_message_t *msg,
 	}
 
 	if (tsig.siglen > 0) {
-		uint16_t addcount_n;
+		isc_uint16_t addcount_n;
 
 		sig_r.base = tsig.signature;
 		sig_r.length = tsig.siglen;
 
-		ret = dst_context_create3(key, mctx,
-					  DNS_LOGCATEGORY_DNSSEC,
-					  false, &ctx);
+		ret = dst_context_create(key, mctx,
+					 DNS_LOGCATEGORY_DNSSEC,
+					 ISC_FALSE, 0, &ctx);
 		if (ret != ISC_R_SUCCESS)
 			return (ret);
 
@@ -1265,7 +1264,7 @@ dns_tsig_verify(isc_buffer_t *source, dns_message_t *msg,
 		 */
 		memmove(&addcount, &header[DNS_MESSAGE_HEADERLEN - 2], 2);
 		addcount_n = ntohs(addcount);
-		addcount = htons((uint16_t)(addcount_n - 1));
+		addcount = htons((isc_uint16_t)(addcount_n - 1));
 		memmove(&header[DNS_MESSAGE_HEADERLEN - 2], &addcount, 2);
 
 		/*
@@ -1374,7 +1373,7 @@ dns_tsig_verify(isc_buffer_t *source, dns_message_t *msg,
 	}
 
 	if (dns__tsig_algvalid(alg)) {
-		uint16_t digestbits = dst_key_getbits(key);
+		isc_uint16_t digestbits = dst_key_getbits(key);
 
 		/*
 		 * XXXRAY: Is this correct? What is the expected
@@ -1437,8 +1436,8 @@ tsig_verify_tcp(isc_buffer_t *source, dns_message_t *msg) {
 	dns_tsigkey_t *tsigkey;
 	dst_key_t *key = NULL;
 	unsigned char header[DNS_MESSAGE_HEADERLEN];
-	uint16_t addcount, id;
-	bool has_tsig = false;
+	isc_uint16_t addcount, id;
+	isc_boolean_t has_tsig = ISC_FALSE;
 	isc_mem_t *mctx;
 	unsigned int siglen;
 	unsigned int alg;
@@ -1476,7 +1475,7 @@ tsig_verify_tcp(isc_buffer_t *source, dns_message_t *msg) {
 	 * If there is a TSIG in this message, do some checks.
 	 */
 	if (msg->tsig != NULL) {
-		has_tsig = true;
+		has_tsig = ISC_TRUE;
 
 		keyname = msg->tsigname;
 		ret = dns_rdataset_first(msg->tsig);
@@ -1527,9 +1526,9 @@ tsig_verify_tcp(isc_buffer_t *source, dns_message_t *msg) {
 	}
 
 	if (msg->tsigctx == NULL) {
-		ret = dst_context_create3(key, mctx,
-					  DNS_LOGCATEGORY_DNSSEC,
-					  false, &msg->tsigctx);
+		ret = dst_context_create(key, mctx,
+					 DNS_LOGCATEGORY_DNSSEC,
+					 ISC_FALSE, 0, &msg->tsigctx);
 		if (ret != ISC_R_SUCCESS)
 			goto cleanup_querystruct;
 
@@ -1566,11 +1565,11 @@ tsig_verify_tcp(isc_buffer_t *source, dns_message_t *msg) {
 	 * Decrement the additional field counter if necessary.
 	 */
 	if (has_tsig) {
-		uint16_t addcount_n;
+		isc_uint16_t addcount_n;
 
 		memmove(&addcount, &header[DNS_MESSAGE_HEADERLEN - 2], 2);
 		addcount_n = ntohs(addcount);
-		addcount = htons((uint16_t)(addcount_n - 1));
+		addcount = htons((isc_uint16_t)(addcount_n - 1));
 		memmove(&header[DNS_MESSAGE_HEADERLEN - 2], &addcount, 2);
 
 		/*
@@ -1678,7 +1677,7 @@ tsig_verify_tcp(isc_buffer_t *source, dns_message_t *msg) {
 		if (ret != ISC_R_SUCCESS)
 			goto cleanup_context;
 		if (dns__tsig_algvalid(alg)) {
-			uint16_t digestbits = dst_key_getbits(key);
+			isc_uint16_t digestbits = dst_key_getbits(key);
 
 			/*
 			 * XXXRAY: Is this correct? What is the
