@@ -11,8 +11,6 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-#include <stdbool.h>
 #include <time.h>
 
 #include <isc/log.h>
@@ -184,7 +182,7 @@ typedef struct rr rr_t;
 
 struct rr {
 	/* dns_name_t name; */
-	uint32_t		ttl;
+	isc_uint32_t		ttl;
 	dns_rdata_t		rdata;
 };
 
@@ -206,7 +204,7 @@ update_log(dns_update_log_t *callback, dns_zone_t *zone,
 	if (callback == NULL)
 		return;
 
-	if (isc_log_wouldlog(dns_lctx, level) == false)
+	if (isc_log_wouldlog(dns_lctx, level) == ISC_FALSE)
 		return;
 
 
@@ -351,7 +349,7 @@ foreach_rrset(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 	dns_rdatasetiter_t *iter;
 
 	node = NULL;
-	result = dns_db_findnode(db, name, false, &node);
+	result = dns_db_findnode(db, name, ISC_FALSE, &node);
 	if (result == ISC_R_NOTFOUND)
 		return (ISC_R_SUCCESS);
 	if (result != ISC_R_SUCCESS)
@@ -436,9 +434,9 @@ foreach_rr(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 	node = NULL;
 	if (type == dns_rdatatype_nsec3 ||
 	    (type == dns_rdatatype_rrsig && covers == dns_rdatatype_nsec3))
-		result = dns_db_findnsec3node(db, name, false, &node);
+		result = dns_db_findnsec3node(db, name, ISC_FALSE, &node);
 	else
-		result = dns_db_findnode(db, name, false, &node);
+		result = dns_db_findnode(db, name, ISC_FALSE, &node);
 	if (result == ISC_R_NOTFOUND)
 		return (ISC_R_SUCCESS);
 	if (result != ISC_R_SUCCESS)
@@ -486,7 +484,7 @@ foreach_rr(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
  * Function type for predicate functions that compare a database RR 'db_rr'
  * against an update RR 'update_rr'.
  */
-typedef bool rr_predicate(dns_rdata_t *update_rr, dns_rdata_t *db_rr);
+typedef isc_boolean_t rr_predicate(dns_rdata_t *update_rr, dns_rdata_t *db_rr);
 
 /*%
  * Helper function for rrset_exists().
@@ -502,7 +500,7 @@ rrset_exists_action(void *data, rr_t *rr) {
  * Utility macro for RR existence checking functions.
  *
  * If the variable 'result' has the value ISC_R_EXISTS or
- * ISC_R_SUCCESS, set *exists to true or false,
+ * ISC_R_SUCCESS, set *exists to ISC_TRUE or ISC_FALSE,
  * respectively, and return success.
  *
  * If 'result' has any other value, there was a failure.
@@ -513,9 +511,9 @@ rrset_exists_action(void *data, rr_t *rr) {
  */
 #define RETURN_EXISTENCE_FLAG				\
 	return ((result == ISC_R_EXISTS) ?		\
-		(*exists = true, ISC_R_SUCCESS) :	\
+		(*exists = ISC_TRUE, ISC_R_SUCCESS) :	\
 		((result == ISC_R_SUCCESS) ?		\
-		 (*exists = false, ISC_R_SUCCESS) :	\
+		 (*exists = ISC_FALSE, ISC_R_SUCCESS) :	\
 		 result))
 
 /*%
@@ -525,7 +523,7 @@ rrset_exists_action(void *data, rr_t *rr) {
 static isc_result_t
 rrset_exists(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 	     dns_rdatatype_t type, dns_rdatatype_t covers,
-	     bool *exists)
+	     isc_boolean_t *exists)
 {
 	isc_result_t result;
 	result = foreach_rr(db, ver, name, type, covers,
@@ -540,7 +538,7 @@ rrset_exists(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
  */
 static isc_result_t
 rrset_visible(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
-	      dns_rdatatype_t type, bool *visible)
+	      dns_rdatatype_t type, isc_boolean_t *visible)
 {
 	isc_result_t result;
 	dns_fixedname_t fixed;
@@ -551,7 +549,7 @@ rrset_visible(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 			     dns_fixedname_name(&fixed), NULL, NULL);
 	switch (result) {
 	case ISC_R_SUCCESS:
-		*visible = true;
+		*visible = ISC_TRUE;
 		break;
 	/*
 	 * Glue, obscured, deleted or replaced records.
@@ -563,11 +561,11 @@ rrset_visible(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 	case DNS_R_NXRRSET:
 	case DNS_R_EMPTYNAME:
 	case DNS_R_COVERINGNSEC:
-		*visible = false;
+		*visible = ISC_FALSE;
 		result = ISC_R_SUCCESS;
 		break;
 	default:
-		*visible = false;	 /* silence false compiler warning */
+		*visible = ISC_FALSE;	 /* silence false compiler warning */
 		break;
 	}
 	return (result);
@@ -589,7 +587,7 @@ name_exists_action(void *data, dns_rdataset_t *rrset) {
  */
 static isc_result_t
 name_exists(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
-	    bool *exists)
+	    isc_boolean_t *exists)
 {
 	isc_result_t result;
 	result = foreach_rrset(db, ver, name,
@@ -655,21 +653,21 @@ typedef struct {
 /*%
  * Return true always.
  */
-static bool
+static isc_boolean_t
 true_p(dns_rdata_t *update_rr, dns_rdata_t *db_rr) {
 	UNUSED(update_rr);
 	UNUSED(db_rr);
-	return (true);
+	return (ISC_TRUE);
 }
 
 /*%
  * Return true if the record is a RRSIG.
  */
-static bool
+static isc_boolean_t
 rrsig_p(dns_rdata_t *update_rr, dns_rdata_t *db_rr) {
 	UNUSED(update_rr);
 	return ((db_rr->type == dns_rdatatype_rrsig) ?
-		true : false);
+		ISC_TRUE : ISC_FALSE);
 }
 
 /*%
@@ -787,12 +785,12 @@ is_non_nsec_action(void *data, dns_rdataset_t *rrset) {
  * i.e., anything that justifies the continued existence of a name
  * after a secure update.
  *
- * If such an rrset exists, set '*exists' to true.
- * Otherwise, set it to false.
+ * If such an rrset exists, set '*exists' to ISC_TRUE.
+ * Otherwise, set it to ISC_FALSE.
  */
 static isc_result_t
 non_nsec_rrset_exists(dns_db_t *db, dns_dbversion_t *ver,
-		     dns_name_t *name, bool *exists)
+		     dns_name_t *name, isc_boolean_t *exists)
 {
 	isc_result_t result;
 	result = foreach_rrset(db, ver, name, is_non_nsec_action, NULL);
@@ -835,7 +833,7 @@ uniqify_name_list(dns_diff_t *list) {
 
 static isc_result_t
 is_active(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
-	  bool *flag, bool *cut, bool *unsecure)
+	  isc_boolean_t *flag, isc_boolean_t *cut, isc_boolean_t *unsecure)
 {
 	isc_result_t result;
 	dns_fixedname_t foundname;
@@ -846,14 +844,14 @@ is_active(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 			     dns_fixedname_name(&foundname),
 			     NULL, NULL);
 	if (result == ISC_R_SUCCESS || result == DNS_R_EMPTYNAME) {
-		*flag = true;
-		*cut = false;
+		*flag = ISC_TRUE;
+		*cut = ISC_FALSE;
 		if (unsecure != NULL)
-			*unsecure = false;
+			*unsecure = ISC_FALSE;
 		return (ISC_R_SUCCESS);
 	} else if (result == DNS_R_ZONECUT) {
-		*flag = true;
-		*cut = true;
+		*flag = ISC_TRUE;
+		*cut = ISC_TRUE;
 		if (unsecure != NULL) {
 			/*
 			 * We are at the zonecut.  Check to see if there
@@ -863,26 +861,26 @@ is_active(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 					(isc_stdtime_t) 0, NULL,
 					dns_fixedname_name(&foundname),
 					NULL, NULL) == DNS_R_NXRRSET)
-				*unsecure = true;
+				*unsecure = ISC_TRUE;
 			else
-				*unsecure = false;
+				*unsecure = ISC_FALSE;
 		}
 		return (ISC_R_SUCCESS);
 	} else if (result == DNS_R_GLUE || result == DNS_R_DNAME ||
 		   result == DNS_R_DELEGATION || result == DNS_R_NXDOMAIN) {
-		*flag = false;
-		*cut = false;
+		*flag = ISC_FALSE;
+		*cut = ISC_FALSE;
 		if (unsecure != NULL)
-			*unsecure = false;
+			*unsecure = ISC_FALSE;
 		return (ISC_R_SUCCESS);
 	} else {
 		/*
 		 * Silence compiler.
 		 */
-		*flag = false;
-		*cut = false;
+		*flag = ISC_FALSE;
+		*cut = ISC_FALSE;
 		if (unsecure != NULL)
-			*unsecure = false;
+			*unsecure = ISC_FALSE;
 		return (result);
 	}
 }
@@ -896,13 +894,13 @@ is_active(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 static isc_result_t
 next_active(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 	    dns_dbversion_t *ver, dns_name_t *oldname, dns_name_t *newname,
-	    bool forward)
+	    isc_boolean_t forward)
 {
 	isc_result_t result;
 	dns_dbiterator_t *dbit = NULL;
-	bool has_nsec = false;
+	isc_boolean_t has_nsec = ISC_FALSE;
 	unsigned int wraps = 0;
-	bool secure = dns_db_issecure(db);
+	isc_boolean_t secure = dns_db_issecure(db);
 
 	CHECK(dns_db_createiterator(db, 0, &dbit));
 
@@ -957,7 +955,7 @@ next_active(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 			    result == DNS_R_CNAME ||
 			    (result == DNS_R_DELEGATION &&
 			     dns_name_equal(newname, found))) {
-				has_nsec = true;
+				has_nsec = ISC_TRUE;
 				result = ISC_R_SUCCESS;
 			} else if (result != DNS_R_NXDOMAIN)
 				break;
@@ -992,12 +990,12 @@ add_nsec(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 	/*
 	 * Find the successor name, aka NSEC target.
 	 */
-	CHECK(next_active(log, zone, db, ver, name, target, true));
+	CHECK(next_active(log, zone, db, ver, name, target, ISC_TRUE));
 
 	/*
 	 * Create the NSEC RDATA.
 	 */
-	CHECK(dns_db_findnode(db, name, false, &node));
+	CHECK(dns_db_findnode(db, name, ISC_FALSE, &node));
 	dns_rdata_init(&rdata);
 	CHECK(dns_nsec_buildrdata(db, ver, node, target, buffer, &rdata));
 	dns_db_detachnode(db, &node);
@@ -1050,11 +1048,14 @@ find_zone_keys(dns_zone_t *zone, dns_db_t *db, dns_dbversion_t *ver,
 	       dst_key_t **keys, unsigned int *nkeys)
 {
 	isc_result_t result;
+	isc_stdtime_t now;
 	dns_dbnode_t *node = NULL;
 	const char *directory = dns_zone_getkeydirectory(zone);
-	CHECK(dns_db_findnode(db, dns_db_origin(db), false, &node));
-	CHECK(dns_dnssec_findzonekeys2(db, ver, node, dns_db_origin(db),
-				       directory, mctx, maxkeys, keys, nkeys));
+	CHECK(dns_db_findnode(db, dns_db_origin(db), ISC_FALSE, &node));
+	isc_stdtime_get(&now);
+	CHECK(dns_dnssec_findzonekeys(db, ver, node, dns_db_origin(db),
+				      directory, now, mctx, maxkeys, keys,
+				      nkeys));
  failure:
 	if (node != NULL)
 		dns_db_detachnode(db, &node);
@@ -1069,7 +1070,7 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 	 dns_dbversion_t *ver, dns_name_t *name, dns_rdatatype_t type,
 	 dns_diff_t *diff, dst_key_t **keys, unsigned int nkeys,
 	 isc_stdtime_t inception, isc_stdtime_t expire,
-	 bool check_ksk, bool keyset_kskonly)
+	 isc_boolean_t check_ksk, isc_boolean_t keyset_kskonly)
 {
 	isc_result_t result;
 	dns_dbnode_t *node = NULL;
@@ -1078,7 +1079,7 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 	isc_buffer_t buffer;
 	unsigned char data[1024]; /* XXX */
 	unsigned int i, j;
-	bool added_sig = false;
+	isc_boolean_t added_sig = ISC_FALSE;
 	isc_mem_t *mctx = diff->mctx;
 
 	dns_rdataset_init(&rdataset);
@@ -1086,9 +1087,9 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 
 	/* Get the rdataset to sign. */
 	if (type == dns_rdatatype_nsec3)
-		CHECK(dns_db_findnsec3node(db, name, false, &node));
+		CHECK(dns_db_findnsec3node(db, name, ISC_FALSE, &node));
 	else
-		CHECK(dns_db_findnode(db, name, false, &node));
+		CHECK(dns_db_findnode(db, name, ISC_FALSE, &node));
 	CHECK(dns_db_findrdataset(db, node, ver, type, 0,
 				  (isc_stdtime_t) 0, &rdataset, NULL));
 	dns_db_detachnode(db, &node);
@@ -1103,7 +1104,7 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 	 * algorithm.
 	 */
 	for (i = 0; i < nkeys; i++) {
-		bool both = false;
+		isc_boolean_t both = ISC_FALSE;
 
 		if (!dst_key_isprivate(keys[i]))
 			continue;
@@ -1111,13 +1112,13 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 			continue;
 
 		if (check_ksk && !REVOKE(keys[i])) {
-			bool have_ksk, have_nonksk;
+			isc_boolean_t have_ksk, have_nonksk;
 			if (KSK(keys[i])) {
-				have_ksk = true;
-				have_nonksk = false;
+				have_ksk = ISC_TRUE;
+				have_nonksk = ISC_FALSE;
 			} else {
-				have_ksk = false;
-				have_nonksk = true;
+				have_ksk = ISC_FALSE;
+				have_nonksk = ISC_TRUE;
 			}
 			for (j = 0; j < nkeys; j++) {
 				if (j == i || ALG(keys[i]) != ALG(keys[j]))
@@ -1129,9 +1130,9 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				if (REVOKE(keys[j]))
 					continue;
 				if (KSK(keys[j]))
-					have_ksk = true;
+					have_ksk = ISC_TRUE;
 				else
-					have_nonksk = true;
+					have_nonksk = ISC_TRUE;
 				both = have_ksk && have_nonksk;
 				if (both)
 					break;
@@ -1166,7 +1167,7 @@ add_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				    rdataset.ttl, &sig_rdata));
 		dns_rdata_reset(&sig_rdata);
 		isc_buffer_init(&buffer, data, sizeof(data));
-		added_sig = true;
+		added_sig = ISC_TRUE;
 	}
 	if (!added_sig) {
 		update_log(log, zone, ISC_LOG_ERROR,
@@ -1197,11 +1198,11 @@ del_keysigs(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	unsigned int i;
 	dns_rdata_rrsig_t rrsig;
-	bool found;
+	isc_boolean_t found;
 
 	dns_rdataset_init(&rdataset);
 
-	result = dns_db_findnode(db, name, false, &node);
+	result = dns_db_findnode(db, name, ISC_FALSE, &node);
 	if (result == ISC_R_NOTFOUND)
 		return (ISC_R_SUCCESS);
 	if (result != ISC_R_SUCCESS)
@@ -1222,10 +1223,10 @@ del_keysigs(dns_db_t *db, dns_dbversion_t *ver, dns_name_t *name,
 		dns_rdataset_current(&rdataset, &rdata);
 		result = dns_rdata_tostruct(&rdata, &rrsig, NULL);
 		RUNTIME_CHECK(result == ISC_R_SUCCESS);
-		found = false;
+		found = ISC_FALSE;
 		for (i = 0; i < nkeys; i++) {
 			if (rrsig.keyid == dst_key_id(keys[i])) {
-				found = true;
+				found = ISC_TRUE;
 				if (!dst_key_isprivate(keys[i]) &&
 				    !dst_key_inactive(keys[i]))
 				{
@@ -1263,10 +1264,10 @@ failure:
 
 static isc_result_t
 add_exposed_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
-		 dns_dbversion_t *ver, dns_name_t *name, bool cut,
+		 dns_dbversion_t *ver, dns_name_t *name, isc_boolean_t cut,
 		 dns_diff_t *diff, dst_key_t **keys, unsigned int nkeys,
 		 isc_stdtime_t inception, isc_stdtime_t expire,
-		 bool check_ksk, bool keyset_kskonly,
+		 isc_boolean_t check_ksk, isc_boolean_t keyset_kskonly,
 		 unsigned int *sigs)
 {
 	isc_result_t result;
@@ -1274,7 +1275,7 @@ add_exposed_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 	dns_rdatasetiter_t *iter;
 
 	node = NULL;
-	result = dns_db_findnode(db, name, false, &node);
+	result = dns_db_findnode(db, name, ISC_FALSE, &node);
 	if (result == ISC_R_NOTFOUND)
 		return (ISC_R_SUCCESS);
 	if (result != ISC_R_SUCCESS)
@@ -1292,7 +1293,7 @@ add_exposed_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 	{
 		dns_rdataset_t rdataset;
 		dns_rdatatype_t type;
-		bool flag;
+		isc_boolean_t flag;
 
 		dns_rdataset_init(&rdataset);
 		dns_rdatasetiter_current(iter, &rdataset);
@@ -1345,7 +1346,7 @@ add_exposed_sigs(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 isc_result_t
 dns_update_signatures(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		      dns_dbversion_t *oldver, dns_dbversion_t *newver,
-		      dns_diff_t *diff, uint32_t sigvalidityinterval)
+		      dns_diff_t *diff, isc_uint32_t sigvalidityinterval)
 {
 	return (dns_update_signaturesinc(log, zone, db, oldver, newver, diff,
 					 sigvalidityinterval, NULL));
@@ -1361,9 +1362,9 @@ struct dns_update_state {
 	dns_diff_t work;
 	dst_key_t *zone_keys[DNS_MAXZONEKEYS];
 	unsigned int nkeys;
-	isc_stdtime_t inception, expire;
+	isc_stdtime_t inception, expire, keyexpire;
 	dns_ttl_t nsecttl;
-	bool check_ksk, keyset_kskonly, build_nsec3;
+	isc_boolean_t check_ksk, keyset_kskonly, build_nsec3;
 	enum { sign_updates, remove_orphaned, build_chain, process_nsec,
 	       sign_nsec, update_nsec3, process_nsec3, sign_nsec3 } state;
 };
@@ -1371,22 +1372,22 @@ struct dns_update_state {
 isc_result_t
 dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 			 dns_dbversion_t *oldver, dns_dbversion_t *newver,
-			 dns_diff_t *diff, uint32_t sigvalidityinterval,
+			 dns_diff_t *diff, isc_uint32_t sigvalidityinterval,
 			 dns_update_state_t **statep)
 {
 	isc_result_t result = ISC_R_SUCCESS;
 	dns_update_state_t mystate, *state;
 
 	dns_difftuple_t *t, *next;
-	bool flag, build_nsec;
+	isc_boolean_t flag, build_nsec;
 	unsigned int i;
 	isc_stdtime_t now;
 	dns_rdata_soa_t soa;
 	dns_rdata_t rdata = DNS_RDATA_INIT;
 	dns_rdataset_t rdataset;
 	dns_dbnode_t *node = NULL;
-	bool unsecure;
-	bool cut;
+	isc_boolean_t unsecure;
+	isc_boolean_t cut;
 	dns_rdatatype_t privatetype = dns_zone_getprivatetype(zone);
 	unsigned int sigs = 0;
 	unsigned int maxsigs = dns_zone_getsignatures(zone);
@@ -1407,7 +1408,7 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		dns_diff_init(diff->mctx, &state->nsec_mindiff);
 		dns_diff_init(diff->mctx, &state->work);
 		state->nkeys = 0;
-		state->build_nsec3 = false;
+		state->build_nsec3 = ISC_FALSE;
 
 		result = find_zone_keys(zone, db, newver, diff->mctx,
 					DNS_MAXZONEKEYS, state->zone_keys,
@@ -1422,6 +1423,12 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		isc_stdtime_get(&now);
 		state->inception = now - 3600; /* Allow for some clock skew. */
 		state->expire = now + sigvalidityinterval;
+		state->keyexpire = dns_zone_getkeyvalidityinterval(zone);
+		if (state->keyexpire == 0) {
+			state->keyexpire = state->expire;
+		} else {
+			state->keyexpire += now;
+		}
 
 		/*
 		 * Do we look at the KSK flag on the DNSKEY to determining which
@@ -1429,17 +1436,15 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		 * check the keys flags to make sure at least one has a ksk set
 		 * and one doesn't.
 		 */
-		state->check_ksk =
-			((dns_zone_getoptions(zone) &
-			  DNS_ZONEOPT_UPDATECHECKKSK) != 0);
-		state->keyset_kskonly =
-			((dns_zone_getoptions(zone) &
-			  DNS_ZONEOPT_DNSKEYKSKONLY) != 0);
+		state->check_ksk = ISC_TF((dns_zone_getoptions(zone) &
+				    DNS_ZONEOPT_UPDATECHECKKSK) != 0);
+		state->keyset_kskonly = ISC_TF((dns_zone_getoptions(zone) &
+					DNS_ZONEOPT_DNSKEYKSKONLY) != 0);
 
 		/*
 		 * Get the NSEC/NSEC3 TTL from the SOA MINIMUM field.
 		 */
-		CHECK(dns_db_findnode(db, dns_db_origin(db), false, &node));
+		CHECK(dns_db_findnode(db, dns_db_origin(db), ISC_FALSE, &node));
 		dns_rdataset_init(&rdataset);
 		CHECK(dns_db_findrdataset(db, node, newver, dns_rdatatype_soa,
 					  0, (isc_stdtime_t) 0, &rdataset,
@@ -1519,13 +1524,22 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				CHECK(rrset_visible(db, newver, name, type,
 						   &flag));
 				if (flag) {
+					isc_stdtime_t exp;
+					if (type == dns_rdatatype_dnskey ||
+					    type == dns_rdatatype_cdnskey ||
+					    type == dns_rdatatype_cds)
+					{
+						exp = state->keyexpire;
+					} else {
+						exp = state->expire;
+					}
+
 					CHECK(add_sigs(log, zone, db, newver,
 						       name, type,
 						       &state->sig_diff,
 						       state->zone_keys,
 						       state->nkeys,
-						       state->inception,
-						       state->expire,
+						       state->inception, exp,
 						       state->check_ksk,
 						       state->keyset_kskonly));
 					sigs++;
@@ -1594,7 +1608,7 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		     t != NULL;
 		     t = ISC_LIST_NEXT(t, link))
 		{
-			bool existed, exists;
+			isc_boolean_t existed, exists;
 			dns_fixedname_t fixedname;
 			dns_name_t *prevname;
 
@@ -1604,7 +1618,7 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				CHECK(name_exists(db, oldver, &t->name,
 						  &existed));
 			else
-				existed = false;
+				existed = ISC_FALSE;
 			CHECK(name_exists(db, newver, &t->name, &exists));
 			if (exists == existed)
 				continue;
@@ -1621,7 +1635,7 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 			 * "affected" list in any case.
 			 */
 			CHECK(next_active(log, zone, db, newver,
-					  &t->name, prevname, false));
+					  &t->name, prevname, ISC_FALSE));
 			CHECK(namelist_append_name(&state->affected, prevname));
 		}
 
@@ -1634,21 +1648,21 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		     t != NULL;
 		     t = ISC_LIST_NEXT(t, link))
 		{
-			bool ns_existed, dname_existed;
-			bool ns_exists, dname_exists;
+			isc_boolean_t ns_existed, dname_existed;
+			isc_boolean_t ns_exists, dname_exists;
 
 			if (oldver != NULL)
 				CHECK(rrset_exists(db, oldver, &t->name,
 						  dns_rdatatype_ns, 0,
 						  &ns_existed));
 			else
-				ns_existed = false;
+				ns_existed = ISC_FALSE;
 			if (oldver != NULL)
 				CHECK(rrset_exists(db, oldver, &t->name,
 						   dns_rdatatype_dname, 0,
 						   &dname_existed));
 			else
-				dname_existed = false;
+				dname_existed = ISC_FALSE;
 			CHECK(rrset_exists(db, newver, &t->name,
 					   dns_rdatatype_ns, 0, &ns_exists));
 			CHECK(rrset_exists(db, newver, &t->name,
@@ -1682,7 +1696,7 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		 * should be part of the NSEC chain.
 		 */
 		while ((t = ISC_LIST_HEAD(state->affected.tuples)) != NULL) {
-			bool exists;
+			isc_boolean_t exists;
 			dns_name_t *name = &t->name;
 
 			CHECK(name_exists(db, newver, name, &exists));
@@ -1809,7 +1823,6 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				sigs++;
 			} else {
 				INSIST(0);
-				ISC_UNREACHABLE();
 			}
 			ISC_LIST_UNLINK(state->nsec_mindiff.tuples, t, link);
 			ISC_LIST_APPEND(state->work.tuples, t, link);
@@ -1860,9 +1873,9 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		while (t != NULL) {
 			dns_name_t *name = &t->name;
 
-			bool ns_existed, dname_existed;
-			bool ns_exists, dname_exists;
-			bool exists, existed;
+			isc_boolean_t ns_existed, dname_existed;
+			isc_boolean_t ns_exists, dname_exists;
+			isc_boolean_t exists, existed;
 
 			if (t->rdata.type == dns_rdatatype_nsec ||
 			    t->rdata.type == dns_rdatatype_rrsig) {
@@ -1877,13 +1890,13 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 						   dns_rdatatype_ns,
 						   0, &ns_existed));
 			else
-				ns_existed = false;
+				ns_existed = ISC_FALSE;
 			if (oldver != NULL)
 				CHECK(rrset_exists(db, oldver, name,
 						   dns_rdatatype_dname, 0,
 						   &dname_existed));
 			else
-				dname_existed = false;
+				dname_existed = ISC_FALSE;
 			CHECK(rrset_exists(db, newver, name, dns_rdatatype_ns,
 					   0, &ns_exists));
 			CHECK(rrset_exists(db, newver, name,
@@ -1912,7 +1925,7 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		while ((t = ISC_LIST_HEAD(state->affected.tuples)) != NULL) {
 			dns_name_t *name = &t->name;
 
-			unsecure = false;	/* Silence compiler warning. */
+			unsecure = ISC_FALSE;	/* Silence compiler warning. */
 			CHECK(is_active(db, newver, name, &flag, &cut,
 					&unsecure));
 
@@ -1983,7 +1996,6 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 				sigs++;
 			} else {
 				INSIST(0);
-				ISC_UNREACHABLE();
 			}
 			ISC_LIST_UNLINK(state->nsec_mindiff.tuples, t, link);
 			ISC_LIST_APPEND(state->work.tuples, t, link);
@@ -2010,7 +2022,6 @@ dns_update_signaturesinc(dns_update_log_t *log, dns_zone_t *zone, dns_db_t *db,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 
  failure:
@@ -2052,10 +2063,10 @@ epoch_to_yyyymmdd(time_t when) {
 		((tm->tm_mon + 1) * 100) + tm->tm_mday);
 }
 
-uint32_t
-dns_update_soaserial(uint32_t serial, dns_updatemethod_t method) {
+isc_uint32_t
+dns_update_soaserial(isc_uint32_t serial, dns_updatemethod_t method) {
 	isc_stdtime_t now;
-	uint32_t new_serial;
+	isc_uint32_t new_serial;
 
 	switch (method) {
 	case dns_updatemethod_none:
