@@ -15,9 +15,6 @@
 
 /*! \file isc/netaddr.h */
 
-#include <inttypes.h>
-#include <stdbool.h>
-
 #include <isc/lang.h>
 #include <isc/net.h>
 #include <isc/types.h>
@@ -38,24 +35,24 @@ struct isc_netaddr {
 		char un[sizeof(((struct sockaddr_un *)0)->sun_path)];
 #endif
 	} type;
-	uint32_t zone;
+	isc_uint32_t zone;
 };
 
-bool
+isc_boolean_t
 isc_netaddr_equal(const isc_netaddr_t *a, const isc_netaddr_t *b);
 
 /*%<
- * Compare network addresses 'a' and 'b'.  Return #true if
- * they are equal, #false if not.
+ * Compare network addresses 'a' and 'b'.  Return #ISC_TRUE if
+ * they are equal, #ISC_FALSE if not.
  */
 
-bool
+isc_boolean_t
 isc_netaddr_eqprefix(const isc_netaddr_t *a, const isc_netaddr_t *b,
 		     unsigned int prefixlen);
 /*%<
  * Compare the 'prefixlen' most significant bits of the network
  * addresses 'a' and 'b'.  If 'b''s scope is zero then 'a''s scope is
- * ignored.  Return #true if they are equal, #false if not.
+ * ignored.  Return #ISC_TRUE if they are equal, #ISC_FALSE if not.
  */
 
 isc_result_t
@@ -110,9 +107,9 @@ isc_result_t
 isc_netaddr_frompath(isc_netaddr_t *netaddr, const char *path);
 
 void
-isc_netaddr_setzone(isc_netaddr_t *netaddr, uint32_t zone);
+isc_netaddr_setzone(isc_netaddr_t *netaddr, isc_uint32_t zone);
 
-uint32_t
+isc_uint32_t
 isc_netaddr_getzone(const isc_netaddr_t *netaddr);
 
 void
@@ -133,34 +130,34 @@ isc_netaddr_unspec(isc_netaddr_t *netaddr);
  * Initialize as AF_UNSPEC address.
  */
 
-bool
+isc_boolean_t
 isc_netaddr_ismulticast(const isc_netaddr_t *na);
 /*%<
- * Returns true if the address is a multicast address.
+ * Returns ISC_TRUE if the address is a multicast address.
  */
 
-bool
+isc_boolean_t
 isc_netaddr_isexperimental(const isc_netaddr_t *na);
 /*%<
- * Returns true if the address is a experimental (CLASS E) address.
+ * Returns ISC_TRUE if the address is a experimental (CLASS E) address.
  */
 
-bool
+isc_boolean_t
 isc_netaddr_islinklocal(const isc_netaddr_t *na);
 /*%<
- * Returns #true if the address is a link local address.
+ * Returns #ISC_TRUE if the address is a link local address.
  */
 
-bool
+isc_boolean_t
 isc_netaddr_issitelocal(const isc_netaddr_t *na);
 /*%<
- * Returns #true if the address is a site local address.
+ * Returns #ISC_TRUE if the address is a site local address.
  */
 
-bool
+isc_boolean_t
 isc_netaddr_isnetzero(const isc_netaddr_t *na);
 /*%<
- * Returns #true if the address is in net zero.
+ * Returns #ISC_TRUE if the address is in net zero.
  */
 
 void
@@ -183,7 +180,7 @@ isc_netaddr_prefixok(const isc_netaddr_t *na, unsigned int prefixlen);
  *	ISC_R_FAILURE		extra bits.
  */
 
-bool
+isc_boolean_t
 isc_netaddr_isloopback(const isc_netaddr_t *na);
 /*
  * Test whether the netaddr 'na' is a loopback IPv4 or IPv6 address (in
