@@ -3,13 +3,18 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
  */
 
-#include <stdbool.h>
+/*
+ * This source was adapted from MRT's RCS Ids:
+ * Id: radix.h,v 1.6 1999/08/03 03:32:53 masaki Exp
+ * Id: mrt.h,v 1.57.2.6 1999/12/28 23:41:27 labovit Exp
+ * Id: defs.h,v 1.5.2.2 2000/01/15 14:19:16 masaki Exp
+ */
 
 #include <isc/magic.h>
 #include <isc/types.h>
@@ -47,7 +52,7 @@ typedef struct isc_prefix {
 	isc_mem_t *mctx;
 	unsigned int family;	/* AF_INET | AF_INET6, or AF_UNSPEC for "any" */
 	unsigned int bitlen;	/* 0 for "any" */
-	bool ecs;	/* true for an EDNS client subnet address */
+	isc_boolean_t ecs;	/* ISC_TRUE for an EDNS client subnet address */
 	isc_refcount_t refcount;
 	union {
 		struct in_addr sin;
@@ -61,6 +66,8 @@ typedef void (*isc_radix_processfunc_t)(isc_prefix_t *, void **);
 #define isc_prefix_tochar(prefix) ((char *)&(prefix)->add.sin)
 #define isc_prefix_touchar(prefix) ((u_char *)&(prefix)->add.sin)
 
+#define BIT_TEST(f, b)  ((f) & (b))
+
 /*
  * We need "first match" when we search the radix tree to preserve
  * compatibility with the existing ACL implementation. Radix trees
@@ -85,26 +92,17 @@ typedef void (*isc_radix_processfunc_t)(isc_prefix_t *, void **);
  * addresses.
  */
 
-#define RADIX_NOECS 0
-#define RADIX_ECS 2
-#define RADIX_V4 0
-#define RADIX_V6 1
-#define RADIX_V4_ECS 2
-#define RADIX_V6_ECS 3
-#define RADIX_FAMILIES 4
-
-#define ISC_RADIX_FAMILY(p) \
-	((((p)->family == AF_INET6) ? RADIX_V6 : RADIX_V4) + \
-	 ((p)->ecs ? RADIX_ECS : RADIX_NOECS))
+#define ISC_RADIX_OFF(p) \
+	((((p)->family == AF_INET6) ? 1 : 0) + ((p)->ecs ? 2 : 0))
 
 typedef struct isc_radix_node {
 	isc_mem_t *mctx;
-	uint32_t bit;		/* bit length of the prefix */
+	isc_uint32_t bit;		/* bit length of the prefix */
 	isc_prefix_t *prefix;		/* who we are in radix tree */
 	struct isc_radix_node *l, *r;	/* left and right children */
 	struct isc_radix_node *parent;	/* may be used */
-	void *data[RADIX_FAMILIES];	/* pointers to IPv4 and IPV6 data */
-	int node_num[RADIX_FAMILIES];	/* which node this was in the tree,
+	void *data[4];			/* pointers to IPv4 and IPV6 data */
+	int node_num[4];		/* which node this was in the tree,
 					   or -1 for glue nodes */
 } isc_radix_node_t;
 
@@ -115,7 +113,7 @@ typedef struct isc_radix_tree {
 	unsigned int magic;
 	isc_mem_t *mctx;
 	isc_radix_node_t *head;
-	uint32_t maxbits;		/* for IP, 32 bit addresses */
+	isc_uint32_t maxbits;		/* for IP, 32 bit addresses */
 	int num_active_node;		/* for debugging purposes */
 	int num_added_node;		/* total number of nodes */
 } isc_radix_tree_t;
@@ -203,6 +201,9 @@ isc_radix_process(isc_radix_tree_t *radix, isc_radix_processfunc_t func);
 #define RADIX_NBIT(x)        (0x80 >> ((x) & 0x7f))
 #define RADIX_NBYTE(x)       ((x) >> 3)
 
+#define RADIX_DATA_GET(node, type) (type *)((node)->data)
+#define RADIX_DATA_SET(node, value) ((node)->data = (void *)(value))
+
 #define RADIX_WALK(Xhead, Xnode) \
     do { \
 	isc_radix_node_t *Xstack[RADIX_MAXBITS+1]; \
@@ -211,6 +212,22 @@ isc_radix_process(isc_radix_tree_t *radix, isc_radix_processfunc_t func);
 	while ((Xnode = Xrn)) { \
 	    if (Xnode->prefix)
 
+#define RADIX_WALK_ALL(Xhead, Xnode) \
+do { \
+	isc_radix_node_t *Xstack[RADIX_MAXBITS+1]; \
+	isc_radix_node_t **Xsp = Xstack; \
+	isc_radix_node_t *Xrn = (Xhead); \
+	while ((Xnode = Xrn)) { \
+	    if (1)
+
+#define RADIX_WALK_BREAK { \
+	    if (Xsp != Xstack) { \
+		Xrn = *(--Xsp); \
+	     } else { \
+		Xrn = (radix_node_t *) 0; \
+	    } \
+	    continue; }
+
 #define RADIX_WALK_END \
 	    if (Xrn->l) { \
 		if (Xrn->r) { \
