@@ -14,8 +14,6 @@
 #include <config.h>
 
 #include <errno.h>
-#include <inttypes.h>
-#include <stdbool.h>
 #include <stdlib.h>
 #include <limits.h>
 #include <time.h>
@@ -114,7 +112,7 @@ struct isc_logconfig {
 	unsigned int			duplicate_interval;
 	int				highest_level;
 	char *				tag;
-	bool			dynamic;
+	isc_boolean_t			dynamic;
 };
 
 /*!
@@ -229,7 +227,7 @@ greatest_version(isc_logfile_t *file, int versions, int *greatest);
 
 static void
 isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
-	     isc_logmodule_t *module, int level, bool write_once,
+	     isc_logmodule_t *module, int level, isc_boolean_t write_once,
 	     isc_msgcat_t *msgcat, int msgset, int msg,
 	     const char *format, va_list args)
      ISC_FORMAT_PRINTF(9, 0);
@@ -338,7 +336,7 @@ isc_logconfig_create(isc_log_t *lctx, isc_logconfig_t **lcfgp) {
 		lcfg->duplicate_interval = 0;
 		lcfg->highest_level = level;
 		lcfg->tag = NULL;
-		lcfg->dynamic = false;
+		lcfg->dynamic = ISC_FALSE;
 
 		ISC_LIST_INIT(lcfg->channels);
 
@@ -546,7 +544,7 @@ isc_logconfig_destroy(isc_logconfig_t **lcfgp) {
 			    lcfg->channellist_count *
 			    sizeof(ISC_LIST(isc_logchannellist_t)));
 
-	lcfg->dynamic = false;
+	lcfg->dynamic = ISC_FALSE;
 	if (lcfg->tag != NULL)
 		isc_mem_free(lcfg->lctx->mctx, lcfg->tag);
 	lcfg->tag = NULL;
@@ -749,7 +747,7 @@ isc_log_createchannel(isc_logconfig_t *lcfg, const char *name,
 		FILE_VERSIONS(channel) = destination->file.versions;
 		FILE_SUFFIX(channel) = destination->file.suffix;
 		FILE_MAXSIZE(channel) = destination->file.maximum_size;
-		FILE_MAXREACHED(channel) = false;
+		FILE_MAXREACHED(channel) = ISC_FALSE;
 		break;
 
 	case ISC_LOG_TOFILEDESC:
@@ -836,7 +834,7 @@ isc_log_write(isc_log_t *lctx, isc_logcategory_t *category,
 	 */
 
 	va_start(args, format);
-	isc_log_doit(lctx, category, module, level, false,
+	isc_log_doit(lctx, category, module, level, ISC_FALSE,
 		     NULL, 0, 0, format, args);
 	va_end(args);
 }
@@ -849,7 +847,7 @@ isc_log_vwrite(isc_log_t *lctx, isc_logcategory_t *category,
 	/*
 	 * Contract checking is done in isc_log_doit().
 	 */
-	isc_log_doit(lctx, category, module, level, false,
+	isc_log_doit(lctx, category, module, level, ISC_FALSE,
 		     NULL, 0, 0, format, args);
 }
 
@@ -864,7 +862,7 @@ isc_log_write1(isc_log_t *lctx, isc_logcategory_t *category,
 	 */
 
 	va_start(args, format);
-	isc_log_doit(lctx, category, module, level, true,
+	isc_log_doit(lctx, category, module, level, ISC_TRUE,
 		     NULL, 0, 0, format, args);
 	va_end(args);
 }
@@ -877,7 +875,7 @@ isc_log_vwrite1(isc_log_t *lctx, isc_logcategory_t *category,
 	/*
 	 * Contract checking is done in isc_log_doit().
 	 */
-	isc_log_doit(lctx, category, module, level, true,
+	isc_log_doit(lctx, category, module, level, ISC_TRUE,
 		     NULL, 0, 0, format, args);
 }
 
@@ -894,7 +892,7 @@ isc_log_iwrite(isc_log_t *lctx, isc_logcategory_t *category,
 	 */
 
 	va_start(args, format);
-	isc_log_doit(lctx, category, module, level, false,
+	isc_log_doit(lctx, category, module, level, ISC_FALSE,
 		     msgcat, msgset, msg, format, args);
 	va_end(args);
 }
@@ -908,7 +906,7 @@ isc_log_ivwrite(isc_log_t *lctx, isc_logcategory_t *category,
 	/*
 	 * Contract checking is done in isc_log_doit().
 	 */
-	isc_log_doit(lctx, category, module, level, false,
+	isc_log_doit(lctx, category, module, level, ISC_FALSE,
 		     msgcat, msgset, msg, format, args);
 }
 
@@ -925,7 +923,7 @@ isc_log_iwrite1(isc_log_t *lctx, isc_logcategory_t *category,
 	 */
 
 	va_start(args, format);
-	isc_log_doit(lctx, category, module, level, true,
+	isc_log_doit(lctx, category, module, level, ISC_TRUE,
 		     msgcat, msgset, msg, format, args);
 	va_end(args);
 }
@@ -939,7 +937,7 @@ isc_log_ivwrite1(isc_log_t *lctx, isc_logcategory_t *category,
 	/*
 	 * Contract checking is done in isc_log_doit().
 	 */
-	isc_log_doit(lctx, category, module, level, true,
+	isc_log_doit(lctx, category, module, level, ISC_TRUE,
 		     msgcat, msgset, msg, format, args);
 }
 
@@ -1091,7 +1089,7 @@ assignchannel(isc_logconfig_t *lcfg, unsigned int category_id,
 		if (lcfg->highest_level < channel->level)
 			lcfg->highest_level = channel->level;
 		if (channel->level == ISC_LOG_DYNAMIC)
-			lcfg->dynamic = true;
+			lcfg->dynamic = ISC_TRUE;
 	}
 
 	return (ISC_R_SUCCESS);
@@ -1222,8 +1220,8 @@ remove_old_tsversions(isc_logfile_t *file, int versions) {
 	isc_result_t result;
 	char *bname, *digit_end;
 	const char *dirname;
-	int64_t version, last = INT64_MAX;
-	int64_t to_keep[ISC_LOG_MAX_VERSIONS];
+	isc_int64_t version, last = ISC_INT64_MAX;
+	isc_int64_t to_keep[ISC_LOG_MAX_VERSIONS];
 	size_t bnamelen;
 	isc_dir_t dir;
 	char sep = '/';
@@ -1279,8 +1277,7 @@ remove_old_tsversions(isc_logfile_t *file, int versions) {
 			    dir.entry.name[bnamelen] == '.')
 			{
 				char *ename = &dir.entry.name[bnamelen + 1];
-				version = isc_string_touint64(ename,
-							      &digit_end, 10);
+				version = strtoull(ename, &digit_end, 10);
 				if (*digit_end == '\0') {
 					int i = 0;
 					while (i < versions &&
@@ -1315,7 +1312,7 @@ remove_old_tsversions(isc_logfile_t *file, int versions) {
 		    dir.entry.name[bnamelen] == '.')
 		{
 			char *ename = &dir.entry.name[bnamelen + 1];
-			version = isc_string_touint64(ename, &digit_end, 10);
+			version = strtoull(ename, &digit_end, 10);
 			/*
 			 * Remove any backup files that exceed versions.
 			 */
@@ -1497,8 +1494,8 @@ isc_logfile_roll(isc_logfile_t *file) {
 static isc_result_t
 isc_log_open(isc_logchannel_t *channel) {
 	struct stat statbuf;
-	bool regular_file;
-	bool roll = false;
+	isc_boolean_t regular_file;
+	isc_boolean_t roll = ISC_FALSE;
 	isc_result_t result = ISC_R_SUCCESS;
 	const char *path;
 
@@ -1515,7 +1512,7 @@ isc_log_open(isc_logchannel_t *channel) {
 	 * and either has no size limit or has reached its size limit.
 	 */
 	if (stat(path, &statbuf) == 0) {
-		regular_file = S_ISREG(statbuf.st_mode) ? true : false;
+		regular_file = S_ISREG(statbuf.st_mode) ? ISC_TRUE : ISC_FALSE;
 		/* XXXDCL if not regular_file complain? */
 		if ((FILE_MAXSIZE(channel) == 0 &&
 		     FILE_VERSIONS(channel) != ISC_LOG_ROLLNEVER) ||
@@ -1523,7 +1520,7 @@ isc_log_open(isc_logchannel_t *channel) {
 		     statbuf.st_size >= FILE_MAXSIZE(channel)))
 			roll = regular_file;
 	} else if (errno == ENOENT) {
-		regular_file = true;
+		regular_file = ISC_TRUE;
 		POST(regular_file);
 	} else
 		result = ISC_R_INVALIDFILE;
@@ -1553,7 +1550,7 @@ isc_log_open(isc_logchannel_t *channel) {
 	return (result);
 }
 
-bool
+isc_boolean_t
 isc_log_wouldlog(isc_log_t *lctx, int level) {
 	/*
 	 * Try to avoid locking the mutex for messages which can't
@@ -1573,16 +1570,16 @@ isc_log_wouldlog(isc_log_t *lctx, int level) {
 	 */
 
 	if (lctx == NULL || lctx->logconfig == NULL)
-		return (false);
+		return (ISC_FALSE);
 
-	return (level <= lctx->logconfig->highest_level ||
-		(lctx->logconfig->dynamic &&
-		 level <= lctx->debug_level));
+	return (ISC_TF(level <= lctx->logconfig->highest_level ||
+		       (lctx->logconfig->dynamic &&
+			level <= lctx->debug_level)));
 }
 
 static void
 isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
-	     isc_logmodule_t *module, int level, bool write_once,
+	     isc_logmodule_t *module, int level, isc_boolean_t write_once,
 	     isc_msgcat_t *msgcat, int msgset, int msg,
 	     const char *format, va_list args)
 {
@@ -1594,9 +1591,9 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 	char level_string[24];
 	const char *iformat;
 	struct stat statbuf;
-	bool matched = false;
-	bool printtime, iso8601, utc, printtag, printcolon;
-	bool printcategory, printmodule, printlevel, buffered;
+	isc_boolean_t matched = ISC_FALSE;
+	isc_boolean_t printtime, iso8601, utc, printtag, printcolon;
+	isc_boolean_t printcategory, printmodule, printlevel, buffered;
 	isc_logconfig_t *lcfg;
 	isc_logchannel_t *channel;
 	isc_logchannellist_t *category_channels;
@@ -1676,7 +1673,7 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 			continue;
 		}
 
-		matched = true;
+		matched = ISC_TRUE;
 
 		channel = category_channels->channel;
 		category_channels = ISC_LIST_NEXT(category_channels, link);
@@ -1837,18 +1834,23 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 			}
 		}
 
-		utc	      = ((channel->flags & ISC_LOG_UTC) != 0);
-		iso8601       = ((channel->flags & ISC_LOG_ISO8601) != 0);
-		printtime     = ((channel->flags & ISC_LOG_PRINTTIME) != 0);
-		printtag      = ((channel->flags &
-				  (ISC_LOG_PRINTTAG|ISC_LOG_PRINTPREFIX)) != 0 &&
-				 lcfg->tag != NULL);
-		printcolon    = ((channel->flags & ISC_LOG_PRINTTAG) != 0 &&
-				 lcfg->tag != NULL);
-		printcategory = ((channel->flags & ISC_LOG_PRINTCATEGORY) != 0);
-		printmodule   = ((channel->flags & ISC_LOG_PRINTMODULE) != 0);
-		printlevel    = ((channel->flags & ISC_LOG_PRINTLEVEL) != 0);
-		buffered      = ((channel->flags & ISC_LOG_BUFFERED) != 0);
+		utc	      = ISC_TF((channel->flags & ISC_LOG_UTC) != 0);
+		iso8601       = ISC_TF((channel->flags & ISC_LOG_ISO8601) != 0);
+		printtime     = ISC_TF((channel->flags & ISC_LOG_PRINTTIME)
+				       != 0);
+		printtag      = ISC_TF((channel->flags &
+					(ISC_LOG_PRINTTAG|ISC_LOG_PRINTPREFIX))
+				       != 0 && lcfg->tag != NULL);
+		printcolon    = ISC_TF((channel->flags & ISC_LOG_PRINTTAG)
+				       != 0 && lcfg->tag != NULL);
+		printcategory = ISC_TF((channel->flags & ISC_LOG_PRINTCATEGORY)
+				       != 0);
+		printmodule   = ISC_TF((channel->flags & ISC_LOG_PRINTMODULE)
+				       != 0);
+		printlevel    = ISC_TF((channel->flags & ISC_LOG_PRINTLEVEL)
+				       != 0);
+		buffered      = ISC_TF((channel->flags & ISC_LOG_BUFFERED)
+				       != 0);
 
 		if (printtime) {
 			if (iso8601) {
@@ -1882,7 +1884,7 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 				    statbuf.st_size < FILE_MAXSIZE(channel)) {
 					(void)fclose(FILE_STREAM(channel));
 					FILE_STREAM(channel) = NULL;
-					FILE_MAXREACHED(channel) = false;
+					FILE_MAXREACHED(channel) = ISC_FALSE;
 				} else
 					/*
 					 * Eh, skip it.
@@ -1939,7 +1941,7 @@ isc_log_doit(isc_log_t *lctx, isc_logcategory_t *category,
 				if (fstat(fileno(FILE_STREAM(channel)),
 					  &statbuf) >= 0 &&
 				    statbuf.st_size > FILE_MAXSIZE(channel))
-					FILE_MAXREACHED(channel) = true;
+					FILE_MAXREACHED(channel) = ISC_TRUE;
 			}
 
 			break;
