@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -33,21 +33,20 @@
 
 #ifndef PK11_MD5_DISABLE
 
-#include <stdbool.h>
-
 #include <isc/assertions.h>
 #include <isc/md5.h>
 #include <isc/platform.h>
 #include <isc/safe.h>
 #include <isc/string.h>
 #include <isc/types.h>
-#include <isc/util.h>
 
-#if PKCS11CRYPTO
+#if HAVE_PKCS11
 #include <pk11/internal.h>
 #include <pk11/pk11.h>
 #endif
 
+#include <isc/util.h>
+
 #ifdef ISC_PLATFORM_OPENSSLHASH
 #if OPENSSL_VERSION_NUMBER < 0x10100000L || defined(LIBRESSL_VERSION_NUMBER)
 #define EVP_MD_CTX_new() &(ctx->_ctx)
@@ -85,15 +84,15 @@ isc_md5_final(isc_md5_t *ctx, unsigned char *digest) {
 	ctx->ctx = NULL;
 }
 
-#elif PKCS11CRYPTO
+#elif HAVE_PKCS11
 
 void
 isc_md5_init(isc_md5_t *ctx) {
 	CK_RV rv;
 	CK_MECHANISM mech = { CKM_MD5, NULL, 0 };
 
-	RUNTIME_CHECK(pk11_get_session(ctx, OP_DIGEST, true, false,
-				       false, NULL, 0) == ISC_R_SUCCESS);
+	RUNTIME_CHECK(pk11_get_session(ctx, OP_DIGEST, ISC_TRUE, ISC_FALSE,
+				       ISC_FALSE, NULL, 0) == ISC_R_SUCCESS);
 	PK11_FATALCHECK(pkcs_C_DigestInit, (ctx->session, &mech));
 }
 
@@ -132,12 +131,12 @@ isc_md5_final(isc_md5_t *ctx, unsigned char *digest) {
 #else
 
 static void
-byteSwap(uint32_t *buf, unsigned words)
+byteSwap(isc_uint32_t *buf, unsigned words)
 {
 	unsigned char *p = (unsigned char *)buf;
 
 	do {
-		*buf++ = (uint32_t)((unsigned)p[3] << 8 | p[2]) << 16 |
+		*buf++ = (isc_uint32_t)((unsigned)p[3] << 8 | p[2]) << 16 |
 			((unsigned)p[1] << 8 | p[0]);
 		p += 4;
 	} while (--words);
@@ -183,8 +182,8 @@ isc_md5_invalidate(isc_md5_t *ctx) {
  * the data and converts bytes into longwords for this routine.
  */
 static void
-transform(uint32_t buf[4], uint32_t const in[16]) {
-	register uint32_t a, b, c, d;
+transform(isc_uint32_t buf[4], isc_uint32_t const in[16]) {
+	register isc_uint32_t a, b, c, d;
 
 	a = buf[0];
 	b = buf[1];
@@ -271,7 +270,7 @@ transform(uint32_t buf[4], uint32_t const in[16]) {
  */
 void
 isc_md5_update(isc_md5_t *ctx, const unsigned char *buf, unsigned int len) {
-	uint32_t t;
+	isc_uint32_t t;
 
 	/* Update byte count */
 
@@ -348,8 +347,8 @@ isc_md5_final(isc_md5_t *ctx, unsigned char *digest) {
  * Standard use is testing false and result true.
  * Testing use is testing true and result false;
  */
-bool
-isc_md5_check(bool testing) {
+isc_boolean_t
+isc_md5_check(isc_boolean_t testing) {
 	isc_md5_t ctx;
 	unsigned char input = 'a';
 	unsigned char digest[ISC_MD5_DIGESTLENGTH];
@@ -377,13 +376,18 @@ isc_md5_check(bool testing) {
 	/*
 	 * Must return true in standard case, should return false for testing.
 	 */
-	return (memcmp(digest, expected, ISC_MD5_DIGESTLENGTH) == 0);
+	return (ISC_TF(memcmp(digest, expected, ISC_MD5_DIGESTLENGTH) == 0));
 }
 
 #else /* !PK11_MD5_DISABLE */
-
+#ifdef WIN32
+/* Make the Visual Studio linker happy */
 #include <isc/util.h>
 
-EMPTY_TRANSLATION_UNIT
-
+void isc_md5_final() { INSIST(0); }
+void isc_md5_init() { INSIST(0); }
+void isc_md5_invalidate() { INSIST(0); }
+void isc_md5_update() { INSIST(0); }
+void isc_md5_check() { INSIST(0); }
+#endif
 #endif /* PK11_MD5_DISABLE */
