@@ -1,9 +1,12 @@
 /*
- * Copyright (C) 1997-2010, 2012-2018  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /*! \file */
@@ -23,7 +26,6 @@
 #include <isc/mem.h>
 #include <isc/msgs.h>
 #include <isc/once.h>
-#include <isc/ondestroy.h>
 #include <isc/string.h>
 #include <isc/mutex.h>
 #include <isc/print.h>
@@ -48,7 +50,7 @@ LIBISC_EXTERNAL_DATA unsigned int isc_mem_defaultflags = ISC_MEMFLAG_DEFAULT;
 #define ALIGNMENT_SIZE		8U		/*%< must be a power of 2 */
 #define NUM_BASIC_BLOCKS	64		/*%< must be > 1 */
 #define TABLE_INCREMENT		1024
-#define DEBUG_TABLE_COUNT	65536
+#define DEBUG_TABLE_COUNT	512U
 
 /*
  * Types.
@@ -117,7 +119,6 @@ static isc_uint64_t		totallost;
 
 struct isc__mem {
 	isc_mem_t		common;
-	isc_ondestroy_t		ondestroy;
 	unsigned int		flags;
 	isc_mutex_t		lock;
 	isc_memalloc_t		memalloc;
@@ -234,8 +235,6 @@ void
 isc___mem_putanddetach(isc_mem_t **ctxp, void *ptr, size_t size FLARG);
 void
 isc__mem_destroy(isc_mem_t **ctxp);
-isc_result_t
-isc__mem_ondestroy(isc_mem_t *ctx, isc_task_t *task, isc_event_t **event);
 void *
 isc___mem_get(isc_mem_t *ctx, size_t size FLARG);
 void
@@ -314,7 +313,7 @@ static struct isc__memmethods {
 	/*%
 	 * The following are defined just for avoiding unused static functions.
 	 */
-	void *createx, *create, *create2, *ondestroy, *stats,
+	void *createx, *create, *create2, *stats,
 	     *setquota, *getquota, *setname, *getname, *gettag;
 } memmethods = {
 	{
@@ -340,7 +339,6 @@ static struct isc__memmethods {
 	(void *)isc_mem_createx,
 	(void *)isc_mem_create,
 	(void *)isc_mem_create2,
-	(void *)isc_mem_ondestroy,
 	(void *)isc_mem_stats,
 	(void *)isc_mem_setquota,
 	(void *)isc_mem_getquota,
@@ -397,17 +395,6 @@ add_trace_entry(isc__mem_t *mctx, const void *ptr, size_t size FLARG) {
 	hash = isc_hash_function(&ptr, sizeof(ptr), ISC_TRUE, NULL);
 	idx = hash % DEBUG_TABLE_COUNT;
 
-	dl = ISC_LIST_TAIL(mctx->debuglist[idx]);
-	if (ISC_LIKELY(dl != NULL && dl->ptr == NULL)) {
-		ISC_LIST_UNLINK(mctx->debuglist[idx], dl, link);
-		dl->ptr = ptr;
-		dl->size = size;
-		dl->file = file;
-		dl->line = line;
-		ISC_LIST_PREPEND(mctx->debuglist[idx], dl, link);
-		return;
-	}
-
 	dl = malloc(sizeof(debuglink_t));
 	INSIST(dl != NULL);
 	mctx->malloced += sizeof(debuglink_t);
@@ -446,14 +433,11 @@ delete_trace_entry(isc__mem_t *mctx, const void *ptr, size_t size,
 	idx = hash % DEBUG_TABLE_COUNT;
 
 	dl = ISC_LIST_HEAD(mctx->debuglist[idx]);
-	while (ISC_LIKELY(dl != NULL && dl->ptr != NULL)) {
+	while (ISC_LIKELY(dl != NULL)) {
 		if (ISC_UNLIKELY(dl->ptr == ptr)) {
 			ISC_LIST_UNLINK(mctx->debuglist[idx], dl, link);
-			dl->ptr = NULL;
-			dl->size = 0;
-			dl->file = NULL;
-			dl->line = 0;
-			ISC_LIST_APPEND(mctx->debuglist[idx], dl, link);
+			mctx->malloced -= sizeof(*dl);
+			free(dl);
 			return;
 		}
 		dl = ISC_LIST_NEXT(dl, link);
@@ -938,7 +922,6 @@ isc_mem_createx2(size_t init_max_size, size_t target_size,
 	ctx->common.impmagic = MEM_MAGIC;
 	ctx->common.magic = ISCAPI_MCTX_MAGIC;
 	ctx->common.methods = (isc_memmethods_t *)&memmethods;
-	isc_ondestroy_init(&ctx->ondestroy);
 	ctx->memalloc = memalloc;
 	ctx->memfree = memfree;
 	ctx->arg = arg;
@@ -1032,7 +1015,6 @@ isc_mem_createx2(size_t init_max_size, size_t target_size,
 static void
 destroy(isc__mem_t *ctx) {
 	unsigned int i;
-	isc_ondestroy_t ondest;
 
 	LOCK(&contextslock);
 	ISC_LIST_UNLINK(contexts, ctx, link);
@@ -1100,16 +1082,12 @@ destroy(isc__mem_t *ctx) {
 		}
 	}
 
-	ondest = ctx->ondestroy;
-
 	if ((ctx->flags & ISC_MEMFLAG_NOLOCK) == 0)
 		DESTROYLOCK(&ctx->lock);
 	ctx->malloced -= sizeof(*ctx);
 	if (ctx->checkfree)
 		INSIST(ctx->malloced == 0);
 	(ctx->memfree)(ctx->arg, ctx);
-
-	isc_ondestroy_notify(&ondest, ctx);
 }
 
 void
@@ -1248,18 +1226,6 @@ isc__mem_destroy(isc_mem_t **ctxp) {
 	*ctxp = NULL;
 }
 
-isc_result_t
-isc_mem_ondestroy(isc_mem_t *ctx0, isc_task_t *task, isc_event_t **event) {
-	isc__mem_t *ctx = (isc__mem_t *)ctx0;
-	isc_result_t res;
-
-	MCTXLOCK(ctx, &ctx->lock);
-	res = isc_ondestroy_register(&ctx->ondestroy, task, event);
-	MCTXUNLOCK(ctx, &ctx->lock);
-
-	return (res);
-}
-
 void *
 isc___mem_get(isc_mem_t *ctx0, size_t size FLARG) {
 	isc__mem_t *ctx = (isc__mem_t *)ctx0;
