@@ -12,8 +12,6 @@
 #include <config.h>
 
 #include <stdio.h>
-#include <inttypes.h>
-#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -47,12 +45,12 @@
 #define PK11_NO_LOGERR 1
 #endif
 
-LIBISC_EXTERNAL_DATA bool pk11_verbose_init = false;
+LIBISC_EXTERNAL_DATA isc_boolean_t pk11_verbose_init = ISC_FALSE;
 
 static isc_once_t once = ISC_ONCE_INIT;
 static isc_mem_t *pk11_mctx = NULL;
-static int32_t allocsize = 0;
-static bool initialized = false;
+static isc_int32_t allocsize = 0;
+static isc_boolean_t initialized = ISC_FALSE;
 
 typedef struct pk11_session pk11_session_t;
 typedef struct pk11_token pk11_token_t;
@@ -71,7 +69,7 @@ struct pk11_token {
 	ISC_LINK(pk11_token_t)	link;
 	CK_SLOT_ID		slotid;
 	pk11_sessionlist_t	sessions;
-	bool		logged;
+	isc_boolean_t		logged;
 	char			name[32];
 	char			manuf[32];
 	char			model[16];
@@ -93,11 +91,11 @@ static isc_result_t free_all_sessions(void);
 static isc_result_t free_session_list(pk11_sessionlist_t *slist);
 static isc_result_t setup_session(pk11_session_t *sp,
 				  pk11_token_t *token,
-				  bool rw);
+				  isc_boolean_t rw);
 static void scan_slots(void);
 static isc_result_t token_login(pk11_session_t *sp);
 static char *percent_decode(char *x, size_t *len);
-static bool pk11strcmp(const char *x, size_t lenx,
+static isc_boolean_t pk11strcmp(const char *x, size_t lenx,
 				const char *y, size_t leny);
 static CK_ATTRIBUTE *push_attribute(pk11_object_t *obj,
 				    isc_mem_t *mctx,
@@ -185,20 +183,21 @@ pk11_mem_put(void *ptr, size_t size) {
 
 isc_result_t
 pk11_initialize(isc_mem_t *mctx, const char *engine) {
-	isc_result_t result = ISC_R_SUCCESS;
+	isc_result_t result;
 	CK_RV rv;
 
 	RUNTIME_CHECK(isc_once_do(&once, initialize) == ISC_R_SUCCESS);
 
-	LOCK(&sessionlock);
 	LOCK(&alloclock);
 	if ((mctx != NULL) && (pk11_mctx == NULL) && (allocsize == 0))
 		isc_mem_attach(mctx, &pk11_mctx);
-	UNLOCK(&alloclock);
 	if (initialized) {
-		goto unlock;
+		UNLOCK(&alloclock);
+		return (ISC_R_SUCCESS);
 	} else {
-		initialized = true;
+		LOCK(&sessionlock);
+		initialized = ISC_TRUE;
+		UNLOCK(&alloclock);
 	}
 
 	ISC_LIST_INIT(tokens);
@@ -222,7 +221,7 @@ pk11_initialize(isc_mem_t *mctx, const char *engine) {
 	}
 
 	scan_slots();
-#ifdef PKCS11CRYPTO
+#if HAVE_PKCS11
 	if (rand_token == NULL) {
 		result = PK11_R_NORANDOMSERVICE;
 		goto unlock;
@@ -237,7 +236,8 @@ pk11_initialize(isc_mem_t *mctx, const char *engine) {
 		goto unlock;
 	}
 #endif
-#endif /* PKCS11CRYPTO */
+#endif /* HAVE_PKCS11 */
+	result = ISC_R_SUCCESS;
  unlock:
 	UNLOCK(&sessionlock);
 	return (result);
@@ -275,7 +275,7 @@ pk11_finalize(void) {
 	}
 	if (pk11_mctx != NULL)
 		isc_mem_detach(&pk11_mctx);
-	initialized = false;
+	initialized = ISC_FALSE;
 	return (ret);
 }
 
@@ -285,8 +285,8 @@ pk11_rand_bytes(unsigned char *buf, int num) {
 	CK_RV rv;
 	pk11_context_t ctx;
 
-	ret = pk11_get_session(&ctx, OP_RAND, false, false,
-			       false, NULL, 0);
+	ret = pk11_get_session(&ctx, OP_RAND, ISC_FALSE, ISC_FALSE,
+			       ISC_FALSE, NULL, 0);
 	if ((ret != ISC_R_SUCCESS) &&
 	    (ret != PK11_R_NODIGESTSERVICE) &&
 	    (ret != PK11_R_NOAESSERVICE))
@@ -312,8 +312,8 @@ pk11_rand_seed_fromfile(const char *randomfile) {
 	size_t cc = 0;
 	isc_result_t ret;
 
-	ret = pk11_get_session(&ctx, OP_RAND, false, false,
-			       false, NULL, 0);
+	ret = pk11_get_session(&ctx, OP_RAND, ISC_FALSE, ISC_FALSE,
+			       ISC_FALSE, NULL, 0);
 	if ((ret != ISC_R_SUCCESS) &&
 	    (ret != PK11_R_NODIGESTSERVICE) &&
 	    (ret != PK11_R_NOAESSERVICE))
@@ -341,14 +341,14 @@ pk11_rand_seed_fromfile(const char *randomfile) {
 
 isc_result_t
 pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
-		 bool need_services, bool rw,
-		 bool logon, const char *pin, CK_SLOT_ID slot)
+		 isc_boolean_t need_services, isc_boolean_t rw,
+		 isc_boolean_t logon, const char *pin, CK_SLOT_ID slot)
 {
 	pk11_token_t *token = NULL;
 	pk11_sessionlist_t *freelist;
 	pk11_session_t *sp;
 	isc_result_t ret;
-#ifdef PKCS11CRYPTO
+#if HAVE_PKCS11
 	isc_result_t service_ret = ISC_R_SUCCESS;
 #else
 	UNUSED(need_services);
@@ -359,7 +359,7 @@ pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
 	ctx->session = CK_INVALID_HANDLE;
 
 	ret = pk11_initialize(NULL, NULL);
-#ifdef PKCS11CRYPTO
+#if HAVE_PKCS11
 	if (ret == PK11_R_NORANDOMSERVICE ||
 	    ret == PK11_R_NODIGESTSERVICE ||
 	    ret == PK11_R_NOAESSERVICE) {
@@ -368,7 +368,7 @@ pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
 		service_ret = ret;
 	}
 	else
-#endif /* PKCS11CRYPTO */
+#endif /* HAVE_PKCS11 */
 	if (ret != ISC_R_SUCCESS)
 		return (ret);
 
@@ -377,7 +377,7 @@ pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
 	UNLOCK(&sessionlock);
 
 	switch(optype) {
-#ifdef PKCS11CRYPTO
+#if HAVE_PKCS11
 	case OP_RAND:
 		token = rand_token;
 		break;
@@ -401,7 +401,7 @@ pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
 		     token = ISC_LIST_NEXT(token, link))
 			if (token->slotid == slot)
 				break;
-#ifdef PKCS11CRYPTO
+#if HAVE_PKCS11
 		if ((token == NULL) ||
 		    ((token->operations & (1 << optype)) == 0))
 			return (ISC_R_NOTFOUND);
@@ -454,7 +454,7 @@ pk11_get_session(pk11_context_t *ctx, pk11_optype_t optype,
 	UNLOCK(&sessionlock);
 	ctx->handle = sp;
 	ctx->session = sp->session;
-#ifdef PKCS11CRYPTO
+#if HAVE_PKCS11
 	if (ret == ISC_R_SUCCESS)
 		ret = service_ret;
 #endif
@@ -515,7 +515,6 @@ free_session_list(pk11_sessionlist_t *slist) {
 	LOCK(&sessionlock);
 	while (!ISC_LIST_EMPTY(*slist)) {
 		sp = ISC_LIST_HEAD(*slist);
-		ISC_LIST_UNLINK(*slist, sp, link);
 		UNLOCK(&sessionlock);
 		if (sp->session != CK_INVALID_HANDLE) {
 			rv = pkcs_C_CloseSession(sp->session);
@@ -523,6 +522,7 @@ free_session_list(pk11_sessionlist_t *slist) {
 				ret = DST_R_CRYPTOFAILURE;
 		}
 		LOCK(&sessionlock);
+		ISC_LIST_UNLINK(*slist, sp, link);
 		pk11_mem_put(sp, sizeof(*sp));
 	}
 	UNLOCK(&sessionlock);
@@ -532,7 +532,7 @@ free_session_list(pk11_sessionlist_t *slist) {
 
 static isc_result_t
 setup_session(pk11_session_t *sp, pk11_token_t *token,
-	      bool rw)
+	      isc_boolean_t rw)
 {
 	CK_RV rv;
 	CK_FLAGS flags = CKF_SERIAL_SESSION;
@@ -565,7 +565,7 @@ token_login(pk11_session_t *sp) {
 					      "pkcs_C_Login", rv);
 #endif
 		} else
-			token->logged = true;
+			token->logged = ISC_TRUE;
 	}
 	UNLOCK(&sessionlock);
 	return (ret);
@@ -590,7 +590,7 @@ scan_slots(void) {
 	CK_ULONG slotCount;
 	pk11_token_t *token;
 	unsigned int i;
-	bool bad;
+	isc_boolean_t bad;
 
 	slotCount = 0;
 	PK11_FATALCHECK(pkcs_C_GetSlotList, (CK_FALSE, NULL_PTR, &slotCount));
@@ -598,7 +598,7 @@ scan_slots(void) {
 	/* it's not an error if we didn't find any providers */
 	if (slotCount == 0)
 		return;
-	slotList = pk11_mem_get(sizeof(CK_SLOT_ID) * slotCount);
+	slotList = pk11_mem_get(sizeof(CK_SLOT_ID_PTR) * slotCount);
 	RUNTIME_CHECK(slotList != NULL);
 	PK11_FATALCHECK(pkcs_C_GetSlotList, (CK_FALSE, slotList, &slotCount));
 
@@ -629,12 +629,12 @@ scan_slots(void) {
 			rand_token = token;
 
 	try_rsa:
-		bad = false;
+		bad = ISC_FALSE;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_RSA_PKCS_KEY_PAIR_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_RSA_PKCS_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_MD5_RSA_PKCS,
@@ -643,7 +643,7 @@ scan_slots(void) {
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
 #if !defined(PK11_MD5_DISABLE) && !defined(PK11_RSA_PKCS_REPLACE)
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_MD5_RSA_PKCS);
 		}
@@ -653,7 +653,7 @@ scan_slots(void) {
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
 #ifndef PK11_RSA_PKCS_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_SHA1_RSA_PKCS);
 		}
@@ -663,7 +663,7 @@ scan_slots(void) {
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
 #ifndef PK11_RSA_PKCS_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_SHA256_RSA_PKCS);
 		}
@@ -673,7 +673,7 @@ scan_slots(void) {
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
 #ifndef PK11_RSA_PKCS_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_SHA512_RSA_PKCS);
 		}
@@ -682,7 +682,7 @@ scan_slots(void) {
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
 #ifdef PK11_RSA_PKCS_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_RSA_PKCS);
 		}
@@ -693,12 +693,12 @@ scan_slots(void) {
 			best_rsa_token = token;
 
 	try_dsa:
-		bad = false;
+		bad = ISC_FALSE;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DSA_PARAMETER_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_GENERATE) == 0)) {
 #ifndef PK11_DSA_PARAMETER_GEN_SKIP
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_DSA_PARAMETER_GEN);
 		}
@@ -706,14 +706,14 @@ scan_slots(void) {
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_DSA_PARAMETER_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DSA_SHA1, &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_DSA_SHA1);
 		}
 		if (bad)
@@ -725,7 +725,7 @@ scan_slots(void) {
 #endif
 
 	try_dh:
-		bad = false;
+		bad = ISC_FALSE;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DH_PKCS_PARAMETER_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_GENERATE) == 0)) {
@@ -736,14 +736,14 @@ scan_slots(void) {
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
 #ifndef PK11_DH_PKCS_PARAMETER_GEN_SKIP
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_DH_PKCS_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_DH_PKCS_DERIVE,
 					     &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DERIVE) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_DH_PKCS_DERIVE);
 		}
 		if (bad)
@@ -755,78 +755,78 @@ scan_slots(void) {
 #endif
 
 	try_digest:
-		bad = false;
+		bad = ISC_FALSE;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_MD5, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
 #ifndef PK11_MD5_DISABLE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_MD5);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA_1, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_SHA_1);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA224, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_SHA224);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA256, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_SHA256);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA384, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_SHA384);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA512, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_SHA512);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_MD5_HMAC, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
 #if !defined(PK11_MD5_DISABLE) && !defined(PK11_MD5_HMAC_REPLACE)
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_MD5_HMAC);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA_1_HMAC, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
 #ifndef PK11_SHA_1_HMAC_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_SHA_1_HMAC);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA224_HMAC, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
 #ifndef PK11_SHA224_HMAC_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_SHA224_HMAC);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA256_HMAC, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
 #ifndef PK11_SHA256_HMAC_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_SHA256_HMAC);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA384_HMAC, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
 #ifndef PK11_SHA384_HMAC_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_SHA384_HMAC);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_SHA512_HMAC, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_SIGN) == 0)) {
 #ifndef PK11_SHA512_HMAC_REPLACE
-			bad = true;
+			bad = ISC_TRUE;
 #endif
 			PK11_TRACEM(CKM_SHA512_HMAC);
 		}
@@ -841,14 +841,14 @@ scan_slots(void) {
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_EC_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_ECDSA, &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_ECDSA);
 		}
 		if (bad)
@@ -858,18 +858,18 @@ scan_slots(void) {
 			best_ec_token = token;
 
 	try_gost:
-		bad = false;
+		bad = ISC_FALSE;
 		/* does GOST require digest too? */
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_GOSTR3411, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_DIGEST) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_GOSTR3411);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_GOSTR3410_KEY_PAIR_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_GOSTR3410_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot,
@@ -878,7 +878,7 @@ scan_slots(void) {
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_GOSTR3410_WITH_GOSTR3411);
 		}
 		if (bad)
@@ -889,19 +889,19 @@ scan_slots(void) {
 
 	try_eddsa:
 #if defined(CKM_EDDSA_KEY_PAIR_GEN) && defined(CKM_EDDSA) && defined(CKK_EDDSA)
-		bad = false;
+		bad = ISC_FALSE;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_EDDSA_KEY_PAIR_GEN,
 					     &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_GENERATE_KEY_PAIR) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_EDDSA_KEY_PAIR_GEN);
 		}
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_EDDSA, &mechInfo);
 		if ((rv != CKR_OK) ||
 		    ((mechInfo.flags & CKF_SIGN) == 0) ||
 		    ((mechInfo.flags & CKF_VERIFY) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_EDDSA);
 		}
 		if (bad)
@@ -909,10 +909,10 @@ scan_slots(void) {
 
 	try_aes:
 #endif
-		bad = false;
+		bad = ISC_FALSE;
 		rv = pkcs_C_GetMechanismInfo(slot, CKM_AES_ECB, &mechInfo);
 		if ((rv != CKR_OK) || ((mechInfo.flags & CKF_ENCRYPT) == 0)) {
-			bad = true;
+			bad = ISC_TRUE;
 			PK11_TRACEM(CKM_AES_ECB);
 		}
 		if (bad)
@@ -922,9 +922,8 @@ scan_slots(void) {
 			aes_token = token;
 	}
 
-	if (slotList != NULL) {
-		pk11_mem_put(slotList, sizeof(CK_SLOT_ID) * slotCount);
-	}
+	if (slotList != NULL)
+		pk11_mem_put(slotList, sizeof(CK_SLOT_ID_PTR) * slotCount);
 }
 
 CK_SLOT_ID
@@ -1113,7 +1112,7 @@ percent_decode(char *x, size_t *len) {
 	return (x);
 }
 
-static bool
+static isc_boolean_t
 pk11strcmp(const char *x, size_t lenx, const char *y, size_t leny) {
 	char buf[32];
 
@@ -1123,7 +1122,7 @@ pk11strcmp(const char *x, size_t lenx, const char *y, size_t leny) {
 	if (lenx > leny)
 		lenx = leny;
 	memmove(buf, x, lenx);
-	return (memcmp(buf, y, leny) == 0);
+	return (ISC_TF(memcmp(buf, y, leny) == 0));
 }
 
 static CK_ATTRIBUTE *
@@ -1169,7 +1168,7 @@ pk11_parse_uri(pk11_object_t *obj, const char *label,
 	size_t len, l;
 	FILE *stream = NULL;
 	char pin[PINLEN + 1];
-	bool gotpin = false;
+	isc_boolean_t gotpin = ISC_FALSE;
 	isc_result_t ret;
 
 	/* get values to work on */
@@ -1286,7 +1285,7 @@ pk11_parse_uri(pk11_object_t *obj, const char *label,
 			stream = NULL;
 			if (ret != ISC_R_SUCCESS)
 				goto err;
-			gotpin = true;
+			gotpin = ISC_TRUE;
 		} else
 			DST_RET(PK11_R_NOPROVIDER);
 	}
@@ -1310,7 +1309,7 @@ pk11_parse_uri(pk11_object_t *obj, const char *label,
 	obj->slot = token->slotid;
 	if (gotpin) {
 		memmove(token->pin, pin, PINLEN + 1);
-		obj->reqlogon = true;
+		obj->reqlogon = ISC_TRUE;
 	}
 
 	ret = ISC_R_SUCCESS;
@@ -1332,7 +1331,7 @@ pk11_error_fatalcheck(const char *file, int line,
 void
 pk11_dump_tokens(void) {
 	pk11_token_t *token;
-	bool first;
+	isc_boolean_t first;
 
 	printf("DEFAULTS\n");
 	printf("\trand_token=%p\n", rand_token);
@@ -1355,45 +1354,47 @@ pk11_dump_tokens(void) {
 		printf("\tmodel=%.16s\n", token->model);
 		printf("\tserialNumber=%.16s\n", token->serial);
 		printf("\tsupported operations=0x%x (", token->operations);
-		first = true;
+		first = ISC_TRUE;
 		if (token->operations & (1 << OP_RAND)) {
 			if (!first)
 				printf(",");
-			first = false;
+			first = ISC_FALSE;
 			printf("RAND");
 		}
 		if (token->operations & (1 << OP_RSA)) {
-			first = false;
+			if (!first)
+				printf(",");
+			first = ISC_FALSE;
 			printf("RSA");
 		}
 		if (token->operations & (1 << OP_DSA)) {
 			if (!first)
 				printf(",");
-			first = false;
+			first = ISC_FALSE;
 			printf("DSA");
 		}
 		if (token->operations & (1 << OP_DH)) {
 			if (!first)
 				printf(",");
-			first = false;
+			first = ISC_FALSE;
 			printf("DH");
 		}
 		if (token->operations & (1 << OP_DIGEST)) {
 			if (!first)
 				printf(",");
-			first = false;
+			first = ISC_FALSE;
 			printf("DIGEST");
 		}
 		if (token->operations & (1 << OP_EC)) {
 			if (!first)
 				printf(",");
-			first = false;
+			first = ISC_FALSE;
 			printf("EC");
 		}
 		if (token->operations & (1 << OP_AES)) {
 			if (!first)
 				printf(",");
-			first = false;
+			first = ISC_FALSE;
 			printf("AES");
 		}
 		printf(")\n");
