@@ -98,8 +98,7 @@ isc_pool_create(isc_mem_t *mctx, unsigned int count,
 
 void *
 isc_pool_get(isc_pool_t *pool) {
-	uint32_t i;
-	isc_random_get(&i);
+	isc_uint32_t i = isc_random();
 	return (pool->pool[i % pool->count]);
 }
 
@@ -133,22 +132,21 @@ isc_pool_expand(isc_pool_t **sourcep, unsigned int count,
 		newpool->init = pool->init;
 		newpool->initarg = pool->initarg;
 
-		/* Populate the new entries */
-		for (i = pool->count; i < count; i++) {
-			result = newpool->init(&newpool->pool[i],
-					       newpool->initarg);
-			if (result != ISC_R_SUCCESS) {
-				isc_pool_destroy(&newpool);
-				return (result);
-			}
-		}
-
 		/* Copy over the objects from the old pool */
 		for (i = 0; i < pool->count; i++) {
 			newpool->pool[i] = pool->pool[i];
 			pool->pool[i] = NULL;
 		}
 
+		/* Populate the new entries */
+		for (i = pool->count; i < count; i++) {
+			result = pool->init(&newpool->pool[i], pool->initarg);
+			if (result != ISC_R_SUCCESS) {
+				isc_pool_destroy(&pool);
+				return (result);
+			}
+		}
+
 		isc_pool_destroy(&pool);
 		pool = newpool;
 	}
