@@ -14,8 +14,6 @@
 #include <config.h>
 
 #include <ctype.h>
-#include <inttypes.h>
-#include <stdbool.h>
 #include <stdio.h>		/* for sprintf() */
 #include <string.h>		/* for strlen() */
 #include <assert.h>		/* for assert() */
@@ -23,6 +21,7 @@
 #define	ISC__PRINT_SOURCE	/* Used to get the isc_print_* prototypes. */
 
 #include <isc/assertions.h>
+#include <isc/int.h>
 #include <isc/msgs.h>
 #include <isc/print.h>
 #include <isc/stdlib.h>
@@ -163,8 +162,9 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 	int left;
 	int plus;
 	int space;
-	int64_t tmpi;
-	uint64_t tmpui;
+	int neg;
+	isc_int64_t tmpi;
+	isc_uint64_t tmpui;
 	unsigned long width;
 	unsigned long precision;
 	unsigned int length;
@@ -178,7 +178,7 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 	int zeropad;
 	int dot;
 	double dbl;
-	bool precision_set;
+	isc_boolean_t precision_set;
 #ifdef HAVE_LONG_DOUBLE
 	long double ldbl;
 #endif
@@ -199,11 +199,11 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 		/*
 		 * Reset flags.
 		 */
-		dot = space = plus = left = zero = alt = h = l = q = z = 0;
+		dot = neg = space = plus = left = zero = alt = h = l = q = z = 0;
 		width = precision = 0;
 		head = "";
 		pad = zeropad = 0;
-		precision_set = false;
+		precision_set = ISC_FALSE;
 
 		do {
 			if (*format == '#') {
@@ -249,12 +249,12 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 			dot = 1;
 			if (*format == '*') {
 				precision = va_arg(ap, int);
-				precision_set = true;
+				precision_set = ISC_TRUE;
 				format++;
 			} else if (isdigit((unsigned char)*format)) {
 				char *e;
 				precision = strtoul(format, &e, 10);
-				precision_set = true;
+				precision_set = ISC_TRUE;
 				format = e;
 			}
 		}
@@ -333,7 +333,7 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 			case 'i':
 			case 'd':
 				if (q)
-					tmpi = va_arg(ap, int64_t);
+					tmpi = va_arg(ap, isc_int64_t);
 				else if (l)
 					tmpi = va_arg(ap, long int);
 				else if (z)
@@ -375,7 +375,7 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 				goto printint;
 			case 'o':
 				if (q)
-					tmpui = va_arg(ap, uint64_t);
+					tmpui = va_arg(ap, isc_uint64_t);
 				else if (l)
 					tmpui = va_arg(ap, long int);
 				else if (z)
@@ -408,7 +408,7 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 				goto printint;
 			case 'u':
 				if (q)
-					tmpui = va_arg(ap, uint64_t);
+					tmpui = va_arg(ap, isc_uint64_t);
 				else if (l)
 					tmpui = va_arg(ap, unsigned long int);
 				else if (z)
@@ -438,7 +438,7 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 				goto printint;
 			case 'x':
 				if (q)
-					tmpui = va_arg(ap, uint64_t);
+					tmpui = va_arg(ap, isc_uint64_t);
 				else if (l)
 					tmpui = va_arg(ap, unsigned long int);
 				else if (z)
@@ -462,7 +462,7 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 				goto printint;
 			case 'X':
 				if (q)
-					tmpui = va_arg(ap, uint64_t);
+					tmpui = va_arg(ap, isc_uint64_t);
 				else if (l)
 					tmpui = va_arg(ap, unsigned long int);
 				else if (z)
@@ -621,20 +621,16 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 			}
 			break;
 		case 'D':	/*deprecated*/
-			/* cppcheck-suppress literalWithCharPtrCompare */
 			assert("use %ld instead of %D" == NULL);
 		case 'O':	/*deprecated*/
-			/* cppcheck-suppress literalWithCharPtrCompare */
 			assert("use %lo instead of %O" == NULL);
 		case 'U':	/*deprecated*/
-			/* cppcheck-suppress literalWithCharPtrCompare */
 			assert("use %lu instead of %U" == NULL);
 
 		case 'L':
 #ifdef HAVE_LONG_DOUBLE
 			l = 1;
 #else
-			/* cppcheck-suppress literalWithCharPtrCompare */
 			assert("long doubles are not supported" == NULL);
 #endif
 			/* FALLTHROUGH */
@@ -689,7 +685,7 @@ isc__print_printf(void (*emit)(char, void *), void *arg,
 						pad--;
 					}
 				cp = buf;
-				while (*cp != '\0')
+				while (*cp != ' ')
 					emit(*cp++, arg);
 				while (pad > 0) {
 					emit(' ', arg);
