@@ -163,6 +163,7 @@ isc_radix_create(isc_mem_t *mctx, isc_radix_tree_t **target, int maxbits) {
 
 static void
 _clear_radix(isc_radix_tree_t *radix, isc_radix_destroyfunc_t func) {
+
 	REQUIRE(radix != NULL);
 
 	if (radix->head != NULL) {
@@ -179,10 +180,10 @@ _clear_radix(isc_radix_tree_t *radix, isc_radix_destroyfunc_t func) {
 				if (func != NULL)
 					func(Xrn->data);
 			} else {
-				INSIST(Xrn->data[RADIX_V4] == NULL &&
-				       Xrn->data[RADIX_V6] == NULL &&
-				       Xrn->data[RADIX_V4_ECS] == NULL &&
-				       Xrn->data[RADIX_V6_ECS] == NULL);
+				INSIST(Xrn->data[0] == NULL &&
+				       Xrn->data[1] == NULL &&
+				       Xrn->data[2] == NULL &&
+				       Xrn->data[3] == NULL);
 			}
 
 			isc_mem_put(radix->mctx, Xrn, sizeof(*Xrn));
@@ -237,7 +238,7 @@ isc_radix_search(isc_radix_tree_t *radix, isc_radix_node_t **target,
 	isc_radix_node_t *stack[RADIX_MAXBITS + 1];
 	u_char *addr;
 	isc_uint32_t bitlen;
-	int tfam = -1, cnt = 0;
+	int toff = -1, cnt = 0;
 
 	REQUIRE(radix != NULL);
 	REQUIRE(prefix != NULL);
@@ -280,13 +281,13 @@ isc_radix_search(isc_radix_tree_t *radix, isc_radix_node_t **target,
 				    isc_prefix_tochar(prefix),
 				    node->prefix->bitlen))
 		{
-			int fam = ISC_RADIX_FAMILY(prefix);
-			if (node->node_num[fam] != -1 &&
+			int off = ISC_RADIX_OFF(prefix);
+			if (node->node_num[off] != -1 &&
 			    ((*target == NULL) ||
-			     (*target)->node_num[tfam] > node->node_num[fam]))
+			     (*target)->node_num[toff] > node->node_num[off]))
 			{
 				*target = node;
-				tfam = fam;
+				toff = off;
 			}
 		}
 	}
@@ -326,9 +327,8 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 		if (node == NULL)
 			return (ISC_R_NOMEMORY);
 		node->bit = bitlen;
-		for (i = 0; i < RADIX_FAMILIES; i++) {
+		for (i = 0; i < 4; i++)
 			node->node_num[i] = -1;
-		}
 		node->prefix = NULL;
 		result = _ref_prefix(radix->mctx, &node->prefix, prefix);
 		if (result != ISC_R_SUCCESS) {
@@ -347,23 +347,21 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 			 * added to num_added_node at the end of
 			 * the merge operation--we don't do it here.
 			 */
-			for (i = 0; i < RADIX_FAMILIES; i++) {
-				if (source->node_num[i] != -1) {
+			for (i = 0; i < 4; i++) {
+				if (source->node_num[i] != -1)
 					node->node_num[i] =
 						radix->num_added_node +
 						source->node_num[i];
-				}
 				node->data[i] = source->data[i];
 			}
 		} else {
 			int next = ++radix->num_added_node;
 			if (fam == AF_UNSPEC) {
 				/* "any" or "none" */
-				for (i = 0; i < RADIX_FAMILIES; i++) {
+				for (i = 0; i < 4; i++)
 					node->node_num[i] = next;
-				}
 			} else {
-				node->node_num[ISC_RADIX_FAMILY(prefix)] = next;
+				node->node_num[ISC_RADIX_OFF(prefix)] = next;
 			}
 
 			memset(node->data, 0, sizeof(node->data));
@@ -399,14 +397,14 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 	/* Find the first bit different. */
 	check_bit = (node->bit < bitlen) ? node->bit : bitlen;
 	differ_bit = 0;
-	for (i = 0; i * 8 < check_bit; i++) {
+	for (i = 0; i*8 < check_bit; i++) {
 		if ((r = (addr[i] ^ test_addr[i])) == 0) {
 			differ_bit = (i + 1) * 8;
 			continue;
 		}
 		/* I know the better way, but for now. */
 		for (j = 0; j < 8; j++) {
-			if (BIT_TEST(r, (0x80 >> j)))
+			if (BIT_TEST (r, (0x80 >> j)))
 				break;
 		}
 		/* Must be found. */
@@ -429,7 +427,7 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 			/* Set node_num only if it hasn't been set before */
 			if (source != NULL) {
 				/* Merging nodes */
-				for (i = 0; i < RADIX_FAMILIES; i++) {
+				for (i = 0; i < 4; i++) {
 					if (node->node_num[i] == -1 &&
 					    source->node_num[i] != -1) {
 						node->node_num[i] =
@@ -442,7 +440,7 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 				if (fam == AF_UNSPEC) {
 					/* "any" or "none" */
 					int next = radix->num_added_node + 1;
-					for (i = 0; i < RADIX_FAMILIES; i++) {
+					for (i = 0; i < 4; i++)  {
 						if (node->node_num[i] == -1) {
 							node->node_num[i] =
 								next;
@@ -451,11 +449,10 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 						}
 					}
 				} else {
-					int foff = ISC_RADIX_FAMILY(prefix);
-					if (node->node_num[foff] == -1) {
-						node->node_num[foff] =
+					int off = ISC_RADIX_OFF(prefix);
+					if (node->node_num[off] == -1)
+						node->node_num[off] =
 							++radix->num_added_node;
-					}
 				}
 			}
 			*target = node;
@@ -466,20 +463,13 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 			if (result != ISC_R_SUCCESS)
 				return (result);
 		}
-
-		/* Check everything is null and empty before we proceed */
-		INSIST(node->data[RADIX_V4] == NULL &&
-		       node->node_num[RADIX_V4] == -1 &&
-		       node->data[RADIX_V6] == NULL &&
-		       node->node_num[RADIX_V6] == -1 &&
-		       node->data[RADIX_V4_ECS] == NULL &&
-		       node->node_num[RADIX_V4_ECS] == -1 &&
-		       node->data[RADIX_V6_ECS] == NULL &&
-		       node->node_num[RADIX_V6_ECS] == -1);
-
+		INSIST(node->data[0] == NULL && node->node_num[0] == -1 &&
+		       node->data[1] == NULL && node->node_num[1] == -1 &&
+		       node->data[2] == NULL && node->node_num[2] == -1 &&
+		       node->data[3] == NULL && node->node_num[3] == -1);
 		if (source != NULL) {
 			/* Merging node */
-			for (i = 0; i < RADIX_FAMILIES; i++) {
+			for (i = 0; i < 4; i++) {
 				int cur = radix->num_added_node;
 				if (source->node_num[i] != -1) {
 					node->node_num[i] =
@@ -491,11 +481,10 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 			int next = ++radix->num_added_node;
 			if (fam == AF_UNSPEC) {
 				/* "any" or "none" */
-				for (i = 0; i < RADIX_FAMILIES; i++) {
+				for (i = 0; i < 4; i++)
 					node->node_num[i] = next;
-				}
 			} else {
-				node->node_num[ISC_RADIX_FAMILY(prefix)] = next;
+				node->node_num[ISC_RADIX_OFF(prefix)] = next;
 			}
 		}
 		*target = node;
@@ -525,7 +514,7 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 	}
 	new_node->parent = NULL;
 	new_node->l = new_node->r = NULL;
-	for (i = 0; i < RADIX_FAMILIES; i++) {
+	for (i = 0; i < 4; i++) {
 		new_node->node_num[i] = -1;
 		new_node->data[i] = NULL;
 	}
@@ -533,7 +522,7 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 
 	if (source != NULL) {
 		/* Merging node */
-		for (i = 0; i < RADIX_FAMILIES; i++) {
+		for (i = 0; i < 4; i++) {
 			int cur = radix->num_added_node;
 			if (source->node_num[i] != -1) {
 				new_node->node_num[i] =
@@ -545,11 +534,10 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 		int next = ++radix->num_added_node;
 		if (fam == AF_UNSPEC) {
 			/* "any" or "none" */
-			for (i = 0; i < RADIX_FAMILIES; i++) {
+			for (i = 0; i < 4; i++)
 				new_node->node_num[i] = next;
-			}
 		} else {
-			new_node->node_num[ISC_RADIX_FAMILY(prefix)] = next;
+			new_node->node_num[ISC_RADIX_OFF(prefix)] = next;
 		}
 		memset(new_node->data, 0, sizeof(new_node->data));
 	}
@@ -593,7 +581,7 @@ isc_radix_insert(isc_radix_tree_t *radix, isc_radix_node_t **target,
 		glue->bit = differ_bit;
 		glue->prefix = NULL;
 		glue->parent = node->parent;
-		for (i = 0; i < RADIX_FAMILIES; i++) {
+		for (i = 0; i < 4; i++) {
 			glue->data[i] = NULL;
 			glue->node_num[i] = -1;
 		}
