@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, you can obtain one at https://mozilla.org/MPL/2.0/.
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -50,8 +50,6 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-
 #include <isc/assertions.h>
 #include <isc/platform.h>
 #include <isc/safe.h>
@@ -59,7 +57,7 @@
 #include <isc/string.h>
 #include <isc/util.h>
 
-#if PKCS11CRYPTO
+#if HAVE_PKCS11
 #include <pk11/internal.h>
 #include <pk11/pk11.h>
 #endif
@@ -90,7 +88,7 @@ isc_sha224_invalidate(isc_sha224_t *context) {
 }
 
 void
-isc_sha224_update(isc_sha224_t *context, const uint8_t* data, size_t len) {
+isc_sha224_update(isc_sha224_t *context, const isc_uint8_t* data, size_t len) {
 	if (len == 0U) {
 		/* Calling with no data is valid - we do nothing */
 		return;
@@ -99,20 +97,20 @@ isc_sha224_update(isc_sha224_t *context, const uint8_t* data, size_t len) {
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha224_t *)0);
 	REQUIRE(context->ctx != (EVP_MD_CTX *)0);
-	REQUIRE(data != (uint8_t*)0);
+	REQUIRE(data != (isc_uint8_t*)0);
 
 	RUNTIME_CHECK(EVP_DigestUpdate(context->ctx,
 				       (const void *) data, len) == 1);
 }
 
 void
-isc_sha224_final(uint8_t digest[], isc_sha224_t *context) {
+isc_sha224_final(isc_uint8_t digest[], isc_sha224_t *context) {
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha224_t *)0);
 	REQUIRE(context->ctx != (EVP_MD_CTX *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0)
+	if (digest != (isc_uint8_t*)0)
 		RUNTIME_CHECK(EVP_DigestFinal(context->ctx,
 					      digest, NULL) == 1);
 	EVP_MD_CTX_free(context->ctx);
@@ -138,7 +136,7 @@ isc_sha256_invalidate(isc_sha256_t *context) {
 }
 
 void
-isc_sha256_update(isc_sha256_t *context, const uint8_t *data, size_t len) {
+isc_sha256_update(isc_sha256_t *context, const isc_uint8_t *data, size_t len) {
 	if (len == 0U) {
 		/* Calling with no data is valid - we do nothing */
 		return;
@@ -147,20 +145,20 @@ isc_sha256_update(isc_sha256_t *context, const uint8_t *data, size_t len) {
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha256_t *)0);
 	REQUIRE(context->ctx != (EVP_MD_CTX *)0);
-	REQUIRE(data != (uint8_t*)0);
+	REQUIRE(data != (isc_uint8_t*)0);
 
 	RUNTIME_CHECK(EVP_DigestUpdate(context->ctx,
 				       (const void *) data, len) == 1);
 }
 
 void
-isc_sha256_final(uint8_t digest[], isc_sha256_t *context) {
+isc_sha256_final(isc_uint8_t digest[], isc_sha256_t *context) {
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha256_t *)0);
 	REQUIRE(context->ctx != (EVP_MD_CTX *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0)
+	if (digest != (isc_uint8_t*)0)
 		RUNTIME_CHECK(EVP_DigestFinal(context->ctx,
 					      digest, NULL) == 1);
 	EVP_MD_CTX_free(context->ctx);
@@ -185,7 +183,7 @@ isc_sha512_invalidate(isc_sha512_t *context) {
 	context->ctx = NULL;
 }
 
-void isc_sha512_update(isc_sha512_t *context, const uint8_t *data, size_t len) {
+void isc_sha512_update(isc_sha512_t *context, const isc_uint8_t *data, size_t len) {
 	if (len == 0U) {
 		/* Calling with no data is valid - we do nothing */
 		return;
@@ -194,19 +192,19 @@ void isc_sha512_update(isc_sha512_t *context, const uint8_t *data, size_t len) {
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha512_t *)0);
 	REQUIRE(context->ctx != (EVP_MD_CTX *)0);
-	REQUIRE(data != (uint8_t*)0);
+	REQUIRE(data != (isc_uint8_t*)0);
 
 	RUNTIME_CHECK(EVP_DigestUpdate(context->ctx,
 				       (const void *) data, len) == 1);
 }
 
-void isc_sha512_final(uint8_t digest[], isc_sha512_t *context) {
+void isc_sha512_final(isc_uint8_t digest[], isc_sha512_t *context) {
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha512_t *)0);
 	REQUIRE(context->ctx != (EVP_MD_CTX *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0)
+	if (digest != (isc_uint8_t*)0)
 		RUNTIME_CHECK(EVP_DigestFinal(context->ctx,
 					      digest, NULL) == 1);
 	EVP_MD_CTX_free(context->ctx);
@@ -232,7 +230,7 @@ isc_sha384_invalidate(isc_sha384_t *context) {
 }
 
 void
-isc_sha384_update(isc_sha384_t *context, const uint8_t* data, size_t len) {
+isc_sha384_update(isc_sha384_t *context, const isc_uint8_t* data, size_t len) {
 	if (len == 0U) {
 		/* Calling with no data is valid - we do nothing */
 		return;
@@ -241,27 +239,27 @@ isc_sha384_update(isc_sha384_t *context, const uint8_t* data, size_t len) {
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha512_t *)0);
 	REQUIRE(context->ctx != (EVP_MD_CTX *)0);
-	REQUIRE(data != (uint8_t*)0);
+	REQUIRE(data != (isc_uint8_t*)0);
 
 	RUNTIME_CHECK(EVP_DigestUpdate(context->ctx,
 				       (const void *) data, len) == 1);
 }
 
 void
-isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
+isc_sha384_final(isc_uint8_t digest[], isc_sha384_t *context) {
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha384_t *)0);
 	REQUIRE(context->ctx != (EVP_MD_CTX *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0)
+	if (digest != (isc_uint8_t*)0)
 		RUNTIME_CHECK(EVP_DigestFinal(context->ctx,
 					      digest, NULL) == 1);
 	EVP_MD_CTX_free(context->ctx);
 	context->ctx = NULL;
 }
 
-#elif PKCS11CRYPTO
+#elif HAVE_PKCS11
 
 void
 isc_sha224_init(isc_sha224_t *context) {
@@ -271,8 +269,8 @@ isc_sha224_init(isc_sha224_t *context) {
 	if (context == (isc_sha224_t *)0) {
 		return;
 	}
-	RUNTIME_CHECK(pk11_get_session(context, OP_DIGEST, true, false,
-				       false, NULL, 0) == ISC_R_SUCCESS);
+	RUNTIME_CHECK(pk11_get_session(context, OP_DIGEST, ISC_TRUE, ISC_FALSE,
+				       ISC_FALSE, NULL, 0) == ISC_R_SUCCESS);
 	PK11_FATALCHECK(pkcs_C_DigestInit, (context->session, &mech));
 }
 
@@ -289,7 +287,7 @@ isc_sha224_invalidate(isc_sha224_t *context) {
 }
 
 void
-isc_sha224_update(isc_sha224_t *context, const uint8_t* data, size_t len) {
+isc_sha224_update(isc_sha224_t *context, const isc_uint8_t* data, size_t len) {
 	CK_RV rv;
 	CK_BYTE_PTR pPart;
 
@@ -299,7 +297,7 @@ isc_sha224_update(isc_sha224_t *context, const uint8_t* data, size_t len) {
 	}
 
 	/* Sanity check: */
-	REQUIRE(context != (isc_sha224_t *)0 && data != (uint8_t*)0);
+	REQUIRE(context != (isc_sha224_t *)0 && data != (isc_uint8_t*)0);
 
 	DE_CONST(data, pPart);
 	PK11_FATALCHECK(pkcs_C_DigestUpdate,
@@ -307,7 +305,7 @@ isc_sha224_update(isc_sha224_t *context, const uint8_t* data, size_t len) {
 }
 
 void
-isc_sha224_final(uint8_t digest[], isc_sha224_t *context) {
+isc_sha224_final(isc_uint8_t digest[], isc_sha224_t *context) {
 	CK_RV rv;
 	CK_ULONG len = ISC_SHA224_DIGESTLENGTH;
 
@@ -315,7 +313,7 @@ isc_sha224_final(uint8_t digest[], isc_sha224_t *context) {
 	REQUIRE(context != (isc_sha224_t *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0) {
+	if (digest != (isc_uint8_t*)0) {
 		PK11_FATALCHECK(pkcs_C_DigestFinal,
 				(context->session,
 				 (CK_BYTE_PTR) digest,
@@ -337,8 +335,8 @@ isc_sha256_init(isc_sha256_t *context) {
 	if (context == (isc_sha256_t *)0) {
 		return;
 	}
-	RUNTIME_CHECK(pk11_get_session(context, OP_DIGEST, true, false,
-				       false, NULL, 0) == ISC_R_SUCCESS);
+	RUNTIME_CHECK(pk11_get_session(context, OP_DIGEST, ISC_TRUE, ISC_FALSE,
+				       ISC_FALSE, NULL, 0) == ISC_R_SUCCESS);
 	PK11_FATALCHECK(pkcs_C_DigestInit, (context->session, &mech));
 }
 
@@ -355,7 +353,7 @@ isc_sha256_invalidate(isc_sha256_t *context) {
 }
 
 void
-isc_sha256_update(isc_sha256_t *context, const uint8_t* data, size_t len) {
+isc_sha256_update(isc_sha256_t *context, const isc_uint8_t* data, size_t len) {
 	CK_RV rv;
 	CK_BYTE_PTR pPart;
 
@@ -365,7 +363,7 @@ isc_sha256_update(isc_sha256_t *context, const uint8_t* data, size_t len) {
 	}
 
 	/* Sanity check: */
-	REQUIRE(context != (isc_sha256_t *)0 && data != (uint8_t*)0);
+	REQUIRE(context != (isc_sha256_t *)0 && data != (isc_uint8_t*)0);
 
 	DE_CONST(data, pPart);
 	PK11_FATALCHECK(pkcs_C_DigestUpdate,
@@ -373,7 +371,7 @@ isc_sha256_update(isc_sha256_t *context, const uint8_t* data, size_t len) {
 }
 
 void
-isc_sha256_final(uint8_t digest[], isc_sha256_t *context) {
+isc_sha256_final(isc_uint8_t digest[], isc_sha256_t *context) {
 	CK_RV rv;
 	CK_ULONG len = ISC_SHA256_DIGESTLENGTH;
 
@@ -381,7 +379,7 @@ isc_sha256_final(uint8_t digest[], isc_sha256_t *context) {
 	REQUIRE(context != (isc_sha256_t *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0) {
+	if (digest != (isc_uint8_t*)0) {
 		PK11_FATALCHECK(pkcs_C_DigestFinal,
 				(context->session,
 				 (CK_BYTE_PTR) digest,
@@ -403,8 +401,8 @@ isc_sha512_init(isc_sha512_t *context) {
 	if (context == (isc_sha512_t *)0) {
 		return;
 	}
-	RUNTIME_CHECK(pk11_get_session(context, OP_DIGEST, true, false,
-				       false, NULL, 0) == ISC_R_SUCCESS);
+	RUNTIME_CHECK(pk11_get_session(context, OP_DIGEST, ISC_TRUE, ISC_FALSE,
+				       ISC_FALSE, NULL, 0) == ISC_R_SUCCESS);
 	PK11_FATALCHECK(pkcs_C_DigestInit, (context->session, &mech));
 }
 
@@ -421,7 +419,7 @@ isc_sha512_invalidate(isc_sha512_t *context) {
 }
 
 void
-isc_sha512_update(isc_sha512_t *context, const uint8_t* data, size_t len) {
+isc_sha512_update(isc_sha512_t *context, const isc_uint8_t* data, size_t len) {
 	CK_RV rv;
 	CK_BYTE_PTR pPart;
 
@@ -431,7 +429,7 @@ isc_sha512_update(isc_sha512_t *context, const uint8_t* data, size_t len) {
 	}
 
 	/* Sanity check: */
-	REQUIRE(context != (isc_sha512_t *)0 && data != (uint8_t*)0);
+	REQUIRE(context != (isc_sha512_t *)0 && data != (isc_uint8_t*)0);
 
 	DE_CONST(data, pPart);
 	PK11_FATALCHECK(pkcs_C_DigestUpdate,
@@ -439,7 +437,7 @@ isc_sha512_update(isc_sha512_t *context, const uint8_t* data, size_t len) {
 }
 
 void
-isc_sha512_final(uint8_t digest[], isc_sha512_t *context) {
+isc_sha512_final(isc_uint8_t digest[], isc_sha512_t *context) {
 	CK_RV rv;
 	CK_ULONG len = ISC_SHA512_DIGESTLENGTH;
 
@@ -447,7 +445,7 @@ isc_sha512_final(uint8_t digest[], isc_sha512_t *context) {
 	REQUIRE(context != (isc_sha512_t *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0) {
+	if (digest != (isc_uint8_t*)0) {
 		PK11_FATALCHECK(pkcs_C_DigestFinal,
 				(context->session,
 				 (CK_BYTE_PTR) digest,
@@ -469,8 +467,8 @@ isc_sha384_init(isc_sha384_t *context) {
 	if (context == (isc_sha384_t *)0) {
 		return;
 	}
-	RUNTIME_CHECK(pk11_get_session(context, OP_DIGEST, true, false,
-				       false, NULL, 0) == ISC_R_SUCCESS);
+	RUNTIME_CHECK(pk11_get_session(context, OP_DIGEST, ISC_TRUE, ISC_FALSE,
+				       ISC_FALSE, NULL, 0) == ISC_R_SUCCESS);
 	PK11_FATALCHECK(pkcs_C_DigestInit, (context->session, &mech));
 }
 
@@ -487,7 +485,7 @@ isc_sha384_invalidate(isc_sha384_t *context) {
 }
 
 void
-isc_sha384_update(isc_sha384_t *context, const uint8_t* data, size_t len) {
+isc_sha384_update(isc_sha384_t *context, const isc_uint8_t* data, size_t len) {
 	CK_RV rv;
 	CK_BYTE_PTR pPart;
 
@@ -497,7 +495,7 @@ isc_sha384_update(isc_sha384_t *context, const uint8_t* data, size_t len) {
 	}
 
 	/* Sanity check: */
-	REQUIRE(context != (isc_sha384_t *)0 && data != (uint8_t*)0);
+	REQUIRE(context != (isc_sha384_t *)0 && data != (isc_uint8_t*)0);
 
 	DE_CONST(data, pPart);
 	PK11_FATALCHECK(pkcs_C_DigestUpdate,
@@ -505,7 +503,7 @@ isc_sha384_update(isc_sha384_t *context, const uint8_t* data, size_t len) {
 }
 
 void
-isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
+isc_sha384_final(isc_uint8_t digest[], isc_sha384_t *context) {
 	CK_RV rv;
 	CK_ULONG len = ISC_SHA384_DIGESTLENGTH;
 
@@ -513,7 +511,7 @@ isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
 	REQUIRE(context != (isc_sha384_t *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0) {
+	if (digest != (isc_uint8_t*)0) {
 		PK11_FATALCHECK(pkcs_C_DigestFinal,
 				(context->session,
 				 (CK_BYTE_PTR) digest,
@@ -599,13 +597,13 @@ isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
 /*** ENDIAN REVERSAL MACROS *******************************************/
 #if BYTE_ORDER == LITTLE_ENDIAN
 #define REVERSE32(w,x)	{ \
-	uint32_t tmp = (w); \
+	isc_uint32_t tmp = (w); \
 	tmp = (tmp >> 16) | (tmp << 16); \
 	(x) = ((tmp & 0xff00ff00UL) >> 8) | ((tmp & 0x00ff00ffUL) << 8); \
 }
 #ifdef WIN32
 #define REVERSE64(w,x)	{ \
-	uint64_t tmp = (w); \
+	isc_uint64_t tmp = (w); \
 	tmp = (tmp >> 32) | (tmp << 32); \
 	tmp = ((tmp & 0xff00ff00ff00ff00UL) >> 8) | \
 	      ((tmp & 0x00ff00ff00ff00ffUL) << 8); \
@@ -614,7 +612,7 @@ isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
 }
 #else
 #define REVERSE64(w,x)	{ \
-	uint64_t tmp = (w); \
+	isc_uint64_t tmp = (w); \
 	tmp = (tmp >> 32) | (tmp << 32); \
 	tmp = ((tmp & 0xff00ff00ff00ff00ULL) >> 8) | \
 	      ((tmp & 0x00ff00ff00ff00ffULL) << 8); \
@@ -630,7 +628,7 @@ isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
  * 64-bit words):
  */
 #define ADDINC128(w,n)	{ \
-	(w)[0] += (uint64_t)(n); \
+	(w)[0] += (isc_uint64_t)(n); \
 	if ((w)[0] < (n)) { \
 		(w)[1]++; \
 	} \
@@ -674,13 +672,13 @@ isc_sha384_final(uint8_t digest[], isc_sha384_t *context) {
  * only.
  */
 void isc_sha512_last(isc_sha512_t *);
-void isc_sha256_transform(isc_sha256_t *, const uint32_t*);
-void isc_sha512_transform(isc_sha512_t *, const uint64_t*);
+void isc_sha256_transform(isc_sha256_t *, const isc_uint32_t*);
+void isc_sha512_transform(isc_sha512_t *, const isc_uint64_t*);
 
 
 /*** SHA-XYZ INITIAL HASH VALUES AND CONSTANTS ************************/
 /* Hash constant words K for SHA-224 and SHA-256: */
-static const uint32_t K256[64] = {
+static const isc_uint32_t K256[64] = {
 	0x428a2f98UL, 0x71374491UL, 0xb5c0fbcfUL, 0xe9b5dba5UL,
 	0x3956c25bUL, 0x59f111f1UL, 0x923f82a4UL, 0xab1c5ed5UL,
 	0xd807aa98UL, 0x12835b01UL, 0x243185beUL, 0x550c7dc3UL,
@@ -700,7 +698,7 @@ static const uint32_t K256[64] = {
 };
 
 /* Initial hash value H for SHA-224: */
-static const uint32_t sha224_initial_hash_value[8] = {
+static const isc_uint32_t sha224_initial_hash_value[8] = {
 	0xc1059ed8UL,
 	0x367cd507UL,
 	0x3070dd17UL,
@@ -712,7 +710,7 @@ static const uint32_t sha224_initial_hash_value[8] = {
 };
 
 /* Initial hash value H for SHA-256: */
-static const uint32_t sha256_initial_hash_value[8] = {
+static const isc_uint32_t sha256_initial_hash_value[8] = {
 	0x6a09e667UL,
 	0xbb67ae85UL,
 	0x3c6ef372UL,
@@ -725,7 +723,7 @@ static const uint32_t sha256_initial_hash_value[8] = {
 
 #ifdef WIN32
 /* Hash constant words K for SHA-384 and SHA-512: */
-static const uint64_t K512[80] = {
+static const isc_uint64_t K512[80] = {
 	0x428a2f98d728ae22UL, 0x7137449123ef65cdUL,
 	0xb5c0fbcfec4d3b2fUL, 0xe9b5dba58189dbbcUL,
 	0x3956c25bf348b538UL, 0x59f111f1b605d019UL,
@@ -769,7 +767,7 @@ static const uint64_t K512[80] = {
 };
 
 /* Initial hash value H for SHA-384: */
-static const uint64_t sha384_initial_hash_value[8] = {
+static const isc_uint64_t sha384_initial_hash_value[8] = {
 	0xcbbb9d5dc1059ed8UL,
 	0x629a292a367cd507UL,
 	0x9159015a3070dd17UL,
@@ -781,7 +779,7 @@ static const uint64_t sha384_initial_hash_value[8] = {
 };
 
 /* Initial hash value H for SHA-512: */
-static const uint64_t sha512_initial_hash_value[8] = {
+static const isc_uint64_t sha512_initial_hash_value[8] = {
 	0x6a09e667f3bcc908U,
 	0xbb67ae8584caa73bUL,
 	0x3c6ef372fe94f82bUL,
@@ -793,7 +791,7 @@ static const uint64_t sha512_initial_hash_value[8] = {
 };
 #else
 /* Hash constant words K for SHA-384 and SHA-512: */
-static const uint64_t K512[80] = {
+static const isc_uint64_t K512[80] = {
 	0x428a2f98d728ae22ULL, 0x7137449123ef65cdULL,
 	0xb5c0fbcfec4d3b2fULL, 0xe9b5dba58189dbbcULL,
 	0x3956c25bf348b538ULL, 0x59f111f1b605d019ULL,
@@ -837,7 +835,7 @@ static const uint64_t K512[80] = {
 };
 
 /* Initial hash value H for SHA-384: */
-static const uint64_t sha384_initial_hash_value[8] = {
+static const isc_uint64_t sha384_initial_hash_value[8] = {
 	0xcbbb9d5dc1059ed8ULL,
 	0x629a292a367cd507ULL,
 	0x9159015a3070dd17ULL,
@@ -849,7 +847,7 @@ static const uint64_t sha384_initial_hash_value[8] = {
 };
 
 /* Initial hash value H for SHA-512: */
-static const uint64_t sha512_initial_hash_value[8] = {
+static const isc_uint64_t sha512_initial_hash_value[8] = {
 	0x6a09e667f3bcc908ULL,
 	0xbb67ae8584caa73bULL,
 	0x3c6ef372fe94f82bULL,
@@ -880,13 +878,13 @@ isc_sha224_invalidate(isc_sha224_t *context) {
 }
 
 void
-isc_sha224_update(isc_sha224_t *context, const uint8_t* data, size_t len) {
+isc_sha224_update(isc_sha224_t *context, const isc_uint8_t* data, size_t len) {
 	isc_sha256_update((isc_sha256_t *)context, data, len);
 }
 
 void
-isc_sha224_final(uint8_t digest[ISC_SHA224_DIGESTLENGTH], isc_sha224_t *context) {
-	uint8_t sha256_digest[ISC_SHA256_DIGESTLENGTH];
+isc_sha224_final(isc_uint8_t digest[], isc_sha224_t *context) {
+	isc_uint8_t sha256_digest[ISC_SHA256_DIGESTLENGTH];
 	isc_sha256_final(sha256_digest, (isc_sha256_t *)context);
 	memmove(digest, sha256_digest, ISC_SHA224_DIGESTLENGTH);
 	isc_safe_memwipe(sha256_digest, sizeof(sha256_digest));
@@ -946,12 +944,12 @@ isc_sha256_invalidate(isc_sha256_t *context) {
 	(h) = T1 + Sigma0_256(a) + Maj((a), (b), (c)); \
 	j++
 
-void isc_sha256_transform(isc_sha256_t *context, const uint32_t* data) {
-	uint32_t	a, b, c, d, e, f, g, h, s0, s1;
-	uint32_t	T1, *W256;
+void isc_sha256_transform(isc_sha256_t *context, const isc_uint32_t* data) {
+	isc_uint32_t	a, b, c, d, e, f, g, h, s0, s1;
+	isc_uint32_t	T1, *W256;
 	int		j;
 
-	W256 = (uint32_t*)context->buffer;
+	W256 = (isc_uint32_t*)context->buffer;
 
 	/* Initialize registers with the prev. intermediate value */
 	a = context->state[0];
@@ -1008,12 +1006,12 @@ void isc_sha256_transform(isc_sha256_t *context, const uint32_t* data) {
 #else /* ISC_SHA2_UNROLL_TRANSFORM */
 
 void
-isc_sha256_transform(isc_sha256_t *context, const uint32_t* data) {
-	uint32_t	a, b, c, d, e, f, g, h, s0, s1;
-	uint32_t	T1, T2, *W256;
+isc_sha256_transform(isc_sha256_t *context, const isc_uint32_t* data) {
+	isc_uint32_t	a, b, c, d, e, f, g, h, s0, s1;
+	isc_uint32_t	T1, T2, *W256;
 	int		j;
 
-	W256 = (uint32_t*)context->buffer;
+	W256 = (isc_uint32_t*)context->buffer;
 
 	/* Initialize registers with the prev. intermediate value */
 	a = context->state[0];
@@ -1092,7 +1090,7 @@ isc_sha256_transform(isc_sha256_t *context, const uint32_t* data) {
 #endif /* ISC_SHA2_UNROLL_TRANSFORM */
 
 void
-isc_sha256_update(isc_sha256_t *context, const uint8_t *data, size_t len) {
+isc_sha256_update(isc_sha256_t *context, const isc_uint8_t *data, size_t len) {
 	unsigned int	freespace, usedspace;
 
 	if (len == 0U) {
@@ -1101,7 +1099,7 @@ isc_sha256_update(isc_sha256_t *context, const uint8_t *data, size_t len) {
 	}
 
 	/* Sanity check: */
-	REQUIRE(context != (isc_sha256_t *)0 && data != (uint8_t*)0);
+	REQUIRE(context != (isc_sha256_t *)0 && data != (isc_uint8_t*)0);
 
 	usedspace = (unsigned int)((context->bitcount >> 3) %
 				   ISC_SHA256_BLOCK_LENGTH);
@@ -1116,7 +1114,7 @@ isc_sha256_update(isc_sha256_t *context, const uint8_t *data, size_t len) {
 			len -= freespace;
 			data += freespace;
 			isc_sha256_transform(context,
-					     (uint32_t*)context->buffer);
+					     (isc_uint32_t*)context->buffer);
 		} else {
 			/* The buffer is not yet full */
 			memmove(&context->buffer[usedspace], data, len);
@@ -1131,7 +1129,7 @@ isc_sha256_update(isc_sha256_t *context, const uint8_t *data, size_t len) {
 	while (len >= ISC_SHA256_BLOCK_LENGTH) {
 		/* Process as many complete blocks as we can */
 		memmove(context->buffer, data, ISC_SHA256_BLOCK_LENGTH);
-		isc_sha256_transform(context, (uint32_t*)context->buffer);
+		isc_sha256_transform(context, (isc_uint32_t*)context->buffer);
 		context->bitcount += ISC_SHA256_BLOCK_LENGTH << 3;
 		len -= ISC_SHA256_BLOCK_LENGTH;
 		data += ISC_SHA256_BLOCK_LENGTH;
@@ -1148,15 +1146,15 @@ isc_sha256_update(isc_sha256_t *context, const uint8_t *data, size_t len) {
 }
 
 void
-isc_sha256_final(uint8_t digest[ISC_SHA256_DIGESTLENGTH], isc_sha256_t *context) {
-	uint32_t	*d = (uint32_t*)digest;
+isc_sha256_final(isc_uint8_t digest[], isc_sha256_t *context) {
+	isc_uint32_t	*d = (isc_uint32_t*)digest;
 	unsigned int	usedspace;
 
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha256_t *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0) {
+	if (digest != (isc_uint8_t*)0) {
 		usedspace = (unsigned int)((context->bitcount >> 3) %
 					   ISC_SHA256_BLOCK_LENGTH);
 #if BYTE_ORDER == LITTLE_ENDIAN
@@ -1179,7 +1177,7 @@ isc_sha256_final(uint8_t digest[ISC_SHA256_DIGESTLENGTH], isc_sha256_t *context)
 				}
 				/* Do second-to-last transform: */
 				isc_sha256_transform(context,
-					       (uint32_t*)context->buffer);
+					       (isc_uint32_t*)context->buffer);
 
 				/* And set-up for the last transform: */
 				memset(context->buffer, 0,
@@ -1193,10 +1191,10 @@ isc_sha256_final(uint8_t digest[ISC_SHA256_DIGESTLENGTH], isc_sha256_t *context)
 			*context->buffer = 0x80;
 		}
 		/* Set the bit count: */
-		*(uint64_t*)&context->buffer[ISC_SHA256_SHORT_BLOCK_LENGTH] = context->bitcount;
+		*(isc_uint64_t*)&context->buffer[ISC_SHA256_SHORT_BLOCK_LENGTH] = context->bitcount;
 
 		/* Final transform: */
-		isc_sha256_transform(context, (uint32_t*)context->buffer);
+		isc_sha256_transform(context, (isc_uint32_t*)context->buffer);
 
 #if BYTE_ORDER == LITTLE_ENDIAN
 		{
@@ -1271,9 +1269,9 @@ isc_sha512_invalidate(isc_sha512_t *context) {
 	(h) = T1 + Sigma0_512(a) + Maj((a), (b), (c)); \
 	j++
 
-void isc_sha512_transform(isc_sha512_t *context, const uint64_t* data) {
-	uint64_t	a, b, c, d, e, f, g, h, s0, s1;
-	uint64_t	T1, *W512 = (uint64_t*)context->buffer;
+void isc_sha512_transform(isc_sha512_t *context, const isc_uint64_t* data) {
+	isc_uint64_t	a, b, c, d, e, f, g, h, s0, s1;
+	isc_uint64_t	T1, *W512 = (isc_uint64_t*)context->buffer;
 	int		j;
 
 	/* Initialize registers with the prev. intermediate value */
@@ -1330,9 +1328,9 @@ void isc_sha512_transform(isc_sha512_t *context, const uint64_t* data) {
 #else /* ISC_SHA2_UNROLL_TRANSFORM */
 
 void
-isc_sha512_transform(isc_sha512_t *context, const uint64_t* data) {
-	uint64_t	a, b, c, d, e, f, g, h, s0, s1;
-	uint64_t	T1, T2, *W512 = (uint64_t*)context->buffer;
+isc_sha512_transform(isc_sha512_t *context, const isc_uint64_t* data) {
+	isc_uint64_t	a, b, c, d, e, f, g, h, s0, s1;
+	isc_uint64_t	T1, T2, *W512 = (isc_uint64_t*)context->buffer;
 	int		j;
 
 	/* Initialize registers with the prev. intermediate value */
@@ -1411,7 +1409,7 @@ isc_sha512_transform(isc_sha512_t *context, const uint64_t* data) {
 
 #endif /* ISC_SHA2_UNROLL_TRANSFORM */
 
-void isc_sha512_update(isc_sha512_t *context, const uint8_t *data, size_t len) {
+void isc_sha512_update(isc_sha512_t *context, const isc_uint8_t *data, size_t len) {
 	unsigned int	freespace, usedspace;
 
 	if (len == 0U) {
@@ -1420,7 +1418,7 @@ void isc_sha512_update(isc_sha512_t *context, const uint8_t *data, size_t len) {
 	}
 
 	/* Sanity check: */
-	REQUIRE(context != (isc_sha512_t *)0 && data != (uint8_t*)0);
+	REQUIRE(context != (isc_sha512_t *)0 && data != (isc_uint8_t*)0);
 
 	usedspace = (unsigned int)((context->bitcount[0] >> 3) %
 				   ISC_SHA512_BLOCK_LENGTH);
@@ -1435,7 +1433,7 @@ void isc_sha512_update(isc_sha512_t *context, const uint8_t *data, size_t len) {
 			len -= freespace;
 			data += freespace;
 			isc_sha512_transform(context,
-					     (uint64_t*)context->buffer);
+					     (isc_uint64_t*)context->buffer);
 		} else {
 			/* The buffer is not yet full */
 			memmove(&context->buffer[usedspace], data, len);
@@ -1450,7 +1448,7 @@ void isc_sha512_update(isc_sha512_t *context, const uint8_t *data, size_t len) {
 	while (len >= ISC_SHA512_BLOCK_LENGTH) {
 		/* Process as many complete blocks as we can */
 		memmove(context->buffer, data, ISC_SHA512_BLOCK_LENGTH);
-		isc_sha512_transform(context, (uint64_t*)context->buffer);
+		isc_sha512_transform(context, (isc_uint64_t*)context->buffer);
 		ADDINC128(context->bitcount, ISC_SHA512_BLOCK_LENGTH << 3);
 		len -= ISC_SHA512_BLOCK_LENGTH;
 		data += ISC_SHA512_BLOCK_LENGTH;
@@ -1491,7 +1489,7 @@ void isc_sha512_last(isc_sha512_t *context) {
 			}
 			/* Do second-to-last transform: */
 			isc_sha512_transform(context,
-					    (uint64_t*)context->buffer);
+					    (isc_uint64_t*)context->buffer);
 
 			/* And set-up for the last transform: */
 			memset(context->buffer, 0, ISC_SHA512_BLOCK_LENGTH - 2);
@@ -1504,21 +1502,21 @@ void isc_sha512_last(isc_sha512_t *context) {
 		*context->buffer = 0x80;
 	}
 	/* Store the length of input data (in bits): */
-	*(uint64_t*)&context->buffer[ISC_SHA512_SHORT_BLOCK_LENGTH] = context->bitcount[1];
-	*(uint64_t*)&context->buffer[ISC_SHA512_SHORT_BLOCK_LENGTH+8] = context->bitcount[0];
+	*(isc_uint64_t*)&context->buffer[ISC_SHA512_SHORT_BLOCK_LENGTH] = context->bitcount[1];
+	*(isc_uint64_t*)&context->buffer[ISC_SHA512_SHORT_BLOCK_LENGTH+8] = context->bitcount[0];
 
 	/* Final transform: */
-	isc_sha512_transform(context, (uint64_t*)context->buffer);
+	isc_sha512_transform(context, (isc_uint64_t*)context->buffer);
 }
 
-void isc_sha512_final(uint8_t digest[ISC_SHA512_DIGESTLENGTH], isc_sha512_t *context) {
-	uint64_t	*d = (uint64_t*)digest;
+void isc_sha512_final(isc_uint8_t digest[], isc_sha512_t *context) {
+	isc_uint64_t	*d = (isc_uint64_t*)digest;
 
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha512_t *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0) {
+	if (digest != (isc_uint8_t*)0) {
 		isc_sha512_last(context);
 
 		/* Save the hash data for output: */
@@ -1559,19 +1557,19 @@ isc_sha384_invalidate(isc_sha384_t *context) {
 }
 
 void
-isc_sha384_update(isc_sha384_t *context, const uint8_t* data, size_t len) {
+isc_sha384_update(isc_sha384_t *context, const isc_uint8_t* data, size_t len) {
 	isc_sha512_update((isc_sha512_t *)context, data, len);
 }
 
 void
-isc_sha384_final(uint8_t digest[ISC_SHA384_DIGESTLENGTH], isc_sha384_t *context) {
-	uint64_t	*d = (uint64_t*)digest;
+isc_sha384_final(isc_uint8_t digest[], isc_sha384_t *context) {
+	isc_uint64_t	*d = (isc_uint64_t*)digest;
 
 	/* Sanity check: */
 	REQUIRE(context != (isc_sha384_t *)0);
 
 	/* If no digest buffer is passed, we don't bother doing this: */
-	if (digest != (uint8_t*)0) {
+	if (digest != (isc_uint8_t*)0) {
 		isc_sha512_last((isc_sha512_t *)context);
 
 		/* Save the hash data for output: */
@@ -1601,8 +1599,8 @@ isc_sha384_final(uint8_t digest[ISC_SHA384_DIGESTLENGTH], isc_sha384_t *context)
 static const char *sha2_hex_digits = "0123456789abcdef";
 
 char *
-isc_sha224_end(isc_sha224_t *context, char buffer[ISC_SHA224_DIGESTSTRINGLENGTH]) {
-	uint8_t	digest[ISC_SHA224_DIGESTLENGTH], *d = digest;
+isc_sha224_end(isc_sha224_t *context, char buffer[]) {
+	isc_uint8_t	digest[ISC_SHA224_DIGESTLENGTH], *d = digest;
 	unsigned int	i;
 
 	/* Sanity check: */
@@ -1620,7 +1618,7 @@ isc_sha224_end(isc_sha224_t *context, char buffer[ISC_SHA224_DIGESTSTRINGLENGTH]
 	} else {
 #if defined(ISC_PLATFORM_OPENSSLHASH) && !defined(LIBRESSL_VERSION_NUMBER)
 		EVP_MD_CTX_reset(context->ctx);
-#elif PKCS11CRYPTO
+#elif HAVE_PKCS11
 		pk11_return_session(context);
 #else
 		isc_safe_memwipe(context, sizeof(*context));
@@ -1631,7 +1629,7 @@ isc_sha224_end(isc_sha224_t *context, char buffer[ISC_SHA224_DIGESTSTRINGLENGTH]
 }
 
 char *
-isc_sha224_data(const uint8_t *data, size_t len,
+isc_sha224_data(const isc_uint8_t *data, size_t len,
 		char digest[ISC_SHA224_DIGESTSTRINGLENGTH])
 {
 	isc_sha224_t context;
@@ -1642,8 +1640,8 @@ isc_sha224_data(const uint8_t *data, size_t len,
 }
 
 char *
-isc_sha256_end(isc_sha256_t *context, char buffer[ISC_SHA256_DIGESTSTRINGLENGTH]) {
-	uint8_t	digest[ISC_SHA256_DIGESTLENGTH], *d = digest;
+isc_sha256_end(isc_sha256_t *context, char buffer[]) {
+	isc_uint8_t	digest[ISC_SHA256_DIGESTLENGTH], *d = digest;
 	unsigned int	i;
 
 	/* Sanity check: */
@@ -1661,7 +1659,7 @@ isc_sha256_end(isc_sha256_t *context, char buffer[ISC_SHA256_DIGESTSTRINGLENGTH]
 	} else {
 #if defined(ISC_PLATFORM_OPENSSLHASH) && !defined(LIBRESSL_VERSION_NUMBER)
 		EVP_MD_CTX_reset(context->ctx);
-#elif PKCS11CRYPTO
+#elif HAVE_PKCS11
 		pk11_return_session(context);
 #else
 		isc_safe_memwipe(context, sizeof(*context));
@@ -1672,7 +1670,7 @@ isc_sha256_end(isc_sha256_t *context, char buffer[ISC_SHA256_DIGESTSTRINGLENGTH]
 }
 
 char *
-isc_sha256_data(const uint8_t* data, size_t len,
+isc_sha256_data(const isc_uint8_t* data, size_t len,
 		char digest[ISC_SHA256_DIGESTSTRINGLENGTH])
 {
 	isc_sha256_t context;
@@ -1683,8 +1681,8 @@ isc_sha256_data(const uint8_t* data, size_t len,
 }
 
 char *
-isc_sha512_end(isc_sha512_t *context, char buffer[ISC_SHA512_DIGESTSTRINGLENGTH]) {
-	uint8_t	digest[ISC_SHA512_DIGESTLENGTH], *d = digest;
+isc_sha512_end(isc_sha512_t *context, char buffer[]) {
+	isc_uint8_t	digest[ISC_SHA512_DIGESTLENGTH], *d = digest;
 	unsigned int	i;
 
 	/* Sanity check: */
@@ -1702,7 +1700,7 @@ isc_sha512_end(isc_sha512_t *context, char buffer[ISC_SHA512_DIGESTSTRINGLENGTH]
 	} else {
 #if defined(ISC_PLATFORM_OPENSSLHASH) && !defined(LIBRESSL_VERSION_NUMBER)
 		EVP_MD_CTX_reset(context->ctx);
-#elif PKCS11CRYPTO
+#elif HAVE_PKCS11
 		pk11_return_session(context);
 #else
 		isc_safe_memwipe(context, sizeof(*context));
@@ -1713,7 +1711,7 @@ isc_sha512_end(isc_sha512_t *context, char buffer[ISC_SHA512_DIGESTSTRINGLENGTH]
 }
 
 char *
-isc_sha512_data(const uint8_t *data, size_t len,
+isc_sha512_data(const isc_uint8_t *data, size_t len,
 		char digest[ISC_SHA512_DIGESTSTRINGLENGTH])
 {
 	isc_sha512_t 	context;
@@ -1724,8 +1722,8 @@ isc_sha512_data(const uint8_t *data, size_t len,
 }
 
 char *
-isc_sha384_end(isc_sha384_t *context, char buffer[ISC_SHA384_DIGESTSTRINGLENGTH]) {
-	uint8_t	digest[ISC_SHA384_DIGESTLENGTH], *d = digest;
+isc_sha384_end(isc_sha384_t *context, char buffer[]) {
+	isc_uint8_t	digest[ISC_SHA384_DIGESTLENGTH], *d = digest;
 	unsigned int	i;
 
 	/* Sanity check: */
@@ -1743,7 +1741,7 @@ isc_sha384_end(isc_sha384_t *context, char buffer[ISC_SHA384_DIGESTSTRINGLENGTH]
 	} else {
 #if defined(ISC_PLATFORM_OPENSSLHASH) && !defined(LIBRESSL_VERSION_NUMBER)
 		EVP_MD_CTX_reset(context->ctx);
-#elif PKCS11CRYPTO
+#elif HAVE_PKCS11
 		pk11_return_session(context);
 #else
 		isc_safe_memwipe(context, sizeof(*context));
@@ -1754,7 +1752,7 @@ isc_sha384_end(isc_sha384_t *context, char buffer[ISC_SHA384_DIGESTSTRINGLENGTH]
 }
 
 char *
-isc_sha384_data(const uint8_t *data, size_t len,
+isc_sha384_data(const isc_uint8_t *data, size_t len,
 		char digest[ISC_SHA384_DIGESTSTRINGLENGTH])
 {
 	isc_sha384_t context;
