@@ -9,6 +9,7 @@
  * information regarding copyright ownership.
  */
 
+#include <config.h>
 
 /*! \file
  * \brief
@@ -17,8 +18,6 @@
  * and 19.16.
  */
 
-#include <inttypes.h>
-
 #include <sys/param.h>
 #include <sys/sysctl.h>
 
