@@ -56,9 +56,7 @@ gettemp(char *path, isc_boolean_t binary, int *doopen) {
 	trv++;
 	/* extra X's get set to 0's */
 	while (*--trv == 'X') {
-		isc_uint32_t which;
-
-		isc_random_get(&which);
+		isc_uint32_t which = isc_random();
 		*trv = alphnum[which % (sizeof(alphnum) - 1)];
 	}
 	/*
