@@ -11,10 +11,6 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-#include <stdbool.h>
-#include <stdlib.h>
-
 #include <isc/mem.h>
 #include <isc/print.h>
 #include <isc/string.h>		/* Required for HP/UX (and others?) */
@@ -28,31 +24,13 @@
 #include <dns/fixedname.h>
 #include <dns/log.h>
 
-#define LOOP_MAGIC ISC_MAGIC('L','O','O','P')
-
-#if defined(HAVE_GEOIP2)
-static const char *geoip_dbnames[] = {
-	"country",
-	"city",
-	"asnum",
-	"isp",
-	"domain",
-	NULL,
-};
-#elif defined(HAVE_GEOIP)
-static const char *geoip_dbnames[] = {
-	"country",
-	"city",
-	"region",
-	"asnum",
-	"isp",
-	"domain",
-	"netspeed",
-	"org",
-	NULL,
-};
+#ifdef HAVE_GEOIP
+#include <stdlib.h>
+#include <math.h>
 #endif /* HAVE_GEOIP */
 
+#define LOOP_MAGIC ISC_MAGIC('L','O','O','P')
+
 isc_result_t
 cfg_aclconfctx_create(isc_mem_t *mctx, cfg_aclconfctx_t **ret) {
 	isc_result_t result;
@@ -73,7 +51,7 @@ cfg_aclconfctx_create(isc_mem_t *mctx, cfg_aclconfctx_t **ret) {
 	isc_mem_attach(mctx, &actx->mctx);
 	ISC_LIST_INIT(actx->named_acl_cache);
 
-#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+#ifdef HAVE_GEOIP
 	actx->geoip = NULL;
 #endif
 
@@ -137,8 +115,7 @@ get_acl_def(const cfg_obj_t *cctx, const char *name, const cfg_obj_t **ret) {
 	     elt != NULL;
 	     elt = cfg_list_next(elt)) {
 		const cfg_obj_t *acl = cfg_listelt_value(elt);
-		const char *aclname =
-			cfg_obj_asstring(cfg_tuple_get(acl, "name"));
+		const char *aclname = cfg_obj_asstring(cfg_tuple_get(acl, "name"));
 		if (strcasecmp(aclname, name) == 0) {
 			if (ret != NULL) {
 				*ret = cfg_tuple_get(acl, "value");
@@ -241,16 +218,16 @@ convert_keyname(const cfg_obj_t *keyobj, isc_log_t *lctx, isc_mem_t *mctx,
 static isc_result_t
 count_acl_elements(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 		   isc_log_t *lctx, cfg_aclconfctx_t *ctx, isc_mem_t *mctx,
-		   uint32_t *count, bool *has_negative)
+		   isc_uint32_t *count, isc_boolean_t *has_negative)
 {
 	const cfg_listelt_t *elt;
 	isc_result_t result;
-	uint32_t n = 0;
+	isc_uint32_t n = 0;
 
 	REQUIRE(count != NULL);
 
 	if (has_negative != NULL)
-		*has_negative = false;
+		*has_negative = ISC_FALSE;
 
 	for (elt = cfg_list_first(caml);
 	     elt != NULL;
@@ -264,15 +241,15 @@ count_acl_elements(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 			if (! cfg_obj_isvoid(negated)) {
 				ce = negated;
 				if (has_negative != NULL)
-					*has_negative = true;
+					*has_negative = ISC_TRUE;
 			}
 		}
 
 		if (cfg_obj_istype(ce, &cfg_type_keyref)) {
 			n++;
 		} else if (cfg_obj_islist(ce)) {
-			bool negative;
-			uint32_t sub;
+			isc_boolean_t negative;
+			isc_uint32_t sub;
 			result = count_acl_elements(ce, cctx, lctx, ctx, mctx,
 						    &sub, &negative);
 			if (result != ISC_R_SUCCESS)
@@ -280,12 +257,12 @@ count_acl_elements(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 			n += sub;
 			if (negative)
 				n++;
-#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+#ifdef HAVE_GEOIP
 		} else if (cfg_obj_istuple(ce) &&
 			   cfg_obj_isvoid(cfg_tuple_get(ce, "negated")))
 		{
 			n++;
-#endif /* HAVE_GEOIP || HAVE_GEOIP2 */
+#endif /* HAVE_GEOIP */
 		} else if (cfg_obj_isstring(ce)) {
 			const char *name = cfg_obj_asstring(ce);
 			if (strcasecmp(name, "localhost") == 0 ||
@@ -317,344 +294,7 @@ count_acl_elements(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 	return (ISC_R_SUCCESS);
 }
 
-#if defined(HAVE_GEOIP2)
-static dns_geoip_subtype_t
-get_subtype(const cfg_obj_t *obj, isc_log_t *lctx,
-	    dns_geoip_subtype_t subtype, const char *dbname)
-{
-	if (dbname == NULL) {
-		return (subtype);
-	}
-
-	switch (subtype) {
-	case dns_geoip_countrycode:
-		if (strcasecmp(dbname, "city") == 0) {
-			return (dns_geoip_city_countrycode);
-		} else if (strcasecmp(dbname, "country") == 0) {
-			return (dns_geoip_country_code);
-		}
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "invalid database specified for "
-			    "country search: ignored");
-		return (subtype);
-	case dns_geoip_countryname:
-		if (strcasecmp(dbname, "city") == 0) {
-			return (dns_geoip_city_countryname);
-		} else if (strcasecmp(dbname, "country") == 0) {
-			return (dns_geoip_country_name);
-		}
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "invalid database specified for "
-			    "country search: ignored");
-		return (subtype);
-	case dns_geoip_continentcode:
-		if (strcasecmp(dbname, "city") == 0) {
-			return (dns_geoip_city_continentcode);
-		} else if (strcasecmp(dbname, "country") == 0) {
-			return (dns_geoip_country_continentcode);
-		}
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "invalid database specified for "
-			    "continent search: ignored");
-		return (subtype);
-	case dns_geoip_continent:
-		if (strcasecmp(dbname, "city") == 0) {
-			return (dns_geoip_city_continent);
-		} else if (strcasecmp(dbname, "country") == 0) {
-			return (dns_geoip_country_continent);
-		}
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "invalid database specified for "
-			    "continent search: ignored");
-		return (subtype);
-	case dns_geoip_region:
-		if (strcasecmp(dbname, "city") == 0) {
-			return (dns_geoip_city_region);
-		}
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "invalid database specified for "
-			    "region/subdivision search: ignored");
-		return (subtype);
-	case dns_geoip_regionname:
-		if (strcasecmp(dbname, "city") == 0) {
-			return (dns_geoip_city_regionname);
-		}
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "invalid database specified for "
-			    "region/subdivision search: ignored");
-		return (subtype);
-
-	/*
-	 * Log a warning if the wrong database was specified
-	 * on an unambiguous query
-	 */
-	case dns_geoip_city_name:
-	case dns_geoip_city_postalcode:
-	case dns_geoip_city_metrocode:
-	case dns_geoip_city_areacode:
-	case dns_geoip_city_timezonecode:
-		if (strcasecmp(dbname, "city") != 0) {
-			cfg_obj_log(obj, lctx, ISC_LOG_WARNING,
-				    "invalid database specified for "
-				    "a 'city'-only search type: ignoring");
-		}
-		return (subtype);
-	case dns_geoip_isp_name:
-		if (strcasecmp(dbname, "isp") != 0) {
-			cfg_obj_log(obj, lctx, ISC_LOG_WARNING,
-				    "invalid database specified for "
-				    "an 'isp' search: ignoring");
-		}
-		return (subtype);
-	case dns_geoip_org_name:
-		if (strcasecmp(dbname, "org") != 0) {
-			cfg_obj_log(obj, lctx, ISC_LOG_WARNING,
-				    "invalid database specified for "
-				    "an 'org' search: ignoring");
-		}
-		return (subtype);
-	case dns_geoip_as_asnum:
-		if (strcasecmp(dbname, "asnum") != 0) {
-			cfg_obj_log(obj, lctx, ISC_LOG_WARNING,
-				    "invalid database specified for "
-				    "an 'asnum' search: ignoring");
-		}
-		return (subtype);
-	case dns_geoip_domain_name:
-		if (strcasecmp(dbname, "domain") != 0) {
-			cfg_obj_log(obj, lctx, ISC_LOG_WARNING,
-				    "invalid database specified for "
-				    "a 'domain' search: ignoring");
-		}
-		return (subtype);
-	case dns_geoip_netspeed_id:
-		if (strcasecmp(dbname, "netspeed") != 0) {
-			cfg_obj_log(obj, lctx, ISC_LOG_WARNING,
-				    "invalid database specified for "
-				    "a 'netspeed' search: ignoring");
-		}
-		return (subtype);
-	default:
-		INSIST(0);
-		ISC_UNREACHABLE();
-	}
-}
-
-static bool
-geoip_can_answer(dns_aclelement_t *elt, cfg_aclconfctx_t *ctx) {
-	if (ctx->geoip == NULL) {
-		return (true);
-	}
-
-	switch (elt->geoip_elem.subtype) {
-	case dns_geoip_countrycode:
-	case dns_geoip_countryname:
-	case dns_geoip_continentcode:
-	case dns_geoip_continent:
-		if (ctx->geoip->country != NULL ||
-		    ctx->geoip->city != NULL)
-		{
-			return (true);
-		}
-		break;
-	case dns_geoip_country_code:
-	case dns_geoip_country_name:
-	case dns_geoip_country_continentcode:
-	case dns_geoip_country_continent:
-		if (ctx->geoip->country != NULL) {
-			return (true);
-		}
-	       /* city db can answer these too, so: */
-	       /* FALLTHROUGH */
-	case dns_geoip_region:
-	case dns_geoip_regionname:
-	case dns_geoip_city_countrycode:
-	case dns_geoip_city_countryname:
-	case dns_geoip_city_region:
-	case dns_geoip_city_regionname:
-	case dns_geoip_city_name:
-	case dns_geoip_city_postalcode:
-	case dns_geoip_city_metrocode:
-	case dns_geoip_city_areacode:
-	case dns_geoip_city_continentcode:
-	case dns_geoip_city_continent:
-	case dns_geoip_city_timezonecode:
-		if (ctx->geoip->city != NULL) {
-			return (true);
-		}
-		break;
-	case dns_geoip_isp_name:
-		if (ctx->geoip->isp != NULL) {
-			return (true);
-		}
-		break;
-	case dns_geoip_as_asnum:
-	case dns_geoip_org_name:
-		if (ctx->geoip->as != NULL) {
-			return (true);
-		}
-		break;
-	case dns_geoip_domain_name:
-		if (ctx->geoip->domain != NULL) {
-			return (true);
-		}
-		break;
-	default:
-		break;
-	}
-
-	return (false);
-}
-
-static isc_result_t
-parse_geoip_element(const cfg_obj_t *obj, isc_log_t *lctx,
-		    cfg_aclconfctx_t *ctx, dns_aclelement_t *dep)
-{
-	const cfg_obj_t *ge;
-	const char *dbname = NULL;
-	const char *stype = NULL, *search = NULL;
-	dns_geoip_subtype_t subtype;
-	dns_aclelement_t de;
-	size_t len;
-
-	REQUIRE(dep != NULL);
-
-	de = *dep;
-
-	ge = cfg_tuple_get(obj, "db");
-	if (!cfg_obj_isvoid(ge)) {
-		int i;
-
-		dbname = cfg_obj_asstring(ge);
-
-		for (i = 0; geoip_dbnames[i] != NULL; i++) {
-			if (strcasecmp(dbname, geoip_dbnames[i]) == 0) {
-				break;
-			}
-		}
-		if (geoip_dbnames[i] == NULL) {
-			cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-				    "database '%s' is not defined for GeoIP2",
-				    dbname);
-			return (ISC_R_UNEXPECTED);
-		}
-	}
-
-	stype = cfg_obj_asstring(cfg_tuple_get(obj, "subtype"));
-	search = cfg_obj_asstring(cfg_tuple_get(obj, "search"));
-	len = strlen(search);
-
-	if (len == 0) {
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "zero-length geoip search field");
-		return (ISC_R_FAILURE);
-	}
-
-	if (strcasecmp(stype, "country") == 0 && len == 2) {
-		/* Two-letter country code */
-		subtype = dns_geoip_countrycode;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "country") == 0 && len == 3) {
-		/* Three-letter country code */
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "three-letter country codes are unavailable "
-			    "in GeoIP2 databases");
-		return (ISC_R_FAILURE);
-	} else if (strcasecmp(stype, "country") == 0) {
-		/* Country name */
-		subtype = dns_geoip_countryname;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "continent") == 0 && len == 2) {
-		/* Two-letter continent code */
-		subtype = dns_geoip_continentcode;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "continent") == 0) {
-		subtype = dns_geoip_continent;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if ((strcasecmp(stype, "region") == 0 ||
-		    strcasecmp(stype, "subdivision") == 0) && len == 2)
-	{
-		/* Two-letter region code */
-		subtype = dns_geoip_region;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "region") == 0 ||
-		   strcasecmp(stype, "subdivision") == 0)
-	{
-		/* Region name */
-		subtype = dns_geoip_regionname;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "city") == 0) {
-		/* City name */
-		subtype = dns_geoip_city_name;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "postal") == 0 ||
-		   strcasecmp(stype, "postalcode") == 0)
-	{
-		if (len < 7) {
-			subtype = dns_geoip_city_postalcode;
-			strlcpy(de.geoip_elem.as_string, search,
-				sizeof(de.geoip_elem.as_string));
-		} else {
-			cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-				    "geoip postal code (%s) too long",
-				    search);
-			return (ISC_R_FAILURE);
-		}
-	} else if (strcasecmp(stype, "metro") == 0 ||
-		   strcasecmp(stype, "metrocode") == 0)
-	{
-		subtype = dns_geoip_city_metrocode;
-		de.geoip_elem.as_int = atoi(search);
-	} else if (strcasecmp(stype, "tz") == 0 ||
-		   strcasecmp(stype, "timezone") == 0)
-	{
-		subtype = dns_geoip_city_timezonecode;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "isp") == 0) {
-		subtype = dns_geoip_isp_name;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "asnum") == 0) {
-		subtype = dns_geoip_as_asnum;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "org") == 0) {
-		subtype = dns_geoip_org_name;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else if (strcasecmp(stype, "domain") == 0) {
-		subtype = dns_geoip_domain_name;
-		strlcpy(de.geoip_elem.as_string, search,
-			sizeof(de.geoip_elem.as_string));
-	} else {
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "type '%s' is unavailable "
-			    "in GeoIP2 databases", stype);
-		return (ISC_R_FAILURE);
-	}
-
-	de.geoip_elem.subtype = get_subtype(obj, lctx, subtype, dbname);
-
-	if (! geoip_can_answer(&de, ctx)) {
-		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "no GeoIP2 database installed which can answer "
-			    "queries of type '%s'", stype);
-		return (ISC_R_FAILURE);
-	}
-
-	*dep = de;
-
-	return (ISC_R_SUCCESS);
-}
-#elif defined(HAVE_GEOIP)
+#ifdef HAVE_GEOIP
 static dns_geoip_subtype_t
 get_subtype(const cfg_obj_t *obj, isc_log_t *lctx,
 	    dns_geoip_subtype_t subtype, const char *dbname)
@@ -758,14 +398,13 @@ get_subtype(const cfg_obj_t *obj, isc_log_t *lctx,
 		return (subtype);
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
 	}
 }
 
-static bool
+static isc_boolean_t
 geoip_can_answer(dns_aclelement_t *elt, cfg_aclconfctx_t *ctx) {
 	if (ctx->geoip == NULL)
-		return (true);
+		return (ISC_TRUE);
 
 	switch (elt->geoip_elem.subtype) {
 	case dns_geoip_countrycode:
@@ -776,27 +415,27 @@ geoip_can_answer(dns_aclelement_t *elt, cfg_aclconfctx_t *ctx) {
 		    ctx->geoip->country_v4 != NULL ||
 		    ctx->geoip->country_v6 != NULL ||
 		    ctx->geoip->region != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_region:
 	case dns_geoip_regionname:
 		if (ctx->geoip->city_v4 != NULL ||
 		    ctx->geoip->city_v6 != NULL ||
 		    ctx->geoip->region != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_country_code:
 	case dns_geoip_country_code3:
 	case dns_geoip_country_name:
 		if (ctx->geoip->country_v4 != NULL ||
 		    ctx->geoip->country_v6 != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_region_countrycode:
 	case dns_geoip_region_code:
 	case dns_geoip_region_name:
 		if (ctx->geoip->region != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_city_countrycode:
 	case dns_geoip_city_countrycode3:
@@ -811,42 +450,30 @@ geoip_can_answer(dns_aclelement_t *elt, cfg_aclconfctx_t *ctx) {
 	case dns_geoip_city_timezonecode:
 		if (ctx->geoip->city_v4 != NULL ||
 		    ctx->geoip->city_v6 != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_isp_name:
 		if (ctx->geoip->isp != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_org_name:
 		if (ctx->geoip->org != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_as_asnum:
 		if (ctx->geoip->as != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_domain_name:
 		if (ctx->geoip->domain != NULL)
-			return (true);
+			return (ISC_TRUE);
 		/* FALLTHROUGH */
 	case dns_geoip_netspeed_id:
 		if (ctx->geoip->netspeed != NULL)
-			return (true);
-		break;
-	/*
-	 * The following enums are only valid with GeoIP2,
-	 * not legacy GeoIP.
-	 */
-	case dns_geoip_continentcode:
-	case dns_geoip_continent:
-	case dns_geoip_country_continentcode:
-	case dns_geoip_country_continent:
-	case dns_geoip_city_continent:
-		INSIST(0);
-		ISC_UNREACHABLE();
+			return (ISC_TRUE);
 	}
 
-	return (false);
+	return (ISC_FALSE);
 }
 
 static isc_result_t
@@ -855,7 +482,7 @@ parse_geoip_element(const cfg_obj_t *obj, isc_log_t *lctx,
 {
 	const cfg_obj_t *ge;
 	const char *dbname = NULL;
-	const char *stype = NULL, *search = NULL;
+	const char *stype, *search;
 	dns_geoip_subtype_t subtype;
 	dns_aclelement_t de;
 	size_t len;
@@ -865,24 +492,9 @@ parse_geoip_element(const cfg_obj_t *obj, isc_log_t *lctx,
 	de = *dep;
 
 	ge = cfg_tuple_get(obj, "db");
-	if (!cfg_obj_isvoid(ge)) {
-		int i;
-
+	if (!cfg_obj_isvoid(ge))
 		dbname = cfg_obj_asstring(ge);
 
-		for (i = 0; geoip_dbnames[i] != NULL; i++) {
-			if (strcasecmp(dbname, geoip_dbnames[i]) == 0) {
-				break;
-			}
-		}
-		if (geoip_dbnames[i] == NULL) {
-			cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-				    "database '%s' is not defined for GeoIP",
-				    dbname);
-			return (ISC_R_UNEXPECTED);
-		}
-	}
-
 	stype = cfg_obj_asstring(cfg_tuple_get(obj, "subtype"));
 	search = cfg_obj_asstring(cfg_tuple_get(obj, "search"));
 	len = strlen(search);
@@ -932,7 +544,7 @@ parse_geoip_element(const cfg_obj_t *obj, isc_log_t *lctx,
 				sizeof(de.geoip_elem.as_string));
 		} else {
 			cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-				    "geoip postal code (%s) too long",
+				    "geoiop postal code (%s) too long",
 				    search);
 			return (ISC_R_FAILURE);
 		}
@@ -959,7 +571,7 @@ parse_geoip_element(const cfg_obj_t *obj, isc_log_t *lctx,
 			sizeof(de.geoip_elem.as_string));
 	} else if (strcasecmp(stype, "continent") == 0) {
 		cfg_obj_log(obj, lctx, ISC_LOG_ERROR,
-			    "geoip continent code (%s) too long", search);
+			    "geoiop continent code (%s) too long", search);
 		return (ISC_R_FAILURE);
 	} else if (strcasecmp(stype, "isp") == 0) {
 		subtype = dns_geoip_isp_name;
@@ -980,10 +592,8 @@ parse_geoip_element(const cfg_obj_t *obj, isc_log_t *lctx,
 	} else if (strcasecmp(stype, "netspeed") == 0) {
 		subtype = dns_geoip_netspeed_id;
 		de.geoip_elem.as_int = atoi(search);
-	} else {
+	} else
 		INSIST(0);
-		ISC_UNREACHABLE();
-	}
 
 	de.geoip_elem.subtype = get_subtype(obj, lctx, subtype, dbname);
 
@@ -998,7 +608,7 @@ parse_geoip_element(const cfg_obj_t *obj, isc_log_t *lctx,
 
 	return (ISC_R_SUCCESS);
 }
-#endif /* HAVE_GEOIP */
+#endif
 
 isc_result_t
 cfg_acl_fromconfig(const cfg_obj_t *caml, const cfg_obj_t *cctx,
@@ -1014,7 +624,7 @@ isc_result_t
 cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 		   isc_log_t *lctx, cfg_aclconfctx_t *ctx,
 		   isc_mem_t *mctx, unsigned int nest_level,
-		   uint16_t family, dns_acl_t **target)
+		   isc_uint16_t family, dns_acl_t **target)
 {
 	isc_result_t result;
 	dns_acl_t *dacl = NULL, *inneracl = NULL;
@@ -1022,6 +632,7 @@ cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 	const cfg_listelt_t *elt;
 	dns_iptable_t *iptab;
 	int new_nest_level = 0;
+	isc_boolean_t setpos;
 
 	if (nest_level != 0)
 		new_nest_level = nest_level - 1;
@@ -1045,21 +656,19 @@ cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 		 * elements table.  (Note that if nest_level is nonzero,
 		 * *everything* goes in the elements table.)
 		 */
-		uint32_t nelem;
+		isc_uint32_t nelem;
 
 		if (nest_level == 0) {
 			result = count_acl_elements(caml, cctx, lctx, ctx,
 						    mctx, &nelem, NULL);
 			if (result != ISC_R_SUCCESS)
 				return (result);
-		} else {
-			nelem = cfg_list_length(caml, false);
-		}
+		} else
+			nelem = cfg_list_length(caml, ISC_FALSE);
 
 		result = dns_acl_create(mctx, nelem, &dacl);
-		if (result != ISC_R_SUCCESS) {
+		if (result != ISC_R_SUCCESS)
 			return (result);
-		}
 	}
 
 	de = dacl->elements;
@@ -1067,7 +676,7 @@ cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 	     elt != NULL;
 	     elt = cfg_list_next(elt)) {
 		const cfg_obj_t *ce = cfg_listelt_value(elt);
-		bool neg = false;
+		isc_boolean_t neg = ISC_FALSE;
 
 		INSIST(dacl->length <= dacl->alloc);
 
@@ -1076,8 +685,8 @@ cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 			const cfg_obj_t *negated =
 				cfg_tuple_get(ce, "negated");
 			if (! cfg_obj_isvoid(negated)) {
-				neg = true;
-				dacl->has_negatives = true;
+				neg = ISC_TRUE;
+				dacl->has_negatives = ISC_TRUE;
 				ce = negated;
 			}
 		}
@@ -1091,11 +700,10 @@ cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 
 		if (nest_level != 0) {
 			result = dns_acl_create(mctx,
-						cfg_list_length(ce, false),
+						cfg_list_length(ce, ISC_FALSE),
 						&de->nestedacl);
-			if (result != ISC_R_SUCCESS) {
+			if (result != ISC_R_SUCCESS)
 				goto cleanup;
-			}
 			iptab = de->nestedacl->iptable;
 		}
 
@@ -1103,7 +711,7 @@ cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 			/* Network prefix */
 			isc_netaddr_t	addr;
 			unsigned int	bitlen;
-			bool	setpos, setecs;
+			isc_boolean_t	setecs;
 
 			cfg_obj_asnetprefix(ce, &addr, &bitlen);
 			if (family != 0 && family != addr.family) {
@@ -1112,39 +720,37 @@ cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 				cfg_obj_log(ce, lctx, ISC_LOG_WARNING,
 					    "'%s': incorrect address family; "
 					    "ignoring", buf);
-				if (nest_level != 0) {
+				if (nest_level != 0)
 					dns_acl_detach(&de->nestedacl);
-				}
 				continue;
 			}
 			result = isc_netaddr_prefixok(&addr, bitlen);
 			if (result != ISC_R_SUCCESS) {
 				char buf[ISC_NETADDR_FORMATSIZE + 1];
 				isc_netaddr_format(&addr, buf, sizeof(buf));
-				cfg_obj_log(ce, lctx, ISC_LOG_WARNING,
+				cfg_obj_log(ce, lctx, ISC_LOG_ERROR,
 					    "'%s/%u': address/prefix length "
 					    "mismatch", buf, bitlen);
+				goto cleanup;
 			}
 
 			/*
 			 * If nesting ACLs (nest_level != 0), we negate
 			 * the nestedacl element, not the iptable entry.
 			 */
-			setpos = (nest_level != 0 || !neg);
+			setpos = ISC_TF(nest_level != 0 || !neg);
 			setecs = cfg_obj_istype(ce, &cfg_type_ecsprefix);
-			result = dns_iptable_addprefix2(iptab, &addr, bitlen,
-							setpos, setecs);
-			if (result != ISC_R_SUCCESS) {
+			result = dns_iptable_addprefix(iptab, &addr, bitlen,
+						       setpos, setecs);
+			if (result != ISC_R_SUCCESS)
 				goto cleanup;
-			}
 
 			if (nest_level > 0) {
 				INSIST(dacl->length < dacl->alloc);
 				de->type = dns_aclelementtype_nestedacl;
 				de->negative = neg;
-			} else {
+			} else
 				continue;
-			}
 		} else if (cfg_obj_islist(ce)) {
 			/*
 			 * If we're nesting ACLs, put the nested
@@ -1153,30 +759,29 @@ cfg_acl_fromconfig2(const cfg_obj_t *caml, const cfg_obj_t *cctx,
 			 * in two cases: 1) sortlist, 2) if the
 			 * nested ACL contains negated members.
 			 */
-			if (inneracl != NULL) {
+			if (inneracl != NULL)
 				dns_acl_detach(&inneracl);
-			}
 			result = cfg_acl_fromconfig(ce, cctx, lctx,
 						    ctx, mctx, new_nest_level,
 						    &inneracl);
-			if (result != ISC_R_SUCCESS) {
+			if (result != ISC_R_SUCCESS)
 				goto cleanup;
-			}
 nested_acl:
 			if (nest_level > 0 || inneracl->has_negatives) {
 				INSIST(dacl->length < dacl->alloc);
 				de->type = dns_aclelementtype_nestedacl;
 				de->negative = neg;
-				if (de->nestedacl != NULL) {
+				if (de->nestedacl != NULL)
 					dns_acl_detach(&de->nestedacl);
-				}
-				dns_acl_attach(inneracl, &de->nestedacl);
+				dns_acl_attach(inneracl,
+					       &de->nestedacl);
 				dns_acl_detach(&inneracl);
 				/* Fall through. */
 			} else {
 				INSIST(dacl->length + inneracl->length
 				       <= dacl->alloc);
-				dns_acl_merge(dacl, inneracl, !neg);
+				dns_acl_merge(dacl, inneracl,
+					      ISC_TF(!neg));
 				de += inneracl->length;  /* elements added */
 				dns_acl_detach(&inneracl);
 				INSIST(dacl->length <= dacl->alloc);
@@ -1190,39 +795,37 @@ nested_acl:
 			dns_name_init(&de->keyname, NULL);
 			result = convert_keyname(ce, lctx, mctx,
 						 &de->keyname);
-			if (result != ISC_R_SUCCESS) {
+			if (result != ISC_R_SUCCESS)
 				goto cleanup;
-			}
-#if defined(HAVE_GEOIP) || defined(HAVE_GEOIP2)
+#ifdef HAVE_GEOIP
 		} else if (cfg_obj_istuple(ce) &&
 			   cfg_obj_isvoid(cfg_tuple_get(ce, "negated")))
 		{
 			INSIST(dacl->length < dacl->alloc);
 			result = parse_geoip_element(ce, lctx, ctx, de);
-			if (result != ISC_R_SUCCESS) {
+			if (result != ISC_R_SUCCESS)
 				goto cleanup;
-			}
 			de->type = dns_aclelementtype_geoip;
 			de->negative = neg;
-#endif /* HAVE_GEOIP || HAVE_GEOIP2 */
+#endif /* HAVE_GEOIP */
 		} else if (cfg_obj_isstring(ce)) {
 			/* ACL name. */
 			const char *name = cfg_obj_asstring(ce);
 			if (strcasecmp(name, "any") == 0) {
 				/* Iptable entry with zero bit length. */
+				setpos = ISC_TF(nest_level != 0 || !neg);
 				result = dns_iptable_addprefix(iptab, NULL, 0,
-					      (nest_level != 0 || !neg));
-				if (result != ISC_R_SUCCESS) {
+							       setpos,
+							       ISC_FALSE);
+				if (result != ISC_R_SUCCESS)
 					goto cleanup;
-				}
 
 				if (nest_level != 0) {
 					INSIST(dacl->length < dacl->alloc);
 					de->type = dns_aclelementtype_nestedacl;
 					de->negative = neg;
-				} else {
+				} else
 					continue;
-				}
 			} else if (strcasecmp(name, "none") == 0) {
 				/* none == !any */
 				/*
@@ -1231,23 +834,22 @@ nested_acl:
 				 * de->negative to true so we can handle
 				 * "!none;".
 				 */
+				setpos = ISC_TF(nest_level != 0 || neg);
 				result = dns_iptable_addprefix(iptab, NULL, 0,
-					      (nest_level != 0 || neg));
-				if (result != ISC_R_SUCCESS) {
+							       setpos,
+							       ISC_FALSE);
+				if (result != ISC_R_SUCCESS)
 					goto cleanup;
-				}
 
-				if (!neg) {
+				if (!neg)
 					dacl->has_negatives = !neg;
-				}
 
 				if (nest_level != 0) {
 					INSIST(dacl->length < dacl->alloc);
 					de->type = dns_aclelementtype_nestedacl;
 					de->negative = !neg;
-				} else {
+				} else
 					continue;
-				}
 			} else if (strcasecmp(name, "localhost") == 0) {
 				INSIST(dacl->length < dacl->alloc);
 				de->type = dns_aclelementtype_localhost;
@@ -1266,9 +868,8 @@ nested_acl:
 				result = convert_named_acl(ce, cctx, lctx, ctx,
 							   mctx, new_nest_level,
 							   &inneracl);
-				if (result != ISC_R_SUCCESS) {
+				if (result != ISC_R_SUCCESS)
 					goto cleanup;
-				}
 
 				goto nested_acl;
 			}
@@ -1287,9 +888,7 @@ nested_acl:
 		 */
 		if (de->nestedacl != NULL &&
 		    de->type != dns_aclelementtype_nestedacl)
-		{
 			dns_acl_detach(&de->nestedacl);
-		}
 
 		dacl->node_count++;
 		de->node_num = dacl->node_count;
@@ -1303,9 +902,8 @@ nested_acl:
 	result = ISC_R_SUCCESS;
 
  cleanup:
-	if (inneracl != NULL) {
+	if (inneracl != NULL)
 		dns_acl_detach(&inneracl);
-	}
 	dns_acl_detach(&dacl);
 	return (result);
 }
