@@ -13,8 +13,6 @@
 
 #include <config.h>
 
-#include <inttypes.h>
-#include <stdbool.h>
 #include <stdlib.h>
 
 #include <isc/buffer.h>
@@ -90,7 +88,7 @@ free_map(cfg_parser_t *pctx, cfg_obj_t *obj);
 static isc_result_t
 parse_symtab_elt(cfg_parser_t *pctx, const char *name,
 		 cfg_type_t *elttype, isc_symtab_t *symtab,
-		 bool callback);
+		 isc_boolean_t callback);
 
 static void
 free_noop(cfg_parser_t *pctx, cfg_obj_t *obj);
@@ -99,7 +97,7 @@ static isc_result_t
 cfg_getstringtoken(cfg_parser_t *pctx);
 
 static void
-parser_complain(cfg_parser_t *pctx, bool is_warning,
+parser_complain(cfg_parser_t *pctx, isc_boolean_t is_warning,
 		unsigned int flags, const char *format, va_list args);
 
 /*
@@ -293,7 +291,7 @@ cfg_print_tuple(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	unsigned int i;
 	const cfg_tuplefielddef_t *fields;
 	const cfg_tuplefielddef_t *f;
-	bool need_space = false;
+	isc_boolean_t need_space = ISC_FALSE;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(obj != NULL);
@@ -305,8 +303,8 @@ cfg_print_tuple(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 		if (need_space && fieldobj->type->rep != &cfg_rep_void)
 			cfg_print_cstr(pctx, " ");
 		cfg_print_obj(pctx, fieldobj);
-		need_space = (need_space ||
-			      fieldobj->type->print != cfg_print_void);
+		need_space = ISC_TF(need_space ||
+				    fieldobj->type->print != cfg_print_void);
 	}
 }
 
@@ -314,7 +312,7 @@ void
 cfg_doc_tuple(cfg_printer_t *pctx, const cfg_type_t *type) {
 	const cfg_tuplefielddef_t *fields;
 	const cfg_tuplefielddef_t *f;
-	bool need_space = false;
+	isc_boolean_t need_space = ISC_FALSE;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(type != NULL);
@@ -325,7 +323,7 @@ cfg_doc_tuple(cfg_printer_t *pctx, const cfg_type_t *type) {
 		if (need_space)
 			cfg_print_cstr(pctx, " ");
 		cfg_doc_obj(pctx, f->type);
-		need_space = (f->type->print != cfg_print_void);
+		need_space = ISC_TF(f->type->print != cfg_print_void);
 	}
 }
 
@@ -347,10 +345,10 @@ free_tuple(cfg_parser_t *pctx, cfg_obj_t *obj) {
 		    nfields * sizeof(cfg_obj_t *));
 }
 
-bool
+isc_boolean_t
 cfg_obj_istuple(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_tuple);
+	return (ISC_TF(obj->type->rep == &cfg_rep_tuple));
 }
 
 const cfg_obj_t *
@@ -368,7 +366,7 @@ cfg_tuple_get(const cfg_obj_t *tupleobj, const char* name) {
 			return (tupleobj->value.tuple[i]);
 	}
 	INSIST(0);
-	ISC_UNREACHABLE();
+	return (NULL);
 }
 
 isc_result_t
@@ -459,8 +457,8 @@ cfg_parser_create(isc_mem_t *mctx, isc_log_t *lctx, cfg_parser_t **ret) {
 
 	pctx->lctx = lctx;
 	pctx->lexer = NULL;
-	pctx->seen_eof = false;
-	pctx->ungotten = false;
+	pctx->seen_eof = ISC_FALSE;
+	pctx->ungotten = ISC_FALSE;
 	pctx->errors = 0;
 	pctx->warnings = 0;
 	pctx->open_files = NULL;
@@ -544,8 +542,8 @@ cfg_parser_reset(cfg_parser_t *pctx) {
 	if (pctx->lexer != NULL)
 		isc_lex_close(pctx->lexer);
 
-	pctx->seen_eof = false;
-	pctx->ungotten = false;
+	pctx->seen_eof = ISC_FALSE;
+	pctx->ungotten = ISC_FALSE;
 	pctx->errors = 0;
 	pctx->warnings = 0;
 	pctx->line = 0;
@@ -617,7 +615,7 @@ isc_result_t
 cfg_parse_buffer(cfg_parser_t *pctx, isc_buffer_t *buffer,
 	const cfg_type_t *type, cfg_obj_t **ret)
 {
-	return (cfg_parse_buffer4(pctx, buffer, NULL, 0, type, 0, ret));
+	return (cfg_parse_buffer3(pctx, buffer, NULL, 0, type, ret));
 }
 
 isc_result_t
@@ -625,22 +623,13 @@ cfg_parse_buffer2(cfg_parser_t *pctx, isc_buffer_t *buffer,
 		  const char *file, const cfg_type_t *type,
 		  cfg_obj_t **ret)
 {
-	return (cfg_parse_buffer4(pctx, buffer, file, 0, type, 0, ret));
+	return (cfg_parse_buffer3(pctx, buffer, file, 0, type, ret));
 }
 
 isc_result_t
 cfg_parse_buffer3(cfg_parser_t *pctx, isc_buffer_t *buffer,
 		  const char *file, unsigned int line,
 		  const cfg_type_t *type, cfg_obj_t **ret)
-{
-	return (cfg_parse_buffer4(pctx, buffer, file, line, type, 0, ret));
-}
-
-isc_result_t
-cfg_parse_buffer4(cfg_parser_t *pctx, isc_buffer_t *buffer,
-		  const char *file, unsigned int line,
-		  const cfg_type_t *type, unsigned int flags,
-		  cfg_obj_t **ret)
 {
 	isc_result_t result;
 
@@ -648,12 +637,10 @@ cfg_parse_buffer4(cfg_parser_t *pctx, isc_buffer_t *buffer,
 	REQUIRE(type != NULL);
 	REQUIRE(buffer != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
-	REQUIRE((flags & ~(CFG_PCTX_NODEPRECATED)) == 0);
 
 	CHECK(isc_lex_openbuffer(pctx->lexer, buffer));
 
 	pctx->buf_name = file;
-	pctx->flags = flags;
 
 	if (line != 0U)
 		CHECK(isc_lex_setsourceline(pctx->lexer, line));
@@ -731,10 +718,10 @@ cfg_doc_void(cfg_printer_t *pctx, const cfg_type_t *type) {
 	UNUSED(type);
 }
 
-bool
+isc_boolean_t
 cfg_obj_isvoid(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_void);
+	return (ISC_TF(obj->type->rep == &cfg_rep_void));
 }
 
 LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_void = {
@@ -751,7 +738,7 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 	char *endp;
 	isc_result_t result;
 	cfg_obj_t *obj = NULL;
-	uint64_t percent;
+	isc_uint64_t percent;
 
 	REQUIRE(pctx != NULL);
 	REQUIRE(ret != NULL && *ret == NULL);
@@ -765,7 +752,7 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 		return (ISC_R_UNEXPECTEDTOKEN);
 	}
 
-	percent = isc_string_touint64(TOKEN_STRING(pctx), &endp, 10);
+	percent = strtoull(TOKEN_STRING(pctx), &endp, 10);
 	if (*endp != '%' || *(endp+1) != 0) {
 		cfg_parser_error(pctx, CFG_LOG_NEAR,
 				 "expected percentage");
@@ -773,7 +760,7 @@ cfg_parse_percentage(cfg_parser_t *pctx, const cfg_type_t *type,
 	}
 
 	CHECK(cfg_create_obj(pctx, &cfg_type_percentage, &obj));
-	obj->value.uint32 = (uint32_t)percent;
+	obj->value.uint32 = (isc_uint32_t)percent;
 	*ret = obj;
 
  cleanup:
@@ -793,7 +780,7 @@ cfg_print_percentage(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	cfg_print_chars(pctx, buf, strlen(buf));
 }
 
-uint32_t
+isc_uint32_t
 cfg_obj_aspercentage(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_percentage);
 	return (obj->value.uint32);
@@ -804,10 +791,10 @@ LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_percentage = {
 	cfg_doc_terminal, &cfg_rep_percentage, NULL
 };
 
-bool
+isc_boolean_t
 cfg_obj_ispercentage(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_percentage);
+	return (ISC_TF(obj->type->rep == &cfg_rep_percentage));
 }
 
 /*
@@ -879,7 +866,7 @@ cfg_print_fixedpoint(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	cfg_print_chars(pctx, buf, strlen(buf));
 }
 
-uint32_t
+isc_uint32_t
 cfg_obj_asfixedpoint(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_fixedpoint);
 	return (obj->value.uint32);
@@ -890,10 +877,10 @@ LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_fixedpoint = {
 	cfg_doc_terminal, &cfg_rep_fixedpoint, NULL
 };
 
-bool
+isc_boolean_t
 cfg_obj_isfixedpoint(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_fixedpoint);
+	return (ISC_TF(obj->type->rep == &cfg_rep_fixedpoint));
 }
 
 /*
@@ -941,13 +928,13 @@ cfg_print_uint32(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	cfg_print_rawuint(pctx, obj->value.uint32);
 }
 
-bool
+isc_boolean_t
 cfg_obj_isuint32(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_uint32);
+	return (ISC_TF(obj->type->rep == &cfg_rep_uint32));
 }
 
-uint32_t
+isc_uint32_t
 cfg_obj_asuint32(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_uint32);
 	return (obj->value.uint32);
@@ -962,13 +949,13 @@ LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_uint32 = {
 /*
  * uint64
  */
-bool
+isc_boolean_t
 cfg_obj_isuint64(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_uint64);
+	return (ISC_TF(obj->type->rep == &cfg_rep_uint64));
 }
 
-uint64_t
+isc_uint64_t
 cfg_obj_asuint64(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_uint64);
 	return (obj->value.uint64);
@@ -978,7 +965,7 @@ void
 cfg_print_uint64(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	char buf[32];
 
-	snprintf(buf, sizeof(buf), "%" PRIu64,
+	snprintf(buf, sizeof(buf), "%" ISC_PRINT_QUADFORMAT "u",
 		 obj->value.uint64);
 	cfg_print_cstr(pctx, buf);
 }
@@ -1142,7 +1129,7 @@ doc_btext(cfg_printer_t *pctx, const cfg_type_t *type) {
 }
 
 
-bool
+isc_boolean_t
 cfg_is_enum(const char *s, const char *const *enums) {
 	const char * const *p;
 
@@ -1151,9 +1138,9 @@ cfg_is_enum(const char *s, const char *const *enums) {
 
 	for (p = enums; *p != NULL; p++) {
 		if (strcasecmp(*p, s) == 0)
-			return (true);
+			return (ISC_TRUE);
 	}
-	return (false);
+	return (ISC_FALSE);
 }
 
 static isc_result_t
@@ -1233,10 +1220,10 @@ free_string(cfg_parser_t *pctx, cfg_obj_t *obj) {
 		    obj->value.string.length + 1);
 }
 
-bool
+isc_boolean_t
 cfg_obj_isstring(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_string);
+	return (ISC_TF(obj->type->rep == &cfg_rep_string));
 }
 
 const char *
@@ -1286,13 +1273,13 @@ LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_bracketed_text = {
  * Booleans
  */
 
-bool
+isc_boolean_t
 cfg_obj_isboolean(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_boolean);
+	return (ISC_TF(obj->type->rep == &cfg_rep_boolean));
 }
 
-bool
+isc_boolean_t
 cfg_obj_asboolean(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL && obj->type->rep == &cfg_rep_boolean);
 	return (obj->value.boolean);
@@ -1302,11 +1289,11 @@ isc_result_t
 cfg_parse_boolean(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 {
 	isc_result_t result;
-	bool value;
+	isc_boolean_t value;
 	cfg_obj_t *obj = NULL;
 
 	REQUIRE(pctx != NULL);
-	REQUIRE(ret != NULL && *ret == NULL);
+	REQUIRE(ret != NULL && ret != NULL);
 
 	UNUSED(type);
 
@@ -1320,11 +1307,11 @@ cfg_parse_boolean(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 	if ((strcasecmp(TOKEN_STRING(pctx), "true") == 0) ||
 	    (strcasecmp(TOKEN_STRING(pctx), "yes") == 0) ||
 	    (strcmp(TOKEN_STRING(pctx), "1") == 0)) {
-		value = true;
+		value = ISC_TRUE;
 	} else if ((strcasecmp(TOKEN_STRING(pctx), "false") == 0) ||
 		   (strcasecmp(TOKEN_STRING(pctx), "no") == 0) ||
 		   (strcmp(TOKEN_STRING(pctx), "0") == 0)) {
-		value = false;
+		value = ISC_FALSE;
 	} else {
 		goto bad_boolean;
 	}
@@ -1581,10 +1568,10 @@ cfg_print_spacelist(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	}
 }
 
-bool
+isc_boolean_t
 cfg_obj_islist(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_list);
+	return (ISC_TF(obj->type->rep == &cfg_rep_list));
 }
 
 const cfg_listelt_t *
@@ -1606,7 +1593,7 @@ cfg_list_next(const cfg_listelt_t *elt) {
  * a list, return 0.
  */
 unsigned int
-cfg_list_length(const cfg_obj_t *obj, bool recurse) {
+cfg_list_length(const cfg_obj_t *obj, isc_boolean_t recurse) {
 	const cfg_listelt_t *elt;
 	unsigned int count = 0;
 
@@ -1710,14 +1697,12 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 		}
 	done:
 		if (clause == NULL || clause->name == NULL) {
-			cfg_parser_error(pctx, CFG_LOG_NOPREP,
-					 "unknown option");
+			cfg_parser_error(pctx, CFG_LOG_NOPREP, "unknown option");
 			/*
 			 * Try to recover by parsing this option as an unknown
 			 * option and discarding it.
 			 */
-			CHECK(cfg_parse_obj(pctx, &cfg_type_unsupported,
-					    &eltobj));
+			CHECK(cfg_parse_obj(pctx, &cfg_type_unsupported, &eltobj));
 			cfg_obj_destroy(pctx, &eltobj);
 			CHECK(parse_semicolon(pctx));
 			continue;
@@ -1726,24 +1711,16 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 		/* Clause is known. */
 
 		/* Issue warnings if appropriate */
-		if ((pctx->flags & CFG_PCTX_NODEPRECATED) == 0 &&
-		    (clause->flags & CFG_CLAUSEFLAG_DEPRECATED) != 0)
-		{
-			cfg_parser_warning(pctx, 0, "option '%s' is deprecated",
-					   clause->name);
-		}
-		if ((clause->flags & CFG_CLAUSEFLAG_OBSOLETE) != 0) {
+		if ((clause->flags & CFG_CLAUSEFLAG_OBSOLETE) != 0)
 			cfg_parser_warning(pctx, 0, "option '%s' is obsolete",
-					   clause->name);
-		}
-		if ((clause->flags & CFG_CLAUSEFLAG_NOTIMP) != 0) {
+				       clause->name);
+		if ((clause->flags & CFG_CLAUSEFLAG_NOTIMP) != 0)
 			cfg_parser_warning(pctx, 0, "option '%s' is "
-					   "not implemented", clause->name);
-		}
-		if ((clause->flags & CFG_CLAUSEFLAG_NYI) != 0) {
+				       "not implemented", clause->name);
+		if ((clause->flags & CFG_CLAUSEFLAG_NYI) != 0)
 			cfg_parser_warning(pctx, 0, "option '%s' is "
-					   "not implemented", clause->name);
-		}
+				       "not implemented", clause->name);
+
 		if ((clause->flags & CFG_CLAUSEFLAG_NOOP) != 0) {
 			cfg_parser_warning(pctx, 0, "option '%s' was not "
 					   "enabled at compile time "
@@ -1802,9 +1779,9 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 		} else {
 			/* Single-valued clause */
 			if (result == ISC_R_NOTFOUND) {
-				bool callback =
-					((clause->flags &
-					  CFG_CLAUSEFLAG_CALLBACK) != 0);
+				isc_boolean_t callback =
+					ISC_TF((clause->flags &
+						CFG_CLAUSEFLAG_CALLBACK) != 0);
 				CHECK(parse_symtab_elt(pctx, clause->name,
 						       clause->type,
 						       obj->value.map.symtab,
@@ -1838,7 +1815,7 @@ cfg_parse_mapbody(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret)
 static isc_result_t
 parse_symtab_elt(cfg_parser_t *pctx, const char *name,
 		 cfg_type_t *elttype, isc_symtab_t *symtab,
-		 bool callback)
+		 isc_boolean_t callback)
 {
 	isc_result_t result;
 	cfg_obj_t *obj = NULL;
@@ -1989,7 +1966,6 @@ cfg_print_mapbody(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 				; /* do nothing */
 			} else {
 				INSIST(0);
-				ISC_UNREACHABLE();
 			}
 		}
 	}
@@ -2014,7 +1990,7 @@ static struct flagtext {
 void
 cfg_print_clauseflags(cfg_printer_t *pctx, unsigned int flags) {
 	struct flagtext *p;
-	bool first = true;
+	isc_boolean_t first = ISC_TRUE;
 	for (p = flagtexts; p->flag != 0; p++) {
 		if ((flags & p->flag) != 0) {
 			if (first)
@@ -2022,7 +1998,7 @@ cfg_print_clauseflags(cfg_printer_t *pctx, unsigned int flags) {
 			else
 				cfg_print_cstr(pctx, ", ");
 			cfg_print_cstr(pctx, p->text);
-			first = false;
+			first = ISC_FALSE;
 		}
 	}
 }
@@ -2097,10 +2073,10 @@ cfg_doc_map(cfg_printer_t *pctx, const cfg_type_t *type) {
 	print_close(pctx);
 }
 
-bool
+isc_boolean_t
 cfg_obj_ismap(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_map);
+	return (ISC_TF(obj->type->rep == &cfg_rep_map));
 }
 
 isc_result_t
@@ -2305,7 +2281,6 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 			return (ISC_R_SUCCESS);
 		} else {
 			INSIST(0);
-			ISC_UNREACHABLE();
 		}
 	} else {
 		if ((flags & (CFG_ADDR_V4OK | CFG_ADDR_V4PREFIXOK)) != 0) {
@@ -2330,7 +2305,7 @@ token_addr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 		if ((flags & CFG_ADDR_V6OK) != 0 && strlen(s) <= 127U) {
 			char buf[128]; /* see lib/bind9/getaddresses.c */
 			char *d; /* zone delimiter */
-			uint32_t zone = 0; /* scope zone ID */
+			isc_uint32_t zone = 0; /* scope zone ID */
 
 			strlcpy(buf, s, sizeof(buf));
 			d = strchr(buf, '%');
@@ -2395,7 +2370,7 @@ cfg_parse_rawaddr(cfg_parser_t *pctx, unsigned int flags, isc_netaddr_t *na) {
 	return (result);
 }
 
-bool
+isc_boolean_t
 cfg_lookingat_netaddr(cfg_parser_t *pctx, unsigned int flags) {
 	isc_result_t result;
 	isc_netaddr_t na_dummy;
@@ -2403,7 +2378,7 @@ cfg_lookingat_netaddr(cfg_parser_t *pctx, unsigned int flags) {
 	REQUIRE(pctx != NULL);
 
 	result = token_addr(pctx, flags, &na_dummy);
-	return (result == ISC_R_SUCCESS);
+	return (ISC_TF(result == ISC_R_SUCCESS));
 }
 
 isc_result_t
@@ -2507,29 +2482,27 @@ static void
 cfg_doc_netaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 	const unsigned int *flagp = type->of;
 	int n = 0;
-	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK) {
+	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK)
 		cfg_print_cstr(pctx, "( ");
-	}
-	if ((*flagp & CFG_ADDR_V4OK) != 0) {
+	if (*flagp & CFG_ADDR_V4OK) {
 		cfg_print_cstr(pctx, "<ipv4_address>");
 		n++;
 	}
-	if ((*flagp & CFG_ADDR_V6OK) != 0) {
+	if (*flagp & CFG_ADDR_V6OK) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "<ipv6_address>");
 		n++;
 	}
-	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
+	if (*flagp & CFG_ADDR_WILDOK) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "*");
 		n++;
 		POST(n);
 	}
-	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK) {
+	if (*flagp != CFG_ADDR_V4OK && *flagp != CFG_ADDR_V6OK)
 		cfg_print_cstr(pctx, " )");
-	}
 }
 
 LIBISCCFG_EXTERNAL_DATA cfg_type_t cfg_type_netaddr = {
@@ -2584,7 +2557,7 @@ cfg_parse_netprefix(cfg_parser_t *pctx, const cfg_type_t *type,
 		break;
 	default:
 		INSIST(0);
-		ISC_UNREACHABLE();
+		break;
 	}
 	CHECK(cfg_peektoken(pctx, 0));
 	if (pctx->token.type == isc_tokentype_special &&
@@ -2624,10 +2597,10 @@ print_netprefix(cfg_printer_t *pctx, const cfg_obj_t *obj) {
 	cfg_print_rawuint(pctx, p->prefixlen);
 }
 
-bool
+isc_boolean_t
 cfg_obj_isnetprefix(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_netprefix);
+	return (ISC_TF(obj->type->rep == &cfg_rep_netprefix));
 }
 
 void
@@ -2757,17 +2730,17 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 	REQUIRE(type != NULL);
 
 	cfg_print_cstr(pctx, "( ");
-	if ((*flagp & CFG_ADDR_V4OK) != 0) {
+	if (*flagp & CFG_ADDR_V4OK) {
 		cfg_print_cstr(pctx, "<ipv4_address>");
 		n++;
 	}
-	if ((*flagp & CFG_ADDR_V6OK) != 0) {
+	if (*flagp & CFG_ADDR_V6OK) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "<ipv6_address>");
 		n++;
 	}
-	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
+	if (*flagp & CFG_ADDR_WILDOK) {
 		if (n != 0)
 			cfg_print_cstr(pctx, " | ");
 		cfg_print_cstr(pctx, "*");
@@ -2775,7 +2748,7 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 		POST(n);
 	}
 	cfg_print_cstr(pctx, " ) ");
-	if ((*flagp & CFG_ADDR_WILDOK) != 0) {
+	if (*flagp & CFG_ADDR_WILDOK) {
 		cfg_print_cstr(pctx, "[ port ( <integer> | * ) ]");
 	} else {
 		cfg_print_cstr(pctx, "[ port <integer> ]");
@@ -2785,10 +2758,10 @@ cfg_doc_sockaddr(cfg_printer_t *pctx, const cfg_type_t *type) {
 	}
 }
 
-bool
+isc_boolean_t
 cfg_obj_issockaddr(const cfg_obj_t *obj) {
 	REQUIRE(obj != NULL);
-	return (obj->type->rep == &cfg_rep_sockaddr);
+	return (ISC_TF(obj->type->rep == &cfg_rep_sockaddr));
 }
 
 const isc_sockaddr_t *
@@ -2817,7 +2790,7 @@ cfg_gettoken(cfg_parser_t *pctx, int options) {
  redo:
 	pctx->token.type = isc_tokentype_unknown;
 	result = isc_lex_gettoken(pctx->lexer, options, &pctx->token);
-	pctx->ungotten = false;
+	pctx->ungotten = ISC_FALSE;
 	pctx->line = isc_lex_getsourceline(pctx->lexer);
 
 	switch (result) {
@@ -2841,7 +2814,7 @@ cfg_gettoken(cfg_parser_t *pctx, int options) {
 						value.list, elt, link);
 				goto redo;
 			}
-			pctx->seen_eof = true;
+			pctx->seen_eof = ISC_TRUE;
 		}
 		break;
 
@@ -2870,7 +2843,7 @@ cfg_ungettoken(cfg_parser_t *pctx) {
 	if (pctx->seen_eof)
 		return;
 	isc_lex_ungettoken(pctx->lexer, &pctx->token);
-	pctx->ungotten = true;
+	pctx->ungotten = ISC_TRUE;
 }
 
 isc_result_t
@@ -2913,7 +2886,7 @@ cfg_parser_error(cfg_parser_t *pctx, unsigned int flags, const char *fmt, ...) {
 	REQUIRE(fmt != NULL);
 
 	va_start(args, fmt);
-	parser_complain(pctx, false, flags, fmt, args);
+	parser_complain(pctx, ISC_FALSE, flags, fmt, args);
 	va_end(args);
 	pctx->errors++;
 }
@@ -2926,24 +2899,24 @@ cfg_parser_warning(cfg_parser_t *pctx, unsigned int flags, const char *fmt, ...)
 	REQUIRE(fmt != NULL);
 
 	va_start(args, fmt);
-	parser_complain(pctx, true, flags, fmt, args);
+	parser_complain(pctx, ISC_TRUE, flags, fmt, args);
 	va_end(args);
 	pctx->warnings++;
 }
 
 #define MAX_LOG_TOKEN 30 /* How much of a token to quote in log messages. */
 
-static bool
+static isc_boolean_t
 have_current_file(cfg_parser_t *pctx) {
 	cfg_listelt_t *elt;
 	if (pctx->open_files == NULL)
-		return (false);
+		return (ISC_FALSE);
 
 	elt = ISC_LIST_TAIL(pctx->open_files->value.list);
 	if (elt == NULL)
-	      return (false);
+	      return (ISC_FALSE);
 
-	return (true);
+	return (ISC_TRUE);
 }
 
 static char *
@@ -2965,7 +2938,7 @@ current_file(cfg_parser_t *pctx) {
 }
 
 static void
-parser_complain(cfg_parser_t *pctx, bool is_warning,
+parser_complain(cfg_parser_t *pctx, isc_boolean_t is_warning,
 		unsigned int flags, const char *format,
 		va_list args)
 {
@@ -3016,13 +2989,12 @@ parser_complain(cfg_parser_t *pctx, bool is_warning,
 		}
 
 		/* Choose a preposition. */
-		if ((flags & CFG_LOG_NEAR) != 0) {
+		if (flags & CFG_LOG_NEAR)
 			prep = " near ";
-		} else if ((flags & CFG_LOG_BEFORE) != 0) {
+		else if (flags & CFG_LOG_BEFORE)
 			prep = " before ";
-		} else {
+		else
 			prep = " ";
-		}
 	} else {
 		tokenbuf[0] = '\0';
 	}
@@ -3119,7 +3091,7 @@ create_map(cfg_parser_t *pctx, const cfg_type_t *type, cfg_obj_t **ret) {
 	CHECK(cfg_create_obj(pctx, type, &obj));
 	CHECK(isc_symtab_create(pctx->mctx, 5, /* XXX */
 				map_symtabitem_destroy,
-				pctx, false, &symtab));
+				pctx, ISC_FALSE, &symtab));
 	obj->value.map.symtab = symtab;
 	obj->value.map.id = NULL;
 
@@ -3138,13 +3110,13 @@ free_map(cfg_parser_t *pctx, cfg_obj_t *obj) {
 	isc_symtab_destroy(&obj->value.map.symtab);
 }
 
-bool
+isc_boolean_t
 cfg_obj_istype(const cfg_obj_t *obj, const cfg_type_t *type) {
 
 	REQUIRE(obj != NULL);
 	REQUIRE(type != NULL);
 
-	return (obj->type == type);
+	return (ISC_TF(obj->type == type));
 }
 
 /*
