@@ -13,8 +13,6 @@
 
 #include <config.h>
 
-#include <stdbool.h>
-
 #include <isc/mem.h>
 #include <isc/stats.h>
 #include <isc/util.h>
@@ -34,8 +32,8 @@
 	} while (0)						\
 
 isc_result_t
-ns_server_create(isc_mem_t *mctx, isc_entropy_t *entropy,
-		 ns_matchview_t matchingview, ns_server_t **sctxp)
+ns_server_create(isc_mem_t *mctx, ns_matchview_t matchingview,
+		 ns_server_t **sctxp)
 {
 	ns_server_t *sctx;
 	isc_result_t result;
@@ -58,8 +56,7 @@ ns_server_create(isc_mem_t *mctx, isc_entropy_t *entropy,
 	CHECKFATAL(isc_quota_init(&sctx->tcpquota, 10));
 	CHECKFATAL(isc_quota_init(&sctx->recursionquota, 100));
 
-	CHECKFATAL(dns_tkeyctx_create(mctx, entropy, &sctx->tkeyctx));
-	CHECKFATAL(isc_rng_create(mctx, entropy, &sctx->rngctx));
+	CHECKFATAL(dns_tkeyctx_create(mctx, &sctx->tkeyctx));
 
 	CHECKFATAL(ns_stats_create(mctx, ns_statscounter_max, &sctx->nsstats));
 
@@ -106,7 +103,6 @@ ns_server_create(isc_mem_t *mctx, isc_entropy_t *entropy,
 	sctx->gethostname = NULL;
 
 	sctx->matchingview = matchingview;
-	sctx->answercookie = true;
 
 	ISC_LIST_INIT(sctx->altsecrets);
 
@@ -162,8 +158,6 @@ ns_server_detach(ns_server_t **sctxp) {
 			dns_acl_detach(&sctx->blackholeacl);
 		if (sctx->keepresporder != NULL)
 			dns_acl_detach(&sctx->keepresporder);
-		if (sctx->rngctx != NULL)
-			isc_rng_detach(&sctx->rngctx);
 		if (sctx->tkeyctx != NULL)
 			dns_tkeyctx_destroy(&sctx->tkeyctx);
 
@@ -249,7 +243,7 @@ ns_server_gettimeouts(ns_server_t *sctx, unsigned int *initial,
 
 void
 ns_server_setoption(ns_server_t *sctx, unsigned int option,
-		    bool value)
+		    isc_boolean_t value)
 {
 	REQUIRE(SCTX_VALID(sctx));
 	if (value) {
@@ -259,9 +253,9 @@ ns_server_setoption(ns_server_t *sctx, unsigned int option,
 	}
 }
 
-bool
+isc_boolean_t
 ns_server_getoption(ns_server_t *sctx, unsigned int option) {
 	REQUIRE(SCTX_VALID(sctx));
 
-	return ((sctx->options & option) != 0);
+	return (ISC_TF((sctx->options & option) != 0));
 }
